# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/py_trees_ros_interfaces/srv/introspect_services.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg import service_details_pb2 as make87__messages__ros2_dot_jazzy_dot_py__trees__ros__interfaces_dot_msg_dot_service__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/jazzy/py_trees_ros_interfaces/srv/introspect_services.proto\x12\x36make87_messages_ros2.jazzy.py_trees_ros_interfaces.srv\x1aLmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/service_details.proto\"\x1b\n\x19IntrospectServicesRequest\"}\n\x1aIntrospectServicesResponse\x12_\n\x0fservice_details\x18\x01 \x03(\x0b\x32\x46.make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.ServiceDetailsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.py_trees_ros_interfaces.srv.introspect_services_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INTROSPECTSERVICESREQUEST']._serialized_start=218
  _globals['_INTROSPECTSERVICESREQUEST']._serialized_end=245
  _globals['_INTROSPECTSERVICESRESPONSE']._serialized_start=247
  _globals['_INTROSPECTSERVICESRESPONSE']._serialized_end=372
# @@protoc_insertion_point(module_scope)
