# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/flexbe_msgs/msg/behavior_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.flexbe_msgs.msg import container_pb2 as make87__messages__ros2_dot_jazzy_dot_flexbe__msgs_dot_msg_dot_container__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/flexbe_msgs/msg/behavior_request.proto\x12*make87_messages_ros2.jazzy.flexbe_msgs.msg\x1a:make87_messages_ros2/jazzy/flexbe_msgs/msg/container.proto\"\xb0\x01\n\x0f\x42\x65haviorRequest\x12\x15\n\rbehavior_name\x18\x01 \x01(\t\x12\x16\n\x0e\x61utonomy_level\x18\x02 \x01(\r\x12\x10\n\x08\x61rg_keys\x18\x03 \x03(\t\x12\x12\n\narg_values\x18\x04 \x03(\t\x12H\n\tstructure\x18\x05 \x03(\x0b\x32\x35.make87_messages_ros2.jazzy.flexbe_msgs.msg.Containerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.flexbe_msgs.msg.behavior_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BEHAVIORREQUEST']._serialized_start=174
  _globals['_BEHAVIORREQUEST']._serialized_end=350
# @@protoc_insertion_point(module_scope)
