# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosbag2_test_msgdefs/msg/complex_msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rosbag2_test_msgdefs.msg import basic_msg_pb2 as make87__messages__ros2_dot_rolling_dot_rosbag2__test__msgdefs_dot_msg_dot_basic__msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/rosbag2_test_msgdefs/msg/complex_msg.proto\x12\x35make87_messages_ros2.rolling.rosbag2_test_msgdefs.msg\x1a\x45make87_messages_ros2/rolling/rosbag2_test_msgdefs/msg/basic_msg.proto\"X\n\nComplexMsg\x12J\n\x01\x62\x18\x01 \x01(\x0b\x32?.make87_messages_ros2.rolling.rosbag2_test_msgdefs.msg.BasicMsgb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosbag2_test_msgdefs.msg.complex_msg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMPLEXMSG']._serialized_start=201
  _globals['_COMPLEXMSG']._serialized_end=289
# @@protoc_insertion_point(module_scope)
