# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/nav_relposned9.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/rolling/ublox_msgs/msg/nav_relposned9.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\"\xa9\x03\n\rNavRELPOSNED9\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x11\n\treserved1\x18\x02 \x01(\r\x12\x16\n\x0eref_station_id\x18\x03 \x01(\r\x12\r\n\x05i_tow\x18\x04 \x01(\r\x12\x11\n\trel_pos_n\x18\x05 \x01(\x05\x12\x11\n\trel_pos_e\x18\x06 \x01(\x05\x12\x11\n\trel_pos_d\x18\x07 \x01(\x05\x12\x16\n\x0erel_pos_length\x18\x08 \x01(\x05\x12\x17\n\x0frel_pos_heading\x18\t \x01(\x05\x12\x11\n\treserved2\x18\n \x03(\r\x12\x13\n\x0brel_pos_hpn\x18\x0b \x01(\x05\x12\x13\n\x0brel_pos_hpe\x18\x0c \x01(\x05\x12\x13\n\x0brel_pos_hpd\x18\r \x01(\x05\x12\x19\n\x11rel_pos_hp_length\x18\x0e \x01(\x05\x12\r\n\x05\x61\x63\x63_n\x18\x0f \x01(\r\x12\r\n\x05\x61\x63\x63_e\x18\x10 \x01(\r\x12\r\n\x05\x61\x63\x63_d\x18\x11 \x01(\r\x12\x12\n\nacc_length\x18\x12 \x01(\r\x12\x13\n\x0b\x61\x63\x63_heading\x18\x13 \x01(\r\x12\x11\n\treserved3\x18\x14 \x03(\r\x12\r\n\x05\x66lags\x18\x15 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.nav_relposned9_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NAVRELPOSNED9']._serialized_start=114
  _globals['_NAVRELPOSNED9']._serialized_end=539
# @@protoc_insertion_point(module_scope)
