# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/py_trees_ros_interfaces/srv/reconfigure_snapshot_stream.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg import snapshot_stream_parameters_pb2 as make87__messages__ros2_dot_jazzy_dot_py__trees__ros__interfaces_dot_msg_dot_snapshot__stream__parameters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXmake87_messages_ros2/jazzy/py_trees_ros_interfaces/srv/reconfigure_snapshot_stream.proto\x12\x36make87_messages_ros2.jazzy.py_trees_ros_interfaces.srv\x1aWmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/snapshot_stream_parameters.proto\"\x9c\x01\n ReconfigureSnapshotStreamRequest\x12\x12\n\ntopic_name\x18\x01 \x01(\t\x12\x64\n\nparameters\x18\x02 \x01(\x0b\x32P.make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.SnapshotStreamParameters\"3\n!ReconfigureSnapshotStreamResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.py_trees_ros_interfaces.srv.reconfigure_snapshot_stream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RECONFIGURESNAPSHOTSTREAMREQUEST']._serialized_start=238
  _globals['_RECONFIGURESNAPSHOTSTREAMREQUEST']._serialized_end=394
  _globals['_RECONFIGURESNAPSHOTSTREAMRESPONSE']._serialized_start=396
  _globals['_RECONFIGURESNAPSHOTSTREAMRESPONSE']._serialized_end=447
# @@protoc_insertion_point(module_scope)
