# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ibeo_msgs/msg/untracked_properties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import contour_point_sigma_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_contour__point__sigma__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import point2_di_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_point2__di__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import point2_dui_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_point2__dui__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/ibeo_msgs/msg/untracked_properties.proto\x12)make87_messages_ros2.humble.ibeo_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x43make87_messages_ros2/humble/ibeo_msgs/msg/contour_point_sigma.proto\x1a\x39make87_messages_ros2/humble/ibeo_msgs/msg/point2_di.proto\x1a:make87_messages_ros2/humble/ibeo_msgs/msg/point2_dui.proto\"\xda\x05\n\x13UntrackedProperties\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12$\n\x1crelative_time_of_measurement\x18\x02 \x01(\r\x12S\n\x16position_closest_point\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.humble.ibeo_msgs.msg.Point2Di\x12L\n\x0fobject_box_size\x18\x04 \x01(\x0b\x32\x33.make87_messages_ros2.humble.ibeo_msgs.msg.Point2Di\x12S\n\x15object_box_size_sigma\x18\x05 \x01(\x0b\x32\x34.make87_messages_ros2.humble.ibeo_msgs.msg.Point2Dui\x12\x1e\n\x16object_box_orientation\x18\x06 \x01(\x05\x12$\n\x1cobject_box_orientation_sigma\x18\x07 \x01(\r\x12V\n\x19tracking_point_coordinate\x18\x08 \x01(\x0b\x32\x33.make87_messages_ros2.humble.ibeo_msgs.msg.Point2Di\x12]\n\x1ftracking_point_coordinate_sigma\x18\t \x01(\x0b\x32\x34.make87_messages_ros2.humble.ibeo_msgs.msg.Point2Dui\x12 \n\x18number_of_contour_points\x18\n \x01(\r\x12X\n\x12\x63ontour_point_list\x18\x0b \x03(\x0b\x32<.make87_messages_ros2.humble.ibeo_msgs.msg.ContourPointSigmab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ibeo_msgs.msg.untracked_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UNTRACKEDPROPERTIES']._serialized_start=339
  _globals['_UNTRACKEDPROPERTIES']._serialized_end=1069
# @@protoc_insertion_point(module_scope)
