# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/srv/endpoint_add.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/mavros_msgs/srv/endpoint_add.proto\x12,make87_messages_ros2.rolling.mavros_msgs.srv\"/\n\x12\x45ndpointAddRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\r\"E\n\x13\x45ndpointAddResponse\x12\x12\n\nsuccessful\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.srv.endpoint_add_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ENDPOINTADDREQUEST']._serialized_start=113
  _globals['_ENDPOINTADDREQUEST']._serialized_end=160
  _globals['_ENDPOINTADDRESPONSE']._serialized_start=162
  _globals['_ENDPOINTADDRESPONSE']._serialized_end=231
# @@protoc_insertion_point(module_scope)
