# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/raw_micro_scan_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import application_data_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_application__data__pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import data_header_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_data__header__pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import derived_values_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_derived__values__pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import general_system_state_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_general__system__state__pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import intrusion_data_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_intrusion__data__pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import measurement_data_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_measurement__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/raw_micro_scan_data.proto\x12>make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg\x1aUmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/application_data.proto\x1aPmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/data_header.proto\x1aSmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/derived_values.proto\x1aYmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/general_system_state.proto\x1aSmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/intrusion_data.proto\x1aUmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/measurement_data.proto\"\x84\x05\n\x10RawMicroScanData\x12Z\n\x06header\x18\x01 \x01(\x0b\x32J.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.DataHeader\x12\x65\n\x0e\x64\x65rived_values\x18\x02 \x01(\x0b\x32M.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.DerivedValues\x12p\n\x14general_system_state\x18\x03 \x01(\x0b\x32R.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.GeneralSystemState\x12i\n\x10measurement_data\x18\x04 \x01(\x0b\x32O.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.MeasurementData\x12\x65\n\x0eintrusion_data\x18\x05 \x01(\x0b\x32M.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.IntrusionData\x12i\n\x10\x61pplication_data\x18\x06 \x01(\x0b\x32O.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.ApplicationDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.raw_micro_scan_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RAWMICROSCANDATA']._serialized_start=674
  _globals['_RAWMICROSCANDATA']._serialized_end=1318
# @@protoc_insertion_point(module_scope)
