# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_receiver_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_receiver_status.proto\x12\x31make87_messages_ros2.rolling.novatel_gps_msgs.msg\"\xc3\x05\n\x15NovatelReceiverStatus\x12\x1c\n\x14original_status_code\x18\x01 \x01(\r\x12\x12\n\nerror_flag\x18\x02 \x01(\x08\x12\x18\n\x10temperature_flag\x18\x03 \x01(\x08\x12\x1b\n\x13voltage_supply_flag\x18\x04 \x01(\x08\x12\x17\n\x0f\x61ntenna_powered\x18\x05 \x01(\x08\x12\x17\n\x0f\x61ntenna_is_open\x18\x06 \x01(\x08\x12\x1a\n\x12\x61ntenna_is_shorted\x18\x07 \x01(\x08\x12\x19\n\x11\x63pu_overload_flag\x18\x08 \x01(\x08\x12\x1b\n\x13\x63om1_buffer_overrun\x18\t \x01(\x08\x12\x1b\n\x13\x63om2_buffer_overrun\x18\n \x01(\x08\x12\x1b\n\x13\x63om3_buffer_overrun\x18\x0b \x01(\x08\x12\x1a\n\x12usb_buffer_overrun\x18\x0c \x01(\x08\x12\x14\n\x0crf1_agc_flag\x18\r \x01(\x08\x12\x14\n\x0crf2_agc_flag\x18\x0e \x01(\x08\x12\x14\n\x0c\x61lmanac_flag\x18\x0f \x01(\x08\x12\x1e\n\x16position_solution_flag\x18\x10 \x01(\x08\x12\x1b\n\x13position_fixed_flag\x18\x11 \x01(\x08\x12%\n\x1d\x63lock_steering_status_enabled\x18\x12 \x01(\x08\x12\x18\n\x10\x63lock_model_flag\x18\x13 \x01(\x08\x12%\n\x1doemv_external_oscillator_flag\x18\x14 \x01(\x08\x12\x1e\n\x16software_resource_flag\x18\x15 \x01(\x08\x12\x1e\n\x16\x61ux1_status_event_flag\x18\x16 \x01(\x08\x12\x1e\n\x16\x61ux2_status_event_flag\x18\x17 \x01(\x08\x12\x1e\n\x16\x61ux3_status_event_flag\x18\x18 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.novatel_gps_msgs.msg.novatel_receiver_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NOVATELRECEIVERSTATUS']._serialized_start=135
  _globals['_NOVATELRECEIVERSTATUS']._serialized_end=842
# @@protoc_insertion_point(module_scope)
