# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/motion_sequence_response.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_robot__state__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_trajectory_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_robot__trajectory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/moveit_msgs/msg/motion_sequence_response.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/move_it_error_codes.proto\x1a<make87_messages_ros2/jazzy/moveit_msgs/msg/robot_state.proto\x1a\x41make87_messages_ros2/jazzy/moveit_msgs/msg/robot_trajectory.proto\"\xac\x02\n\x16MotionSequenceResponse\x12P\n\nerror_code\x18\x01 \x01(\x0b\x32<.make87_messages_ros2.jazzy.moveit_msgs.msg.MoveItErrorCodes\x12N\n\x0esequence_start\x18\x02 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.moveit_msgs.msg.RobotState\x12Y\n\x14planned_trajectories\x18\x03 \x03(\x0b\x32;.make87_messages_ros2.jazzy.moveit_msgs.msg.RobotTrajectory\x12\x15\n\rplanning_time\x18\x04 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.motion_sequence_response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MOTIONSEQUENCERESPONSE']._serialized_start=321
  _globals['_MOTIONSEQUENCERESPONSE']._serialized_end=621
# @@protoc_insertion_point(module_scope)
