# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/marti_nav_msgs/srv/save_route.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.marti_nav_msgs.msg import route_pb2 as make87__messages__ros2_dot_jazzy_dot_marti__nav__msgs_dot_msg_dot_route__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/marti_nav_msgs/srv/save_route.proto\x12-make87_messages_ros2.jazzy.marti_nav_msgs.srv\x1a\x39make87_messages_ros2/jazzy/marti_nav_msgs/msg/route.proto\"\x86\x01\n\x10SaveRouteRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04guid\x18\x02 \x01(\t\x12\x43\n\x05route\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.marti_nav_msgs.msg.Route\x12\x11\n\tthumbnail\x18\x04 \x01(\t\"5\n\x11SaveRouteResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.marti_nav_msgs.srv.save_route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SAVEROUTEREQUEST']._serialized_start=173
  _globals['_SAVEROUTEREQUEST']._serialized_end=307
  _globals['_SAVEROUTERESPONSE']._serialized_start=309
  _globals['_SAVEROUTERESPONSE']._serialized_end=362
# @@protoc_insertion_point(module_scope)
