# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/srv/grasp_planning.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import collision_object_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_collision__object__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import grasp_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_grasp__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/moveit_msgs/srv/grasp_planning.proto\x12+make87_messages_ros2.humble.moveit_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x42make87_messages_ros2/humble/moveit_msgs/msg/collision_object.proto\x1a\x37make87_messages_ros2/humble/moveit_msgs/msg/grasp.proto\x1a\x45make87_messages_ros2/humble/moveit_msgs/msg/move_it_error_codes.proto\"\xe7\x02\n\x14GraspPlanningRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12L\n\x06target\x18\x03 \x01(\x0b\x32<.make87_messages_ros2.humble.moveit_msgs.msg.CollisionObject\x12\x18\n\x10support_surfaces\x18\x04 \x03(\t\x12L\n\x10\x63\x61ndidate_grasps\x18\x05 \x03(\x0b\x32\x32.make87_messages_ros2.humble.moveit_msgs.msg.Grasp\x12W\n\x11movable_obstacles\x18\x06 \x03(\x0b\x32<.make87_messages_ros2.humble.moveit_msgs.msg.CollisionObject\"\xdc\x01\n\x15GraspPlanningResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x42\n\x06grasps\x18\x02 \x03(\x0b\x32\x32.make87_messages_ros2.humble.moveit_msgs.msg.Grasp\x12Q\n\nerror_code\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.humble.moveit_msgs.msg.MoveItErrorCodesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.srv.grasp_planning_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GRASPPLANNINGREQUEST']._serialized_start=345
  _globals['_GRASPPLANNINGREQUEST']._serialized_end=704
  _globals['_GRASPPLANNINGRESPONSE']._serialized_start=707
  _globals['_GRASPPLANNINGRESPONSE']._serialized_end=927
# @@protoc_insertion_point(module_scope)
