# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/turtlesim_msgs/srv/kill.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/rolling/turtlesim_msgs/srv/kill.proto\x12/make87_messages_ros2.rolling.turtlesim_msgs.srv\"\x1b\n\x0bKillRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x0e\n\x0cKillResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.turtlesim_msgs.srv.kill_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_KILLREQUEST']._serialized_start=111
  _globals['_KILLREQUEST']._serialized_end=138
  _globals['_KILLRESPONSE']._serialized_start=140
  _globals['_KILLRESPONSE']._serialized_end=154
# @@protoc_insertion_point(module_scope)
