# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/shape_msgs/msg/solid_primitive.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import polygon_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_polygon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/shape_msgs/msg/solid_primitive.proto\x12+make87_messages_ros2.rolling.shape_msgs.msg\x1a<make87_messages_ros2/rolling/geometry_msgs/msg/polygon.proto\"|\n\x0eSolidPrimitive\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x12\n\ndimensions\x18\x02 \x03(\x01\x12H\n\x07polygon\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Polygonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.shape_msgs.msg.solid_primitive_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SOLIDPRIMITIVE']._serialized_start=176
  _globals['_SOLIDPRIMITIVE']._serialized_end=300
# @@protoc_insertion_point(module_scope)
