# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/controller_manager_msgs/srv/unload_controller.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/rolling/controller_manager_msgs/srv/unload_controller.proto\x12\x38make87_messages_ros2.rolling.controller_manager_msgs.srv\"\'\n\x17UnloadControllerRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"&\n\x18UnloadControllerResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.controller_manager_msgs.srv.unload_controller_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UNLOADCONTROLLERREQUEST']._serialized_start=142
  _globals['_UNLOADCONTROLLERREQUEST']._serialized_end=181
  _globals['_UNLOADCONTROLLERRESPONSE']._serialized_start=183
  _globals['_UNLOADCONTROLLERRESPONSE']._serialized_end=221
# @@protoc_insertion_point(module_scope)
