# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/derived_object_msgs/msg/object_with_covariance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.derived_object_msgs.msg import solid_primitive_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_derived__object__msgs_dot_msg_dot_solid__primitive__with__covariance__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import accel_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_accel__with__covariance__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import polygon_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_polygon__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_twist__with__covariance__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/derived_object_msgs/msg/object_with_covariance.proto\x12\x33make87_messages_ros2.humble.derived_object_msgs.msg\x1a!make87_messages/core/header.proto\x1aYmake87_messages_ros2/humble/derived_object_msgs/msg/solid_primitive_with_covariance.proto\x1aImake87_messages_ros2/humble/geometry_msgs/msg/accel_with_covariance.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/polygon.proto\x1aHmake87_messages_ros2/humble/geometry_msgs/msg/pose_with_covariance.proto\x1aImake87_messages_ros2/humble/geometry_msgs/msg/twist_with_covariance.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xc3\x05\n\x14ObjectWithCovariance\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\n\n\x02id\x18\x03 \x01(\r\x12\x17\n\x0f\x64\x65tection_level\x18\x04 \x01(\r\x12\x19\n\x11object_classified\x18\x05 \x01(\x08\x12O\n\x04pose\x18\x06 \x01(\x0b\x32\x41.make87_messages_ros2.humble.geometry_msgs.msg.PoseWithCovariance\x12Q\n\x05twist\x18\x07 \x01(\x0b\x32\x42.make87_messages_ros2.humble.geometry_msgs.msg.TwistWithCovariance\x12Q\n\x05\x61\x63\x63\x65l\x18\x08 \x01(\x0b\x32\x42.make87_messages_ros2.humble.geometry_msgs.msg.AccelWithCovariance\x12G\n\x07polygon\x18\t \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Polygon\x12`\n\x05shape\x18\n \x01(\x0b\x32Q.make87_messages_ros2.humble.derived_object_msgs.msg.SolidPrimitiveWithCovariance\x12\x16\n\x0e\x63lassification\x18\x0b \x01(\r\x12 \n\x18\x63lassification_certainty\x18\x0c \x01(\r\x12\x1a\n\x12\x63lassification_age\x18\r \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.derived_object_msgs.msg.object_with_covariance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECTWITHCOVARIANCE']._serialized_start=604
  _globals['_OBJECTWITHCOVARIANCE']._serialized_end=1311
# @@protoc_insertion_point(module_scope)
