# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_scan_xd/msg/nav_reflector_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/sick_scan_xd/msg/nav_reflector_data.proto\x12+make87_messages_ros2.jazzy.sick_scan_xd.msg\"\x93\x03\n\x10NAVReflectorData\x12\x1c\n\x14\x63\x61rtesian_data_valid\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x05\x12\t\n\x01y\x18\x03 \x01(\x05\x12\x18\n\x10polar_data_valid\x18\x04 \x01(\r\x12\x0c\n\x04\x64ist\x18\x05 \x01(\r\x12\x0b\n\x03phi\x18\x06 \x01(\r\x12 \n\x18opt_reflector_data_valid\x18\x07 \x01(\r\x12\x10\n\x08local_id\x18\x08 \x01(\r\x12\x11\n\tglobal_id\x18\t \x01(\r\x12\x0c\n\x04type\x18\n \x01(\r\x12\x10\n\x08sub_type\x18\x0b \x01(\r\x12\x0f\n\x07quality\x18\x0c \x01(\r\x12\x11\n\ttimestamp\x18\r \x01(\r\x12\x0c\n\x04size\x18\x0e \x01(\r\x12\x11\n\thit_count\x18\x0f \x01(\r\x12\x11\n\tmean_echo\x18\x10 \x01(\r\x12\x13\n\x0bstart_index\x18\x11 \x01(\r\x12\x11\n\tend_index\x18\x12 \x01(\r\x12\x11\n\tpos_valid\x18\x13 \x01(\x05\x12\r\n\x05pos_x\x18\x14 \x01(\x02\x12\r\n\x05pos_y\x18\x15 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_scan_xd.msg.nav_reflector_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NAVREFLECTORDATA']._serialized_start=118
  _globals['_NAVREFLECTORDATA']._serialized_end=521
# @@protoc_insertion_point(module_scope)
