# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/set_model_configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/jazzy/gazebo_msgs/srv/set_model_configuration.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\"y\n\x1cSetModelConfigurationRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x17\n\x0furdf_param_name\x18\x02 \x01(\t\x12\x13\n\x0bjoint_names\x18\x03 \x03(\t\x12\x17\n\x0fjoint_positions\x18\x04 \x03(\x01\"H\n\x1dSetModelConfigurationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0estatus_message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.set_model_configuration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETMODELCONFIGURATIONREQUEST']._serialized_start=120
  _globals['_SETMODELCONFIGURATIONREQUEST']._serialized_end=241
  _globals['_SETMODELCONFIGURATIONRESPONSE']._serialized_start=243
  _globals['_SETMODELCONFIGURATIONRESPONSE']._serialized_end=315
# @@protoc_insertion_point(module_scope)
