# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/srv/get_motion_sequence.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import motion_sequence_request_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_motion__sequence__request__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import motion_sequence_response_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_motion__sequence__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/moveit_msgs/srv/get_motion_sequence.proto\x12,make87_messages_ros2.rolling.moveit_msgs.srv\x1aJmake87_messages_ros2/rolling/moveit_msgs/msg/motion_sequence_request.proto\x1aKmake87_messages_ros2/rolling/moveit_msgs/msg/motion_sequence_response.proto\"p\n\x18GetMotionSequenceRequest\x12T\n\x07request\x18\x01 \x01(\x0b\x32\x43.make87_messages_ros2.rolling.moveit_msgs.msg.MotionSequenceRequest\"s\n\x19GetMotionSequenceResponse\x12V\n\x08response\x18\x01 \x01(\x0b\x32\x44.make87_messages_ros2.rolling.moveit_msgs.msg.MotionSequenceResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.srv.get_motion_sequence_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETMOTIONSEQUENCEREQUEST']._serialized_start=273
  _globals['_GETMOTIONSEQUENCEREQUEST']._serialized_end=385
  _globals['_GETMOTIONSEQUENCERESPONSE']._serialized_start=387
  _globals['_GETMOTIONSEQUENCERESPONSE']._serialized_end=502
# @@protoc_insertion_point(module_scope)
