# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/gazebo_msgs/srv/set_link_properties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/gazebo_msgs/srv/set_link_properties.proto\x12+make87_messages_ros2.humble.gazebo_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\"\x8f\x02\n\x18SetLinkPropertiesRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x11\n\tlink_name\x18\x02 \x01(\t\x12@\n\x03\x63om\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12\x14\n\x0cgravity_mode\x18\x04 \x01(\x08\x12\x0c\n\x04mass\x18\x05 \x01(\x01\x12\x0b\n\x03ixx\x18\x06 \x01(\x01\x12\x0b\n\x03ixy\x18\x07 \x01(\x01\x12\x0b\n\x03ixz\x18\x08 \x01(\x01\x12\x0b\n\x03iyy\x18\t \x01(\x01\x12\x0b\n\x03iyz\x18\n \x01(\x01\x12\x0b\n\x03izz\x18\x0b \x01(\x01\"r\n\x19SetLinkPropertiesResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x16\n\x0estatus_message\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.gazebo_msgs.srv.set_link_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETLINKPROPERTIESREQUEST']._serialized_start=212
  _globals['_SETLINKPROPERTIESREQUEST']._serialized_end=483
  _globals['_SETLINKPROPERTIESRESPONSE']._serialized_start=485
  _globals['_SETLINKPROPERTIESRESPONSE']._serialized_end=599
# @@protoc_insertion_point(module_scope)
