# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/flexbe_msgs/msg/behavior_selection.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.flexbe_msgs.msg import behavior_modification_pb2 as make87__messages__ros2_dot_humble_dot_flexbe__msgs_dot_msg_dot_behavior__modification__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/flexbe_msgs/msg/behavior_selection.proto\x12+make87_messages_ros2.humble.flexbe_msgs.msg\x1a!make87_messages/core/header.proto\x1aGmake87_messages_ros2/humble/flexbe_msgs/msg/behavior_modification.proto\"\xae\x02\n\x11\x42\x65haviorSelection\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x14\n\x0c\x62\x65havior_key\x18\x02 \x01(\x05\x12\x13\n\x0b\x62\x65havior_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x61utonomy_level\x18\x04 \x01(\r\x12\x10\n\x08\x61rg_keys\x18\x05 \x03(\t\x12\x12\n\narg_values\x18\x06 \x03(\t\x12\x12\n\ninput_keys\x18\x07 \x03(\t\x12\x14\n\x0cinput_values\x18\x08 \x03(\t\x12X\n\rmodifications\x18\t \x03(\x0b\x32\x41.make87_messages_ros2.humble.flexbe_msgs.msg.BehaviorModificationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.flexbe_msgs.msg.behavior_selection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BEHAVIORSELECTION']._serialized_start=226
  _globals['_BEHAVIORSELECTION']._serialized_end=528
# @@protoc_insertion_point(module_scope)
