# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/robot_calibration_msgs/msg/observation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_stamped_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_point__stamped__pb2
from make87_messages_ros2.humble.robot_calibration_msgs.msg import extended_camera_info_pb2 as make87__messages__ros2_dot_humble_dot_robot__calibration__msgs_dot_msg_dot_extended__camera__info__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import image_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_image__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/humble/robot_calibration_msgs/msg/observation.proto\x12\x36make87_messages_ros2.humble.robot_calibration_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x41make87_messages_ros2/humble/geometry_msgs/msg/point_stamped.proto\x1aQmake87_messages_ros2/humble/robot_calibration_msgs/msg/extended_camera_info.proto\x1a\x37make87_messages_ros2/humble/sensor_msgs/msg/image.proto\x1a>make87_messages_ros2/humble/sensor_msgs/msg/point_cloud2.proto\"\x90\x03\n\x0bObservation\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x13\n\x0bsensor_name\x18\x02 \x01(\t\x12M\n\x08\x66\x65\x61tures\x18\x03 \x03(\x0b\x32;.make87_messages_ros2.humble.geometry_msgs.msg.PointStamped\x12\x63\n\x0f\x65xt_camera_info\x18\x04 \x01(\x0b\x32J.make87_messages_ros2.humble.robot_calibration_msgs.msg.ExtendedCameraInfo\x12G\n\x05\x63loud\x18\x05 \x01(\x0b\x32\x38.make87_messages_ros2.humble.sensor_msgs.msg.PointCloud2\x12\x41\n\x05image\x18\x06 \x01(\x0b\x32\x32.make87_messages_ros2.humble.sensor_msgs.msg.Imageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.robot_calibration_msgs.msg.observation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBSERVATION']._serialized_start=439
  _globals['_OBSERVATION']._serialized_end=839
# @@protoc_insertion_point(module_scope)
