# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/graph_msgs/msg/edges.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/rolling/graph_msgs/msg/edges.proto\x12+make87_messages_ros2.rolling.graph_msgs.msg\"*\n\x05\x45\x64ges\x12\x10\n\x08node_ids\x18\x01 \x03(\r\x12\x0f\n\x07weights\x18\x02 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.graph_msgs.msg.edges_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_EDGES']._serialized_start=104
  _globals['_EDGES']._serialized_end=146
# @@protoc_insertion_point(module_scope)
