# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/leo_msgs/srv/set_imu_calibration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/leo_msgs/srv/set_imu_calibration.proto\x12\'make87_messages_ros2.jazzy.leo_msgs.srv\"Y\n\x18SetImuCalibrationRequest\x12\x13\n\x0bgyro_bias_x\x18\x01 \x01(\x01\x12\x13\n\x0bgyro_bias_y\x18\x02 \x01(\x01\x12\x13\n\x0bgyro_bias_z\x18\x03 \x01(\x01\",\n\x19SetImuCalibrationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.leo_msgs.srv.set_imu_calibration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETIMUCALIBRATIONREQUEST']._serialized_start=110
  _globals['_SETIMUCALIBRATIONREQUEST']._serialized_end=199
  _globals['_SETIMUCALIBRATIONRESPONSE']._serialized_start=201
  _globals['_SETIMUCALIBRATIONRESPONSE']._serialized_end=245
# @@protoc_insertion_point(module_scope)
