# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/rename_robot_state_in_warehouse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/jazzy/moveit_msgs/srv/rename_robot_state_in_warehouse.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\"W\n\"RenameRobotStateInWarehouseRequest\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\x12\r\n\x05robot\x18\x03 \x01(\t\"%\n#RenameRobotStateInWarehouseResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.rename_robot_state_in_warehouse_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RENAMEROBOTSTATEINWAREHOUSEREQUEST']._serialized_start=128
  _globals['_RENAMEROBOTSTATEINWAREHOUSEREQUEST']._serialized_end=215
  _globals['_RENAMEROBOTSTATEINWAREHOUSERESPONSE']._serialized_start=217
  _globals['_RENAMEROBOTSTATEINWAREHOUSERESPONSE']._serialized_end=254
# @@protoc_insertion_point(module_scope)
