# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/novatel_gps_msgs/msg/novatel_rx_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.novatel_gps_msgs.msg import novatel_message_header_pb2 as make87__messages__ros2_dot_humble_dot_novatel__gps__msgs_dot_msg_dot_novatel__message__header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/humble/novatel_gps_msgs/msg/novatel_rx_status.proto\x12\x30make87_messages_ros2.humble.novatel_gps_msgs.msg\x1a!make87_messages/core/header.proto\x1aMmake87_messages_ros2/humble/novatel_gps_msgs/msg/novatel_message_header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xd1\x02\n\x0fNovatelRxStatus\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x62\n\x12novatel_msg_header\x18\x03 \x01(\x0b\x32\x46.make87_messages_ros2.humble.novatel_gps_msgs.msg.NovatelMessageHeader\x12\r\n\x05\x65rror\x18\x04 \x01(\r\x12\x0e\n\x06rxstat\x18\x05 \x01(\r\x12\x10\n\x08\x61ux1stat\x18\x06 \x01(\r\x12\x10\n\x08\x61ux2stat\x18\x07 \x01(\r\x12\x10\n\x08\x61ux3stat\x18\x08 \x01(\r\x12\x10\n\x08\x61ux4stat\x18\t \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.novatel_gps_msgs.msg.novatel_rx_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NOVATELRXSTATUS']._serialized_start=296
  _globals['_NOVATELRXSTATUS']._serialized_end=633
# @@protoc_insertion_point(module_scope)
