# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_ubx_msgs/msg/cor_status_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/ublox_ubx_msgs/msg/cor_status_info.proto\x12/make87_messages_ros2.rolling.ublox_ubx_msgs.msg\"\xda\x01\n\rCorStatusInfo\x12\x10\n\x08protocol\x18\x01 \x01(\r\x12\x12\n\nerr_status\x18\x02 \x01(\r\x12\x10\n\x08msg_used\x18\x03 \x01(\r\x12\x15\n\rcorrection_id\x18\x04 \x01(\r\x12\x16\n\x0emsg_type_valid\x18\x05 \x01(\x08\x12\x1a\n\x12msg_sub_type_valid\x18\x06 \x01(\x08\x12\x18\n\x10msg_input_handle\x18\x07 \x01(\x08\x12\x15\n\rmsg_encrypted\x18\x08 \x01(\r\x12\x15\n\rmsg_decrypted\x18\t \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_ubx_msgs.msg.cor_status_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CORSTATUSINFO']._serialized_start=123
  _globals['_CORSTATUSINFO']._serialized_end=341
# @@protoc_insertion_point(module_scope)
