# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/wrapyfi_ros2_interfaces/srv/ros2_audio_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.wrapyfi_ros2_interfaces.msg import ros2_audio_message_pb2 as make87__messages__ros2_dot_humble_dot_wrapyfi__ros2__interfaces_dot_msg_dot_ros2__audio__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/wrapyfi_ros2_interfaces/srv/ros2_audio_service.proto\x12\x37make87_messages_ros2.humble.wrapyfi_ros2_interfaces.srv\x1a!make87_messages/core/header.proto\x1aPmake87_messages_ros2/humble/wrapyfi_ros2_interfaces/msg/ros2_audio_message.proto\"X\n\x17ROS2AudioServiceRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07request\x18\x02 \x01(\t\"\xa5\x01\n\x18ROS2AudioServiceResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12[\n\x08response\x18\x02 \x01(\x0b\x32I.make87_messages_ros2.humble.wrapyfi_ros2_interfaces.msg.ROS2AudioMessageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.wrapyfi_ros2_interfaces.srv.ros2_audio_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROS2AUDIOSERVICEREQUEST']._serialized_start=258
  _globals['_ROS2AUDIOSERVICEREQUEST']._serialized_end=346
  _globals['_ROS2AUDIOSERVICERESPONSE']._serialized_start=349
  _globals['_ROS2AUDIOSERVICERESPONSE']._serialized_end=514
# @@protoc_insertion_point(module_scope)
