# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/robot_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import attached_collision_object_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_attached__collision__object__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import joint_state_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_joint__state__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import multi_dof_joint_state_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_multi__dof__joint__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/moveit_msgs/msg/robot_state.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1aJmake87_messages_ros2/jazzy/moveit_msgs/msg/attached_collision_object.proto\x1a<make87_messages_ros2/jazzy/sensor_msgs/msg/joint_state.proto\x1a\x46make87_messages_ros2/jazzy/sensor_msgs/msg/multi_dof_joint_state.proto\"\xb2\x02\n\nRobotState\x12K\n\x0bjoint_state\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.sensor_msgs.msg.JointState\x12]\n\x15multi_dof_joint_state\x18\x02 \x01(\x0b\x32>.make87_messages_ros2.jazzy.sensor_msgs.msg.MultiDOFJointState\x12g\n\x1a\x61ttached_collision_objects\x18\x03 \x03(\x0b\x32\x43.make87_messages_ros2.jazzy.moveit_msgs.msg.AttachedCollisionObject\x12\x0f\n\x07is_diff\x18\x04 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.robot_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROBOTSTATE']._serialized_start=319
  _globals['_ROBOTSTATE']._serialized_end=625
# @@protoc_insertion_point(module_scope)
