# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_scheduler_msgs/srv/list_schedule_states.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_scheduler_msgs.msg import schedule_state_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__scheduler__msgs_dot_msg_dot_schedule__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/rmf_scheduler_msgs/srv/list_schedule_states.proto\x12\x33make87_messages_ros2.rolling.rmf_scheduler_msgs.srv\x1aHmake87_messages_ros2/rolling/rmf_scheduler_msgs/msg/schedule_state.proto\"3\n\x19ListScheduleStatesRequest\x12\x16\n\x0emodified_after\x18\x01 \x01(\x03\"\x95\x01\n\x1aListScheduleStatesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12U\n\tschedules\x18\x03 \x03(\x0b\x32\x42.make87_messages_ros2.rolling.rmf_scheduler_msgs.msg.ScheduleStateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_scheduler_msgs.srv.list_schedule_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LISTSCHEDULESTATESREQUEST']._serialized_start=209
  _globals['_LISTSCHEDULESTATESREQUEST']._serialized_end=260
  _globals['_LISTSCHEDULESTATESRESPONSE']._serialized_start=263
  _globals['_LISTSCHEDULESTATESRESPONSE']._serialized_end=412
# @@protoc_insertion_point(module_scope)
