# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/srv/vehicle_info_get.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.mavros_msgs.msg import vehicle_info_pb2 as make87__messages__ros2_dot_jazzy_dot_mavros__msgs_dot_msg_dot_vehicle__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/mavros_msgs/srv/vehicle_info_get.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.srv\x1a=make87_messages_ros2/jazzy/mavros_msgs/msg/vehicle_info.proto\"G\n\x15VehicleInfoGetRequest\x12\r\n\x05sysid\x18\x01 \x01(\r\x12\x0e\n\x06\x63ompid\x18\x02 \x01(\r\x12\x0f\n\x07get_all\x18\x03 \x01(\x08\"t\n\x16VehicleInfoGetResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12I\n\x08vehicles\x18\x02 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.mavros_msgs.msg.VehicleInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.srv.vehicle_info_get_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_VEHICLEINFOGETREQUEST']._serialized_start=176
  _globals['_VEHICLEINFOGETREQUEST']._serialized_end=247
  _globals['_VEHICLEINFOGETRESPONSE']._serialized_start=249
  _globals['_VEHICLEINFOGETRESPONSE']._serialized_end=365
# @@protoc_insertion_point(module_scope)
