# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/micro_ros_msgs/msg/node.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.micro_ros_msgs.msg import entity_pb2 as make87__messages__ros2_dot_jazzy_dot_micro__ros__msgs_dot_msg_dot_entity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/micro_ros_msgs/msg/node.proto\x12-make87_messages_ros2.jazzy.micro_ros_msgs.msg\x1a:make87_messages_ros2/jazzy/micro_ros_msgs/msg/entity.proto\"z\n\x04Node\x12\x16\n\x0enode_namespace\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12G\n\x08\x65ntities\x18\x03 \x03(\x0b\x32\x35.make87_messages_ros2.jazzy.micro_ros_msgs.msg.Entityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.micro_ros_msgs.msg.node_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NODE']._serialized_start=167
  _globals['_NODE']._serialized_end=289
# @@protoc_insertion_point(module_scope)
