# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/octomap_msgs/srv/get_octomap.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.octomap_msgs.msg import octomap_pb2 as make87__messages__ros2_dot_rolling_dot_octomap__msgs_dot_msg_dot_octomap__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/octomap_msgs/srv/get_octomap.proto\x12-make87_messages_ros2.rolling.octomap_msgs.srv\x1a;make87_messages_ros2/rolling/octomap_msgs/msg/octomap.proto\"\x13\n\x11GetOctomapRequest\"Y\n\x12GetOctomapResponse\x12\x43\n\x03map\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.rolling.octomap_msgs.msg.Octomapb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.octomap_msgs.srv.get_octomap_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETOCTOMAPREQUEST']._serialized_start=175
  _globals['_GETOCTOMAPREQUEST']._serialized_end=194
  _globals['_GETOCTOMAPRESPONSE']._serialized_start=196
  _globals['_GETOCTOMAPRESPONSE']._serialized_end=285
# @@protoc_insertion_point(module_scope)
