# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/object_recognition_msgs/srv/get_object_information.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.object_recognition_msgs.msg import object_information_pb2 as make87__messages__ros2_dot_jazzy_dot_object__recognition__msgs_dot_msg_dot_object__information__pb2
from make87_messages_ros2.jazzy.object_recognition_msgs.msg import object_type_pb2 as make87__messages__ros2_dot_jazzy_dot_object__recognition__msgs_dot_msg_dot_object__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/jazzy/object_recognition_msgs/srv/get_object_information.proto\x12\x36make87_messages_ros2.jazzy.object_recognition_msgs.srv\x1aOmake87_messages_ros2/jazzy/object_recognition_msgs/msg/object_information.proto\x1aHmake87_messages_ros2/jazzy/object_recognition_msgs/msg/object_type.proto\"o\n\x1bGetObjectInformationRequest\x12P\n\x04type\x18\x01 \x01(\x0b\x32\x42.make87_messages_ros2.jazzy.object_recognition_msgs.msg.ObjectType\"~\n\x1cGetObjectInformationResponse\x12^\n\x0binformation\x18\x01 \x01(\x0b\x32I.make87_messages_ros2.jazzy.object_recognition_msgs.msg.ObjectInformationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.object_recognition_msgs.srv.get_object_information_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETOBJECTINFORMATIONREQUEST']._serialized_start=298
  _globals['_GETOBJECTINFORMATIONREQUEST']._serialized_end=409
  _globals['_GETOBJECTINFORMATIONRESPONSE']._serialized_start=411
  _globals['_GETOBJECTINFORMATIONRESPONSE']._serialized_end=537
# @@protoc_insertion_point(module_scope)
