# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/create_msgs/msg/bumper.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/humble/create_msgs/msg/bumper.proto\x12+make87_messages_ros2.humble.create_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x96\x04\n\x06\x42umper\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x17\n\x0fis_left_pressed\x18\x03 \x01(\x08\x12\x18\n\x10is_right_pressed\x18\x04 \x01(\x08\x12\x15\n\ris_light_left\x18\x05 \x01(\x08\x12\x1b\n\x13is_light_front_left\x18\x06 \x01(\x08\x12\x1c\n\x14is_light_center_left\x18\x07 \x01(\x08\x12\x1d\n\x15is_light_center_right\x18\x08 \x01(\x08\x12\x1c\n\x14is_light_front_right\x18\t \x01(\x08\x12\x16\n\x0eis_light_right\x18\n \x01(\x08\x12\x19\n\x11light_signal_left\x18\x0b \x01(\r\x12\x1f\n\x17light_signal_front_left\x18\x0c \x01(\r\x12 \n\x18light_signal_center_left\x18\r \x01(\r\x12!\n\x19light_signal_center_right\x18\x0e \x01(\r\x12 \n\x18light_signal_front_right\x18\x0f \x01(\r\x12\x1a\n\x12light_signal_right\x18\x10 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.create_msgs.msg.bumper_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BUMPER']._serialized_start=196
  _globals['_BUMPER']._serialized_end=730
# @@protoc_insertion_point(module_scope)
