# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/msg/entity_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import twist_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_twist__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/gazebo_msgs/msg/entity_state.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.msg\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/twist.proto\"\xba\x01\n\x0b\x45ntityState\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\x04pose\x18\x02 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x42\n\x05twist\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Twist\x12\x17\n\x0freference_frame\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.msg.entity_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ENTITYSTATE']._serialized_start=225
  _globals['_ENTITYSTATE']._serialized_end=411
# @@protoc_insertion_point(module_scope)
