# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/novatel_gps_msgs/msg/trackstat_channel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/novatel_gps_msgs/msg/trackstat_channel.proto\x12\x31make87_messages_ros2.rolling.novatel_gps_msgs.msg\"\xb9\x01\n\x10TrackstatChannel\x12\x0b\n\x03prn\x18\x01 \x01(\x05\x12\x0f\n\x07glofreq\x18\x02 \x01(\x05\x12\x14\n\x0c\x63h_tr_status\x18\x03 \x01(\r\x12\x0b\n\x03psr\x18\x04 \x01(\x01\x12\x0f\n\x07\x64oppler\x18\x05 \x01(\x02\x12\x0c\n\x04\x63_no\x18\x06 \x01(\x02\x12\x10\n\x08locktime\x18\x07 \x01(\x02\x12\x0f\n\x07psr_res\x18\x08 \x01(\x02\x12\x0e\n\x06reject\x18\t \x01(\t\x12\x12\n\npsr_weight\x18\n \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.novatel_gps_msgs.msg.trackstat_channel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TRACKSTATCHANNEL']._serialized_start=129
  _globals['_TRACKSTATCHANNEL']._serialized_end=314
# @@protoc_insertion_point(module_scope)
