# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/robot_localization/srv/set_datum.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geographic_msgs.msg import geo_pose_pb2 as make87__messages__ros2_dot_rolling_dot_geographic__msgs_dot_msg_dot_geo__pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/rolling/robot_localization/srv/set_datum.proto\x12\x33make87_messages_ros2.rolling.robot_localization.srv\x1a?make87_messages_ros2/rolling/geographic_msgs/msg/geo_pose.proto\"^\n\x0fSetDatumRequest\x12K\n\x08geo_pose\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.geographic_msgs.msg.GeoPose\"\x12\n\x10SetDatumResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.robot_localization.srv.set_datum_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETDATUMREQUEST']._serialized_start=189
  _globals['_SETDATUMREQUEST']._serialized_end=283
  _globals['_SETDATUMRESPONSE']._serialized_start=285
  _globals['_SETDATUMRESPONSE']._serialized_end=303
# @@protoc_insertion_point(module_scope)
