# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/srv/gimbal_manager_camera_track.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/jazzy/mavros_msgs/srv/gimbal_manager_camera_track.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.srv\"\xad\x01\n\x1fGimbalManagerCameraTrackRequest\x12\x0c\n\x04mode\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\x0e\n\x06radius\x18\x04 \x01(\x02\x12\x12\n\ntop_left_x\x18\x05 \x01(\x02\x12\x12\n\ntop_left_y\x18\x06 \x01(\x02\x12\x16\n\x0e\x62ottom_right_x\x18\x07 \x01(\x02\x12\x16\n\x0e\x62ottom_right_y\x18\x08 \x01(\x02\"C\n GimbalManagerCameraTrackResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06result\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.srv.gimbal_manager_camera_track_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GIMBALMANAGERCAMERATRACKREQUEST']._serialized_start=125
  _globals['_GIMBALMANAGERCAMERATRACKREQUEST']._serialized_end=298
  _globals['_GIMBALMANAGERCAMERATRACKRESPONSE']._serialized_start=300
  _globals['_GIMBALMANAGERCAMERATRACKRESPONSE']._serialized_end=367
# @@protoc_insertion_point(module_scope)
