# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/flexbe_msgs/msg/behavior_log.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/flexbe_msgs/msg/behavior_log.proto\x12*make87_messages_ros2.jazzy.flexbe_msgs.msg\"0\n\x0b\x42\x65haviorLog\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x13\n\x0bstatus_code\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.flexbe_msgs.msg.behavior_log_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BEHAVIORLOG']._serialized_start=109
  _globals['_BEHAVIORLOG']._serialized_end=157
# @@protoc_insertion_point(module_scope)
