# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_task_msgs/msg/task_profile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import task_description_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_task__description__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/rmf_task_msgs/msg/task_profile.proto\x12.make87_messages_ros2.rolling.rmf_task_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x45make87_messages_ros2/rolling/rmf_task_msgs/msg/task_description.proto\"\xc8\x01\n\x0bTaskProfile\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12R\n\x0fsubmission_time\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12T\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32?.make87_messages_ros2.rolling.rmf_task_msgs.msg.TaskDescriptionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_task_msgs.msg.task_profile_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TASKPROFILE']._serialized_start=253
  _globals['_TASKPROFILE']._serialized_end=453
# @@protoc_insertion_point(module_scope)
