# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rosbag2_test_msgdefs/srv/complex_srv_msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rosbag2_test_msgdefs.msg import basic_msg_pb2 as make87__messages__ros2_dot_jazzy_dot_rosbag2__test__msgdefs_dot_msg_dot_basic__msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/rosbag2_test_msgdefs/srv/complex_srv_msg.proto\x12\x33make87_messages_ros2.jazzy.rosbag2_test_msgdefs.srv\x1a\x43make87_messages_ros2/jazzy/rosbag2_test_msgdefs/msg/basic_msg.proto\"b\n\x14\x43omplexSrvMsgRequest\x12J\n\x03req\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.jazzy.rosbag2_test_msgdefs.msg.BasicMsg\"d\n\x15\x43omplexSrvMsgResponse\x12K\n\x04resp\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.jazzy.rosbag2_test_msgdefs.msg.BasicMsgb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rosbag2_test_msgdefs.srv.complex_srv_msg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMPLEXSRVMSGREQUEST']._serialized_start=199
  _globals['_COMPLEXSRVMSGREQUEST']._serialized_end=297
  _globals['_COMPLEXSRVMSGRESPONSE']._serialized_start=299
  _globals['_COMPLEXSRVMSGRESPONSE']._serialized_end=399
# @@protoc_insertion_point(module_scope)
