# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/pcl_msgs/msg/polygon_mesh.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.pcl_msgs.msg import vertices_pb2 as make87__messages__ros2_dot_rolling_dot_pcl__msgs_dot_msg_dot_vertices__pb2
from make87_messages_ros2.rolling.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_rolling_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/rolling/pcl_msgs/msg/polygon_mesh.proto\x12)make87_messages_ros2.rolling.pcl_msgs.msg\x1a\x38make87_messages_ros2/rolling/pcl_msgs/msg/vertices.proto\x1a?make87_messages_ros2/rolling/sensor_msgs/msg/point_cloud2.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xe1\x01\n\x0bPolygonMesh\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12H\n\x05\x63loud\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.sensor_msgs.msg.PointCloud2\x12\x45\n\x08polygons\x18\x03 \x03(\x0b\x32\x33.make87_messages_ros2.rolling.pcl_msgs.msg.Verticesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.pcl_msgs.msg.polygon_mesh_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_POLYGONMESH']._serialized_start=287
  _globals['_POLYGONMESH']._serialized_end=512
# @@protoc_insertion_point(module_scope)
