# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/controller_manager_msgs/srv/list_hardware_interfaces.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.controller_manager_msgs.msg import hardware_interface_pb2 as make87__messages__ros2_dot_rolling_dot_controller__manager__msgs_dot_msg_dot_hardware__interface__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWmake87_messages_ros2/rolling/controller_manager_msgs/srv/list_hardware_interfaces.proto\x12\x38make87_messages_ros2.rolling.controller_manager_msgs.srv\x1aQmake87_messages_ros2/rolling/controller_manager_msgs/msg/hardware_interface.proto\"\x1f\n\x1dListHardwareInterfacesRequest\"\xf0\x01\n\x1eListHardwareInterfacesResponse\x12g\n\x12\x63ommand_interfaces\x18\x01 \x03(\x0b\x32K.make87_messages_ros2.rolling.controller_manager_msgs.msg.HardwareInterface\x12\x65\n\x10state_interfaces\x18\x02 \x03(\x0b\x32K.make87_messages_ros2.rolling.controller_manager_msgs.msg.HardwareInterfaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.controller_manager_msgs.srv.list_hardware_interfaces_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LISTHARDWAREINTERFACESREQUEST']._serialized_start=232
  _globals['_LISTHARDWAREINTERFACESREQUEST']._serialized_end=263
  _globals['_LISTHARDWAREINTERFACESRESPONSE']._serialized_start=266
  _globals['_LISTHARDWAREINTERFACESRESPONSE']._serialized_end=506
# @@protoc_insertion_point(module_scope)
