# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/septentrio_gnss_driver/msg/meas_epoch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.septentrio_gnss_driver.msg import block_header_pb2 as make87__messages__ros2_dot_humble_dot_septentrio__gnss__driver_dot_msg_dot_block__header__pb2
from make87_messages_ros2.humble.septentrio_gnss_driver.msg import meas_epoch_channel_type1_pb2 as make87__messages__ros2_dot_humble_dot_septentrio__gnss__driver_dot_msg_dot_meas__epoch__channel__type1__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/septentrio_gnss_driver/msg/meas_epoch.proto\x12\x36make87_messages_ros2.humble.septentrio_gnss_driver.msg\x1a!make87_messages/core/header.proto\x1aImake87_messages_ros2/humble/septentrio_gnss_driver/msg/block_header.proto\x1aUmake87_messages_ros2/humble/septentrio_gnss_driver/msg/meas_epoch_channel_type1.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x99\x03\n\tMeasEpoch\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12Y\n\x0c\x62lock_header\x18\x03 \x01(\x0b\x32\x43.make87_messages_ros2.humble.septentrio_gnss_driver.msg.BlockHeader\x12\t\n\x01n\x18\x04 \x01(\r\x12\x12\n\nsb1_length\x18\x05 \x01(\r\x12\x12\n\nsb2_length\x18\x06 \x01(\r\x12\x14\n\x0c\x63ommon_flags\x18\x07 \x01(\r\x12\x15\n\rcum_clk_jumps\x18\x08 \x01(\r\x12\\\n\x05type1\x18\t \x03(\x0b\x32M.make87_messages_ros2.humble.septentrio_gnss_driver.msg.MeasEpochChannelType1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.septentrio_gnss_driver.msg.meas_epoch_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MEASEPOCH']._serialized_start=384
  _globals['_MEASEPOCH']._serialized_end=793
# @@protoc_insertion_point(module_scope)
