# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_perception_msgs/msg/tracked_object_kinematics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import accel_with_covariance_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_accel__with__covariance__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import twist_with_covariance_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_twist__with__covariance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYmake87_messages_ros2/rolling/autoware_perception_msgs/msg/tracked_object_kinematics.proto\x12\x39make87_messages_ros2.rolling.autoware_perception_msgs.msg\x1aJmake87_messages_ros2/rolling/geometry_msgs/msg/accel_with_covariance.proto\x1aImake87_messages_ros2/rolling/geometry_msgs/msg/pose_with_covariance.proto\x1aJmake87_messages_ros2/rolling/geometry_msgs/msg/twist_with_covariance.proto\"\x83\x03\n\x17TrackedObjectKinematics\x12`\n\x14pose_with_covariance\x18\x01 \x01(\x0b\x32\x42.make87_messages_ros2.rolling.geometry_msgs.msg.PoseWithCovariance\x12\x62\n\x15twist_with_covariance\x18\x02 \x01(\x0b\x32\x43.make87_messages_ros2.rolling.geometry_msgs.msg.TwistWithCovariance\x12i\n\x1c\x61\x63\x63\x65leration_with_covariance\x18\x03 \x01(\x0b\x32\x43.make87_messages_ros2.rolling.geometry_msgs.msg.AccelWithCovariance\x12 \n\x18orientation_availability\x18\x04 \x01(\r\x12\x15\n\ris_stationary\x18\x05 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_perception_msgs.msg.tracked_object_kinematics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TRACKEDOBJECTKINEMATICS']._serialized_start=380
  _globals['_TRACKEDOBJECTKINEMATICS']._serialized_end=767
# @@protoc_insertion_point(module_scope)
