# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/nav_msgs/srv/load_map.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.nav_msgs.msg import occupancy_grid_pb2 as make87__messages__ros2_dot_humble_dot_nav__msgs_dot_msg_dot_occupancy__grid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/humble/nav_msgs/srv/load_map.proto\x12(make87_messages_ros2.humble.nav_msgs.srv\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/nav_msgs/msg/occupancy_grid.proto\"O\n\x0eLoadMapRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07map_url\x18\x02 \x01(\t\"\x95\x01\n\x0fLoadMapResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x44\n\x03map\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.humble.nav_msgs.msg.OccupancyGrid\x12\x0e\n\x06result\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.nav_msgs.srv.load_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LOADMAPREQUEST']._serialized_start=199
  _globals['_LOADMAPREQUEST']._serialized_end=278
  _globals['_LOADMAPRESPONSE']._serialized_start=281
  _globals['_LOADMAPRESPONSE']._serialized_end=430
# @@protoc_insertion_point(module_scope)
