# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/geographic_msgs/srv/update_geographic_map.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geographic_msgs.msg import geographic_map_changes_pb2 as make87__messages__ros2_dot_jazzy_dot_geographic__msgs_dot_msg_dot_geographic__map__changes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/geographic_msgs/srv/update_geographic_map.proto\x12.make87_messages_ros2.jazzy.geographic_msgs.srv\x1aKmake87_messages_ros2/jazzy/geographic_msgs/msg/geographic_map_changes.proto\"s\n\x1aUpdateGeographicMapRequest\x12U\n\x07updates\x18\x01 \x01(\x0b\x32\x44.make87_messages_ros2.jazzy.geographic_msgs.msg.GeographicMapChanges\">\n\x1bUpdateGeographicMapResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.geographic_msgs.srv.update_geographic_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UPDATEGEOGRAPHICMAPREQUEST']._serialized_start=203
  _globals['_UPDATEGEOGRAPHICMAPREQUEST']._serialized_end=318
  _globals['_UPDATEGEOGRAPHICMAPRESPONSE']._serialized_start=320
  _globals['_UPDATEGEOGRAPHICMAPRESPONSE']._serialized_end=382
# @@protoc_insertion_point(module_scope)
