# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/mqtt_client_interfaces/srv/new_ros2_mqtt_bridge.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/humble/mqtt_client_interfaces/srv/new_ros2_mqtt_bridge.proto\x12\x36make87_messages_ros2.humble.mqtt_client_interfaces.srv\x1a!make87_messages/core/header.proto\"\xdd\x01\n\x18NewRos2MqttBridgeRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x11\n\tros_topic\x18\x02 \x01(\t\x12\x12\n\nmqtt_topic\x18\x03 \x01(\t\x12\x11\n\tprimitive\x18\x04 \x01(\x08\x12\x18\n\x10inject_timestamp\x18\x05 \x01(\x08\x12\x16\n\x0eros_queue_size\x18\x06 \x01(\r\x12\x10\n\x08mqtt_qos\x18\x07 \x01(\r\x12\x15\n\rmqtt_retained\x18\x08 \x01(\x08\"Z\n\x19NewRos2MqttBridgeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.mqtt_client_interfaces.srv.new_ros2_mqtt_bridge_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NEWROS2MQTTBRIDGEREQUEST']._serialized_start=177
  _globals['_NEWROS2MQTTBRIDGEREQUEST']._serialized_end=398
  _globals['_NEWROS2MQTTBRIDGERESPONSE']._serialized_start=400
  _globals['_NEWROS2MQTTBRIDGERESPONSE']._serialized_end=490
# @@protoc_insertion_point(module_scope)
