# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/delphi_mrr_msgs/msg/vehicle_state_msg2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/delphi_mrr_msgs/msg/vehicle_state_msg2.proto\x12\x30make87_messages_ros2.rolling.delphi_mrr_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xab\x02\n\x10VehicleStateMsg2\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x1a\n\x12\x66sm_yaw_rate_valid\x18\x02 \x01(\x08\x12\x14\n\x0c\x66sm_yaw_rate\x18\x03 \x01(\x02\x12\x1d\n\x15\x63\x61n_vehicle_index_4fa\x18\x04 \x01(\r\x12\x1c\n\x14\x66sm_vehicle_velocity\x18\x05 \x01(\x02\x12!\n\x19\x63\x61n_steering_whl_angle_qf\x18\x06 \x01(\x08\x12\"\n\x1a\x66sm_vehicle_velocity_valid\x18\x07 \x01(\x08\x12\x1e\n\x16\x63\x61n_steering_whl_angle\x18\x08 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.delphi_mrr_msgs.msg.vehicle_state_msg2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_VEHICLESTATEMSG2']._serialized_start=184
  _globals['_VEHICLESTATEMSG2']._serialized_end=483
# @@protoc_insertion_point(module_scope)
