# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/srv/stream_rate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/mavros_msgs/srv/stream_rate.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.srv\"L\n\x11StreamRateRequest\x12\x11\n\tstream_id\x18\x01 \x01(\r\x12\x14\n\x0cmessage_rate\x18\x02 \x01(\r\x12\x0e\n\x06on_off\x18\x03 \x01(\x08\"\x14\n\x12StreamRateResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.srv.stream_rate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STREAMRATEREQUEST']._serialized_start=108
  _globals['_STREAMRATEREQUEST']._serialized_end=184
  _globals['_STREAMRATERESPONSE']._serialized_start=186
  _globals['_STREAMRATERESPONSE']._serialized_end=206
# @@protoc_insertion_point(module_scope)
