# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/delphi_esr_msgs/msg/esr_vehicle2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/humble/delphi_esr_msgs/msg/esr_vehicle2.proto\x12/make87_messages_ros2.humble.delphi_esr_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xc1\x04\n\x0b\x45srVehicle2\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x16\n\x0escan_index_ack\x18\x03 \x01(\r\x12\x1e\n\x16use_angle_misalignment\x18\x04 \x01(\x08\x12\x14\n\x0c\x63lear_faults\x18\x05 \x01(\x08\x12\x16\n\x0ehigh_yaw_angle\x18\x06 \x01(\x05\x12\x18\n\x10mr_only_transmit\x18\x07 \x01(\x08\x12\x18\n\x10lr_only_transmit\x18\x08 \x01(\x08\x12\x1a\n\x12\x61ngle_misalignment\x18\t \x01(\x02\x12\x1f\n\x17lateral_mounting_offset\x18\n \x01(\x02\x12\x19\n\x11radar_cmd_radiate\x18\x0b \x01(\x08\x12\x18\n\x10\x62lockage_disable\x18\x0c \x01(\x08\x12\x16\n\x0emaximum_tracks\x18\r \x01(\r\x12\x1a\n\x12turn_signal_status\x18\x0e \x01(\r\x12\x1e\n\x16vehicle_speed_validity\x18\x0f \x01(\x08\x12\x17\n\x0fmmr_upside_down\x18\x10 \x01(\x08\x12\x15\n\rgrouping_mode\x18\x11 \x01(\r\x12\x14\n\x0cwiper_status\x18\x12 \x01(\x08\x12\x17\n\x0fraw_data_enable\x18\x13 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.delphi_esr_msgs.msg.esr_vehicle2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ESRVEHICLE2']._serialized_start=210
  _globals['_ESRVEHICLE2']._serialized_end=787
# @@protoc_insertion_point(module_scope)
