# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_valdel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_valdel.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\"M\n\tCfgVALDEL\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x0e\n\x06layers\x18\x02 \x01(\r\x12\x11\n\treserved0\x18\x03 \x03(\r\x12\x0c\n\x04keys\x18\x04 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.cfg_valdel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CFGVALDEL']._serialized_start=105
  _globals['_CFGVALDEL']._serialized_end=182
# @@protoc_insertion_point(module_scope)
