# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ros2cli_test_interfaces/srv/short_varied_multi_nested.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ros2cli_test_interfaces.msg import short_varied_nested_pb2 as make87__messages__ros2_dot_humble_dot_ros2cli__test__interfaces_dot_msg_dot_short__varied__nested__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWmake87_messages_ros2/humble/ros2cli_test_interfaces/srv/short_varied_multi_nested.proto\x12\x37make87_messages_ros2.humble.ros2cli_test_interfaces.srv\x1a!make87_messages/core/header.proto\x1aQmake87_messages_ros2/humble/ros2cli_test_interfaces/msg/short_varied_nested.proto\"\xb6\x01\n\x1dShortVariedMultiNestedRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12g\n\x13short_varied_nested\x18\x02 \x01(\x0b\x32J.make87_messages_ros2.humble.ros2cli_test_interfaces.msg.ShortVariedNested\"b\n\x1eShortVariedMultiNestedResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x12\n\nbool_value\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ros2cli_test_interfaces.srv.short_varied_multi_nested_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SHORTVARIEDMULTINESTEDREQUEST']._serialized_start=267
  _globals['_SHORTVARIEDMULTINESTEDREQUEST']._serialized_end=449
  _globals['_SHORTVARIEDMULTINESTEDRESPONSE']._serialized_start=451
  _globals['_SHORTVARIEDMULTINESTEDRESPONSE']._serialized_end=549
# @@protoc_insertion_point(module_scope)
