# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/get_position_ik.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import position_ik_request_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_position__ik__request__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/moveit_msgs/srv/get_position_ik.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/move_it_error_codes.proto\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/position_ik_request.proto\x1a<make87_messages_ros2/jazzy/moveit_msgs/msg/robot_state.proto\"i\n\x14GetPositionIKRequest\x12Q\n\nik_request\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.jazzy.moveit_msgs.msg.PositionIKRequest\"\xb3\x01\n\x15GetPositionIKResponse\x12H\n\x08solution\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.moveit_msgs.msg.RobotState\x12P\n\nerror_code\x18\x02 \x01(\x0b\x32<.make87_messages_ros2.jazzy.moveit_msgs.msg.MoveItErrorCodesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.get_position_ik_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETPOSITIONIKREQUEST']._serialized_start=314
  _globals['_GETPOSITIONIKREQUEST']._serialized_end=419
  _globals['_GETPOSITIONIKRESPONSE']._serialized_start=422
  _globals['_GETPOSITIONIKRESPONSE']._serialized_end=601
# @@protoc_insertion_point(module_scope)
