# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/psdk_interfaces/msg/flight_anomaly.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/psdk_interfaces/msg/flight_anomaly.proto\x12/make87_messages_ros2.humble.psdk_interfaces.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x85\x04\n\rFlightAnomaly\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x15\n\rimpact_in_air\x18\x03 \x01(\r\x12\x12\n\nrandom_fly\x18\x04 \x01(\r\x12\x18\n\x10height_ctrl_fail\x18\x05 \x01(\r\x12\x1c\n\x14roll_pitch_ctrl_fail\x18\x06 \x01(\r\x12\x15\n\ryaw_ctrl_fail\x18\x07 \x01(\r\x12\x1b\n\x13\x61ircraft_is_falling\x18\x08 \x01(\r\x12\x1a\n\x12strong_wind_level1\x18\t \x01(\r\x12\x1a\n\x12strong_wind_level2\x18\n \x01(\r\x12\"\n\x1a\x63ompass_installation_error\x18\x0b \x01(\r\x12\x1e\n\x16imu_installation_error\x18\x0c \x01(\r\x12\x1c\n\x14\x65sc_temperature_high\x18\r \x01(\r\x12%\n\x1d\x61t_least_one_esc_disconnected\x18\x0e \x01(\r\x12\x15\n\rgps_yaw_error\x18\x0f \x01(\r\x12\x10\n\x08reserved\x18\x10 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.psdk_interfaces.msg.flight_anomaly_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FLIGHTANOMALY']._serialized_start=212
  _globals['_FLIGHTANOMALY']._serialized_end=729
# @@protoc_insertion_point(module_scope)
