# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/topic_tools_interfaces/srv/mux_list.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/topic_tools_interfaces/srv/mux_list.proto\x12\x35make87_messages_ros2.jazzy.topic_tools_interfaces.srv\"\x10\n\x0eMuxListRequest\"!\n\x0fMuxListResponse\x12\x0e\n\x06topics\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.topic_tools_interfaces.srv.mux_list_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MUXLISTREQUEST']._serialized_start=127
  _globals['_MUXLISTREQUEST']._serialized_end=143
  _globals['_MUXLISTRESPONSE']._serialized_start=145
  _globals['_MUXLISTRESPONSE']._serialized_end=178
# @@protoc_insertion_point(module_scope)
