# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_nav_msgs/srv/plan_route.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.marti_nav_msgs.msg import route_pb2 as make87__messages__ros2_dot_rolling_dot_marti__nav__msgs_dot_msg_dot_route__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/rolling/marti_nav_msgs/srv/plan_route.proto\x12/make87_messages_ros2.rolling.marti_nav_msgs.srv\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a;make87_messages_ros2/rolling/marti_nav_msgs/msg/route.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xb9\x01\n\x10PlanRouteRequest\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12G\n\twaypoints\x18\x02 \x03(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\x19\n\x11plan_from_vehicle\x18\x03 \x01(\x08\"\x8a\x01\n\x11PlanRouteResponse\x12\x45\n\x05route\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.rolling.marti_nav_msgs.msg.Route\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0c\n\x04\x63ost\x18\x04 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_nav_msgs.srv.plan_route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLANROUTEREQUEST']._serialized_start=294
  _globals['_PLANROUTEREQUEST']._serialized_end=479
  _globals['_PLANROUTERESPONSE']._serialized_start=482
  _globals['_PLANROUTERESPONSE']._serialized_end=620
# @@protoc_insertion_point(module_scope)
