# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rcss3d_agent_msgs/msg/effector.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rcss3d_agent_msgs.msg import beam_pb2 as make87__messages__ros2_dot_rolling_dot_rcss3d__agent__msgs_dot_msg_dot_beam__pb2
from make87_messages_ros2.rolling.rcss3d_agent_msgs.msg import hinge_joint_vel_pb2 as make87__messages__ros2_dot_rolling_dot_rcss3d__agent__msgs_dot_msg_dot_hinge__joint__vel__pb2
from make87_messages_ros2.rolling.rcss3d_agent_msgs.msg import say_pb2 as make87__messages__ros2_dot_rolling_dot_rcss3d__agent__msgs_dot_msg_dot_say__pb2
from make87_messages_ros2.rolling.rcss3d_agent_msgs.msg import universal_joint_vel_pb2 as make87__messages__ros2_dot_rolling_dot_rcss3d__agent__msgs_dot_msg_dot_universal__joint__vel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/rcss3d_agent_msgs/msg/effector.proto\x12\x32make87_messages_ros2.rolling.rcss3d_agent_msgs.msg\x1a=make87_messages_ros2/rolling/rcss3d_agent_msgs/msg/beam.proto\x1aHmake87_messages_ros2/rolling/rcss3d_agent_msgs/msg/hinge_joint_vel.proto\x1a<make87_messages_ros2/rolling/rcss3d_agent_msgs/msg/say.proto\x1aLmake87_messages_ros2/rolling/rcss3d_agent_msgs/msg/universal_joint_vel.proto\"\xdc\x02\n\x08\x45\x66\x66\x65\x63tor\x12[\n\x10hinge_joint_vels\x18\x01 \x03(\x0b\x32\x41.make87_messages_ros2.rolling.rcss3d_agent_msgs.msg.HingeJointVel\x12\x63\n\x14universal_joint_vels\x18\x02 \x03(\x0b\x32\x45.make87_messages_ros2.rolling.rcss3d_agent_msgs.msg.UniversalJointVel\x12G\n\x05\x62\x65\x61ms\x18\x03 \x03(\x0b\x32\x38.make87_messages_ros2.rolling.rcss3d_agent_msgs.msg.Beam\x12\x45\n\x04says\x18\x04 \x03(\x0b\x32\x37.make87_messages_ros2.rolling.rcss3d_agent_msgs.msg.Sayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rcss3d_agent_msgs.msg.effector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_EFFECTOR']._serialized_start=399
  _globals['_EFFECTOR']._serialized_end=747
# @@protoc_insertion_point(module_scope)
