# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rosbag2_test_msgdefs/srv/basic_srv.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/rosbag2_test_msgdefs/srv/basic_srv.proto\x12\x33make87_messages_ros2.jazzy.rosbag2_test_msgdefs.srv\"\x1e\n\x0f\x42\x61sicSrvRequest\x12\x0b\n\x03req\x18\x01 \x01(\t\" \n\x10\x42\x61sicSrvResponse\x12\x0c\n\x04resp\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rosbag2_test_msgdefs.srv.basic_srv_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BASICSRVREQUEST']._serialized_start=124
  _globals['_BASICSRVREQUEST']._serialized_end=154
  _globals['_BASICSRVRESPONSE']._serialized_start=156
  _globals['_BASICSRVRESPONSE']._serialized_end=188
# @@protoc_insertion_point(module_scope)
