# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rmf_traffic_msgs/srv/register_query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import schedule_identity_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_schedule__identity__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import schedule_query_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_schedule__query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/rmf_traffic_msgs/srv/register_query.proto\x12\x30make87_messages_ros2.humble.rmf_traffic_msgs.srv\x1a!make87_messages/core/header.proto\x1aHmake87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_identity.proto\x1a\x45make87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_query.proto\"\x94\x01\n\x14RegisterQueryRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12N\n\x05query\x18\x02 \x01(\x0b\x32?.make87_messages_ros2.humble.rmf_traffic_msgs.msg.ScheduleQuery\"\xbb\x01\n\x15RegisterQueryResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12S\n\x07node_id\x18\x02 \x01(\x0b\x32\x42.make87_messages_ros2.humble.rmf_traffic_msgs.msg.ScheduleIdentity\x12\x10\n\x08query_id\x18\x03 \x01(\x04\x12\r\n\x05\x65rror\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rmf_traffic_msgs.srv.register_query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_REGISTERQUERYREQUEST']._serialized_start=304
  _globals['_REGISTERQUERYREQUEST']._serialized_end=452
  _globals['_REGISTERQUERYRESPONSE']._serialized_start=455
  _globals['_REGISTERQUERYRESPONSE']._serialized_end=642
# @@protoc_insertion_point(module_scope)
