# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/get_joint_properties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/gazebo_msgs/srv/get_joint_properties.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\"/\n\x19GetJointPropertiesRequest\x12\x12\n\njoint_name\x18\x01 \x01(\t\"\x84\x01\n\x1aGetJointPropertiesResponse\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x61mping\x18\x02 \x03(\x01\x12\x10\n\x08position\x18\x03 \x03(\x01\x12\x0c\n\x04rate\x18\x04 \x03(\x01\x12\x0f\n\x07success\x18\x05 \x01(\x08\x12\x16\n\x0estatus_message\x18\x06 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.get_joint_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETJOINTPROPERTIESREQUEST']._serialized_start=117
  _globals['_GETJOINTPROPERTIESREQUEST']._serialized_end=164
  _globals['_GETJOINTPROPERTIESRESPONSE']._serialized_start=167
  _globals['_GETJOINTPROPERTIESRESPONSE']._serialized_end=299
# @@protoc_insertion_point(module_scope)
