# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ibeo_msgs/msg/object2221.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ibeo_msgs.msg import point2_di_pb2 as make87__messages__ros2_dot_jazzy_dot_ibeo__msgs_dot_msg_dot_point2__di__pb2
from make87_messages_ros2.jazzy.ibeo_msgs.msg import size2_d_pb2 as make87__messages__ros2_dot_jazzy_dot_ibeo__msgs_dot_msg_dot_size2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/ibeo_msgs/msg/object2221.proto\x12(make87_messages_ros2.jazzy.ibeo_msgs.msg\x1a\x38make87_messages_ros2/jazzy/ibeo_msgs/msg/point2_di.proto\x1a\x36make87_messages_ros2/jazzy/ibeo_msgs/msg/size2_d.proto\"\xc1\x08\n\nObject2221\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0b\n\x03\x61ge\x18\x02 \x01(\r\x12\x16\n\x0eprediction_age\x18\x03 \x01(\r\x12\x1a\n\x12relative_timestamp\x18\x04 \x01(\r\x12K\n\x0freference_point\x18\x05 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12Q\n\x15reference_point_sigma\x18\x06 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12I\n\rclosest_point\x18\x07 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12O\n\x13\x62ounding_box_center\x18\x08 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12\x1a\n\x12\x62ounding_box_width\x18\t \x01(\r\x12\x1b\n\x13\x62ounding_box_length\x18\n \x01(\r\x12M\n\x11object_box_center\x18\x0b \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12I\n\x0fobject_box_size\x18\x0c \x01(\x0b\x32\x30.make87_messages_ros2.jazzy.ibeo_msgs.msg.Size2D\x12\x1e\n\x16object_box_orientation\x18\r \x01(\x05\x12M\n\x11\x61\x62solute_velocity\x18\x0e \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12Q\n\x17\x61\x62solute_velocity_sigma\x18\x0f \x01(\x0b\x32\x30.make87_messages_ros2.jazzy.ibeo_msgs.msg.Size2D\x12M\n\x11relative_velocity\x18\x10 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Di\x12\x16\n\x0e\x63lassification\x18\x11 \x01(\r\x12\x1a\n\x12\x63lassification_age\x18\x12 \x01(\r\x12 \n\x18\x63lassification_certainty\x18\x13 \x01(\r\x12 \n\x18number_of_contour_points\x18\x14 \x01(\r\x12N\n\x12\x63ontour_point_list\x18\x15 \x03(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Dib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ibeo_msgs.msg.object2221_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECT2221']._serialized_start=218
  _globals['_OBJECT2221']._serialized_end=1307
# @@protoc_insertion_point(module_scope)
