# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rc_reason_msgs/srv/set_load_carrier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_humble_dot_rc__common__msgs_dot_msg_dot_return__code__pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import load_carrier_model_pb2 as make87__messages__ros2_dot_humble_dot_rc__reason__msgs_dot_msg_dot_load__carrier__model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/rc_reason_msgs/srv/set_load_carrier.proto\x12.make87_messages_ros2.humble.rc_reason_msgs.srv\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/rc_common_msgs/msg/return_code.proto\x1aGmake87_messages_ros2/humble/rc_reason_msgs/msg/load_carrier_model.proto\"\x9d\x01\n\x15SetLoadCarrierRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12V\n\x0cload_carrier\x18\x02 \x01(\x0b\x32@.make87_messages_ros2.humble.rc_reason_msgs.msg.LoadCarrierModel\"\x97\x01\n\x16SetLoadCarrierResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12O\n\x0breturn_code\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.humble.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rc_reason_msgs.srv.set_load_carrier_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETLOADCARRIERREQUEST']._serialized_start=296
  _globals['_SETLOADCARRIERREQUEST']._serialized_end=453
  _globals['_SETLOADCARRIERRESPONSE']._serialized_start=456
  _globals['_SETLOADCARRIERRESPONSE']._serialized_end=607
# @@protoc_insertion_point(module_scope)
