# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_scheduler_msgs/msg/trigger.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg import payload_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__scheduler__msgs_dot_msg_dot_payload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/rmf_scheduler_msgs/msg/trigger.proto\x12\x31make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg\x1a?make87_messages_ros2/jazzy/rmf_scheduler_msgs/msg/payload.proto\"\x93\x01\n\x07Trigger\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncreated_at\x18\x02 \x01(\x03\x12\n\n\x02\x61t\x18\x03 \x01(\x03\x12\r\n\x05group\x18\x04 \x01(\t\x12K\n\x07payload\x18\x05 \x01(\x0b\x32:.make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg.Payloadb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg.trigger_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TRIGGER']._serialized_start=184
  _globals['_TRIGGER']._serialized_end=331
# @@protoc_insertion_point(module_scope)
