# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/camera_aravis2_msgs/srv/calculate_white_balance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.diagnostic_msgs.msg import key_value_pb2 as make87__messages__ros2_dot_humble_dot_diagnostic__msgs_dot_msg_dot_key__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/humble/camera_aravis2_msgs/srv/calculate_white_balance.proto\x12\x33make87_messages_ros2.humble.camera_aravis2_msgs.srv\x1a!make87_messages/core/header.proto\x1a?make87_messages_ros2/humble/diagnostic_msgs/msg/key_value.proto\"L\n\x1c\x43\x61lculateWhiteBalanceRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\"\xb7\x01\n\x1d\x43\x61lculateWhiteBalanceResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x15\n\ris_successful\x18\x02 \x01(\x08\x12Q\n\x0e\x62\x61lance_ratios\x18\x03 \x03(\x0b\x32\x39.make87_messages_ros2.humble.diagnostic_msgs.msg.KeyValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.camera_aravis2_msgs.srv.calculate_white_balance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CALCULATEWHITEBALANCEREQUEST']._serialized_start=238
  _globals['_CALCULATEWHITEBALANCEREQUEST']._serialized_end=314
  _globals['_CALCULATEWHITEBALANCERESPONSE']._serialized_start=317
  _globals['_CALCULATEWHITEBALANCERESPONSE']._serialized_end=500
# @@protoc_insertion_point(module_scope)
