# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/puma_motor_msgs/msg/feedback.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/humble/puma_motor_msgs/msg/feedback.proto\x12/make87_messages_ros2.humble.puma_motor_msgs.msg\x1a!make87_messages/core/header.proto\"\xba\x01\n\x08\x46\x65\x65\x64\x62\x61\x63k\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x15\n\rdevice_number\x18\x02 \x01(\r\x12\x13\n\x0b\x64\x65vice_name\x18\x03 \x01(\t\x12\x12\n\nduty_cycle\x18\x04 \x01(\x02\x12\x0f\n\x07\x63urrent\x18\x05 \x01(\x02\x12\x0e\n\x06travel\x18\x06 \x01(\x01\x12\r\n\x05speed\x18\x07 \x01(\x01\x12\x10\n\x08setpoint\x18\x08 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.puma_motor_msgs.msg.feedback_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FEEDBACK']._serialized_start=151
  _globals['_FEEDBACK']._serialized_end=337
# @@protoc_insertion_point(module_scope)
