# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/topic_tools_interfaces/srv/demux_add.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/topic_tools_interfaces/srv/demux_add.proto\x12\x35make87_messages_ros2.jazzy.topic_tools_interfaces.srv\" \n\x0f\x44\x65muxAddRequest\x12\r\n\x05topic\x18\x01 \x01(\t\"#\n\x10\x44\x65muxAddResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.topic_tools_interfaces.srv.demux_add_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DEMUXADDREQUEST']._serialized_start=128
  _globals['_DEMUXADDREQUEST']._serialized_end=160
  _globals['_DEMUXADDRESPONSE']._serialized_start=162
  _globals['_DEMUXADDRESPONSE']._serialized_end=197
# @@protoc_insertion_point(module_scope)
