# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/esf_status_sens.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/ublox_msgs/msg/esf_status_sens.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\"Y\n\rEsfSTATUSSens\x12\x14\n\x0csens_status1\x18\x01 \x01(\r\x12\x14\n\x0csens_status2\x18\x02 \x01(\r\x12\x0c\n\x04\x66req\x18\x03 \x01(\r\x12\x0e\n\x06\x66\x61ults\x18\x04 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.esf_status_sens_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ESFSTATUSSENS']._serialized_start=110
  _globals['_ESFSTATUSSENS']._serialized_end=199
# @@protoc_insertion_point(module_scope)
