# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/flexbe_msgs/srv/get_userdata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.flexbe_msgs.msg import userdata_info_pb2 as make87__messages__ros2_dot_jazzy_dot_flexbe__msgs_dot_msg_dot_userdata__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/flexbe_msgs/srv/get_userdata.proto\x12*make87_messages_ros2.jazzy.flexbe_msgs.srv\x1a>make87_messages_ros2/jazzy/flexbe_msgs/msg/userdata_info.proto\"*\n\x12GetUserdataRequest\x12\x14\n\x0cuserdata_key\x18\x01 \x01(\t\"\x83\x01\n\x13GetUserdataResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12J\n\x08userdata\x18\x03 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.flexbe_msgs.msg.UserdataInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.flexbe_msgs.srv.get_userdata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETUSERDATAREQUEST']._serialized_start=173
  _globals['_GETUSERDATAREQUEST']._serialized_end=215
  _globals['_GETUSERDATARESPONSE']._serialized_start=218
  _globals['_GETUSERDATARESPONSE']._serialized_end=349
# @@protoc_insertion_point(module_scope)
