# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ptz_action_server_msgs/msg/ptz_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/ptz_action_server_msgs/msg/ptz_state.proto\x12\x35make87_messages_ros2.jazzy.ptz_action_server_msgs.msg\"A\n\x08PtzState\x12\x0c\n\x04mode\x18\x01 \x01(\x05\x12\x0b\n\x03pan\x18\x02 \x01(\x02\x12\x0c\n\x04tilt\x18\x03 \x01(\x02\x12\x0c\n\x04zoom\x18\x04 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ptz_action_server_msgs.msg.ptz_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PTZSTATE']._serialized_start=128
  _globals['_PTZSTATE']._serialized_end=193
# @@protoc_insertion_point(module_scope)
