# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/tf2_msgs/msg/tf_message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import transform_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_transform__stamped__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/tf2_msgs/msg/tf_message.proto\x12\'make87_messages_ros2.jazzy.tf2_msgs.msg\x1a\x44make87_messages_ros2/jazzy/geometry_msgs/msg/transform_stamped.proto\"_\n\tTFMessage\x12R\n\ntransforms\x18\x01 \x03(\x0b\x32>.make87_messages_ros2.jazzy.geometry_msgs.msg.TransformStampedb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.tf2_msgs.msg.tf_message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TFMESSAGE']._serialized_start=171
  _globals['_TFMESSAGE']._serialized_end=266
# @@protoc_insertion_point(module_scope)
