from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectedMapInfo(_message.Message):
    __slots__ = ["frame_id", "x", "y", "width", "height", "min_z", "max_z"]
    FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    MIN_Z_FIELD_NUMBER: _ClassVar[int]
    MAX_Z_FIELD_NUMBER: _ClassVar[int]
    frame_id: str
    x: float
    y: float
    width: float
    height: float
    min_z: float
    max_z: float
    def __init__(self, frame_id: _Optional[str] = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., width: _Optional[float] = ..., height: _Optional[float] = ..., min_z: _Optional[float] = ..., max_z: _Optional[float] = ...) -> None: ...
