# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sensor_msgs/msg/joy_feedback_array.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.sensor_msgs.msg import joy_feedback_pb2 as make87__messages__ros2_dot_rolling_dot_sensor__msgs_dot_msg_dot_joy__feedback__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/sensor_msgs/msg/joy_feedback_array.proto\x12,make87_messages_ros2.rolling.sensor_msgs.msg\x1a?make87_messages_ros2/rolling/sensor_msgs/msg/joy_feedback.proto\"\\\n\x10JoyFeedbackArray\x12H\n\x05\x61rray\x18\x01 \x03(\x0b\x32\x39.make87_messages_ros2.rolling.sensor_msgs.msg.JoyFeedbackb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sensor_msgs.msg.joy_feedback_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_JOYFEEDBACKARRAY']._serialized_start=184
  _globals['_JOYFEEDBACKARRAY']._serialized_end=276
# @@protoc_insertion_point(module_scope)
