# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/trajectory.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.mavros_msgs.msg import position_target_pb2 as make87__messages__ros2_dot_jazzy_dot_mavros__msgs_dot_msg_dot_position__target__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/jazzy/mavros_msgs/msg/trajectory.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\x1a@make87_messages_ros2/jazzy/mavros_msgs/msg/position_target.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x98\x04\n\nTrajectory\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0c\n\x04type\x18\x02 \x01(\r\x12K\n\x07point_1\x18\x03 \x01(\x0b\x32:.make87_messages_ros2.jazzy.mavros_msgs.msg.PositionTarget\x12K\n\x07point_2\x18\x04 \x01(\x0b\x32:.make87_messages_ros2.jazzy.mavros_msgs.msg.PositionTarget\x12K\n\x07point_3\x18\x05 \x01(\x0b\x32:.make87_messages_ros2.jazzy.mavros_msgs.msg.PositionTarget\x12K\n\x07point_4\x18\x06 \x01(\x0b\x32:.make87_messages_ros2.jazzy.mavros_msgs.msg.PositionTarget\x12K\n\x07point_5\x18\x07 \x01(\x0b\x32:.make87_messages_ros2.jazzy.mavros_msgs.msg.PositionTarget\x12\x13\n\x0bpoint_valid\x18\x08 \x03(\r\x12\x0f\n\x07\x63ommand\x18\t \x03(\r\x12\x14\n\x0ctime_horizon\x18\n \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.trajectory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TRAJECTORY']._serialized_start=228
  _globals['_TRAJECTORY']._serialized_end=764
# @@protoc_insertion_point(module_scope)
