# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/sbas_sv_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/sbas_sv_data.proto\x12-make87_messages_ros2.jazzy.ublox_ubx_msgs.msg\"\xa1\x01\n\nSBASSvData\x12\x0c\n\x04svid\x18\x01 \x01(\r\x12\x12\n\nreserved_1\x18\x02 \x01(\r\x12\x0c\n\x04udre\x18\x03 \x01(\r\x12\x0e\n\x06sv_sys\x18\x04 \x01(\r\x12\x12\n\nsv_service\x18\x05 \x01(\r\x12\x12\n\nreserved_2\x18\x06 \x01(\r\x12\x0b\n\x03prc\x18\x07 \x01(\x05\x12\x12\n\nreserved_3\x18\x08 \x03(\r\x12\n\n\x02ic\x18\t \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.sbas_sv_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SBASSVDATA']._serialized_start=116
  _globals['_SBASSVDATA']._serialized_end=277
# @@protoc_insertion_point(module_scope)
