# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_status.proto\x12/make87_messages_ros2.jazzy.rmf_traffic_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\"\xe5\x01\n\x11NegotiationStatus\x12\x18\n\x10\x63onflict_version\x18\x01 \x01(\x04\x12\x14\n\x0cparticipants\x18\x02 \x03(\x04\x12K\n\nstart_time\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12S\n\x12last_response_time\x18\x04 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Timeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.negotiation_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NEGOTIATIONSTATUS']._serialized_start=188
  _globals['_NEGOTIATIONSTATUS']._serialized_end=417
# @@protoc_insertion_point(module_scope)
