# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/game_controller_spl_interfaces/msg/team_info14.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.game_controller_spl_interfaces.msg import robot_info14_pb2 as make87__messages__ros2_dot_rolling_dot_game__controller__spl__interfaces_dot_msg_dot_robot__info14__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/rolling/game_controller_spl_interfaces/msg/team_info14.proto\x12?make87_messages_ros2.rolling.game_controller_spl_interfaces.msg\x1aRmake87_messages_ros2/rolling/game_controller_spl_interfaces/msg/robot_info14.proto\"\xe8\x01\n\nTeamInfo14\x12\x13\n\x0bteam_number\x18\x01 \x01(\r\x12\x13\n\x0bteam_colour\x18\x02 \x01(\r\x12\r\n\x05score\x18\x03 \x01(\r\x12\x14\n\x0cpenalty_shot\x18\x04 \x01(\r\x12\x14\n\x0csingle_shots\x18\x05 \x01(\r\x12\x16\n\x0emessage_budget\x18\x06 \x01(\r\x12]\n\x07players\x18\x07 \x03(\x0b\x32L.make87_messages_ros2.rolling.game_controller_spl_interfaces.msg.RobotInfo14b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.game_controller_spl_interfaces.msg.team_info14_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TEAMINFO14']._serialized_start=235
  _globals['_TEAMINFO14']._serialized_end=467
# @@protoc_insertion_point(module_scope)
