# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosapi_msgs/srv/service_node.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/rosapi_msgs/srv/service_node.proto\x12,make87_messages_ros2.rolling.rosapi_msgs.srv\"%\n\x12ServiceNodeRequest\x12\x0f\n\x07service\x18\x01 \x01(\t\"#\n\x13ServiceNodeResponse\x12\x0c\n\x04node\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosapi_msgs.srv.service_node_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SERVICENODEREQUEST']._serialized_start=113
  _globals['_SERVICENODEREQUEST']._serialized_end=150
  _globals['_SERVICENODERESPONSE']._serialized_start=152
  _globals['_SERVICENODERESPONSE']._serialized_end=187
# @@protoc_insertion_point(module_scope)
