# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosbridge_msgs/msg/connected_client.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/rosbridge_msgs/msg/connected_client.proto\x12/make87_messages_ros2.rolling.rosbridge_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\"y\n\x0f\x43onnectedClient\x12\x12\n\nip_address\x18\x01 \x01(\t\x12R\n\x0f\x63onnection_time\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Timeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosbridge_msgs.msg.connected_client_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONNECTEDCLIENT']._serialized_start=187
  _globals['_CONNECTEDCLIENT']._serialized_end=308
# @@protoc_insertion_point(module_scope)
