# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_fleet_msgs/msg/speed_limit_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import speed_limited_lane_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__fleet__msgs_dot_msg_dot_speed__limited__lane__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/rmf_fleet_msgs/msg/speed_limit_request.proto\x12-make87_messages_ros2.jazzy.rmf_fleet_msgs.msg\x1a\x46make87_messages_ros2/jazzy/rmf_fleet_msgs/msg/speed_limited_lane.proto\"\x95\x01\n\x11SpeedLimitRequest\x12\x12\n\nfleet_name\x18\x01 \x01(\t\x12U\n\x0cspeed_limits\x18\x02 \x03(\x0b\x32?.make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.SpeedLimitedLane\x12\x15\n\rremove_limits\x18\x03 \x03(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.speed_limit_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SPEEDLIMITREQUEST']._serialized_start=195
  _globals['_SPEEDLIMITREQUEST']._serialized_end=344
# @@protoc_insertion_point(module_scope)
