# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/sensor_msgs/msg/camera_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import region_of_interest_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_region__of__interest__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/humble/sensor_msgs/msg/camera_info.proto\x12+make87_messages_ros2.humble.sensor_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x44make87_messages_ros2/humble/sensor_msgs/msg/region_of_interest.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xd8\x02\n\nCameraInfo\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0e\n\x06height\x18\x03 \x01(\r\x12\r\n\x05width\x18\x04 \x01(\r\x12\x18\n\x10\x64istortion_model\x18\x05 \x01(\t\x12\t\n\x01\x64\x18\x06 \x03(\x01\x12\t\n\x01k\x18\x07 \x03(\x01\x12\t\n\x01r\x18\x08 \x03(\x01\x12\t\n\x01p\x18\t \x03(\x01\x12\x11\n\tbinning_x\x18\n \x01(\r\x12\x11\n\tbinning_y\x18\x0b \x01(\r\x12J\n\x03roi\x18\x0c \x01(\x0b\x32=.make87_messages_ros2.humble.sensor_msgs.msg.RegionOfInterestb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.sensor_msgs.msg.camera_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CAMERAINFO']._serialized_start=271
  _globals['_CAMERAINFO']._serialized_end=615
# @@protoc_insertion_point(module_scope)
