# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rcl_interfaces/srv/describe_parameters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rcl_interfaces.msg import parameter_descriptor_pb2 as make87__messages__ros2_dot_humble_dot_rcl__interfaces_dot_msg_dot_parameter__descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/humble/rcl_interfaces/srv/describe_parameters.proto\x12.make87_messages_ros2.humble.rcl_interfaces.srv\x1a!make87_messages/core/header.proto\x1aImake87_messages_ros2/humble/rcl_interfaces/msg/parameter_descriptor.proto\"X\n\x19\x44\x65scribeParametersRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05names\x18\x02 \x03(\t\"\xa4\x01\n\x1a\x44\x65scribeParametersResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12X\n\x0b\x64\x65scriptors\x18\x02 \x03(\x0b\x32\x43.make87_messages_ros2.humble.rcl_interfaces.msg.ParameterDescriptorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rcl_interfaces.srv.describe_parameters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DESCRIBEPARAMETERSREQUEST']._serialized_start=234
  _globals['_DESCRIBEPARAMETERSREQUEST']._serialized_end=322
  _globals['_DESCRIBEPARAMETERSRESPONSE']._serialized_start=325
  _globals['_DESCRIBEPARAMETERSRESPONSE']._serialized_end=489
# @@protoc_insertion_point(module_scope)
