# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/lifecycle_msgs/srv/get_available_states.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.lifecycle_msgs.msg import state_pb2 as make87__messages__ros2_dot_humble_dot_lifecycle__msgs_dot_msg_dot_state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/humble/lifecycle_msgs/srv/get_available_states.proto\x12.make87_messages_ros2.humble.lifecycle_msgs.srv\x1a!make87_messages/core/header.proto\x1a:make87_messages_ros2/humble/lifecycle_msgs/msg/state.proto\"I\n\x19GetAvailableStatesRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\"\x9b\x01\n\x1aGetAvailableStatesResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12O\n\x10\x61vailable_states\x18\x02 \x03(\x0b\x32\x35.make87_messages_ros2.humble.lifecycle_msgs.msg.Stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.lifecycle_msgs.srv.get_available_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETAVAILABLESTATESREQUEST']._serialized_start=220
  _globals['_GETAVAILABLESTATESREQUEST']._serialized_end=293
  _globals['_GETAVAILABLESTATESRESPONSE']._serialized_start=296
  _globals['_GETAVAILABLESTATESRESPONSE']._serialized_end=451
# @@protoc_insertion_point(module_scope)
