# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_map2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rtabmap_msgs.msg import map_data_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_map__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_map2.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.srv\x1a:make87_messages_ros2/jazzy/rtabmap_msgs/msg/map_data.proto\"\xc1\x01\n\x0eGetMap2Request\x12\x12\n\nglobal_map\x18\x01 \x01(\x08\x12\x11\n\toptimized\x18\x02 \x01(\x08\x12\x13\n\x0bwith_images\x18\x03 \x01(\x08\x12\x12\n\nwith_scans\x18\x04 \x01(\x08\x12\x16\n\x0ewith_user_data\x18\x05 \x01(\x08\x12\x12\n\nwith_grids\x18\x06 \x01(\x08\x12\x12\n\nwith_words\x18\x07 \x01(\x08\x12\x1f\n\x17with_global_descriptors\x18\x08 \x01(\x08\"U\n\x0fGetMap2Response\x12\x42\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.rtabmap_msgs.msg.MapDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.srv.get_map2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETMAP2REQUEST']._serialized_start=168
  _globals['_GETMAP2REQUEST']._serialized_end=361
  _globals['_GETMAP2RESPONSE']._serialized_start=363
  _globals['_GETMAP2RESPONSE']._serialized_end=448
# @@protoc_insertion_point(module_scope)
