# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ur_msgs/srv/set_speed_slider_fraction.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/ur_msgs/srv/set_speed_slider_fraction.proto\x12(make87_messages_ros2.rolling.ur_msgs.srv\">\n\x1dSetSpeedSliderFractionRequest\x12\x1d\n\x15speed_slider_fraction\x18\x01 \x01(\x01\"1\n\x1eSetSpeedSliderFractionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ur_msgs.srv.set_speed_slider_fraction_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETSPEEDSLIDERFRACTIONREQUEST']._serialized_start=118
  _globals['_SETSPEEDSLIDERFRACTIONREQUEST']._serialized_end=180
  _globals['_SETSPEEDSLIDERFRACTIONRESPONSE']._serialized_start=182
  _globals['_SETSPEEDSLIDERFRACTIONRESPONSE']._serialized_end=231
# @@protoc_insertion_point(module_scope)
