# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/participants.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import participant_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__traffic__msgs_dot_msg_dot_participant__pb2
from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import schedule_identity_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__traffic__msgs_dot_msg_dot_schedule__identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/participants.proto\x12/make87_messages_ros2.jazzy.rmf_traffic_msgs.msg\x1a\x41make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/participant.proto\x1aGmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/schedule_identity.proto\"\xb6\x01\n\x0cParticipants\x12R\n\x07node_id\x18\x01 \x01(\x0b\x32\x41.make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.ScheduleIdentity\x12R\n\x0cparticipants\x18\x02 \x03(\x0b\x32<.make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.Participantb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.participants_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PARTICIPANTS']._serialized_start=260
  _globals['_PARTICIPANTS']._serialized_end=442
# @@protoc_insertion_point(module_scope)
