# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rcl_interfaces/msg/parameter_event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.rcl_interfaces.msg import parameter_pb2 as make87__messages__ros2_dot_jazzy_dot_rcl__interfaces_dot_msg_dot_parameter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/rcl_interfaces/msg/parameter_event.proto\x12-make87_messages_ros2.jazzy.rcl_interfaces.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a=make87_messages_ros2/jazzy/rcl_interfaces/msg/parameter.proto\"\xe4\x02\n\x0eParameterEvent\x12\x46\n\x05stamp\x18\x01 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x0c\n\x04node\x18\x02 \x01(\t\x12P\n\x0enew_parameters\x18\x03 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.rcl_interfaces.msg.Parameter\x12T\n\x12\x63hanged_parameters\x18\x04 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.rcl_interfaces.msg.Parameter\x12T\n\x12\x64\x65leted_parameters\x18\x05 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.rcl_interfaces.msg.Parameterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rcl_interfaces.msg.parameter_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PARAMETEREVENT']._serialized_start=244
  _globals['_PARAMETEREVENT']._serialized_end=600
# @@protoc_insertion_point(module_scope)
