# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosbag2_interfaces/srv/burst.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/rosbag2_interfaces/srv/burst.proto\x12\x33make87_messages_ros2.rolling.rosbag2_interfaces.srv\"$\n\x0c\x42urstRequest\x12\x14\n\x0cnum_messages\x18\x01 \x01(\x04\"\'\n\rBurstResponse\x12\x16\n\x0e\x61\x63tually_burst\x18\x01 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosbag2_interfaces.srv.burst_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BURSTREQUEST']._serialized_start=120
  _globals['_BURSTREQUEST']._serialized_end=156
  _globals['_BURSTRESPONSE']._serialized_start=158
  _globals['_BURSTRESPONSE']._serialized_end=197
# @@protoc_insertion_point(module_scope)
