# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/system_modes_msgs/srv/change_mode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/system_modes_msgs/srv/change_mode.proto\x12\x30make87_messages_ros2.jazzy.system_modes_msgs.srv\"&\n\x11\x43hangeModeRequest\x12\x11\n\tmode_name\x18\x01 \x01(\t\"%\n\x12\x43hangeModeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.system_modes_msgs.srv.change_mode_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CHANGEMODEREQUEST']._serialized_start=120
  _globals['_CHANGEMODEREQUEST']._serialized_end=158
  _globals['_CHANGEMODERESPONSE']._serialized_start=160
  _globals['_CHANGEMODERESPONSE']._serialized_end=197
# @@protoc_insertion_point(module_scope)
