# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/tuw_geo_msgs/msg/geo_json_properties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/tuw_geo_msgs/msg/geo_json_properties.proto\x12-make87_messages_ros2.rolling.tuw_geo_msgs.msg\"_\n\x11GeoJSONProperties\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x18\n\x10\x65nflation_radius\x18\x03 \x03(\x01\x12\x16\n\x0e\x62ondary_radius\x18\x04 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.tuw_geo_msgs.msg.geo_json_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GEOJSONPROPERTIES']._serialized_start=122
  _globals['_GEOJSONPROPERTIES']._serialized_end=217
# @@protoc_insertion_point(module_scope)
