# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/tuw_multi_robot_msgs/srv/station_manager_station_protocol.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.tuw_multi_robot_msgs.msg import station_pb2 as make87__messages__ros2_dot_humble_dot_tuw__multi__robot__msgs_dot_msg_dot_station__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n[make87_messages_ros2/humble/tuw_multi_robot_msgs/srv/station_manager_station_protocol.proto\x12\x34make87_messages_ros2.humble.tuw_multi_robot_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x42make87_messages_ros2/humble/tuw_multi_robot_msgs/msg/station.proto\"\xb5\x01\n$StationManagerStationProtocolRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07request\x18\x02 \x01(\t\x12N\n\x07station\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.humble.tuw_multi_robot_msgs.msg.Station\"g\n%StationManagerStationProtocolResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08response\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.tuw_multi_robot_msgs.srv.station_manager_station_protocol_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STATIONMANAGERSTATIONPROTOCOLREQUEST']._serialized_start=253
  _globals['_STATIONMANAGERSTATIONPROTOCOLREQUEST']._serialized_end=434
  _globals['_STATIONMANAGERSTATIONPROTOCOLRESPONSE']._serialized_start=436
  _globals['_STATIONMANAGERSTATIONPROTOCOLRESPONSE']._serialized_end=539
# @@protoc_insertion_point(module_scope)
