# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rcl_interfaces/msg/parameter_value.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/rcl_interfaces/msg/parameter_value.proto\x12.make87_messages_ros2.humble.rcl_interfaces.msg\x1a!make87_messages/core/header.proto\"\xac\x02\n\x0eParameterValue\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x12\n\nbool_value\x18\x03 \x01(\x08\x12\x15\n\rinteger_value\x18\x04 \x01(\x03\x12\x14\n\x0c\x64ouble_value\x18\x05 \x01(\x01\x12\x14\n\x0cstring_value\x18\x06 \x01(\t\x12\x18\n\x10\x62yte_array_value\x18\x07 \x03(\r\x12\x18\n\x10\x62ool_array_value\x18\x08 \x03(\x08\x12\x1b\n\x13integer_array_value\x18\t \x03(\x03\x12\x1a\n\x12\x64ouble_array_value\x18\n \x03(\x01\x12\x1a\n\x12string_array_value\x18\x0b \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rcl_interfaces.msg.parameter_value_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PARAMETERVALUE']._serialized_start=156
  _globals['_PARAMETERVALUE']._serialized_end=456
# @@protoc_insertion_point(module_scope)
