from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MonitorReport(_message.Message):
    __slots__ = ["header", "ros2_header", "fault", "shutoff", "shutoff_on_motion", "stationary", "fault_test", "fault_system", "fault_steer", "fault_brake", "fault_thrtl", "fault_gear", "fault_ulc", "fault_vehicle_velocity", "fault_steer_feedback", "fault_steer_input", "fault_steer_param", "fault_steer_limit", "fault_steer_override", "fault_steer_cmd", "fault_steer_cmd_rate", "fault_steer_cmd_en", "fault_steer_cmd_sys", "fault_steer_cmd_ovr", "fault_brake_feedback", "fault_brake_input", "fault_brake_param", "fault_brake_limit", "fault_brake_override", "fault_brake_cmd", "fault_brake_cmd_ulc", "fault_brake_cmd_en", "fault_brake_cmd_sys", "fault_brake_cmd_ovr", "fault_thrtl_feedback", "fault_thrtl_input", "fault_thrtl_param", "fault_thrtl_limit", "fault_thrtl_override", "fault_thrtl_cmd", "fault_thrtl_cmd_ulc", "fault_thrtl_cmd_en", "fault_thrtl_cmd_sys", "fault_thrtl_cmd_ovr", "fault_gear_feedback", "fault_gear_input", "fault_gear_param", "fault_gear_override", "fault_gear_cmd", "fault_gear_cmd_ulc", "fault_system_param", "steer_cmd_match_oem", "steer_cmd_match_dbw", "brake_cmd_match_oem", "brake_cmd_match_dbw", "thrtl_cmd_match_oem", "thrtl_cmd_match_dbw", "gear_cmd_match_oem", "gear_cmd_match_dbw"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    FAULT_FIELD_NUMBER: _ClassVar[int]
    SHUTOFF_FIELD_NUMBER: _ClassVar[int]
    SHUTOFF_ON_MOTION_FIELD_NUMBER: _ClassVar[int]
    STATIONARY_FIELD_NUMBER: _ClassVar[int]
    FAULT_TEST_FIELD_NUMBER: _ClassVar[int]
    FAULT_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_FIELD_NUMBER: _ClassVar[int]
    FAULT_ULC_FIELD_NUMBER: _ClassVar[int]
    FAULT_VEHICLE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_FEEDBACK_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_INPUT_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_PARAM_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_LIMIT_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_CMD_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_CMD_RATE_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_CMD_EN_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_CMD_SYS_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_CMD_OVR_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_FEEDBACK_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_INPUT_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_PARAM_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_LIMIT_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_CMD_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_CMD_ULC_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_CMD_EN_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_CMD_SYS_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_CMD_OVR_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_FEEDBACK_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_INPUT_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_PARAM_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_LIMIT_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_CMD_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_CMD_ULC_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_CMD_EN_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_CMD_SYS_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_CMD_OVR_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_FEEDBACK_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_INPUT_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_PARAM_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_CMD_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_CMD_ULC_FIELD_NUMBER: _ClassVar[int]
    FAULT_SYSTEM_PARAM_FIELD_NUMBER: _ClassVar[int]
    STEER_CMD_MATCH_OEM_FIELD_NUMBER: _ClassVar[int]
    STEER_CMD_MATCH_DBW_FIELD_NUMBER: _ClassVar[int]
    BRAKE_CMD_MATCH_OEM_FIELD_NUMBER: _ClassVar[int]
    BRAKE_CMD_MATCH_DBW_FIELD_NUMBER: _ClassVar[int]
    THRTL_CMD_MATCH_OEM_FIELD_NUMBER: _ClassVar[int]
    THRTL_CMD_MATCH_DBW_FIELD_NUMBER: _ClassVar[int]
    GEAR_CMD_MATCH_OEM_FIELD_NUMBER: _ClassVar[int]
    GEAR_CMD_MATCH_DBW_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    fault: bool
    shutoff: bool
    shutoff_on_motion: bool
    stationary: bool
    fault_test: int
    fault_system: int
    fault_steer: int
    fault_brake: int
    fault_thrtl: int
    fault_gear: int
    fault_ulc: int
    fault_vehicle_velocity: int
    fault_steer_feedback: int
    fault_steer_input: int
    fault_steer_param: int
    fault_steer_limit: int
    fault_steer_override: int
    fault_steer_cmd: int
    fault_steer_cmd_rate: int
    fault_steer_cmd_en: int
    fault_steer_cmd_sys: int
    fault_steer_cmd_ovr: int
    fault_brake_feedback: int
    fault_brake_input: int
    fault_brake_param: int
    fault_brake_limit: int
    fault_brake_override: int
    fault_brake_cmd: int
    fault_brake_cmd_ulc: int
    fault_brake_cmd_en: int
    fault_brake_cmd_sys: int
    fault_brake_cmd_ovr: int
    fault_thrtl_feedback: int
    fault_thrtl_input: int
    fault_thrtl_param: int
    fault_thrtl_limit: int
    fault_thrtl_override: int
    fault_thrtl_cmd: int
    fault_thrtl_cmd_ulc: int
    fault_thrtl_cmd_en: int
    fault_thrtl_cmd_sys: int
    fault_thrtl_cmd_ovr: int
    fault_gear_feedback: int
    fault_gear_input: int
    fault_gear_param: int
    fault_gear_override: int
    fault_gear_cmd: int
    fault_gear_cmd_ulc: int
    fault_system_param: int
    steer_cmd_match_oem: bool
    steer_cmd_match_dbw: bool
    brake_cmd_match_oem: bool
    brake_cmd_match_dbw: bool
    thrtl_cmd_match_oem: bool
    thrtl_cmd_match_dbw: bool
    gear_cmd_match_oem: bool
    gear_cmd_match_dbw: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., fault: bool = ..., shutoff: bool = ..., shutoff_on_motion: bool = ..., stationary: bool = ..., fault_test: _Optional[int] = ..., fault_system: _Optional[int] = ..., fault_steer: _Optional[int] = ..., fault_brake: _Optional[int] = ..., fault_thrtl: _Optional[int] = ..., fault_gear: _Optional[int] = ..., fault_ulc: _Optional[int] = ..., fault_vehicle_velocity: _Optional[int] = ..., fault_steer_feedback: _Optional[int] = ..., fault_steer_input: _Optional[int] = ..., fault_steer_param: _Optional[int] = ..., fault_steer_limit: _Optional[int] = ..., fault_steer_override: _Optional[int] = ..., fault_steer_cmd: _Optional[int] = ..., fault_steer_cmd_rate: _Optional[int] = ..., fault_steer_cmd_en: _Optional[int] = ..., fault_steer_cmd_sys: _Optional[int] = ..., fault_steer_cmd_ovr: _Optional[int] = ..., fault_brake_feedback: _Optional[int] = ..., fault_brake_input: _Optional[int] = ..., fault_brake_param: _Optional[int] = ..., fault_brake_limit: _Optional[int] = ..., fault_brake_override: _Optional[int] = ..., fault_brake_cmd: _Optional[int] = ..., fault_brake_cmd_ulc: _Optional[int] = ..., fault_brake_cmd_en: _Optional[int] = ..., fault_brake_cmd_sys: _Optional[int] = ..., fault_brake_cmd_ovr: _Optional[int] = ..., fault_thrtl_feedback: _Optional[int] = ..., fault_thrtl_input: _Optional[int] = ..., fault_thrtl_param: _Optional[int] = ..., fault_thrtl_limit: _Optional[int] = ..., fault_thrtl_override: _Optional[int] = ..., fault_thrtl_cmd: _Optional[int] = ..., fault_thrtl_cmd_ulc: _Optional[int] = ..., fault_thrtl_cmd_en: _Optional[int] = ..., fault_thrtl_cmd_sys: _Optional[int] = ..., fault_thrtl_cmd_ovr: _Optional[int] = ..., fault_gear_feedback: _Optional[int] = ..., fault_gear_input: _Optional[int] = ..., fault_gear_param: _Optional[int] = ..., fault_gear_override: _Optional[int] = ..., fault_gear_cmd: _Optional[int] = ..., fault_gear_cmd_ulc: _Optional[int] = ..., fault_system_param: _Optional[int] = ..., steer_cmd_match_oem: bool = ..., steer_cmd_match_dbw: bool = ..., brake_cmd_match_oem: bool = ..., brake_cmd_match_dbw: bool = ..., thrtl_cmd_match_oem: bool = ..., thrtl_cmd_match_dbw: bool = ..., gear_cmd_match_oem: bool = ..., gear_cmd_match_dbw: bool = ...) -> None: ...
