# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/cartographer_ros_msgs/srv/get_trajectory_states.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.cartographer_ros_msgs.msg import status_response_pb2 as make87__messages__ros2_dot_rolling_dot_cartographer__ros__msgs_dot_msg_dot_status__response__pb2
from make87_messages_ros2.rolling.cartographer_ros_msgs.msg import trajectory_states_pb2 as make87__messages__ros2_dot_rolling_dot_cartographer__ros__msgs_dot_msg_dot_trajectory__states__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/cartographer_ros_msgs/srv/get_trajectory_states.proto\x12\x36make87_messages_ros2.rolling.cartographer_ros_msgs.srv\x1aLmake87_messages_ros2/rolling/cartographer_ros_msgs/msg/status_response.proto\x1aNmake87_messages_ros2/rolling/cartographer_ros_msgs/msg/trajectory_states.proto\"\x1c\n\x1aGetTrajectoryStatesRequest\"\xda\x01\n\x1bGetTrajectoryStatesResponse\x12V\n\x06status\x18\x01 \x01(\x0b\x32\x46.make87_messages_ros2.rolling.cartographer_ros_msgs.msg.StatusResponse\x12\x63\n\x11trajectory_states\x18\x02 \x01(\x0b\x32H.make87_messages_ros2.rolling.cartographer_ros_msgs.msg.TrajectoryStatesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.cartographer_ros_msgs.srv.get_trajectory_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETTRAJECTORYSTATESREQUEST']._serialized_start=300
  _globals['_GETTRAJECTORYSTATESREQUEST']._serialized_end=328
  _globals['_GETTRAJECTORYSTATESRESPONSE']._serialized_start=331
  _globals['_GETTRAJECTORYSTATESRESPONSE']._serialized_end=549
# @@protoc_insertion_point(module_scope)
