# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosidl_generator_py/msg/string_arrays.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/rosidl_generator_py/msg/string_arrays.proto\x12\x34make87_messages_ros2.rolling.rosidl_generator_py.msg\"\x97\x03\n\x0cStringArrays\x12$\n\x1cub_string_static_array_value\x18\x01 \x03(\t\x12 \n\x18ub_string_ub_array_value\x18\x02 \x03(\t\x12%\n\x1dub_string_dynamic_array_value\x18\x03 \x03(\t\x12\"\n\x1astring_dynamic_array_value\x18\x04 \x03(\t\x12!\n\x19string_static_array_value\x18\x05 \x03(\t\x12\"\n\x1astring_bounded_array_value\x18\x06 \x03(\t\x12&\n\x1e\x64\x65\x66_string_dynamic_array_value\x18\x07 \x03(\t\x12%\n\x1d\x64\x65\x66_string_static_array_value\x18\x08 \x03(\t\x12&\n\x1e\x64\x65\x66_string_bounded_array_value\x18\t \x03(\t\x12\x1a\n\x12\x64\x65\x66_various_quotes\x18\n \x03(\t\x12\x1a\n\x12\x64\x65\x66_various_commas\x18\x0b \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosidl_generator_py.msg.string_arrays_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STRINGARRAYS']._serialized_start=131
  _globals['_STRINGARRAYS']._serialized_end=538
# @@protoc_insertion_point(module_scope)
