# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/set_hand_eye_calibration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/rc_reason_msgs/srv/set_hand_eye_calibration.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\"y\n\x1cSetHandEyeCalibrationRequest\x12\x42\n\x04pose\x18\x01 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\x15\n\rrobot_mounted\x18\x02 \x01(\x08\"Q\n\x1dSetHandEyeCalibrationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.set_hand_eye_calibration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETHANDEYECALIBRATIONREQUEST']._serialized_start=190
  _globals['_SETHANDEYECALIBRATIONREQUEST']._serialized_end=311
  _globals['_SETHANDEYECALIBRATIONRESPONSE']._serialized_start=313
  _globals['_SETHANDEYECALIBRATIONRESPONSE']._serialized_end=394
# @@protoc_insertion_point(module_scope)
