# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/nav_cov.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/rolling/ublox_msgs/msg/nav_cov.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\"\xda\x02\n\x06NavCOV\x12\r\n\x05i_tow\x18\x01 \x01(\r\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x15\n\rpos_cov_valid\x18\x03 \x01(\r\x12\x15\n\rvel_cov_valid\x18\x04 \x01(\r\x12\x12\n\nreserved_0\x18\x05 \x03(\r\x12\x12\n\npos_cov_nn\x18\x06 \x01(\x02\x12\x12\n\npos_cov_ne\x18\x07 \x01(\x02\x12\x12\n\npos_cov_nd\x18\x08 \x01(\x02\x12\x12\n\npos_cov_ee\x18\t \x01(\x02\x12\x12\n\npos_cov_ed\x18\n \x01(\x02\x12\x12\n\npos_cov_dd\x18\x0b \x01(\x02\x12\x12\n\nvel_cov_nn\x18\x0c \x01(\x02\x12\x12\n\nvel_cov_ne\x18\r \x01(\x02\x12\x12\n\nvel_cov_nd\x18\x0e \x01(\x02\x12\x12\n\nvel_cov_ee\x18\x0f \x01(\x02\x12\x12\n\nvel_cov_ed\x18\x10 \x01(\x02\x12\x12\n\nvel_cov_dd\x18\x11 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.nav_cov_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NAVCOV']._serialized_start=107
  _globals['_NAVCOV']._serialized_end=453
# @@protoc_insertion_point(module_scope)
