# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/msg/scan_descriptor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rtabmap_msgs.msg import global_descriptor_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_global__descriptor__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import laser_scan_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_laser__scan__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/rtabmap_msgs/msg/scan_descriptor.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.msg\x1a\x43make87_messages_ros2/jazzy/rtabmap_msgs/msg/global_descriptor.proto\x1a;make87_messages_ros2/jazzy/sensor_msgs/msg/laser_scan.proto\x1a=make87_messages_ros2/jazzy/sensor_msgs/msg/point_cloud2.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xbd\x02\n\x0eScanDescriptor\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x43\n\x04scan\x18\x02 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.sensor_msgs.msg.LaserScan\x12K\n\nscan_cloud\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.sensor_msgs.msg.PointCloud2\x12X\n\x11global_descriptor\x18\x04 \x01(\x0b\x32=.make87_messages_ros2.jazzy.rtabmap_msgs.msg.GlobalDescriptorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.msg.scan_descriptor_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCANDESCRIPTOR']._serialized_start=362
  _globals['_SCANDESCRIPTOR']._serialized_end=679
# @@protoc_insertion_point(module_scope)
