# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/delphi_srr_msgs/msg/srr_status2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/delphi_srr_msgs/msg/srr_status2.proto\x12\x30make87_messages_ros2.rolling.delphi_srr_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xeb\x03\n\nSrrStatus2\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x1f\n\x17\x63\x61n_tx_alignment_status\x18\x02 \x01(\r\x12\x19\n\x11\x63\x61n_tx_comm_error\x18\x03 \x01(\x08\x12\"\n\x1a\x63\x61n_tx_steering_angle_sign\x18\x04 \x01(\x08\x12\x1c\n\x14\x63\x61n_tx_yaw_rate_bias\x18\x05 \x01(\x02\x12\"\n\x1a\x63\x61n_tx_veh_spd_comp_factor\x18\x06 \x01(\x02\x12\x1d\n\x15\x63\x61n_tx_sw_version_dsp\x18\x07 \x01(\r\x12\x1a\n\x12\x63\x61n_tx_temperature\x18\x08 \x01(\x05\x12\x1f\n\x17\x63\x61n_tx_range_perf_error\x18\t \x01(\x08\x12\x1d\n\x15\x63\x61n_tx_overheat_error\x18\n \x01(\x08\x12\x1d\n\x15\x63\x61n_tx_internal_error\x18\x0b \x01(\x08\x12\x1f\n\x17\x63\x61n_tx_xcvr_operational\x18\x0c \x01(\x08\x12\x1d\n\x15\x63\x61n_tx_steering_angle\x18\r \x01(\r\x12\x1e\n\x16\x63\x61n_tx_rolling_count_2\x18\x0e \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.delphi_srr_msgs.msg.srr_status2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SRRSTATUS2']._serialized_start=177
  _globals['_SRRSTATUS2']._serialized_end=668
# @@protoc_insertion_point(module_scope)
