# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/turtlesim_msgs/srv/spawn.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/rolling/turtlesim_msgs/srv/spawn.proto\x12/make87_messages_ros2.rolling.turtlesim_msgs.srv\"A\n\x0cSpawnRequest\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\r\n\x05theta\x18\x03 \x01(\x02\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x1d\n\rSpawnResponse\x12\x0c\n\x04name\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.turtlesim_msgs.srv.spawn_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SPAWNREQUEST']._serialized_start=112
  _globals['_SPAWNREQUEST']._serialized_end=177
  _globals['_SPAWNRESPONSE']._serialized_start=179
  _globals['_SPAWNRESPONSE']._serialized_end=208
# @@protoc_insertion_point(module_scope)
