# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gc_spl_interfaces/msg/rcgcrd4.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/gc_spl_interfaces/msg/rcgcrd4.proto\x12\x30make87_messages_ros2.jazzy.gc_spl_interfaces.msg\"m\n\x07RCGCRD4\x12\x12\n\nplayer_num\x18\x01 \x01(\r\x12\x10\n\x08team_num\x18\x02 \x01(\r\x12\x0e\n\x06\x66\x61llen\x18\x03 \x01(\r\x12\x0c\n\x04pose\x18\x04 \x03(\x02\x12\x10\n\x08\x62\x61ll_age\x18\x05 \x01(\x02\x12\x0c\n\x04\x62\x61ll\x18\x06 \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gc_spl_interfaces.msg.rcgcrd4_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RCGCRD4']._serialized_start=116
  _globals['_RCGCRD4']._serialized_end=225
# @@protoc_insertion_point(module_scope)
