# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/blockade_heartbeat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import blockade_status_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_blockade__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/blockade_heartbeat.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1aGmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/blockade_status.proto\"~\n\x11\x42lockadeHeartbeat\x12S\n\x08statuses\x18\x01 \x03(\x0b\x32\x41.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.BlockadeStatus\x12\x14\n\x0chas_gridlock\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.blockade_heartbeat_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BLOCKADEHEARTBEAT']._serialized_start=202
  _globals['_BLOCKADEHEARTBEAT']._serialized_end=328
# @@protoc_insertion_point(module_scope)
