# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/mavros_msgs/srv/gimbal_manager_set_roi.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/humble/mavros_msgs/srv/gimbal_manager_set_roi.proto\x12+make87_messages_ros2.humble.mavros_msgs.srv\x1a!make87_messages/core/header.proto\"\xf7\x01\n\x1aGimbalManagerSetRoiRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04mode\x18\x02 \x01(\r\x12\x18\n\x10gimbal_device_id\x18\x03 \x01(\r\x12\x10\n\x08latitude\x18\x04 \x01(\x02\x12\x11\n\tlongitude\x18\x05 \x01(\x02\x12\x10\n\x08\x61ltitude\x18\x06 \x01(\x02\x12\x14\n\x0cpitch_offset\x18\x07 \x01(\x02\x12\x13\n\x0broll_offset\x18\x08 \x01(\x02\x12\x12\n\nyaw_offset\x18\t \x01(\x02\x12\r\n\x05sysid\x18\n \x01(\r\"l\n\x1bGimbalManagerSetRoiResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0e\n\x06result\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.mavros_msgs.srv.gimbal_manager_set_roi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GIMBALMANAGERSETROIREQUEST']._serialized_start=157
  _globals['_GIMBALMANAGERSETROIREQUEST']._serialized_end=404
  _globals['_GIMBALMANAGERSETROIRESPONSE']._serialized_start=406
  _globals['_GIMBALMANAGERSETROIRESPONSE']._serialized_end=514
# @@protoc_insertion_point(module_scope)
