# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/mavros_msgs/srv/file_list.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.mavros_msgs.msg import file_entry_pb2 as make87__messages__ros2_dot_humble_dot_mavros__msgs_dot_msg_dot_file__entry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/humble/mavros_msgs/srv/file_list.proto\x12+make87_messages_ros2.humble.mavros_msgs.srv\x1a!make87_messages/core/header.proto\x1a<make87_messages_ros2/humble/mavros_msgs/msg/file_entry.proto\"Q\n\x0f\x46ileListRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08\x64ir_path\x18\x02 \x01(\t\"\xa8\x01\n\x10\x46ileListResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x44\n\x04list\x18\x02 \x03(\x0b\x32\x36.make87_messages_ros2.humble.mavros_msgs.msg.FileEntry\x12\x0f\n\x07success\x18\x03 \x01(\x08\x12\x0f\n\x07r_errno\x18\x04 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.mavros_msgs.srv.file_list_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FILELISTREQUEST']._serialized_start=205
  _globals['_FILELISTREQUEST']._serialized_end=286
  _globals['_FILELISTRESPONSE']._serialized_start=289
  _globals['_FILELISTRESPONSE']._serialized_end=457
# @@protoc_insertion_point(module_scope)
