# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ur_msgs/srv/set_analog_output.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ur_msgs.msg import analog_pb2 as make87__messages__ros2_dot_rolling_dot_ur__msgs_dot_msg_dot_analog__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/rolling/ur_msgs/srv/set_analog_output.proto\x12(make87_messages_ros2.rolling.ur_msgs.srv\x1a\x35make87_messages_ros2/rolling/ur_msgs/msg/analog.proto\"X\n\x16SetAnalogOutputRequest\x12>\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x30.make87_messages_ros2.rolling.ur_msgs.msg.Analog\"*\n\x17SetAnalogOutputResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ur_msgs.srv.set_analog_output_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETANALOGOUTPUTREQUEST']._serialized_start=165
  _globals['_SETANALOGOUTPUTREQUEST']._serialized_end=253
  _globals['_SETANALOGOUTPUTRESPONSE']._serialized_start=255
  _globals['_SETANALOGOUTPUTRESPONSE']._serialized_end=297
# @@protoc_insertion_point(module_scope)
