# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_ubx_msgs/msg/ubx_nav_rel_pos_ned.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import carr_soln_pb2 as make87__messages__ros2_dot_rolling_dot_ublox__ubx__msgs_dot_msg_dot_carr__soln__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/ublox_ubx_msgs/msg/ubx_nav_rel_pos_ned.proto\x12/make87_messages_ros2.rolling.ublox_ubx_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\x1a?make87_messages_ros2/rolling/ublox_ubx_msgs/msg/carr_soln.proto\"\xaf\x05\n\x0fUBXNavRelPosNED\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x16\n\x0eref_station_id\x18\x03 \x01(\r\x12\x0c\n\x04itow\x18\x04 \x01(\r\x12\x11\n\trel_pos_n\x18\x05 \x01(\x05\x12\x11\n\trel_pos_e\x18\x06 \x01(\x05\x12\x11\n\trel_pos_d\x18\x07 \x01(\x05\x12\x16\n\x0erel_pos_length\x18\x08 \x01(\x05\x12\x17\n\x0frel_pos_heading\x18\t \x01(\x05\x12\x14\n\x0crel_pos_hp_n\x18\n \x01(\x05\x12\x14\n\x0crel_pos_hp_e\x18\x0b \x01(\x05\x12\x14\n\x0crel_pos_hp_d\x18\x0c \x01(\x05\x12\x19\n\x11rel_pos_hp_length\x18\r \x01(\x05\x12\r\n\x05\x61\x63\x63_n\x18\x0e \x01(\r\x12\r\n\x05\x61\x63\x63_e\x18\x0f \x01(\r\x12\r\n\x05\x61\x63\x63_d\x18\x10 \x01(\r\x12\x12\n\nacc_length\x18\x11 \x01(\r\x12\x13\n\x0b\x61\x63\x63_heading\x18\x12 \x01(\r\x12\x13\n\x0bgnss_fix_ok\x18\x13 \x01(\x08\x12\x11\n\tdiff_soln\x18\x14 \x01(\x08\x12\x15\n\rrel_pos_valid\x18\x15 \x01(\x08\x12L\n\tcarr_soln\x18\x16 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.ublox_ubx_msgs.msg.CarrSoln\x12\x11\n\tis_moving\x18\x17 \x01(\x08\x12\x14\n\x0cref_pos_miss\x18\x18 \x01(\x08\x12\x14\n\x0cref_obs_miss\x18\x19 \x01(\x08\x12\x1d\n\x15rel_pos_heading_valid\x18\x1a \x01(\x08\x12\x1a\n\x12rel_pos_normalized\x18\x1b \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_ubx_msgs.msg.ubx_nav_rel_pos_ned_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UBXNAVRELPOSNED']._serialized_start=248
  _globals['_UBXNAVRELPOSNED']._serialized_end=935
# @@protoc_insertion_point(module_scope)
