# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/marine_acoustic_msgs/msg/sonar_image_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/marine_acoustic_msgs/msg/sonar_image_data.proto\x12\x33make87_messages_ros2.jazzy.marine_acoustic_msgs.msg\"W\n\x0eSonarImageData\x12\x14\n\x0cis_bigendian\x18\x01 \x01(\x08\x12\r\n\x05\x64type\x18\x02 \x01(\r\x12\x12\n\nbeam_count\x18\x03 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x04 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.marine_acoustic_msgs.msg.sonar_image_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SONARIMAGEDATA']._serialized_start=131
  _globals['_SONARIMAGEDATA']._serialized_end=218
# @@protoc_insertion_point(module_scope)
