from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ActiveFaultLatched1(_message.Message):
    __slots__ = ["header", "active_flt_latched_byte7_bit7", "active_flt_latched_byte7_bit6", "active_flt_latched_byte7_bit5", "active_flt_latched_byte7_bit4", "arm_to_dsp_chksum_fault", "dsp_to_arm_chksum_fault", "host_to_arm_chksum_fault", "arm_to_host_chksum_fault", "loop_bw_out_of_range", "dsp_overrun_fault", "active_flt_latched_byte6_bit5", "tuning_sensitivity_fault", "saturated_tuning_freq_fault", "local_osc_power_fault", "transmitter_power_fault", "active_flt_latched_byte6_bit0", "active_flt_latched_byte5_bit7", "active_flt_latched_byte5_bit6", "xcvr_device_spi_fault", "freq_synthesizer_spi_fault", "analog_converter_devic_spi_fault", "side_lobe_blockage", "active_flt_latched_byte5_bit1", "mnr_blocked", "ecu_temp_high_fault", "transmitter_temp_high_fault", "alignment_routine_failed_fault", "unreasonable_radar_data", "microprocessor_temp_high_fault", "vertical_alignment_out_of_range", "horizontal_alignment_out_of_range", "factory_alignment_mode", "battery_low_fault", "battery_high_fault", "v_1p25_supply_out_of_range", "active_flt_latched_byte3_bit4", "thermistor_out_of_range", "v_3p3_dac_supply_out_of_range", "v_3p3_raw_supply_out_of_range", "v_5_supply_out_of_range", "transmitter_id_fault", "active_flt_latched_byte2_bit6", "active_flt_latched_byte2_bit5", "active_flt_latched_byte2_bit4", "active_flt_latched_byte2_bit3", "active_flt_latched_byte2_bit2", "pcan_missing_msg_fault", "pcan_bus_off", "active_flt_latched_byte1_bit7", "active_flt_latched_byte1_bit6", "instruction_set_check_fault", "stack_overflow_fault", "watchdog_fault", "pll_lock_fault", "active_flt_latched_byte1_bit1", "ram_memory_test_fault", "usc_validation_fault", "active_flt_latched_byte0_bit6", "active_flt_latched_byte0_bit5", "active_flt_latched_byte0_bit4", "active_flt_latched_byte0_bit3", "keep_alive_checksum_fault", "program_calibration_flash_checksum", "application_flash_checksum_fault"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE7_BIT7_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE7_BIT6_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE7_BIT5_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE7_BIT4_FIELD_NUMBER: _ClassVar[int]
    ARM_TO_DSP_CHKSUM_FAULT_FIELD_NUMBER: _ClassVar[int]
    DSP_TO_ARM_CHKSUM_FAULT_FIELD_NUMBER: _ClassVar[int]
    HOST_TO_ARM_CHKSUM_FAULT_FIELD_NUMBER: _ClassVar[int]
    ARM_TO_HOST_CHKSUM_FAULT_FIELD_NUMBER: _ClassVar[int]
    LOOP_BW_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    DSP_OVERRUN_FAULT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE6_BIT5_FIELD_NUMBER: _ClassVar[int]
    TUNING_SENSITIVITY_FAULT_FIELD_NUMBER: _ClassVar[int]
    SATURATED_TUNING_FREQ_FAULT_FIELD_NUMBER: _ClassVar[int]
    LOCAL_OSC_POWER_FAULT_FIELD_NUMBER: _ClassVar[int]
    TRANSMITTER_POWER_FAULT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE6_BIT0_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE5_BIT7_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE5_BIT6_FIELD_NUMBER: _ClassVar[int]
    XCVR_DEVICE_SPI_FAULT_FIELD_NUMBER: _ClassVar[int]
    FREQ_SYNTHESIZER_SPI_FAULT_FIELD_NUMBER: _ClassVar[int]
    ANALOG_CONVERTER_DEVIC_SPI_FAULT_FIELD_NUMBER: _ClassVar[int]
    SIDE_LOBE_BLOCKAGE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE5_BIT1_FIELD_NUMBER: _ClassVar[int]
    MNR_BLOCKED_FIELD_NUMBER: _ClassVar[int]
    ECU_TEMP_HIGH_FAULT_FIELD_NUMBER: _ClassVar[int]
    TRANSMITTER_TEMP_HIGH_FAULT_FIELD_NUMBER: _ClassVar[int]
    ALIGNMENT_ROUTINE_FAILED_FAULT_FIELD_NUMBER: _ClassVar[int]
    UNREASONABLE_RADAR_DATA_FIELD_NUMBER: _ClassVar[int]
    MICROPROCESSOR_TEMP_HIGH_FAULT_FIELD_NUMBER: _ClassVar[int]
    VERTICAL_ALIGNMENT_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    HORIZONTAL_ALIGNMENT_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    FACTORY_ALIGNMENT_MODE_FIELD_NUMBER: _ClassVar[int]
    BATTERY_LOW_FAULT_FIELD_NUMBER: _ClassVar[int]
    BATTERY_HIGH_FAULT_FIELD_NUMBER: _ClassVar[int]
    V_1P25_SUPPLY_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE3_BIT4_FIELD_NUMBER: _ClassVar[int]
    THERMISTOR_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    V_3P3_DAC_SUPPLY_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    V_3P3_RAW_SUPPLY_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    V_5_SUPPLY_OUT_OF_RANGE_FIELD_NUMBER: _ClassVar[int]
    TRANSMITTER_ID_FAULT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE2_BIT6_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE2_BIT5_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE2_BIT4_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE2_BIT3_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE2_BIT2_FIELD_NUMBER: _ClassVar[int]
    PCAN_MISSING_MSG_FAULT_FIELD_NUMBER: _ClassVar[int]
    PCAN_BUS_OFF_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE1_BIT7_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE1_BIT6_FIELD_NUMBER: _ClassVar[int]
    INSTRUCTION_SET_CHECK_FAULT_FIELD_NUMBER: _ClassVar[int]
    STACK_OVERFLOW_FAULT_FIELD_NUMBER: _ClassVar[int]
    WATCHDOG_FAULT_FIELD_NUMBER: _ClassVar[int]
    PLL_LOCK_FAULT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE1_BIT1_FIELD_NUMBER: _ClassVar[int]
    RAM_MEMORY_TEST_FAULT_FIELD_NUMBER: _ClassVar[int]
    USC_VALIDATION_FAULT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE0_BIT6_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE0_BIT5_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE0_BIT4_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FLT_LATCHED_BYTE0_BIT3_FIELD_NUMBER: _ClassVar[int]
    KEEP_ALIVE_CHECKSUM_FAULT_FIELD_NUMBER: _ClassVar[int]
    PROGRAM_CALIBRATION_FLASH_CHECKSUM_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_FLASH_CHECKSUM_FAULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    active_flt_latched_byte7_bit7: bool
    active_flt_latched_byte7_bit6: bool
    active_flt_latched_byte7_bit5: bool
    active_flt_latched_byte7_bit4: bool
    arm_to_dsp_chksum_fault: bool
    dsp_to_arm_chksum_fault: bool
    host_to_arm_chksum_fault: bool
    arm_to_host_chksum_fault: bool
    loop_bw_out_of_range: bool
    dsp_overrun_fault: bool
    active_flt_latched_byte6_bit5: bool
    tuning_sensitivity_fault: bool
    saturated_tuning_freq_fault: bool
    local_osc_power_fault: bool
    transmitter_power_fault: bool
    active_flt_latched_byte6_bit0: bool
    active_flt_latched_byte5_bit7: bool
    active_flt_latched_byte5_bit6: bool
    xcvr_device_spi_fault: bool
    freq_synthesizer_spi_fault: bool
    analog_converter_devic_spi_fault: bool
    side_lobe_blockage: bool
    active_flt_latched_byte5_bit1: bool
    mnr_blocked: bool
    ecu_temp_high_fault: bool
    transmitter_temp_high_fault: bool
    alignment_routine_failed_fault: bool
    unreasonable_radar_data: bool
    microprocessor_temp_high_fault: bool
    vertical_alignment_out_of_range: bool
    horizontal_alignment_out_of_range: bool
    factory_alignment_mode: bool
    battery_low_fault: bool
    battery_high_fault: bool
    v_1p25_supply_out_of_range: bool
    active_flt_latched_byte3_bit4: bool
    thermistor_out_of_range: bool
    v_3p3_dac_supply_out_of_range: bool
    v_3p3_raw_supply_out_of_range: bool
    v_5_supply_out_of_range: bool
    transmitter_id_fault: bool
    active_flt_latched_byte2_bit6: bool
    active_flt_latched_byte2_bit5: bool
    active_flt_latched_byte2_bit4: bool
    active_flt_latched_byte2_bit3: bool
    active_flt_latched_byte2_bit2: bool
    pcan_missing_msg_fault: bool
    pcan_bus_off: bool
    active_flt_latched_byte1_bit7: bool
    active_flt_latched_byte1_bit6: bool
    instruction_set_check_fault: bool
    stack_overflow_fault: bool
    watchdog_fault: bool
    pll_lock_fault: bool
    active_flt_latched_byte1_bit1: bool
    ram_memory_test_fault: bool
    usc_validation_fault: bool
    active_flt_latched_byte0_bit6: bool
    active_flt_latched_byte0_bit5: bool
    active_flt_latched_byte0_bit4: bool
    active_flt_latched_byte0_bit3: bool
    keep_alive_checksum_fault: bool
    program_calibration_flash_checksum: bool
    application_flash_checksum_fault: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., active_flt_latched_byte7_bit7: bool = ..., active_flt_latched_byte7_bit6: bool = ..., active_flt_latched_byte7_bit5: bool = ..., active_flt_latched_byte7_bit4: bool = ..., arm_to_dsp_chksum_fault: bool = ..., dsp_to_arm_chksum_fault: bool = ..., host_to_arm_chksum_fault: bool = ..., arm_to_host_chksum_fault: bool = ..., loop_bw_out_of_range: bool = ..., dsp_overrun_fault: bool = ..., active_flt_latched_byte6_bit5: bool = ..., tuning_sensitivity_fault: bool = ..., saturated_tuning_freq_fault: bool = ..., local_osc_power_fault: bool = ..., transmitter_power_fault: bool = ..., active_flt_latched_byte6_bit0: bool = ..., active_flt_latched_byte5_bit7: bool = ..., active_flt_latched_byte5_bit6: bool = ..., xcvr_device_spi_fault: bool = ..., freq_synthesizer_spi_fault: bool = ..., analog_converter_devic_spi_fault: bool = ..., side_lobe_blockage: bool = ..., active_flt_latched_byte5_bit1: bool = ..., mnr_blocked: bool = ..., ecu_temp_high_fault: bool = ..., transmitter_temp_high_fault: bool = ..., alignment_routine_failed_fault: bool = ..., unreasonable_radar_data: bool = ..., microprocessor_temp_high_fault: bool = ..., vertical_alignment_out_of_range: bool = ..., horizontal_alignment_out_of_range: bool = ..., factory_alignment_mode: bool = ..., battery_low_fault: bool = ..., battery_high_fault: bool = ..., v_1p25_supply_out_of_range: bool = ..., active_flt_latched_byte3_bit4: bool = ..., thermistor_out_of_range: bool = ..., v_3p3_dac_supply_out_of_range: bool = ..., v_3p3_raw_supply_out_of_range: bool = ..., v_5_supply_out_of_range: bool = ..., transmitter_id_fault: bool = ..., active_flt_latched_byte2_bit6: bool = ..., active_flt_latched_byte2_bit5: bool = ..., active_flt_latched_byte2_bit4: bool = ..., active_flt_latched_byte2_bit3: bool = ..., active_flt_latched_byte2_bit2: bool = ..., pcan_missing_msg_fault: bool = ..., pcan_bus_off: bool = ..., active_flt_latched_byte1_bit7: bool = ..., active_flt_latched_byte1_bit6: bool = ..., instruction_set_check_fault: bool = ..., stack_overflow_fault: bool = ..., watchdog_fault: bool = ..., pll_lock_fault: bool = ..., active_flt_latched_byte1_bit1: bool = ..., ram_memory_test_fault: bool = ..., usc_validation_fault: bool = ..., active_flt_latched_byte0_bit6: bool = ..., active_flt_latched_byte0_bit5: bool = ..., active_flt_latched_byte0_bit4: bool = ..., active_flt_latched_byte0_bit3: bool = ..., keep_alive_checksum_fault: bool = ..., program_calibration_flash_checksum: bool = ..., application_flash_checksum_fault: bool = ...) -> None: ...
