# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/derived_values.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUmake87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/derived_values.proto\x12@make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg\"\xaa\x01\n\rDerivedValues\x12\x1d\n\x15multiplication_factor\x18\x01 \x01(\r\x12\x17\n\x0fnumber_of_beams\x18\x02 \x01(\r\x12\x11\n\tscan_time\x18\x03 \x01(\r\x12\x13\n\x0bstart_angle\x18\x04 \x01(\x02\x12\x1f\n\x17\x61ngular_beam_resolution\x18\x05 \x01(\x02\x12\x18\n\x10interbeam_period\x18\x06 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg.derived_values_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DERIVEDVALUES']._serialized_start=156
  _globals['_DERIVEDVALUES']._serialized_end=326
# @@protoc_insertion_point(module_scope)
