# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/soccer_vision_2d_msgs/msg/goalpost.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.soccer_vision_attribute_msgs.msg import confidence_pb2 as make87__messages__ros2_dot_humble_dot_soccer__vision__attribute__msgs_dot_msg_dot_confidence__pb2
from make87_messages_ros2.humble.soccer_vision_attribute_msgs.msg import goalpost_pb2 as make87__messages__ros2_dot_humble_dot_soccer__vision__attribute__msgs_dot_msg_dot_goalpost__pb2
from make87_messages_ros2.humble.vision_msgs.msg import bounding_box2_d_pb2 as make87__messages__ros2_dot_humble_dot_vision__msgs_dot_msg_dot_bounding__box2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/soccer_vision_2d_msgs/msg/goalpost.proto\x12\x35make87_messages_ros2.humble.soccer_vision_2d_msgs.msg\x1a!make87_messages/core/header.proto\x1aMmake87_messages_ros2/humble/soccer_vision_attribute_msgs/msg/confidence.proto\x1aKmake87_messages_ros2/humble/soccer_vision_attribute_msgs/msg/goalpost.proto\x1a\x41make87_messages_ros2/humble/vision_msgs/msg/bounding_box2_d.proto\"\xba\x02\n\x08Goalpost\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x46\n\x02\x62\x62\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.humble.vision_msgs.msg.BoundingBox2D\x12Z\n\nattributes\x18\x03 \x01(\x0b\x32\x46.make87_messages_ros2.humble.soccer_vision_attribute_msgs.msg.Goalpost\x12\\\n\nconfidence\x18\x04 \x01(\x0b\x32H.make87_messages_ros2.humble.soccer_vision_attribute_msgs.msg.Confidenceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.soccer_vision_2d_msgs.msg.goalpost_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GOALPOST']._serialized_start=386
  _globals['_GOALPOST']._serialized_end=700
# @@protoc_insertion_point(module_scope)
