# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/turtlebot3_msgs/srv/dqn.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/rolling/turtlebot3_msgs/srv/dqn.proto\x12\x30make87_messages_ros2.rolling.turtlebot3_msgs.srv\"*\n\nDqnRequest\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\r\x12\x0c\n\x04init\x18\x02 \x01(\x08\":\n\x0b\x44qnResponse\x12\r\n\x05state\x18\x01 \x03(\x02\x12\x0e\n\x06reward\x18\x02 \x01(\x02\x12\x0c\n\x04\x64one\x18\x03 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.turtlebot3_msgs.srv.dqn_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DQNREQUEST']._serialized_start=112
  _globals['_DQNREQUEST']._serialized_end=154
  _globals['_DQNRESPONSE']._serialized_start=156
  _globals['_DQNRESPONSE']._serialized_end=214
# @@protoc_insertion_point(module_scope)
