# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/msg/estimator_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/rolling/mavros_msgs/msg/estimator_status.proto\x12,make87_messages_ros2.rolling.mavros_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xf8\x03\n\x0f\x45stimatorStatus\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x1c\n\x14\x61ttitude_status_flag\x18\x02 \x01(\x08\x12\"\n\x1avelocity_horiz_status_flag\x18\x03 \x01(\x08\x12!\n\x19velocity_vert_status_flag\x18\x04 \x01(\x08\x12!\n\x19pos_horiz_rel_status_flag\x18\x05 \x01(\x08\x12!\n\x19pos_horiz_abs_status_flag\x18\x06 \x01(\x08\x12 \n\x18pos_vert_abs_status_flag\x18\x07 \x01(\x08\x12 \n\x18pos_vert_agl_status_flag\x18\x08 \x01(\x08\x12\"\n\x1a\x63onst_pos_mode_status_flag\x18\t \x01(\x08\x12&\n\x1epred_pos_horiz_rel_status_flag\x18\n \x01(\x08\x12&\n\x1epred_pos_horiz_abs_status_flag\x18\x0b \x01(\x08\x12\x1e\n\x16gps_glitch_status_flag\x18\x0c \x01(\x08\x12\x1f\n\x17\x61\x63\x63\x65l_error_status_flag\x18\r \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.msg.estimator_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ESTIMATORSTATUS']._serialized_start=174
  _globals['_ESTIMATORSTATUS']._serialized_end=678
# @@protoc_insertion_point(module_scope)
