# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/visualization_msgs/msg/marker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import compressed_image_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_compressed__image__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_color__rgba__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.visualization_msgs.msg import mesh_file_pb2 as make87__messages__ros2_dot_jazzy_dot_visualization__msgs_dot_msg_dot_mesh__file__pb2
from make87_messages_ros2.jazzy.visualization_msgs.msg import uv_coordinate_pb2 as make87__messages__ros2_dot_jazzy_dot_visualization__msgs_dot_msg_dot_uv__coordinate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/visualization_msgs/msg/marker.proto\x12\x31make87_messages_ros2.jazzy.visualization_msgs.msg\x1a@make87_messages_ros2/jazzy/builtin_interfaces/msg/duration.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x1a:make87_messages_ros2/jazzy/geometry_msgs/msg/vector3.proto\x1a\x41make87_messages_ros2/jazzy/sensor_msgs/msg/compressed_image.proto\x1a\x38make87_messages_ros2/jazzy/std_msgs/msg/color_rgba.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a\x41make87_messages_ros2/jazzy/visualization_msgs/msg/mesh_file.proto\x1a\x45make87_messages_ros2/jazzy/visualization_msgs/msg/uv_coordinate.proto\"\x93\x07\n\x06Marker\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\n\n\x02ns\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x05\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\x05\x12@\n\x04pose\x18\x06 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x44\n\x05scale\x18\x07 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12\x41\n\x05\x63olor\x18\x08 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBA\x12M\n\x08lifetime\x18\t \x01(\x0b\x32;.make87_messages_ros2.jazzy.builtin_interfaces.msg.Duration\x12\x14\n\x0c\x66rame_locked\x18\n \x01(\x08\x12\x43\n\x06points\x18\x0b \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12\x42\n\x06\x63olors\x18\x0c \x03(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBA\x12\x18\n\x10texture_resource\x18\r \x01(\t\x12L\n\x07texture\x18\x0e \x01(\x0b\x32;.make87_messages_ros2.jazzy.sensor_msgs.msg.CompressedImage\x12W\n\x0euv_coordinates\x18\x0f \x03(\x0b\x32?.make87_messages_ros2.jazzy.visualization_msgs.msg.UVCoordinate\x12\x0c\n\x04text\x18\x10 \x01(\t\x12\x15\n\rmesh_resource\x18\x11 \x01(\t\x12N\n\tmesh_file\x18\x12 \x01(\x0b\x32;.make87_messages_ros2.jazzy.visualization_msgs.msg.MeshFile\x12#\n\x1bmesh_use_embedded_materials\x18\x13 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.visualization_msgs.msg.marker_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MARKER']._serialized_start=676
  _globals['_MARKER']._serialized_end=1591
# @@protoc_insertion_point(module_scope)
