# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nav2_msgs/srv/clear_costmap_around_robot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import empty_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/nav2_msgs/srv/clear_costmap_around_robot.proto\x12(make87_messages_ros2.jazzy.nav2_msgs.srv\x1a\x33make87_messages_ros2/jazzy/std_msgs/msg/empty.proto\"8\n\x1e\x43learCostmapAroundRobotRequest\x12\x16\n\x0ereset_distance\x18\x01 \x01(\x02\"c\n\x1f\x43learCostmapAroundRobotResponse\x12@\n\x08response\x18\x01 \x01(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nav2_msgs.srv.clear_costmap_around_robot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLEARCOSTMAPAROUNDROBOTREQUEST']._serialized_start=172
  _globals['_CLEARCOSTMAPAROUNDROBOTREQUEST']._serialized_end=228
  _globals['_CLEARCOSTMAPAROUNDROBOTRESPONSE']._serialized_start=230
  _globals['_CLEARCOSTMAPAROUNDROBOTRESPONSE']._serialized_end=329
# @@protoc_insertion_point(module_scope)
