# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/nav2_msgs/msg/voxel_grid.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point32_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_point32__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/humble/nav2_msgs/msg/voxel_grid.proto\x12)make87_messages_ros2.humble.nav2_msgs.msg\x1a!make87_messages/core/header.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/point32.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/vector3.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xd3\x02\n\tVoxelGrid\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\r\x12\x46\n\x06origin\x18\x04 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Point32\x12K\n\x0bresolutions\x18\x05 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12\x0e\n\x06size_x\x18\x06 \x01(\r\x12\x0e\n\x06size_y\x18\x07 \x01(\r\x12\x0e\n\x06size_z\x18\x08 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.nav2_msgs.msg.voxel_grid_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_VOXELGRID']._serialized_start=318
  _globals['_VOXELGRID']._serialized_end=657
# @@protoc_insertion_point(module_scope)
