# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/webots_ros2_msgs/srv/emitter_send_string.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/rolling/webots_ros2_msgs/srv/emitter_send_string.proto\x12\x31make87_messages_ros2.rolling.webots_ros2_msgs.srv\")\n\x18\x45mitterSendStringRequest\x12\r\n\x05value\x18\x01 \x01(\t\"+\n\x19\x45mitterSendStringResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.webots_ros2_msgs.srv.emitter_send_string_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_EMITTERSENDSTRINGREQUEST']._serialized_start=130
  _globals['_EMITTERSENDSTRINGREQUEST']._serialized_end=171
  _globals['_EMITTERSENDSTRINGRESPONSE']._serialized_start=173
  _globals['_EMITTERSENDSTRINGRESPONSE']._serialized_end=216
# @@protoc_insertion_point(module_scope)
