# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_ingestor_msgs/msg/ingestor_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.rmf_ingestor_msgs.msg import ingestor_request_item_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__ingestor__msgs_dot_msg_dot_ingestor__request__item__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/rmf_ingestor_msgs/msg/ingestor_request.proto\x12\x32make87_messages_ros2.rolling.rmf_ingestor_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1aNmake87_messages_ros2/rolling/rmf_ingestor_msgs/msg/ingestor_request_item.proto\"\xf7\x01\n\x0fIngestorRequest\x12G\n\x04time\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x14\n\x0crequest_guid\x18\x02 \x01(\t\x12\x13\n\x0btarget_guid\x18\x03 \x01(\t\x12\x18\n\x10transporter_type\x18\x04 \x01(\t\x12V\n\x05items\x18\x05 \x03(\x0b\x32G.make87_messages_ros2.rolling.rmf_ingestor_msgs.msg.IngestorRequestItemb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_ingestor_msgs.msg.ingestor_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INGESTORREQUEST']._serialized_start=274
  _globals['_INGESTORREQUEST']._serialized_end=521
# @@protoc_insertion_point(module_scope)
