# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_map_msgs/srv/get_partial_point_cloud_map.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.autoware_map_msgs.msg import area_info_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__map__msgs_dot_msg_dot_area__info__pb2
from make87_messages_ros2.jazzy.autoware_map_msgs.msg import point_cloud_map_cell_with_id_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__map__msgs_dot_msg_dot_point__cloud__map__cell__with__id__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/jazzy/autoware_map_msgs/srv/get_partial_point_cloud_map.proto\x12\x30make87_messages_ros2.jazzy.autoware_map_msgs.srv\x1a@make87_messages_ros2/jazzy/autoware_map_msgs/msg/area_info.proto\x1aSmake87_messages_ros2/jazzy/autoware_map_msgs/msg/point_cloud_map_cell_with_id.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"j\n\x1eGetPartialPointCloudMapRequest\x12H\n\x04\x61rea\x18\x01 \x01(\x0b\x32:.make87_messages_ros2.jazzy.autoware_map_msgs.msg.AreaInfo\"\xce\x01\n\x1fGetPartialPointCloudMapResponse\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12j\n\x17new_pointcloud_with_ids\x18\x02 \x03(\x0b\x32I.make87_messages_ros2.jazzy.autoware_map_msgs.msg.PointCloudMapCellWithIDb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_map_msgs.srv.get_partial_point_cloud_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETPARTIALPOINTCLOUDMAPREQUEST']._serialized_start=341
  _globals['_GETPARTIALPOINTCLOUDMAPREQUEST']._serialized_end=447
  _globals['_GETPARTIALPOINTCLOUDMAPRESPONSE']._serialized_start=450
  _globals['_GETPARTIALPOINTCLOUDMAPRESPONSE']._serialized_end=656
# @@protoc_insertion_point(module_scope)
