# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/action_msgs/srv/cancel_goal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.action_msgs.msg import goal_info_pb2 as make87__messages__ros2_dot_jazzy_dot_action__msgs_dot_msg_dot_goal__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/action_msgs/srv/cancel_goal.proto\x12*make87_messages_ros2.jazzy.action_msgs.srv\x1a:make87_messages_ros2/jazzy/action_msgs/msg/goal_info.proto\"\\\n\x11\x43\x61ncelGoalRequest\x12G\n\tgoal_info\x18\x01 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.action_msgs.msg.GoalInfo\"x\n\x12\x43\x61ncelGoalResponse\x12\x13\n\x0breturn_code\x18\x01 \x01(\x05\x12M\n\x0fgoals_canceling\x18\x02 \x03(\x0b\x32\x34.make87_messages_ros2.jazzy.action_msgs.msg.GoalInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.action_msgs.srv.cancel_goal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CANCELGOALREQUEST']._serialized_start=168
  _globals['_CANCELGOALREQUEST']._serialized_end=260
  _globals['_CANCELGOALRESPONSE']._serialized_start=262
  _globals['_CANCELGOALRESPONSE']._serialized_end=382
# @@protoc_insertion_point(module_scope)
