# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_task_msgs/msg/dispatch_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_task_msgs.msg import assignment_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__task__msgs_dot_msg_dot_assignment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/rmf_task_msgs/msg/dispatch_state.proto\x12,make87_messages_ros2.jazzy.rmf_task_msgs.msg\x1a=make87_messages_ros2/jazzy/rmf_task_msgs/msg/assignment.proto\"\x8e\x01\n\rDispatchState\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12L\n\nassignment\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.rmf_task_msgs.msg.Assignment\x12\x0e\n\x06\x65rrors\x18\x04 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_task_msgs.msg.dispatch_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DISPATCHSTATE']._serialized_start=179
  _globals['_DISPATCHSTATE']._serialized_end=321
# @@protoc_insertion_point(module_scope)
