# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/map_msgs/msg/projected_map_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/map_msgs/msg/projected_map_info.proto\x12(make87_messages_ros2.humble.map_msgs.msg\x1a!make87_messages/core/header.proto\"\xa5\x01\n\x10ProjectedMapInfo\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08\x66rame_id\x18\x02 \x01(\t\x12\t\n\x01x\x18\x03 \x01(\x01\x12\t\n\x01y\x18\x04 \x01(\x01\x12\r\n\x05width\x18\x05 \x01(\x01\x12\x0e\n\x06height\x18\x06 \x01(\x01\x12\r\n\x05min_z\x18\x07 \x01(\x01\x12\r\n\x05max_z\x18\x08 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.map_msgs.msg.projected_map_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PROJECTEDMAPINFO']._serialized_start=147
  _globals['_PROJECTEDMAPINFO']._serialized_end=312
# @@protoc_insertion_point(module_scope)
