# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/robot_trajectory.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.trajectory_msgs.msg import joint_trajectory_pb2 as make87__messages__ros2_dot_jazzy_dot_trajectory__msgs_dot_msg_dot_joint__trajectory__pb2
from make87_messages_ros2.jazzy.trajectory_msgs.msg import multi_dof_joint_trajectory_pb2 as make87__messages__ros2_dot_jazzy_dot_trajectory__msgs_dot_msg_dot_multi__dof__joint__trajectory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/moveit_msgs/msg/robot_trajectory.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a\x45make87_messages_ros2/jazzy/trajectory_msgs/msg/joint_trajectory.proto\x1aOmake87_messages_ros2/jazzy/trajectory_msgs/msg/multi_dof_joint_trajectory.proto\"\xd9\x01\n\x0fRobotTrajectory\x12Y\n\x10joint_trajectory\x18\x01 \x01(\x0b\x32?.make87_messages_ros2.jazzy.trajectory_msgs.msg.JointTrajectory\x12k\n\x1amulti_dof_joint_trajectory\x18\x02 \x01(\x0b\x32G.make87_messages_ros2.jazzy.trajectory_msgs.msg.MultiDOFJointTrajectoryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.robot_trajectory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROBOTTRAJECTORY']._serialized_start=266
  _globals['_ROBOTTRAJECTORY']._serialized_end=483
# @@protoc_insertion_point(module_scope)
