# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/marti_introspection_msgs/msg/node_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.marti_introspection_msgs.msg import param_info_pb2 as make87__messages__ros2_dot_humble_dot_marti__introspection__msgs_dot_msg_dot_param__info__pb2
from make87_messages_ros2.humble.marti_introspection_msgs.msg import service_info_pb2 as make87__messages__ros2_dot_humble_dot_marti__introspection__msgs_dot_msg_dot_service__info__pb2
from make87_messages_ros2.humble.marti_introspection_msgs.msg import topic_info_pb2 as make87__messages__ros2_dot_humble_dot_marti__introspection__msgs_dot_msg_dot_topic__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/humble/marti_introspection_msgs/msg/node_info.proto\x12\x38make87_messages_ros2.humble.marti_introspection_msgs.msg\x1a!make87_messages/core/header.proto\x1aImake87_messages_ros2/humble/marti_introspection_msgs/msg/param_info.proto\x1aKmake87_messages_ros2/humble/marti_introspection_msgs/msg/service_info.proto\x1aImake87_messages_ros2/humble/marti_introspection_msgs/msg/topic_info.proto\"\x8d\x03\n\x08NodeInfo\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x17\n\x0fnodelet_manager\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12S\n\x06topics\x18\x06 \x03(\x0b\x32\x43.make87_messages_ros2.humble.marti_introspection_msgs.msg.TopicInfo\x12W\n\nparameters\x18\x07 \x03(\x0b\x32\x43.make87_messages_ros2.humble.marti_introspection_msgs.msg.ParamInfo\x12W\n\x08services\x18\x08 \x03(\x0b\x32\x45.make87_messages_ros2.humble.marti_introspection_msgs.msg.ServiceInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.marti_introspection_msgs.msg.node_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NODEINFO']._serialized_start=397
  _globals['_NODEINFO']._serialized_end=794
# @@protoc_insertion_point(module_scope)
