# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ur_msgs/srv/get_robot_software_version.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/ur_msgs/srv/get_robot_software_version.proto\x12&make87_messages_ros2.jazzy.ur_msgs.srv\" \n\x1eGetRobotSoftwareVersionRequest\"^\n\x1fGetRobotSoftwareVersionResponse\x12\r\n\x05major\x18\x01 \x01(\r\x12\r\n\x05minor\x18\x02 \x01(\r\x12\x0e\n\x06\x62ugfix\x18\x03 \x01(\r\x12\r\n\x05\x62uild\x18\x04 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ur_msgs.srv.get_robot_software_version_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETROBOTSOFTWAREVERSIONREQUEST']._serialized_start=115
  _globals['_GETROBOTSOFTWAREVERSIONREQUEST']._serialized_end=147
  _globals['_GETROBOTSOFTWAREVERSIONRESPONSE']._serialized_start=149
  _globals['_GETROBOTSOFTWAREVERSIONRESPONSE']._serialized_end=243
# @@protoc_insertion_point(module_scope)
