from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Packet(_message.Message):
    __slots__ = ["header", "data", "b_o_s", "e_o_s", "granulepos", "packetno"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    B_O_S_FIELD_NUMBER: _ClassVar[int]
    E_O_S_FIELD_NUMBER: _ClassVar[int]
    GRANULEPOS_FIELD_NUMBER: _ClassVar[int]
    PACKETNO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    data: _containers.RepeatedScalarFieldContainer[int]
    b_o_s: int
    e_o_s: int
    granulepos: int
    packetno: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., data: _Optional[_Iterable[int]] = ..., b_o_s: _Optional[int] = ..., e_o_s: _Optional[int] = ..., granulepos: _Optional[int] = ..., packetno: _Optional[int] = ...) -> None: ...
