# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/sick_safetyscanners2_interfaces/msg/application_inputs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXmake87_messages_ros2/humble/sick_safetyscanners2_interfaces/msg/application_inputs.proto\x12?make87_messages_ros2.humble.sick_safetyscanners2_interfaces.msg\x1a!make87_messages/core/header.proto\"\xa5\x04\n\x11\x41pplicationInputs\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12#\n\x1bunsafe_inputs_input_sources\x18\x02 \x03(\x08\x12\x1b\n\x13unsafe_inputs_flags\x18\x03 \x03(\x08\x12%\n\x1dmonitoring_case_number_inputs\x18\x04 \x03(\r\x12+\n#monitoring_case_number_inputs_flags\x18\x05 \x03(\x08\x12)\n!linear_velocity_inputs_velocity_0\x18\x06 \x01(\x05\x12/\n\'linear_velocity_inputs_velocity_0_valid\x18\x07 \x01(\x08\x12<\n4linear_velocity_inputs_velocity_0_transmitted_safely\x18\x08 \x01(\x08\x12)\n!linear_velocity_inputs_velocity_1\x18\t \x01(\x05\x12/\n\'linear_velocity_inputs_velocity_1_valid\x18\n \x01(\x08\x12<\n4linear_velocity_inputs_velocity_1_transmitted_safely\x18\x0b \x01(\x08\x12\x18\n\x10sleep_mode_input\x18\x0c \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.sick_safetyscanners2_interfaces.msg.application_inputs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_APPLICATIONINPUTS']._serialized_start=193
  _globals['_APPLICATIONINPUTS']._serialized_end=742
# @@protoc_insertion_point(module_scope)
