from make87_messages_ros2.rolling.autoware_map_msgs.msg import lanelet_map_cell_meta_data_pb2 as _lanelet_map_cell_meta_data_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LaneletMapMetaData(_message.Message):
    __slots__ = ["header", "metadata_list"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    METADATA_LIST_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    metadata_list: _containers.RepeatedCompositeFieldContainer[_lanelet_map_cell_meta_data_pb2.LaneletMapCellMetaData]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., metadata_list: _Optional[_Iterable[_Union[_lanelet_map_cell_meta_data_pb2.LaneletMapCellMetaData, _Mapping]]] = ...) -> None: ...
