# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/tuw_multi_robot_msgs/msg/robot_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg import route_precondition_pb2 as make87__messages__ros2_dot_rolling_dot_tuw__multi__robot__msgs_dot_msg_dot_route__precondition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/tuw_multi_robot_msgs/msg/robot_info.proto\x12\x35make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg\x1aImake87_messages_ros2/rolling/geometry_msgs/msg/pose_with_covariance.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\x1aNmake87_messages_ros2/rolling/tuw_multi_robot_msgs/msg/route_precondition.proto\"\x8b\x03\n\tRobotInfo\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x12\n\nrobot_name\x18\x02 \x01(\t\x12P\n\x04pose\x18\x03 \x01(\x0b\x32\x42.make87_messages_ros2.rolling.geometry_msgs.msg.PoseWithCovariance\x12\r\n\x05shape\x18\x04 \x01(\x05\x12\x17\n\x0fshape_variables\x18\x05 \x03(\x02\x12V\n\x04sync\x18\x06 \x01(\x0b\x32H.make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg.RoutePrecondition\x12\x0c\n\x04mode\x18\x07 \x01(\x05\x12\x0e\n\x06status\x18\x08 \x01(\x05\x12\x0f\n\x07good_id\x18\t \x01(\x05\x12\x10\n\x08order_id\x18\n \x01(\x05\x12\x14\n\x0corder_status\x18\x0b \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg.robot_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROBOTINFO']._serialized_start=341
  _globals['_ROBOTINFO']._serialized_end=736
# @@protoc_insertion_point(module_scope)
