# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ublox_msgs/msg/cfg_nmea.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/humble/ublox_msgs/msg/cfg_nmea.proto\x12*make87_messages_ros2.humble.ublox_msgs.msg\x1a!make87_messages/core/header.proto\"\x94\x02\n\x07\x43\x66gNMEA\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\r\x12\x14\n\x0cnmea_version\x18\x03 \x01(\r\x12\x0e\n\x06num_sv\x18\x04 \x01(\r\x12\r\n\x05\x66lags\x18\x05 \x01(\r\x12\x16\n\x0egnss_to_filter\x18\x06 \x01(\r\x12\x14\n\x0csv_numbering\x18\x07 \x01(\r\x12\x16\n\x0emain_talker_id\x18\x08 \x01(\r\x12\x15\n\rgsv_talker_id\x18\t \x01(\r\x12\x0f\n\x07version\x18\n \x01(\r\x12\x15\n\rbds_talker_id\x18\x0b \x03(\r\x12\x11\n\treserved1\x18\x0c \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ublox_msgs.msg.cfg_nmea_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CFGNMEA']._serialized_start=141
  _globals['_CFGNMEA']._serialized_end=417
# @@protoc_insertion_point(module_scope)
