# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/apply_body_wrench.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import wrench_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_wrench__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/gazebo_msgs/srv/apply_body_wrench.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\x1a@make87_messages_ros2/jazzy/builtin_interfaces/msg/duration.proto\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a\x39make87_messages_ros2/jazzy/geometry_msgs/msg/wrench.proto\"\xf4\x02\n\x16\x41pplyBodyWrenchRequest\x12\x11\n\tbody_name\x18\x01 \x01(\t\x12\x17\n\x0freference_frame\x18\x02 \x01(\t\x12L\n\x0freference_point\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12\x44\n\x06wrench\x18\x04 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.geometry_msgs.msg.Wrench\x12K\n\nstart_time\x18\x05 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12M\n\x08\x64uration\x18\x06 \x01(\x0b\x32;.make87_messages_ros2.jazzy.builtin_interfaces.msg.Duration\"B\n\x17\x41pplyBodyWrenchResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0estatus_message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.apply_body_wrench_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_APPLYBODYWRENCHREQUEST']._serialized_start=360
  _globals['_APPLYBODYWRENCHREQUEST']._serialized_end=732
  _globals['_APPLYBODYWRENCHRESPONSE']._serialized_start=734
  _globals['_APPLYBODYWRENCHRESPONSE']._serialized_end=800
# @@protoc_insertion_point(module_scope)
