# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/error_warning.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/ibeo_msgs/msg/error_warning.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a\x41make87_messages_ros2/rolling/ibeo_msgs/msg/ibeo_data_header.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xbb\x0b\n\x0c\x45rrorWarning\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12O\n\x0bibeo_header\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.ibeo_msgs.msg.IbeoDataHeader\x12\x1a\n\x12\x65rr_internal_error\x18\x03 \x01(\x08\x12\x19\n\x11\x65rr_motor_1_fault\x18\x04 \x01(\x08\x12\'\n\x1f\x65rr_buffer_error_xmt_incomplete\x18\x05 \x01(\x08\x12!\n\x19\x65rr_buffer_error_overflow\x18\x06 \x01(\x08\x12 \n\x18\x65rr_apd_over_temperature\x18\x07 \x01(\x08\x12!\n\x19\x65rr_apd_under_temperature\x18\x08 \x01(\x08\x12)\n!err_apd_temperature_sensor_defect\x18\t \x01(\x08\x12\x19\n\x11\x65rr_motor_2_fault\x18\n \x01(\x08\x12\x19\n\x11\x65rr_motor_3_fault\x18\x0b \x01(\x08\x12\x19\n\x11\x65rr_motor_4_fault\x18\x0c \x01(\x08\x12\x19\n\x11\x65rr_motor_5_fault\x18\r \x01(\x08\x12\x1c\n\x14\x65rr_int_no_scan_data\x18\x0e \x01(\x08\x12#\n\x1b\x65rr_int_communication_error\x18\x0f \x01(\x08\x12#\n\x1b\x65rr_int_incorrect_scan_data\x18\x10 \x01(\x08\x12(\n err_config_fpga_not_configurable\x18\x11 \x01(\x08\x12(\n err_config_incorrect_config_data\x18\x12 \x01(\x08\x12,\n$err_config_contains_incorrect_params\x18\x13 \x01(\x08\x12#\n\x1b\x65rr_timeout_data_processing\x18\x14 \x01(\x08\x12/\n\'err_timeout_env_model_computation_reset\x18\x15 \x01(\x08\x12#\n\x1bwrn_int_communication_error\x18\x16 \x01(\x08\x12\x1b\n\x13wrn_low_temperature\x18\x17 \x01(\x08\x12\x1c\n\x14wrn_high_temperature\x18\x18 \x01(\x08\x12\x17\n\x0fwrn_int_motor_1\x18\x19 \x01(\x08\x12\x16\n\x0ewrn_sync_error\x18\x1a \x01(\x08\x12\'\n\x1fwrn_laser_1_start_pulse_missing\x18\x1b \x01(\x08\x12\'\n\x1fwrn_laser_2_start_pulse_missing\x18\x1c \x01(\x08\x12!\n\x19wrn_can_interface_blocked\x18\x1d \x01(\x08\x12!\n\x19wrn_eth_interface_blocked\x18\x1e \x01(\x08\x12#\n\x1bwrn_incorrect_can_data_rcvd\x18\x1f \x01(\x08\x12#\n\x1bwrn_int_incorrect_scan_data\x18  \x01(\x08\x12%\n\x1dwrn_eth_unkwn_incomplete_data\x18! \x01(\x08\x12+\n#wrn_incorrect_or_forbidden_cmd_rcvd\x18\" \x01(\x08\x12!\n\x19wrn_memory_access_failure\x18# \x01(\x08\x12\x18\n\x10wrn_int_overflow\x18$ \x01(\x08\x12#\n\x1bwrn_ego_motion_data_missing\x18% \x01(\x08\x12%\n\x1dwrn_incorrect_mounting_params\x18& \x01(\x08\x12(\n wrn_no_obj_comp_due_to_scan_freq\x18\' \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.error_warning_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ERRORWARNING']._serialized_start=234
  _globals['_ERRORWARNING']._serialized_end=1701
# @@protoc_insertion_point(module_scope)
