# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ublox_msgs/msg/mon_hw6.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/humble/ublox_msgs/msg/mon_hw6.proto\x12*make87_messages_ros2.humble.ublox_msgs.msg\x1a!make87_messages/core/header.proto\"\xdb\x02\n\x06MonHW6\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07pin_sel\x18\x02 \x01(\r\x12\x10\n\x08pin_bank\x18\x03 \x01(\r\x12\x0f\n\x07pin_dir\x18\x04 \x01(\r\x12\x0f\n\x07pin_val\x18\x05 \x01(\r\x12\x14\n\x0cnoise_per_ms\x18\x06 \x01(\r\x12\x0f\n\x07\x61gc_cnt\x18\x07 \x01(\r\x12\x10\n\x08\x61_status\x18\x08 \x01(\r\x12\x0f\n\x07\x61_power\x18\t \x01(\r\x12\r\n\x05\x66lags\x18\n \x01(\r\x12\x11\n\treserved0\x18\x0b \x01(\r\x12\x11\n\tused_mask\x18\x0c \x01(\r\x12\n\n\x02vp\x18\r \x03(\r\x12\x0f\n\x07jam_ind\x18\x0e \x01(\r\x12\x11\n\treserved1\x18\x0f \x03(\r\x12\x0f\n\x07pin_irq\x18\x10 \x01(\r\x12\x0e\n\x06pull_h\x18\x11 \x01(\r\x12\x0e\n\x06pull_l\x18\x12 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ublox_msgs.msg.mon_hw6_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MONHW6']._serialized_start=140
  _globals['_MONHW6']._serialized_end=487
# @@protoc_insertion_point(module_scope)
