# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ds_dbw_msgs/msg/brake_report.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ds_dbw_msgs.msg import cmd_src_pb2 as make87__messages__ros2_dot_humble_dot_ds__dbw__msgs_dot_msg_dot_cmd__src__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/humble/ds_dbw_msgs/msg/brake_report.proto\x12+make87_messages_ros2.humble.ds_dbw_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/ds_dbw_msgs/msg/cmd_src.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xb7\x07\n\x0b\x42rakeReport\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x10\n\x08\x63md_type\x18\x03 \x01(\r\x12\x16\n\x0epressure_input\x18\x04 \x01(\x02\x12\x14\n\x0cpressure_cmd\x18\x05 \x01(\x02\x12\x17\n\x0fpressure_output\x18\x06 \x01(\x02\x12\x14\n\x0ctorque_input\x18\x07 \x01(\x02\x12\x12\n\ntorque_cmd\x18\x08 \x01(\x02\x12\x15\n\rtorque_output\x18\t \x01(\x02\x12\x11\n\taccel_cmd\x18\n \x01(\x02\x12\x14\n\x0c\x61\x63\x63\x65l_output\x18\x0b \x01(\x02\x12\x15\n\rpercent_input\x18\x0c \x01(\x02\x12\x13\n\x0bpercent_cmd\x18\r \x01(\x02\x12\x16\n\x0epercent_output\x18\x0e \x01(\x02\x12\x10\n\x08\x62tsi_cmd\x18\x0f \x01(\x08\x12\x15\n\ryield_request\x18\x10 \x01(\x08\x12\x16\n\x0elimiting_value\x18\x11 \x01(\x08\x12\x15\n\rlimiting_rate\x18\x12 \x01(\x08\x12\x18\n\x10\x65xternal_control\x18\x13 \x01(\x08\x12\r\n\x05ready\x18\x14 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x15 \x01(\x08\x12\x17\n\x0foverride_active\x18\x16 \x01(\x08\x12\x16\n\x0eoverride_other\x18\x17 \x01(\x08\x12\x18\n\x10override_latched\x18\x18 \x01(\x08\x12\x0f\n\x07timeout\x18\x19 \x01(\x08\x12\r\n\x05\x66\x61ult\x18\x1a \x01(\x08\x12\x0f\n\x07\x62\x61\x64_crc\x18\x1b \x01(\x08\x12\x0e\n\x06\x62\x61\x64_rc\x18\x1c \x01(\x08\x12\x10\n\x08\x64\x65graded\x18\x1d \x01(\x08\x12\x13\n\x0blimit_value\x18\x1e \x01(\x02\x12 \n\x18\x62rake_available_duration\x18\x1f \x01(\x02\x12\x1c\n\x14\x62rake_available_full\x18  \x01(\x08\x12\x16\n\x0ereq_shift_park\x18! \x01(\x08\x12\x16\n\x0ereq_park_brake\x18\" \x01(\x08\x12\x17\n\x0f\x65xternal_button\x18# \x01(\x08\x12\x18\n\x10\x63omms_loss_armed\x18$ \x01(\x08\x12\x44\n\x07\x63md_src\x18% \x01(\x0b\x32\x33.make87_messages_ros2.humble.ds_dbw_msgs.msg.CmdSrcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ds_dbw_msgs.msg.brake_report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BRAKEREPORT']._serialized_start=261
  _globals['_BRAKEREPORT']._serialized_end=1212
# @@protoc_insertion_point(module_scope)
