# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/bosch_locator_bridge/msg/client_expand_map_visualization.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.bosch_locator_bridge.msg import client_expand_map_overwrite_zone_information_pb2 as make87__messages__ros2_dot_humble_dot_bosch__locator__bridge_dot_msg_dot_client__expand__map__overwrite__zone__information__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_array_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__array__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZmake87_messages_ros2/humble/bosch_locator_bridge/msg/client_expand_map_visualization.proto\x12\x34make87_messages_ros2.humble.bosch_locator_bridge.msg\x1a!make87_messages/core/header.proto\x1agmake87_messages_ros2/humble/bosch_locator_bridge/msg/client_expand_map_overwrite_zone_information.proto\x1a=make87_messages_ros2/humble/builtin_interfaces/msg/time.proto\x1a>make87_messages_ros2/humble/geometry_msgs/msg/pose_array.proto\"\x92\x03\n\x1c\x43lientExpandMapVisualization\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12K\n\ttimestamp\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12\x18\n\x10visualization_id\x18\x03 \x01(\x04\x12l\n\x05zones\x18\x04 \x03(\x0b\x32].make87_messages_ros2.humble.bosch_locator_bridge.msg.ClientExpandMapOverwriteZoneInformation\x12Q\n\x0fprior_map_poses\x18\x05 \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.PoseArray\x12\x1c\n\x14prior_map_pose_types\x18\x06 \x03(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.bosch_locator_bridge.msg.client_expand_map_visualization_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLIENTEXPANDMAPVISUALIZATION']._serialized_start=416
  _globals['_CLIENTEXPANDMAPVISUALIZATION']._serialized_end=818
# @@protoc_insertion_point(module_scope)
