# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rosapi_msgs/srv/get_action_servers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/rosapi_msgs/srv/get_action_servers.proto\x12*make87_messages_ros2.jazzy.rosapi_msgs.srv\"\x19\n\x17GetActionServersRequest\"2\n\x18GetActionServersResponse\x12\x16\n\x0e\x61\x63tion_servers\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rosapi_msgs.srv.get_action_servers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETACTIONSERVERSREQUEST']._serialized_start=115
  _globals['_GETACTIONSERVERSREQUEST']._serialized_end=140
  _globals['_GETACTIONSERVERSRESPONSE']._serialized_start=142
  _globals['_GETACTIONSERVERSRESPONSE']._serialized_end=192
# @@protoc_insertion_point(module_scope)
