# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/slg_msgs/msg/segment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/rolling/slg_msgs/msg/segment.proto\x12)make87_messages_ros2.rolling.slg_msgs.msg\x1a:make87_messages_ros2/rolling/geometry_msgs/msg/point.proto\"\xb7\x02\n\x07Segment\x12\n\n\x02id\x18\x01 \x01(\x04\x12\r\n\x05label\x18\x02 \x01(\r\x12\x18\n\x10\x61ngular_distance\x18\x03 \x01(\x01\x12W\n\x18last_point_prior_segment\x18\x04 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Point\x12W\n\x18\x66irst_point_next_segment\x18\x05 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Point\x12\x45\n\x06points\x18\x06 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Pointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.slg_msgs.msg.segment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SEGMENT']._serialized_start=163
  _globals['_SEGMENT']._serialized_end=474
# @@protoc_insertion_point(module_scope)
