# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/output_paths.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/output_paths.proto\x12@make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg\"`\n\x0bOutputPaths\x12\x0e\n\x06status\x18\x01 \x03(\x08\x12\x0f\n\x07is_safe\x18\x02 \x03(\x08\x12\x10\n\x08is_valid\x18\x03 \x03(\x08\x12\x1e\n\x16\x61\x63tive_monitoring_case\x18\x04 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg.output_paths_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OUTPUTPATHS']._serialized_start=153
  _globals['_OUTPUTPATHS']._serialized_end=249
# @@protoc_insertion_point(module_scope)
