# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_scheduler_msgs/srv/create_schedule.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_scheduler_msgs.msg import schedule_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__scheduler__msgs_dot_msg_dot_schedule__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/rmf_scheduler_msgs/srv/create_schedule.proto\x12\x33make87_messages_ros2.rolling.rmf_scheduler_msgs.srv\x1a\x42make87_messages_ros2/rolling/rmf_scheduler_msgs/msg/schedule.proto\"h\n\x15\x43reateScheduleRequest\x12O\n\x08schedule\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.rolling.rmf_scheduler_msgs.msg.Schedule\":\n\x16\x43reateScheduleResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_scheduler_msgs.srv.create_schedule_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CREATESCHEDULEREQUEST']._serialized_start=198
  _globals['_CREATESCHEDULEREQUEST']._serialized_end=302
  _globals['_CREATESCHEDULERESPONSE']._serialized_start=304
  _globals['_CREATESCHEDULERESPONSE']._serialized_end=362
# @@protoc_insertion_point(module_scope)
