# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nicla_vision_ros2/msg/audio_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/nicla_vision_ros2/msg/audio_info.proto\x12\x30make87_messages_ros2.jazzy.nicla_vision_ros2.msg\"q\n\tAudioInfo\x12\x10\n\x08\x63hannels\x18\x01 \x01(\r\x12\x13\n\x0bsample_rate\x18\x02 \x01(\r\x12\x15\n\rsample_format\x18\x03 \x01(\t\x12\x0f\n\x07\x62itrate\x18\x04 \x01(\r\x12\x15\n\rcoding_format\x18\x05 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nicla_vision_ros2.msg.audio_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AUDIOINFO']._serialized_start=119
  _globals['_AUDIOINFO']._serialized_end=232
# @@protoc_insertion_point(module_scope)
