# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/plansys2_msgs/msg/durative_action.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.plansys2_msgs.msg import param_pb2 as make87__messages__ros2_dot_humble_dot_plansys2__msgs_dot_msg_dot_param__pb2
from make87_messages_ros2.humble.plansys2_msgs.msg import tree_pb2 as make87__messages__ros2_dot_humble_dot_plansys2__msgs_dot_msg_dot_tree__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/humble/plansys2_msgs/msg/durative_action.proto\x12-make87_messages_ros2.humble.plansys2_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/plansys2_msgs/msg/param.proto\x1a\x38make87_messages_ros2/humble/plansys2_msgs/msg/tree.proto\"\xac\x04\n\x0e\x44urativeAction\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\x12H\n\nparameters\x18\x03 \x03(\x0b\x32\x34.make87_messages_ros2.humble.plansys2_msgs.msg.Param\x12R\n\x15\x61t_start_requirements\x18\x04 \x01(\x0b\x32\x33.make87_messages_ros2.humble.plansys2_msgs.msg.Tree\x12R\n\x15over_all_requirements\x18\x05 \x01(\x0b\x32\x33.make87_messages_ros2.humble.plansys2_msgs.msg.Tree\x12P\n\x13\x61t_end_requirements\x18\x06 \x01(\x0b\x32\x33.make87_messages_ros2.humble.plansys2_msgs.msg.Tree\x12M\n\x10\x61t_start_effects\x18\x07 \x01(\x0b\x32\x33.make87_messages_ros2.humble.plansys2_msgs.msg.Tree\x12K\n\x0e\x61t_end_effects\x18\x08 \x01(\x0b\x32\x33.make87_messages_ros2.humble.plansys2_msgs.msg.Treeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.plansys2_msgs.msg.durative_action_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DURATIVEACTION']._serialized_start=271
  _globals['_DURATIVEACTION']._serialized_end=827
# @@protoc_insertion_point(module_scope)
