# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/srv/request_changes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_identity_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_schedule__identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/rmf_traffic_msgs/srv/request_changes.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.srv\x1aImake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_identity.proto\"O\n\x15RequestChangesRequest\x12\x10\n\x08query_id\x18\x01 \x01(\x04\x12\x0f\n\x07version\x18\x02 \x01(\x04\x12\x13\n\x0b\x66ull_update\x18\x03 \x01(\x08\"\x8d\x01\n\x16RequestChangesResponse\x12T\n\x07node_id\x18\x01 \x01(\x0b\x32\x43.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.ScheduleIdentity\x12\x0e\n\x06result\x18\x02 \x01(\r\x12\r\n\x05\x65rror\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.srv.request_changes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_REQUESTCHANGESREQUEST']._serialized_start=201
  _globals['_REQUESTCHANGESREQUEST']._serialized_end=280
  _globals['_REQUESTCHANGESRESPONSE']._serialized_start=283
  _globals['_REQUESTCHANGESRESPONSE']._serialized_end=424
# @@protoc_insertion_point(module_scope)
