# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/activity_item.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/activity_item.proto\x12\x36make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg\"v\n\x0c\x41\x63tivityItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x13\n\x0b\x63lient_name\x18\x02 \x01(\t\x12\x15\n\ractivity_type\x18\x03 \x01(\t\x12\x16\n\x0eprevious_value\x18\x04 \x01(\t\x12\x15\n\rcurrent_value\x18\x05 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.activity_item_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ACTIVITYITEM']._serialized_start=134
  _globals['_ACTIVITYITEM']._serialized_end=252
# @@protoc_insertion_point(module_scope)
