# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ros_babel_fish_test_msgs/msg/test_message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/ros_babel_fish_test_msgs/msg/test_message.proto\x12\x37make87_messages_ros2.jazzy.ros_babel_fish_test_msgs.msg\x1a@make87_messages_ros2/jazzy/builtin_interfaces/msg/duration.proto\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xd3\x03\n\x0bTestMessage\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\t\n\x01\x62\x18\x02 \x01(\x08\x12\x0b\n\x03ui8\x18\x03 \x01(\r\x12\x0c\n\x04ui16\x18\x04 \x01(\r\x12\x0c\n\x04ui32\x18\x05 \x01(\r\x12\x0c\n\x04ui64\x18\x06 \x01(\x04\x12\n\n\x02i8\x18\x07 \x01(\x05\x12\x0b\n\x03i16\x18\x08 \x01(\x05\x12\x0b\n\x03i32\x18\t \x01(\x05\x12\x0b\n\x03i64\x18\n \x01(\x03\x12\x0b\n\x03\x66\x33\x32\x18\x0b \x01(\x02\x12\x0b\n\x03\x66\x36\x34\x18\x0c \x01(\x01\x12\x0b\n\x03str\x18\r \x01(\t\x12\x13\n\x0b\x62ounded_str\x18\x0e \x01(\t\x12\x42\n\x01t\x18\x0f \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x46\n\x01\x64\x18\x10 \x01(\x0b\x32;.make87_messages_ros2.jazzy.builtin_interfaces.msg.Duration\x12\x46\n\tpoint_arr\x18\x11 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Pointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ros_babel_fish_test_msgs.msg.test_message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TESTMESSAGE']._serialized_start=376
  _globals['_TESTMESSAGE']._serialized_end=843
# @@protoc_insertion_point(module_scope)
