# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/gazebo_msgs/srv/get_model_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_twist__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/gazebo_msgs/srv/get_model_state.proto\x12+make87_messages_ros2.humble.gazebo_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\x1a\x39make87_messages_ros2/humble/geometry_msgs/msg/twist.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"v\n\x14GetModelStateRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x1c\n\x14relative_entity_name\x18\x03 \x01(\t\"\xbd\x02\n\x15GetModelStateResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x41\n\x04pose\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12\x43\n\x05twist\x18\x04 \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Twist\x12\x0f\n\x07success\x18\x05 \x01(\x08\x12\x16\n\x0estatus_message\x18\x06 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.gazebo_msgs.srv.get_model_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETMODELSTATEREQUEST']._serialized_start=321
  _globals['_GETMODELSTATEREQUEST']._serialized_end=439
  _globals['_GETMODELSTATERESPONSE']._serialized_start=442
  _globals['_GETMODELSTATERESPONSE']._serialized_end=759
# @@protoc_insertion_point(module_scope)
