# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/data_tamer_msgs/msg/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/data_tamer_msgs/msg/snapshot.proto\x12\x30make87_messages_ros2.rolling.data_tamer_msgs.msg\"]\n\x08Snapshot\x12\x16\n\x0etimestamp_nsec\x18\x01 \x01(\x04\x12\x13\n\x0bschema_hash\x18\x02 \x01(\x04\x12\x13\n\x0b\x61\x63tive_mask\x18\x03 \x03(\r\x12\x0f\n\x07payload\x18\x04 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.data_tamer_msgs.msg.snapshot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SNAPSHOT']._serialized_start=117
  _globals['_SNAPSHOT']._serialized_end=210
# @@protoc_insertion_point(module_scope)
