# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rc_reason_msgs/srv/get_regions_of_interest2_d.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_humble_dot_rc__common__msgs_dot_msg_dot_return__code__pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import region_of_interest2_d_pb2 as make87__messages__ros2_dot_humble_dot_rc__reason__msgs_dot_msg_dot_region__of__interest2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/humble/rc_reason_msgs/srv/get_regions_of_interest2_d.proto\x12.make87_messages_ros2.humble.rc_reason_msgs.srv\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/rc_common_msgs/msg/return_code.proto\x1aJmake87_messages_ros2/humble/rc_reason_msgs/msg/region_of_interest2_d.proto\"p\n\x1dGetRegionsOfInterest2DRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12!\n\x19region_of_interest_2d_ids\x18\x02 \x03(\t\"\x80\x02\n\x1eGetRegionsOfInterest2DResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12_\n\x13regions_of_interest\x18\x02 \x03(\x0b\x32\x42.make87_messages_ros2.humble.rc_reason_msgs.msg.RegionOfInterest2D\x12O\n\x0breturn_code\x18\x03 \x01(\x0b\x32:.make87_messages_ros2.humble.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rc_reason_msgs.srv.get_regions_of_interest2_d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETREGIONSOFINTEREST2DREQUEST']._serialized_start=308
  _globals['_GETREGIONSOFINTEREST2DREQUEST']._serialized_end=420
  _globals['_GETREGIONSOFINTEREST2DRESPONSE']._serialized_start=423
  _globals['_GETREGIONSOFINTEREST2DRESPONSE']._serialized_end=679
# @@protoc_insertion_point(module_scope)
