# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/slam_toolbox/srv/deserialize_pose_graph.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose2_d_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/humble/slam_toolbox/srv/deserialize_pose_graph.proto\x12,make87_messages_ros2.humble.slam_toolbox.srv\x1a!make87_messages/core/header.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/pose2_d.proto\"\xbe\x01\n\x1b\x44\x65serializePoseGraphRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x12\n\nmatch_type\x18\x03 \x01(\x05\x12K\n\x0cinitial_pose\x18\x04 \x01(\x0b\x32\x35.make87_messages_ros2.humble.geometry_msgs.msg.Pose2D\"L\n\x1c\x44\x65serializePoseGraphResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Headerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.slam_toolbox.srv.deserialize_pose_graph_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DESERIALIZEPOSEGRAPHREQUEST']._serialized_start=220
  _globals['_DESERIALIZEPOSEGRAPHREQUEST']._serialized_end=410
  _globals['_DESERIALIZEPOSEGRAPHRESPONSE']._serialized_start=412
  _globals['_DESERIALIZEPOSEGRAPHRESPONSE']._serialized_end=488
# @@protoc_insertion_point(module_scope)
