# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/novatel_gps_msgs/msg/time.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/rolling/novatel_gps_msgs/msg/time.proto\x12\x31make87_messages_ros2.rolling.novatel_gps_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xa0\x02\n\x04Time\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x14\n\x0c\x63lock_status\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x01\x12\x12\n\noffset_std\x18\x04 \x01(\x01\x12\x12\n\nutc_offset\x18\x05 \x01(\x01\x12\x10\n\x08utc_year\x18\x06 \x01(\r\x12\x11\n\tutc_month\x18\x07 \x01(\r\x12\x0f\n\x07utc_day\x18\x08 \x01(\r\x12\x10\n\x08utc_hour\x18\t \x01(\r\x12\x12\n\nutc_minute\x18\n \x01(\r\x12\x17\n\x0futc_millisecond\x18\x0b \x01(\r\x12\x12\n\nutc_status\x18\x0c \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.novatel_gps_msgs.msg.time_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TIME']._serialized_start=172
  _globals['_TIME']._serialized_end=460
# @@protoc_insertion_point(module_scope)
