# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_fleet_msgs/msg/robot_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import location_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__fleet__msgs_dot_msg_dot_location__pb2
from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import robot_mode_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__fleet__msgs_dot_msg_dot_robot__mode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/rmf_fleet_msgs/msg/robot_state.proto\x12/make87_messages_ros2.rolling.rmf_fleet_msgs.msg\x1a>make87_messages_ros2/rolling/rmf_fleet_msgs/msg/location.proto\x1a@make87_messages_ros2/rolling/rmf_fleet_msgs/msg/robot_mode.proto\"\xc0\x02\n\nRobotState\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05model\x18\x02 \x01(\t\x12\x0f\n\x07task_id\x18\x03 \x01(\t\x12\x0b\n\x03seq\x18\x04 \x01(\x04\x12H\n\x04mode\x18\x05 \x01(\x0b\x32:.make87_messages_ros2.rolling.rmf_fleet_msgs.msg.RobotMode\x12\x17\n\x0f\x62\x61ttery_percent\x18\x06 \x01(\x02\x12K\n\x08location\x18\x07 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.rmf_fleet_msgs.msg.Location\x12G\n\x04path\x18\x08 \x03(\x0b\x32\x39.make87_messages_ros2.rolling.rmf_fleet_msgs.msg.Locationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_fleet_msgs.msg.robot_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROBOTSTATE']._serialized_start=249
  _globals['_ROBOTSTATE']._serialized_end=569
# @@protoc_insertion_point(module_scope)
