# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/gazebo_msgs/srv/delete_entity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/humble/gazebo_msgs/srv/delete_entity.proto\x12+make87_messages_ros2.humble.gazebo_msgs.srv\x1a!make87_messages/core/header.proto\"Q\n\x13\x44\x65leteEntityRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x14\x44\x65leteEntityResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x16\n\x0estatus_message\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.gazebo_msgs.srv.delete_entity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DELETEENTITYREQUEST']._serialized_start=147
  _globals['_DELETEENTITYREQUEST']._serialized_end=228
  _globals['_DELETEENTITYRESPONSE']._serialized_start=230
  _globals['_DELETEENTITYRESPONSE']._serialized_end=339
# @@protoc_insertion_point(module_scope)
