# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/test_interface_files/msg/unbounded_sequences.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.test_interface_files.msg import basic_types_pb2 as make87__messages__ros2_dot_rolling_dot_test__interface__files_dot_msg_dot_basic__types__pb2
from make87_messages_ros2.rolling.test_interface_files.msg import constants_pb2 as make87__messages__ros2_dot_rolling_dot_test__interface__files_dot_msg_dot_constants__pb2
from make87_messages_ros2.rolling.test_interface_files.msg import defaults_pb2 as make87__messages__ros2_dot_rolling_dot_test__interface__files_dot_msg_dot_defaults__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/rolling/test_interface_files/msg/unbounded_sequences.proto\x12\x35make87_messages_ros2.rolling.test_interface_files.msg\x1aGmake87_messages_ros2/rolling/test_interface_files/msg/basic_types.proto\x1a\x45make87_messages_ros2/rolling/test_interface_files/msg/constants.proto\x1a\x44make87_messages_ros2/rolling/test_interface_files/msg/defaults.proto\"\xa2\x08\n\x12UnboundedSequences\x12\x13\n\x0b\x62ool_values\x18\x01 \x03(\x08\x12\x13\n\x0b\x62yte_values\x18\x02 \x03(\r\x12\x13\n\x0b\x63har_values\x18\x03 \x03(\x05\x12\x16\n\x0e\x66loat32_values\x18\x04 \x03(\x02\x12\x16\n\x0e\x66loat64_values\x18\x05 \x03(\x01\x12\x13\n\x0bint8_values\x18\x06 \x03(\x05\x12\x14\n\x0cuint8_values\x18\x07 \x03(\r\x12\x14\n\x0cint16_values\x18\x08 \x03(\x05\x12\x15\n\ruint16_values\x18\t \x03(\r\x12\x14\n\x0cint32_values\x18\n \x03(\x05\x12\x15\n\ruint32_values\x18\x0b \x03(\r\x12\x14\n\x0cint64_values\x18\x0c \x03(\x03\x12\x15\n\ruint64_values\x18\r \x03(\x04\x12\x15\n\rstring_values\x18\x0e \x03(\t\x12]\n\x12\x62\x61sic_types_values\x18\x0f \x03(\x0b\x32\x41.make87_messages_ros2.rolling.test_interface_files.msg.BasicTypes\x12Z\n\x10\x63onstants_values\x18\x10 \x03(\x0b\x32@.make87_messages_ros2.rolling.test_interface_files.msg.Constants\x12X\n\x0f\x64\x65\x66\x61ults_values\x18\x11 \x03(\x0b\x32?.make87_messages_ros2.rolling.test_interface_files.msg.Defaults\x12\x1b\n\x13\x62ool_values_default\x18\x12 \x03(\x08\x12\x1b\n\x13\x62yte_values_default\x18\x13 \x03(\r\x12\x1b\n\x13\x63har_values_default\x18\x14 \x03(\x05\x12\x1e\n\x16\x66loat32_values_default\x18\x15 \x03(\x02\x12\x1e\n\x16\x66loat64_values_default\x18\x16 \x03(\x01\x12\x1b\n\x13int8_values_default\x18\x17 \x03(\x05\x12\x1c\n\x14uint8_values_default\x18\x18 \x03(\r\x12\x1c\n\x14int16_values_default\x18\x19 \x03(\x05\x12\x1d\n\x15uint16_values_default\x18\x1a \x03(\r\x12\x1c\n\x14int32_values_default\x18\x1b \x03(\x05\x12\x1d\n\x15uint32_values_default\x18\x1c \x03(\r\x12\x1c\n\x14int64_values_default\x18\x1d \x03(\x03\x12\x1d\n\x15uint64_values_default\x18\x1e \x03(\x04\x12\x1d\n\x15string_values_default\x18\x1f \x03(\t\x12\x17\n\x0f\x61lignment_check\x18  \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.test_interface_files.msg.unbounded_sequences_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UNBOUNDEDSEQUENCES']._serialized_start=353
  _globals['_UNBOUNDEDSEQUENCES']._serialized_end=1411
# @@protoc_insertion_point(module_scope)
