# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/delphi_mrr_msgs/msg/vehicle_state_msg1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/delphi_mrr_msgs/msg/vehicle_state_msg1.proto\x12.make87_messages_ros2.jazzy.delphi_mrr_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xa5\x04\n\x10VehicleStateMsg1\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12!\n\x19\x63\x61n_fcw_sensitivity_level\x18\x02 \x01(\r\x12\x1e\n\x16\x63\x61n_vehicle_stationary\x18\x03 \x01(\x08\x12\x1e\n\x16\x63\x61n_intf_minor_version\x18\x04 \x01(\r\x12\x1e\n\x16\x63\x61n_intf_major_version\x18\x05 \x01(\r\x12\x17\n\x0f\x63\x61n_brake_pedal\x18\x06 \x01(\r\x12\x1b\n\x13\x63\x61n_high_wheel_slip\x18\x07 \x01(\x08\x12\x1e\n\x16\x63\x61n_turn_signal_status\x18\x08 \x01(\r\x12\x1c\n\x14\x63\x61n_washer_front_cmd\x18\t \x01(\x08\x12\x1b\n\x13\x63\x61n_wiper_front_cmd\x18\n \x01(\x08\x12\x1c\n\x14\x63\x61n_wiper_speed_info\x18\x0b \x01(\r\x12\x18\n\x10\x63\x61n_reverse_gear\x18\x0c \x01(\x08\x12#\n\x1b\x63\x61n_beam_shape_actual_right\x18\r \x01(\r\x12\"\n\x1a\x63\x61n_beam_shape_actual_left\x18\x0e \x01(\r\x12 \n\x18\x63\x61n_main_beam_indication\x18\x0f \x01(\x08\x12\x19\n\x11\x63\x61n_vehicle_index\x18\x10 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.delphi_mrr_msgs.msg.vehicle_state_msg1_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_VEHICLESTATEMSG1']._serialized_start=178
  _globals['_VEHICLESTATEMSG1']._serialized_end=727
# @@protoc_insertion_point(module_scope)
