# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sensor_msgs/msg/multi_dof_joint_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_transform__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import twist_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_twist__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import wrench_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_wrench__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/sensor_msgs/msg/multi_dof_joint_state.proto\x12,make87_messages_ros2.rolling.sensor_msgs.msg\x1a>make87_messages_ros2/rolling/geometry_msgs/msg/transform.proto\x1a:make87_messages_ros2/rolling/geometry_msgs/msg/twist.proto\x1a;make87_messages_ros2/rolling/geometry_msgs/msg/wrench.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xc9\x02\n\x12MultiDOFJointState\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x13\n\x0bjoint_names\x18\x02 \x03(\t\x12M\n\ntransforms\x18\x03 \x03(\x0b\x32\x39.make87_messages_ros2.rolling.geometry_msgs.msg.Transform\x12\x44\n\x05twist\x18\x04 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Twist\x12\x46\n\x06wrench\x18\x05 \x03(\x0b\x32\x36.make87_messages_ros2.rolling.geometry_msgs.msg.Wrenchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sensor_msgs.msg.multi_dof_joint_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MULTIDOFJOINTSTATE']._serialized_start=364
  _globals['_MULTIDOFJOINTSTATE']._serialized_end=693
# @@protoc_insertion_point(module_scope)
