# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rcss3d_agent_msgs/msg/percept.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import accelerometer_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_accelerometer__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import agent_state_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_agent__state__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import force_resistance_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_force__resistance__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import game_state_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_game__state__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import gyro_rate_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_gyro__rate__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import hear_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_hear__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import hinge_joint_pos_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_hinge__joint__pos__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import universal_joint_pos_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_universal__joint__pos__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import vision_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_vision__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/humble/rcss3d_agent_msgs/msg/percept.proto\x12\x31make87_messages_ros2.humble.rcss3d_agent_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x45make87_messages_ros2/humble/rcss3d_agent_msgs/msg/accelerometer.proto\x1a\x43make87_messages_ros2/humble/rcss3d_agent_msgs/msg/agent_state.proto\x1aHmake87_messages_ros2/humble/rcss3d_agent_msgs/msg/force_resistance.proto\x1a\x42make87_messages_ros2/humble/rcss3d_agent_msgs/msg/game_state.proto\x1a\x41make87_messages_ros2/humble/rcss3d_agent_msgs/msg/gyro_rate.proto\x1a<make87_messages_ros2/humble/rcss3d_agent_msgs/msg/hear.proto\x1aGmake87_messages_ros2/humble/rcss3d_agent_msgs/msg/hinge_joint_pos.proto\x1aKmake87_messages_ros2/humble/rcss3d_agent_msgs/msg/universal_joint_pos.proto\x1a>make87_messages_ros2/humble/rcss3d_agent_msgs/msg/vision.proto\"\xb2\x06\n\x07Percept\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12O\n\ngyro_rates\x18\x02 \x03(\x0b\x32;.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.GyroRate\x12V\n\x0chinge_joints\x18\x03 \x03(\x0b\x32@.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.HingeJointPos\x12^\n\x10universal_joints\x18\x04 \x03(\x0b\x32\x44.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.UniversalJointPos\x12]\n\x11\x66orce_resistances\x18\x05 \x03(\x0b\x32\x42.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.ForceResistance\x12X\n\x0e\x61\x63\x63\x65lerometers\x18\x06 \x03(\x0b\x32@.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.Accelerometer\x12I\n\x06vision\x18\x07 \x03(\x0b\x32\x39.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.Vision\x12P\n\ngame_state\x18\x08 \x01(\x0b\x32<.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.GameState\x12R\n\x0b\x61gent_state\x18\t \x03(\x0b\x32=.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.AgentState\x12\x46\n\x05hears\x18\n \x03(\x0b\x32\x37.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.Hearb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rcss3d_agent_msgs.msg.percept_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PERCEPT']._serialized_start=779
  _globals['_PERCEPT']._serialized_end=1597
# @@protoc_insertion_point(module_scope)
