# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/automotive_navigation_msgs/msg/point_of_interest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/rolling/automotive_navigation_msgs/msg/point_of_interest.proto\x12;make87_messages_ros2.rolling.automotive_navigation_msgs.msg\"T\n\x0fPointOfInterest\x12\x0c\n\x04guid\x18\x01 \x01(\x04\x12\x10\n\x08latitude\x18\x02 \x01(\x01\x12\x11\n\tlongitude\x18\x03 \x01(\x01\x12\x0e\n\x06params\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.automotive_navigation_msgs.msg.point_of_interest_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_POINTOFINTEREST']._serialized_start=148
  _globals['_POINTOFINTEREST']._serialized_end=232
# @@protoc_insertion_point(module_scope)
