# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/novatel_gps_msgs/msg/inspvax.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_extended_solution_status_pb2 as make87__messages__ros2_dot_rolling_dot_novatel__gps__msgs_dot_msg_dot_novatel__extended__solution__status__pb2
from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_message_header_pb2 as make87__messages__ros2_dot_rolling_dot_novatel__gps__msgs_dot_msg_dot_novatel__message__header__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/novatel_gps_msgs/msg/inspvax.proto\x12\x31make87_messages_ros2.rolling.novatel_gps_msgs.msg\x1aXmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_extended_solution_status.proto\x1aNmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_message_header.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xef\x05\n\x07Inspvax\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x63\n\x12novatel_msg_header\x18\x02 \x01(\x0b\x32G.make87_messages_ros2.rolling.novatel_gps_msgs.msg.NovatelMessageHeader\x12\x12\n\nins_status\x18\x03 \x01(\t\x12\x15\n\rposition_type\x18\x04 \x01(\t\x12\x10\n\x08latitude\x18\x05 \x01(\x01\x12\x11\n\tlongitude\x18\x06 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x07 \x01(\x01\x12\x12\n\nundulation\x18\x08 \x01(\x02\x12\x16\n\x0enorth_velocity\x18\t \x01(\x01\x12\x15\n\reast_velocity\x18\n \x01(\x01\x12\x13\n\x0bup_velocity\x18\x0b \x01(\x01\x12\x0c\n\x04roll\x18\x0c \x01(\x01\x12\r\n\x05pitch\x18\r \x01(\x01\x12\x0f\n\x07\x61zimuth\x18\x0e \x01(\x01\x12\x14\n\x0clatitude_std\x18\x0f \x01(\x02\x12\x15\n\rlongitude_std\x18\x10 \x01(\x02\x12\x14\n\x0c\x61ltitude_std\x18\x11 \x01(\x02\x12\x1a\n\x12north_velocity_std\x18\x12 \x01(\x02\x12\x19\n\x11\x65\x61st_velocity_std\x18\x13 \x01(\x02\x12\x17\n\x0fup_velocity_std\x18\x14 \x01(\x02\x12\x10\n\x08roll_std\x18\x15 \x01(\x02\x12\x11\n\tpitch_std\x18\x16 \x01(\x02\x12\x13\n\x0b\x61zimuth_std\x18\x17 \x01(\x02\x12i\n\x0f\x65xtended_status\x18\x18 \x01(\x0b\x32P.make87_messages_ros2.rolling.novatel_gps_msgs.msg.NovatelExtendedSolutionStatus\x12\x1c\n\x14seconds_since_update\x18\x19 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.novatel_gps_msgs.msg.inspvax_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INSPVAX']._serialized_start=345
  _globals['_INSPVAX']._serialized_end=1096
# @@protoc_insertion_point(module_scope)
