# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/irobot_create_msgs/srv/e_stop.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/irobot_create_msgs/srv/e_stop.proto\x12\x31make87_messages_ros2.jazzy.irobot_create_msgs.srv\"!\n\x0c\x45StopRequest\x12\x11\n\te_stop_on\x18\x01 \x01(\x08\"1\n\rEStopResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.irobot_create_msgs.srv.e_stop_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ESTOPREQUEST']._serialized_start=117
  _globals['_ESTOPREQUEST']._serialized_end=150
  _globals['_ESTOPRESPONSE']._serialized_start=152
  _globals['_ESTOPRESPONSE']._serialized_end=201
# @@protoc_insertion_point(module_scope)
