# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/plansys2_msgs/msg/action.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.plansys2_msgs.msg import param_pb2 as make87__messages__ros2_dot_jazzy_dot_plansys2__msgs_dot_msg_dot_param__pb2
from make87_messages_ros2.jazzy.plansys2_msgs.msg import tree_pb2 as make87__messages__ros2_dot_jazzy_dot_plansys2__msgs_dot_msg_dot_tree__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/plansys2_msgs/msg/action.proto\x12,make87_messages_ros2.jazzy.plansys2_msgs.msg\x1a\x38make87_messages_ros2/jazzy/plansys2_msgs/msg/param.proto\x1a\x37make87_messages_ros2/jazzy/plansys2_msgs/msg/tree.proto\"\xef\x01\n\x06\x41\x63tion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12G\n\nparameters\x18\x02 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.plansys2_msgs.msg.Param\x12I\n\rpreconditions\x18\x03 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.plansys2_msgs.msg.Tree\x12\x43\n\x07\x65\x66\x66\x65\x63ts\x18\x04 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.plansys2_msgs.msg.Treeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.plansys2_msgs.msg.action_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ACTION']._serialized_start=223
  _globals['_ACTION']._serialized_end=462
# @@protoc_insertion_point(module_scope)
