# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/srv/get_planning_scene.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import planning_scene_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_planning__scene__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import planning_scene_components_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_planning__scene__components__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/moveit_msgs/srv/get_planning_scene.proto\x12,make87_messages_ros2.rolling.moveit_msgs.srv\x1a\x41make87_messages_ros2/rolling/moveit_msgs/msg/planning_scene.proto\x1aLmake87_messages_ros2/rolling/moveit_msgs/msg/planning_scene_components.proto\"t\n\x17GetPlanningSceneRequest\x12Y\n\ncomponents\x18\x01 \x01(\x0b\x32\x45.make87_messages_ros2.rolling.moveit_msgs.msg.PlanningSceneComponents\"f\n\x18GetPlanningSceneResponse\x12J\n\x05scene\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.rolling.moveit_msgs.msg.PlanningSceneb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.srv.get_planning_scene_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETPLANNINGSCENEREQUEST']._serialized_start=264
  _globals['_GETPLANNINGSCENEREQUEST']._serialized_end=380
  _globals['_GETPLANNINGSCENERESPONSE']._serialized_start=382
  _globals['_GETPLANNINGSCENERESPONSE']._serialized_end=484
# @@protoc_insertion_point(module_scope)
