# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/application_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg import application_inputs_pb2 as make87__messages__ros2_dot_rolling_dot_sick__safetyscanners2__interfaces_dot_msg_dot_application__inputs__pb2
from make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg import application_outputs_pb2 as make87__messages__ros2_dot_rolling_dot_sick__safetyscanners2__interfaces_dot_msg_dot_application__outputs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWmake87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/application_data.proto\x12@make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg\x1aYmake87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/application_inputs.proto\x1aZmake87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/application_outputs.proto\"\xdd\x01\n\x0f\x41pplicationData\x12\x63\n\x06inputs\x18\x01 \x01(\x0b\x32S.make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg.ApplicationInputs\x12\x65\n\x07outputs\x18\x02 \x01(\x0b\x32T.make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg.ApplicationOutputsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg.application_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_APPLICATIONDATA']._serialized_start=341
  _globals['_APPLICATIONDATA']._serialized_end=562
# @@protoc_insertion_point(module_scope)
