# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/msg/motion_plan_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import constraints_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_constraints__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import generic_trajectory_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_generic__trajectory__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_robot__state__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import trajectory_constraints_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_trajectory__constraints__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import workspace_parameters_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_workspace__parameters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/moveit_msgs/msg/motion_plan_request.proto\x12+make87_messages_ros2.humble.moveit_msgs.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/constraints.proto\x1a\x44make87_messages_ros2/humble/moveit_msgs/msg/generic_trajectory.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/robot_state.proto\x1aHmake87_messages_ros2/humble/moveit_msgs/msg/trajectory_constraints.proto\x1a\x46make87_messages_ros2/humble/moveit_msgs/msg/workspace_parameters.proto\"\xe7\x06\n\x11MotionPlanRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12^\n\x14workspace_parameters\x18\x02 \x01(\x0b\x32@.make87_messages_ros2.humble.moveit_msgs.msg.WorkspaceParameters\x12L\n\x0bstart_state\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.RobotState\x12R\n\x10goal_constraints\x18\x04 \x03(\x0b\x32\x38.make87_messages_ros2.humble.moveit_msgs.msg.Constraints\x12R\n\x10path_constraints\x18\x05 \x01(\x0b\x32\x38.make87_messages_ros2.humble.moveit_msgs.msg.Constraints\x12\x62\n\x16trajectory_constraints\x18\x06 \x01(\x0b\x32\x42.make87_messages_ros2.humble.moveit_msgs.msg.TrajectoryConstraints\x12^\n\x16reference_trajectories\x18\x07 \x03(\x0b\x32>.make87_messages_ros2.humble.moveit_msgs.msg.GenericTrajectory\x12\x13\n\x0bpipeline_id\x18\x08 \x01(\t\x12\x12\n\nplanner_id\x18\t \x01(\t\x12\x12\n\ngroup_name\x18\n \x01(\t\x12\x1d\n\x15num_planning_attempts\x18\x0b \x01(\x05\x12\x1d\n\x15\x61llowed_planning_time\x18\x0c \x01(\x01\x12#\n\x1bmax_velocity_scaling_factor\x18\r \x01(\x01\x12\'\n\x1fmax_acceleration_scaling_factor\x18\x0e \x01(\x01\x12$\n\x1c\x63\x61rtesian_speed_limited_link\x18\x0f \x01(\t\x12\x1b\n\x13max_cartesian_speed\x18\x10 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.msg.motion_plan_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MOTIONPLANREQUEST']._serialized_start=496
  _globals['_MOTIONPLANREQUEST']._serialized_end=1367
# @@protoc_insertion_point(module_scope)
