# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/servo_command_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/moveit_msgs/srv/servo_command_type.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\"/\n\x17ServoCommandTypeRequest\x12\x14\n\x0c\x63ommand_type\x18\x01 \x01(\x05\"+\n\x18ServoCommandTypeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.servo_command_type_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SERVOCOMMANDTYPEREQUEST']._serialized_start=115
  _globals['_SERVOCOMMANDTYPEREQUEST']._serialized_end=162
  _globals['_SERVOCOMMANDTYPERESPONSE']._serialized_start=164
  _globals['_SERVOCOMMANDTYPERESPONSE']._serialized_end=207
# @@protoc_insertion_point(module_scope)
