# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_planning_msgs/msg/lanelet_segment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.autoware_planning_msgs.msg import lanelet_primitive_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__planning__msgs_dot_msg_dot_lanelet__primitive__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/jazzy/autoware_planning_msgs/msg/lanelet_segment.proto\x12\x35make87_messages_ros2.jazzy.autoware_planning_msgs.msg\x1aMmake87_messages_ros2/jazzy/autoware_planning_msgs/msg/lanelet_primitive.proto\"\xd3\x01\n\x0eLaneletSegment\x12\x64\n\x13preferred_primitive\x18\x01 \x01(\x0b\x32G.make87_messages_ros2.jazzy.autoware_planning_msgs.msg.LaneletPrimitive\x12[\n\nprimitives\x18\x02 \x03(\x0b\x32G.make87_messages_ros2.jazzy.autoware_planning_msgs.msg.LaneletPrimitiveb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_planning_msgs.msg.lanelet_segment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LANELETSEGMENT']._serialized_start=214
  _globals['_LANELETSEGMENT']._serialized_end=425
# @@protoc_insertion_point(module_scope)
