# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_planning_msgs/msg/lanelet_primitive.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/rolling/autoware_planning_msgs/msg/lanelet_primitive.proto\x12\x37make87_messages_ros2.rolling.autoware_planning_msgs.msg\"6\n\x10LaneletPrimitive\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x16\n\x0eprimitive_type\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_planning_msgs.msg.lanelet_primitive_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LANELETPRIMITIVE']._serialized_start=140
  _globals['_LANELETPRIMITIVE']._serialized_end=194
# @@protoc_insertion_point(module_scope)
