# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rosapi_msgs/srv/topics_for_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/rosapi_msgs/srv/topics_for_type.proto\x12*make87_messages_ros2.jazzy.rosapi_msgs.srv\"$\n\x14TopicsForTypeRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"\'\n\x15TopicsForTypeResponse\x12\x0e\n\x06topics\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rosapi_msgs.srv.topics_for_type_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TOPICSFORTYPEREQUEST']._serialized_start=112
  _globals['_TOPICSFORTYPEREQUEST']._serialized_end=148
  _globals['_TOPICSFORTYPERESPONSE']._serialized_start=150
  _globals['_TOPICSFORTYPERESPONSE']._serialized_end=189
# @@protoc_insertion_point(module_scope)
