# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/msg/position_ik_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import constraints_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_constraints__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/moveit_msgs/msg/position_ik_request.proto\x12+make87_messages_ros2.humble.moveit_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x41make87_messages_ros2/humble/builtin_interfaces/msg/duration.proto\x1a@make87_messages_ros2/humble/geometry_msgs/msg/pose_stamped.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/constraints.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/robot_state.proto\"\xb3\x04\n\x11PositionIKRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12L\n\x0brobot_state\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.RobotState\x12M\n\x0b\x63onstraints\x18\x04 \x01(\x0b\x32\x38.make87_messages_ros2.humble.moveit_msgs.msg.Constraints\x12\x18\n\x10\x61void_collisions\x18\x05 \x01(\x08\x12\x14\n\x0cik_link_name\x18\x06 \x01(\t\x12P\n\x0cpose_stamped\x18\x07 \x01(\x0b\x32:.make87_messages_ros2.humble.geometry_msgs.msg.PoseStamped\x12\x15\n\rik_link_names\x18\x08 \x03(\t\x12W\n\x13pose_stamped_vector\x18\t \x03(\x0b\x32:.make87_messages_ros2.humble.geometry_msgs.msg.PoseStamped\x12M\n\x07timeout\x18\n \x01(\x0b\x32<.make87_messages_ros2.humble.builtin_interfaces.msg.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.msg.position_ik_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_POSITIONIKREQUEST']._serialized_start=413
  _globals['_POSITIONIKREQUEST']._serialized_end=976
# @@protoc_insertion_point(module_scope)
