# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rosbridge_msgs/msg/connected_clients.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rosbridge_msgs.msg import connected_client_pb2 as make87__messages__ros2_dot_jazzy_dot_rosbridge__msgs_dot_msg_dot_connected__client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/rosbridge_msgs/msg/connected_clients.proto\x12-make87_messages_ros2.jazzy.rosbridge_msgs.msg\x1a\x44make87_messages_ros2/jazzy/rosbridge_msgs/msg/connected_client.proto\"c\n\x10\x43onnectedClients\x12O\n\x07\x63lients\x18\x01 \x03(\x0b\x32>.make87_messages_ros2.jazzy.rosbridge_msgs.msg.ConnectedClientb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rosbridge_msgs.msg.connected_clients_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONNECTEDCLIENTS']._serialized_start=190
  _globals['_CONNECTEDCLIENTS']._serialized_end=289
# @@protoc_insertion_point(module_scope)
