# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/tuw_object_msgs/msg/object_with_covariance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.tuw_object_msgs.msg import object_pb2 as make87__messages__ros2_dot_rolling_dot_tuw__object__msgs_dot_msg_dot_object__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/rolling/tuw_object_msgs/msg/object_with_covariance.proto\x12\x30make87_messages_ros2.rolling.tuw_object_msgs.msg\x1a=make87_messages_ros2/rolling/tuw_object_msgs/msg/object.proto\"\xa8\x01\n\x14ObjectWithCovariance\x12H\n\x06object\x18\x01 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.tuw_object_msgs.msg.Object\x12\x17\n\x0f\x63ovariance_pose\x18\x02 \x03(\x01\x12\x18\n\x10\x63ovariance_twist\x18\x03 \x03(\x01\x12\x13\n\x0b\x63orrelation\x18\x04 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.tuw_object_msgs.msg.object_with_covariance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECTWITHCOVARIANCE']._serialized_start=195
  _globals['_OBJECTWITHCOVARIANCE']._serialized_end=363
# @@protoc_insertion_point(module_scope)
