# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/param_event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rcl_interfaces.msg import parameter_value_pb2 as make87__messages__ros2_dot_jazzy_dot_rcl__interfaces_dot_msg_dot_parameter__value__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/mavros_msgs/msg/param_event.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\x1a\x43make87_messages_ros2/jazzy/rcl_interfaces/msg/parameter_value.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xd7\x01\n\nParamEvent\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x10\n\x08param_id\x18\x02 \x01(\t\x12L\n\x05value\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.jazzy.rcl_interfaces.msg.ParameterValue\x12\x13\n\x0bparam_index\x18\x04 \x01(\r\x12\x13\n\x0bparam_count\x18\x05 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.param_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PARAMEVENT']._serialized_start=232
  _globals['_PARAMEVENT']._serialized_end=447
# @@protoc_insertion_point(module_scope)
