# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/warmup_template.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_rolling_dot_rc__common__msgs_dot_msg_dot_return__code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/rc_reason_msgs/srv/warmup_template.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a\x41make87_messages_ros2/rolling/rc_common_msgs/msg/return_code.proto\",\n\x15WarmupTemplateRequest\x12\x13\n\x0btemplate_id\x18\x01 \x01(\t\"j\n\x16WarmupTemplateResponse\x12P\n\x0breturn_code\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.rolling.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.warmup_template_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_WARMUPTEMPLATEREQUEST']._serialized_start=189
  _globals['_WARMUPTEMPLATEREQUEST']._serialized_end=233
  _globals['_WARMUPTEMPLATERESPONSE']._serialized_start=235
  _globals['_WARMUPTEMPLATERESPONSE']._serialized_end=341
# @@protoc_insertion_point(module_scope)
