# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/automotive_navigation_msgs/msg/point_of_interest_response.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.automotive_navigation_msgs.msg import point_of_interest_status_pb2 as make87__messages__ros2_dot_jazzy_dot_automotive__navigation__msgs_dot_msg_dot_point__of__interest__status__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZmake87_messages_ros2/jazzy/automotive_navigation_msgs/msg/point_of_interest_response.proto\x12\x39make87_messages_ros2.jazzy.automotive_navigation_msgs.msg\x1aXmake87_messages_ros2/jazzy/automotive_navigation_msgs/msg/point_of_interest_status.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x8f\x02\n\x17PointOfInterestResponse\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bmodule_name\x18\x03 \x01(\t\x12\x12\n\nrequest_id\x18\x04 \x01(\r\x12\x12\n\nupdate_num\x18\x05 \x01(\r\x12h\n\x0epoint_statuses\x18\x06 \x03(\x0b\x32P.make87_messages_ros2.jazzy.automotive_navigation_msgs.msg.PointOfInterestStatusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.automotive_navigation_msgs.msg.point_of_interest_response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_POINTOFINTERESTRESPONSE']._serialized_start=298
  _globals['_POINTOFINTERESTRESPONSE']._serialized_end=569
# @@protoc_insertion_point(module_scope)
