# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/controller_manager_msgs/srv/reload_controller_libraries.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZmake87_messages_ros2/rolling/controller_manager_msgs/srv/reload_controller_libraries.proto\x12\x38make87_messages_ros2.rolling.controller_manager_msgs.srv\"6\n ReloadControllerLibrariesRequest\x12\x12\n\nforce_kill\x18\x01 \x01(\x08\"/\n!ReloadControllerLibrariesResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.controller_manager_msgs.srv.reload_controller_libraries_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RELOADCONTROLLERLIBRARIESREQUEST']._serialized_start=152
  _globals['_RELOADCONTROLLERLIBRARIESREQUEST']._serialized_end=206
  _globals['_RELOADCONTROLLERLIBRARIESRESPONSE']._serialized_start=208
  _globals['_RELOADCONTROLLERLIBRARIESRESPONSE']._serialized_end=255
# @@protoc_insertion_point(module_scope)
