# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_rxm_measx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import measx_data_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_measx__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_rxm_measx.proto\x12-make87_messages_ros2.jazzy.ublox_ubx_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a>make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/measx_data.proto\"\xe3\x02\n\x0bUBXRxmMeasx\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x0f\n\x07gps_tow\x18\x03 \x01(\r\x12\x0f\n\x07glo_tow\x18\x04 \x01(\r\x12\x0f\n\x07\x62\x64s_tow\x18\x05 \x01(\r\x12\x10\n\x08qzss_tow\x18\x06 \x01(\r\x12\x13\n\x0bgps_tow_acc\x18\x07 \x01(\r\x12\x13\n\x0bglo_tow_acc\x18\x08 \x01(\r\x12\x13\n\x0b\x62\x64s_tow_acc\x18\t \x01(\r\x12\x14\n\x0cqzss_tow_acc\x18\n \x01(\r\x12\x0e\n\x06num_sv\x18\x0b \x01(\r\x12\r\n\x05\x66lags\x18\x0c \x01(\r\x12I\n\x07sv_data\x18\r \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.MeasxDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.ubx_rxm_measx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UBXRXMMEASX']._serialized_start=235
  _globals['_UBXRXMMEASX']._serialized_end=590
# @@protoc_insertion_point(module_scope)
