# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/cartographer_ros_msgs/msg/submap_texture.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/rolling/cartographer_ros_msgs/msg/submap_texture.proto\x12\x36make87_messages_ros2.rolling.cartographer_ros_msgs.msg\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\"\x9b\x01\n\rSubmapTexture\x12\r\n\x05\x63\x65lls\x18\x01 \x03(\r\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\x12\n\nresolution\x18\x04 \x01(\x01\x12H\n\nslice_pose\x18\x05 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Poseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.cartographer_ros_msgs.msg.submap_texture_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SUBMAPTEXTURE']._serialized_start=195
  _globals['_SUBMAPTEXTURE']._serialized_end=350
# @@protoc_insertion_point(module_scope)
