# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mqtt_client_interfaces/srv/new_ros2_mqtt_bridge.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/mqtt_client_interfaces/srv/new_ros2_mqtt_bridge.proto\x12\x37make87_messages_ros2.rolling.mqtt_client_interfaces.srv\"\xaf\x01\n\x18NewRos2MqttBridgeRequest\x12\x11\n\tros_topic\x18\x01 \x01(\t\x12\x12\n\nmqtt_topic\x18\x02 \x01(\t\x12\x11\n\tprimitive\x18\x03 \x01(\x08\x12\x18\n\x10inject_timestamp\x18\x04 \x01(\x08\x12\x16\n\x0eros_queue_size\x18\x05 \x01(\r\x12\x10\n\x08mqtt_qos\x18\x06 \x01(\r\x12\x15\n\rmqtt_retained\x18\x07 \x01(\x08\",\n\x19NewRos2MqttBridgeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mqtt_client_interfaces.srv.new_ros2_mqtt_bridge_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NEWROS2MQTTBRIDGEREQUEST']._serialized_start=144
  _globals['_NEWROS2MQTTBRIDGEREQUEST']._serialized_end=319
  _globals['_NEWROS2MQTTBRIDGERESPONSE']._serialized_start=321
  _globals['_NEWROS2MQTTBRIDGERESPONSE']._serialized_end=365
# @@protoc_insertion_point(module_scope)
