# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_ubx_msgs/msg/comms_port_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/ublox_ubx_msgs/msg/comms_port_info.proto\x12/make87_messages_ros2.rolling.ublox_ubx_msgs.msg\"\xf3\x01\n\rCommsPortInfo\x12\x0f\n\x07port_id\x18\x01 \x01(\r\x12\x12\n\ntx_pending\x18\x02 \x01(\r\x12\x10\n\x08tx_bytes\x18\x03 \x01(\r\x12\x10\n\x08tx_usage\x18\x04 \x01(\r\x12\x15\n\rtx_peak_usage\x18\x05 \x01(\r\x12\x12\n\nrx_pending\x18\x06 \x01(\r\x12\x10\n\x08rx_bytes\x18\x07 \x01(\r\x12\x10\n\x08rx_usage\x18\x08 \x01(\r\x12\x15\n\rrx_peak_usage\x18\t \x01(\r\x12\x14\n\x0coverrun_errs\x18\n \x01(\r\x12\x0c\n\x04msgs\x18\x0b \x03(\r\x12\x0f\n\x07skipped\x18\x0c \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_ubx_msgs.msg.comms_port_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMMSPORTINFO']._serialized_start=123
  _globals['_COMMSPORTINFO']._serialized_end=366
# @@protoc_insertion_point(module_scope)
