# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ibeo_msgs/msg/scan_point2208.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/humble/ibeo_msgs/msg/scan_point2208.proto\x12)make87_messages_ros2.humble.ibeo_msgs.msg\x1a!make87_messages/core/header.proto\"\xfd\x01\n\rScanPoint2208\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04\x65\x63ho\x18\x02 \x01(\r\x12\r\n\x05layer\x18\x03 \x01(\r\x12\x19\n\x11transparent_point\x18\x04 \x01(\x08\x12\x1b\n\x13\x63lutter_atmospheric\x18\x05 \x01(\x08\x12\x0e\n\x06ground\x18\x06 \x01(\x08\x12\x0c\n\x04\x64irt\x18\x07 \x01(\x08\x12\x18\n\x10horizontal_angle\x18\x08 \x01(\x05\x12\x17\n\x0fradial_distance\x18\t \x01(\r\x12\x18\n\x10\x65\x63ho_pulse_width\x18\n \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ibeo_msgs.msg.scan_point2208_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCANPOINT2208']._serialized_start=145
  _globals['_SCANPOINT2208']._serialized_end=398
# @@protoc_insertion_point(module_scope)
