# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_ubx_interfaces/srv/hot_start.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/ublox_ubx_interfaces/srv/hot_start.proto\x12\x33make87_messages_ros2.jazzy.ublox_ubx_interfaces.srv\"%\n\x0fHotStartRequest\x12\x12\n\nreset_type\x18\x01 \x01(\r\"\x12\n\x10HotStartResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_ubx_interfaces.srv.hot_start_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_HOTSTARTREQUEST']._serialized_start=124
  _globals['_HOTSTARTREQUEST']._serialized_end=161
  _globals['_HOTSTARTRESPONSE']._serialized_start=163
  _globals['_HOTSTARTRESPONSE']._serialized_end=181
# @@protoc_insertion_point(module_scope)
