# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ros_gz_interfaces/msg/joint_wrench.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import wrench_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_wrench__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import string_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_string__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import u_int32_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_u__int32__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/ros_gz_interfaces/msg/joint_wrench.proto\x12\x30make87_messages_ros2.jazzy.ros_gz_interfaces.msg\x1a\x39make87_messages_ros2/jazzy/geometry_msgs/msg/wrench.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/string.proto\x1a\x35make87_messages_ros2/jazzy/std_msgs/msg/u_int32.proto\"\xfc\x03\n\x0bJointWrench\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x44\n\x0b\x62ody_1_name\x18\x02 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.String\x12\x42\n\tbody_1_id\x18\x03 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.UInt32\x12\x44\n\x0b\x62ody_2_name\x18\x04 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.String\x12\x42\n\tbody_2_id\x18\x05 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.UInt32\x12K\n\rbody_1_wrench\x18\x06 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.geometry_msgs.msg.Wrench\x12K\n\rbody_2_wrench\x18\x07 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.geometry_msgs.msg.Wrenchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ros_gz_interfaces.msg.joint_wrench_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_JOINTWRENCH']._serialized_start=344
  _globals['_JOINTWRENCH']._serialized_end=852
# @@protoc_insertion_point(module_scope)
