# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/py_trees_ros_interfaces/srv/close_snapshot_stream.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/rolling/py_trees_ros_interfaces/srv/close_snapshot_stream.proto\x12\x38make87_messages_ros2.rolling.py_trees_ros_interfaces.srv\"0\n\x1a\x43loseSnapshotStreamRequest\x12\x12\n\ntopic_name\x18\x01 \x01(\t\"-\n\x1b\x43loseSnapshotStreamResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.py_trees_ros_interfaces.srv.close_snapshot_stream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLOSESNAPSHOTSTREAMREQUEST']._serialized_start=146
  _globals['_CLOSESNAPSHOTSTREAMREQUEST']._serialized_end=194
  _globals['_CLOSESNAPSHOTSTREAMRESPONSE']._serialized_start=196
  _globals['_CLOSESNAPSHOTSTREAMRESPONSE']._serialized_end=241
# @@protoc_insertion_point(module_scope)
