# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/soccer_vision_3d_msgs/msg/ball.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.soccer_vision_attribute_msgs.msg import confidence_pb2 as make87__messages__ros2_dot_jazzy_dot_soccer__vision__attribute__msgs_dot_msg_dot_confidence__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/soccer_vision_3d_msgs/msg/ball.proto\x12\x34make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1aLmake87_messages_ros2/jazzy/soccer_vision_attribute_msgs/msg/confidence.proto\"\xa8\x01\n\x04\x42\x61ll\x12\x43\n\x06\x63\x65nter\x18\x01 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12[\n\nconfidence\x18\x02 \x01(\x0b\x32G.make87_messages_ros2.jazzy.soccer_vision_attribute_msgs.msg.Confidenceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.soccer_vision_3d_msgs.msg.ball_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BALL']._serialized_start=258
  _globals['_BALL']._serialized_end=426
# @@protoc_insertion_point(module_scope)
