# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_fleet_msgs/msg/dock_summary.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import dock_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__fleet__msgs_dot_msg_dot_dock__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/rmf_fleet_msgs/msg/dock_summary.proto\x12/make87_messages_ros2.rolling.rmf_fleet_msgs.msg\x1a:make87_messages_ros2/rolling/rmf_fleet_msgs/msg/dock.proto\"S\n\x0b\x44ockSummary\x12\x44\n\x05\x64ocks\x18\x01 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.rmf_fleet_msgs.msg.Dockb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_fleet_msgs.msg.dock_summary_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DOCKSUMMARY']._serialized_start=179
  _globals['_DOCKSUMMARY']._serialized_end=262
# @@protoc_insertion_point(module_scope)
