# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/composition_interfaces/srv/load_node.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rcl_interfaces.msg import parameter_pb2 as make87__messages__ros2_dot_jazzy_dot_rcl__interfaces_dot_msg_dot_parameter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/composition_interfaces/srv/load_node.proto\x12\x35make87_messages_ros2.jazzy.composition_interfaces.srv\x1a=make87_messages_ros2/jazzy/rcl_interfaces/msg/parameter.proto\"\xb0\x02\n\x0fLoadNodeRequest\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x13\n\x0bplugin_name\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\x12\x16\n\x0enode_namespace\x18\x04 \x01(\t\x12\x11\n\tlog_level\x18\x05 \x01(\r\x12\x13\n\x0bremap_rules\x18\x06 \x03(\t\x12L\n\nparameters\x18\x07 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.rcl_interfaces.msg.Parameter\x12Q\n\x0f\x65xtra_arguments\x18\x08 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.rcl_interfaces.msg.Parameter\"e\n\x10LoadNodeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x16\n\x0e\x66ull_node_name\x18\x03 \x01(\t\x12\x11\n\tunique_id\x18\x04 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.composition_interfaces.srv.load_node_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LOADNODEREQUEST']._serialized_start=192
  _globals['_LOADNODEREQUEST']._serialized_end=496
  _globals['_LOADNODERESPONSE']._serialized_start=498
  _globals['_LOADNODERESPONSE']._serialized_end=599
# @@protoc_insertion_point(module_scope)
