# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/get_world_properties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/gazebo_msgs/srv/get_world_properties.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\"\x1b\n\x19GetWorldPropertiesRequest\"\x87\x01\n\x1aGetWorldPropertiesResponse\x12\x10\n\x08sim_time\x18\x01 \x01(\x01\x12\x13\n\x0bmodel_names\x18\x02 \x03(\t\x12\x19\n\x11rendering_enabled\x18\x03 \x01(\x08\x12\x0f\n\x07success\x18\x04 \x01(\x08\x12\x16\n\x0estatus_message\x18\x05 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.get_world_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETWORLDPROPERTIESREQUEST']._serialized_start=117
  _globals['_GETWORLDPROPERTIESREQUEST']._serialized_end=144
  _globals['_GETWORLDPROPERTIESRESPONSE']._serialized_start=147
  _globals['_GETWORLDPROPERTIESRESPONSE']._serialized_end=282
# @@protoc_insertion_point(module_scope)
