# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/flexbe_msgs/msg/container.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/flexbe_msgs/msg/container.proto\x12*make87_messages_ros2.jazzy.flexbe_msgs.msg\"\x84\x01\n\tContainer\x12\x10\n\x08state_id\x18\x01 \x01(\x05\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x10\n\x08\x63hildren\x18\x03 \x03(\t\x12\x10\n\x08outcomes\x18\x04 \x03(\t\x12\x13\n\x0btransitions\x18\x05 \x03(\t\x12\x0c\n\x04type\x18\x06 \x01(\x05\x12\x10\n\x08\x61utonomy\x18\x07 \x03(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.flexbe_msgs.msg.container_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONTAINER']._serialized_start=107
  _globals['_CONTAINER']._serialized_end=239
# @@protoc_insertion_point(module_scope)
