# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rmf_scheduler_msgs/srv/list_trigger_states.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rmf_scheduler_msgs.msg import trigger_state_pb2 as make87__messages__ros2_dot_humble_dot_rmf__scheduler__msgs_dot_msg_dot_trigger__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/humble/rmf_scheduler_msgs/srv/list_trigger_states.proto\x12\x32make87_messages_ros2.humble.rmf_scheduler_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x46make87_messages_ros2/humble/rmf_scheduler_msgs/msg/trigger_state.proto\"`\n\x18ListTriggerStatesRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x16\n\x0emodified_after\x18\x02 \x01(\x03\"\xbf\x01\n\x19ListTriggerStatesResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0f\n\x07message\x18\x03 \x01(\t\x12R\n\x08triggers\x18\x04 \x03(\x0b\x32@.make87_messages_ros2.humble.rmf_scheduler_msgs.msg.TriggerStateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rmf_scheduler_msgs.srv.list_trigger_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LISTTRIGGERSTATESREQUEST']._serialized_start=239
  _globals['_LISTTRIGGERSTATESREQUEST']._serialized_end=335
  _globals['_LISTTRIGGERSTATESRESPONSE']._serialized_start=338
  _globals['_LISTTRIGGERSTATESRESPONSE']._serialized_end=529
# @@protoc_insertion_point(module_scope)
