# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/data_tamer_msgs/msg/schemas.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.data_tamer_msgs.msg import schema_pb2 as make87__messages__ros2_dot_rolling_dot_data__tamer__msgs_dot_msg_dot_schema__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/data_tamer_msgs/msg/schemas.proto\x12\x30make87_messages_ros2.rolling.data_tamer_msgs.msg\x1a=make87_messages_ros2/rolling/data_tamer_msgs/msg/schema.proto\"T\n\x07Schemas\x12I\n\x07schemas\x18\x01 \x03(\x0b\x32\x38.make87_messages_ros2.rolling.data_tamer_msgs.msg.Schemab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.data_tamer_msgs.msg.schemas_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCHEMAS']._serialized_start=179
  _globals['_SCHEMAS']._serialized_end=263
# @@protoc_insertion_point(module_scope)
