# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosapi_msgs/srv/service_request_details.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rosapi_msgs.msg import type_def_pb2 as make87__messages__ros2_dot_rolling_dot_rosapi__msgs_dot_msg_dot_type__def__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/rosapi_msgs/srv/service_request_details.proto\x12,make87_messages_ros2.rolling.rosapi_msgs.srv\x1a;make87_messages_ros2/rolling/rosapi_msgs/msg/type_def.proto\",\n\x1cServiceRequestDetailsRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"h\n\x1dServiceRequestDetailsResponse\x12G\n\x08typedefs\x18\x01 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.rosapi_msgs.msg.TypeDefb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosapi_msgs.srv.service_request_details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SERVICEREQUESTDETAILSREQUEST']._serialized_start=185
  _globals['_SERVICEREQUESTDETAILSREQUEST']._serialized_end=229
  _globals['_SERVICEREQUESTDETAILSRESPONSE']._serialized_start=231
  _globals['_SERVICEREQUESTDETAILSRESPONSE']._serialized_end=335
# @@protoc_insertion_point(module_scope)
