# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_status_msgs/msg/chrony_tracking_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/rolling/marti_status_msgs/msg/chrony_tracking_status.proto\x12\x32make87_messages_ros2.rolling.marti_status_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xe1\x02\n\x14\x43hronyTrackingStatus\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0f\n\x07stratum\x18\x03 \x01(\x05\x12\x1a\n\x12system_time_offset\x18\x04 \x01(\x01\x12\x13\n\x0blast_offset\x18\x05 \x01(\x01\x12\x12\n\nrms_offset\x18\x06 \x01(\x01\x12\x18\n\x10\x66requency_offset\x18\x07 \x01(\x02\x12\x1a\n\x12residual_frequency\x18\x08 \x01(\x02\x12\x0c\n\x04skew\x18\t \x01(\x02\x12\x12\n\nroot_delay\x18\n \x01(\x01\x12\x17\n\x0froot_dispersion\x18\x0b \x01(\x01\x12\x17\n\x0fupdate_interval\x18\x0c \x01(\x02\x12\x13\n\x0bleap_status\x18\r \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_status_msgs.msg.chrony_tracking_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CHRONYTRACKINGSTATUS']._serialized_start=192
  _globals['_CHRONYTRACKINGSTATUS']._serialized_end=545
# @@protoc_insertion_point(module_scope)
