# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/sick_safevisionary_interfaces/msg/roi_array.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.sick_safevisionary_interfaces.msg import roi_pb2 as make87__messages__ros2_dot_humble_dot_sick__safevisionary__interfaces_dot_msg_dot_roi__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/humble/sick_safevisionary_interfaces/msg/roi_array.proto\x12=make87_messages_ros2.humble.sick_safevisionary_interfaces.msg\x1a!make87_messages/core/header.proto\x1aGmake87_messages_ros2/humble/sick_safevisionary_interfaces/msg/roi.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xd1\x01\n\x08ROIArray\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12P\n\x04rois\x18\x03 \x03(\x0b\x32\x42.make87_messages_ros2.humble.sick_safevisionary_interfaces.msg.ROIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.sick_safevisionary_interfaces.msg.roi_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROIARRAY']._serialized_start=308
  _globals['_ROIARRAY']._serialized_end=517
# @@protoc_insertion_point(module_scope)
