# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/marti_nav_msgs/srv/update_route_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.marti_nav_msgs.msg import route_point_pb2 as make87__messages__ros2_dot_jazzy_dot_marti__nav__msgs_dot_msg_dot_route__point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/marti_nav_msgs/srv/update_route_metadata.proto\x12-make87_messages_ros2.jazzy.marti_nav_msgs.srv\x1a?make87_messages_ros2/jazzy/marti_nav_msgs/msg/route_point.proto\"\x84\x01\n\x1aUpdateRouteMetadataRequest\x12\x12\n\nroute_guid\x18\x01 \x01(\t\x12R\n\x0fmetadata_points\x18\x02 \x03(\x0b\x32\x39.make87_messages_ros2.jazzy.marti_nav_msgs.msg.RoutePoint\"?\n\x1bUpdateRouteMetadataResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.marti_nav_msgs.srv.update_route_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UPDATEROUTEMETADATAREQUEST']._serialized_start=190
  _globals['_UPDATEROUTEMETADATAREQUEST']._serialized_end=322
  _globals['_UPDATEROUTEMETADATARESPONSE']._serialized_start=324
  _globals['_UPDATEROUTEMETADATARESPONSE']._serialized_end=387
# @@protoc_insertion_point(module_scope)
