# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ur_msgs/msg/tool_data_msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/rolling/ur_msgs/msg/tool_data_msg.proto\x12(make87_messages_ros2.rolling.ur_msgs.msg\"\xef\x01\n\x0bToolDataMsg\x12\x1b\n\x13\x61nalog_input_range2\x18\x01 \x01(\x05\x12\x1b\n\x13\x61nalog_input_range3\x18\x02 \x01(\x05\x12\x15\n\ranalog_input2\x18\x03 \x01(\x01\x12\x15\n\ranalog_input3\x18\x04 \x01(\x01\x12\x18\n\x10tool_voltage_48v\x18\x05 \x01(\x02\x12\x1b\n\x13tool_output_voltage\x18\x06 \x01(\r\x12\x14\n\x0ctool_current\x18\x07 \x01(\x02\x12\x18\n\x10tool_temperature\x18\x08 \x01(\x02\x12\x11\n\ttool_mode\x18\t \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ur_msgs.msg.tool_data_msg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TOOLDATAMSG']._serialized_start=107
  _globals['_TOOLDATAMSG']._serialized_end=346
# @@protoc_insertion_point(module_scope)
