# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/tuw_geometry_msgs/msg/line_segment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/tuw_geometry_msgs/msg/line_segment.proto\x12\x31make87_messages_ros2.humble.tuw_geometry_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/geometry_msgs/msg/point.proto\"\xcb\x01\n\x0bLineSegment\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\r\x12@\n\x02p0\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Point\x12@\n\x02p1\x18\x04 \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Pointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.tuw_geometry_msgs.msg.line_segment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LINESEGMENT']._serialized_start=218
  _globals['_LINESEGMENT']._serialized_end=421
# @@protoc_insertion_point(module_scope)
