# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/visualization_msgs/msg/interactive_marker_feedback.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUmake87_messages_ros2/rolling/visualization_msgs/msg/interactive_marker_feedback.proto\x12\x33make87_messages_ros2.rolling.visualization_msgs.msg\x1a:make87_messages_ros2/rolling/geometry_msgs/msg/point.proto\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xf2\x02\n\x19InteractiveMarkerFeedback\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x13\n\x0bmarker_name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontrol_name\x18\x04 \x01(\t\x12\x12\n\nevent_type\x18\x05 \x01(\r\x12\x42\n\x04pose\x18\x06 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\x15\n\rmenu_entry_id\x18\x07 \x01(\r\x12J\n\x0bmouse_point\x18\x08 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Point\x12\x19\n\x11mouse_point_valid\x18\t \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.visualization_msgs.msg.interactive_marker_feedback_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INTERACTIVEMARKERFEEDBACK']._serialized_start=318
  _globals['_INTERACTIVEMARKERFEEDBACK']._serialized_end=688
# @@protoc_insertion_point(module_scope)
