# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/plansys2_msgs/msg/action_execution_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/humble/plansys2_msgs/msg/action_execution_info.proto\x12-make87_messages_ros2.humble.plansys2_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x41make87_messages_ros2/humble/builtin_interfaces/msg/duration.proto\x1a=make87_messages_ros2/humble/builtin_interfaces/msg/time.proto\"\xab\x03\n\x13\x41\x63tionExecutionInfo\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12M\n\x0bstart_stamp\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12N\n\x0cstatus_stamp\x18\x04 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12\x18\n\x10\x61\x63tion_full_name\x18\x05 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x06 \x01(\t\x12\x11\n\targuments\x18\x07 \x03(\t\x12N\n\x08\x64uration\x18\x08 \x01(\x0b\x32<.make87_messages_ros2.humble.builtin_interfaces.msg.Duration\x12\x12\n\ncompletion\x18\t \x01(\x02\x12\x16\n\x0emessage_status\x18\n \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.plansys2_msgs.msg.action_execution_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ACTIONEXECUTIONINFO']._serialized_start=290
  _globals['_ACTIONEXECUTIONINFO']._serialized_end=717
# @@protoc_insertion_point(module_scope)
