# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/planning_scene.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import transform_stamped_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_transform__stamped__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import allowed_collision_matrix_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_allowed__collision__matrix__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import link_padding_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_link__padding__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import link_scale_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_link__scale__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import object_color_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_object__color__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import planning_scene_world_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_planning__scene__world__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/moveit_msgs/msg/planning_scene.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\x1a\x46make87_messages_ros2/rolling/geometry_msgs/msg/transform_stamped.proto\x1aKmake87_messages_ros2/rolling/moveit_msgs/msg/allowed_collision_matrix.proto\x1a?make87_messages_ros2/rolling/moveit_msgs/msg/link_padding.proto\x1a=make87_messages_ros2/rolling/moveit_msgs/msg/link_scale.proto\x1a?make87_messages_ros2/rolling/moveit_msgs/msg/object_color.proto\x1aGmake87_messages_ros2/rolling/moveit_msgs/msg/planning_scene_world.proto\x1a>make87_messages_ros2/rolling/moveit_msgs/msg/robot_state.proto\"\xa2\x05\n\rPlanningScene\x12\x0c\n\x04name\x18\x01 \x01(\t\x12M\n\x0brobot_state\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.moveit_msgs.msg.RobotState\x12\x18\n\x10robot_model_name\x18\x03 \x01(\t\x12`\n\x16\x66ixed_frame_transforms\x18\x04 \x03(\x0b\x32@.make87_messages_ros2.rolling.geometry_msgs.msg.TransformStamped\x12\x66\n\x18\x61llowed_collision_matrix\x18\x05 \x01(\x0b\x32\x44.make87_messages_ros2.rolling.moveit_msgs.msg.AllowedCollisionMatrix\x12O\n\x0clink_padding\x18\x06 \x03(\x0b\x32\x39.make87_messages_ros2.rolling.moveit_msgs.msg.LinkPadding\x12K\n\nlink_scale\x18\x07 \x03(\x0b\x32\x37.make87_messages_ros2.rolling.moveit_msgs.msg.LinkScale\x12P\n\robject_colors\x18\x08 \x03(\x0b\x32\x39.make87_messages_ros2.rolling.moveit_msgs.msg.ObjectColor\x12O\n\x05world\x18\t \x01(\x0b\x32@.make87_messages_ros2.rolling.moveit_msgs.msg.PlanningSceneWorld\x12\x0f\n\x07is_diff\x18\n \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.planning_scene_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLANNINGSCENE']._serialized_start=595
  _globals['_PLANNINGSCENE']._serialized_end=1269
# @@protoc_insertion_point(module_scope)
