# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/find_object_2d/msg/detection_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import float32_multi_array_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_float32__multi__array__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import int32_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_int32__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import string_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_string__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/find_object_2d/msg/detection_info.proto\x12-make87_messages_ros2.jazzy.find_object_2d.msg\x1a\x41make87_messages_ros2/jazzy/std_msgs/msg/float32_multi_array.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a\x33make87_messages_ros2/jazzy/std_msgs/msg/int32.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/string.proto\"\xa8\x04\n\rDetectionInfo\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12;\n\x03ids\x18\x02 \x03(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Int32\x12>\n\x06widths\x18\x03 \x03(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Int32\x12?\n\x07heights\x18\x04 \x03(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Int32\x12\x43\n\nfile_paths\x18\x05 \x03(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.String\x12?\n\x07inliers\x18\x06 \x03(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Int32\x12@\n\x08outliers\x18\x07 \x03(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Int32\x12P\n\x0chomographies\x18\x08 \x03(\x0b\x32:.make87_messages_ros2.jazzy.std_msgs.msg.Float32MultiArrayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.find_object_2d.msg.detection_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DETECTIONINFO']._serialized_start=346
  _globals['_DETECTIONINFO']._serialized_end=898
# @@protoc_insertion_point(module_scope)
