# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_reservation_msgs/msg/flexible_time_reservation_alt.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.rolling.rmf_reservation_msgs.msg import start_time_range_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__reservation__msgs_dot_msg_dot_start__time__range__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYmake87_messages_ros2/rolling/rmf_reservation_msgs/msg/flexible_time_reservation_alt.proto\x12\x35make87_messages_ros2.rolling.rmf_reservation_msgs.msg\x1a\x42make87_messages_ros2/rolling/builtin_interfaces/msg/duration.proto\x1aLmake87_messages_ros2/rolling/rmf_reservation_msgs/msg/start_time_range.proto\"\xfe\x01\n\x1a\x46lexibleTimeReservationAlt\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ost\x18\x02 \x01(\x01\x12Y\n\nstart_time\x18\x03 \x01(\x0b\x32\x45.make87_messages_ros2.rolling.rmf_reservation_msgs.msg.StartTimeRange\x12\x0f\n\x07has_end\x18\x04 \x01(\x08\x12O\n\x08\x64uration\x18\x05 \x01(\x0b\x32=.make87_messages_ros2.rolling.builtin_interfaces.msg.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_reservation_msgs.msg.flexible_time_reservation_alt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FLEXIBLETIMERESERVATIONALT']._serialized_start=295
  _globals['_FLEXIBLETIMERESERVATIONALT']._serialized_end=549
# @@protoc_insertion_point(module_scope)
