# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/webots_ros2_msgs/srv/spawn_urdf_robot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.webots_ros2_msgs.msg import urdf_robot_pb2 as make87__messages__ros2_dot_humble_dot_webots__ros2__msgs_dot_msg_dot_urdf__robot__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/webots_ros2_msgs/srv/spawn_urdf_robot.proto\x12\x30make87_messages_ros2.humble.webots_ros2_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x41make87_messages_ros2/humble/webots_ros2_msgs/msg/urdf_robot.proto\"\x91\x01\n\x15SpawnUrdfRobotRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12J\n\x05robot\x18\x02 \x01(\x0b\x32;.make87_messages_ros2.humble.webots_ros2_msgs.msg.UrdfRobot\"W\n\x16SpawnUrdfRobotResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.webots_ros2_msgs.srv.spawn_urdf_robot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SPAWNURDFROBOTREQUEST']._serialized_start=228
  _globals['_SPAWNURDFROBOTREQUEST']._serialized_end=373
  _globals['_SPAWNURDFROBOTRESPONSE']._serialized_start=375
  _globals['_SPAWNURDFROBOTRESPONSE']._serialized_end=462
# @@protoc_insertion_point(module_scope)
