from make87_messages_ros2.jazzy.geographic_msgs.msg import geographic_map_pb2 as _geographic_map_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.jazzy.unique_identifier_msgs.msg import uuid_pb2 as _uuid_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GeographicMapChanges(_message.Message):
    __slots__ = ["header", "diffs", "deletes"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DIFFS_FIELD_NUMBER: _ClassVar[int]
    DELETES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    diffs: _geographic_map_pb2.GeographicMap
    deletes: _containers.RepeatedCompositeFieldContainer[_uuid_pb2.UUID]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., diffs: _Optional[_Union[_geographic_map_pb2.GeographicMap, _Mapping]] = ..., deletes: _Optional[_Iterable[_Union[_uuid_pb2.UUID, _Mapping]]] = ...) -> None: ...
