# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rviz_2d_overlay_msgs/msg/overlay_text.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_color__rgba__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/rviz_2d_overlay_msgs/msg/overlay_text.proto\x12\x33make87_messages_ros2.jazzy.rviz_2d_overlay_msgs.msg\x1a\x38make87_messages_ros2/jazzy/std_msgs/msg/color_rgba.proto\"\xfd\x02\n\x0bOverlayText\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\x1b\n\x13horizontal_distance\x18\x04 \x01(\x05\x12\x19\n\x11vertical_distance\x18\x05 \x01(\x05\x12\x1c\n\x14horizontal_alignment\x18\x06 \x01(\r\x12\x1a\n\x12vertical_alignment\x18\x07 \x01(\r\x12\x44\n\x08\x62g_color\x18\x08 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBA\x12\x12\n\nline_width\x18\t \x01(\x05\x12\x11\n\ttext_size\x18\n \x01(\x02\x12\x0c\n\x04\x66ont\x18\x0b \x01(\t\x12\x44\n\x08\x66g_color\x18\x0c \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBA\x12\x0c\n\x04text\x18\r \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rviz_2d_overlay_msgs.msg.overlay_text_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OVERLAYTEXT']._serialized_start=186
  _globals['_OVERLAYTEXT']._serialized_end=567
# @@protoc_insertion_point(module_scope)
