# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/display_robot_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import object_color_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_object__color__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/moveit_msgs/msg/display_robot_state.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a=make87_messages_ros2/jazzy/moveit_msgs/msg/object_color.proto\x1a<make87_messages_ros2/jazzy/moveit_msgs/msg/robot_state.proto\"\xba\x01\n\x11\x44isplayRobotState\x12\x45\n\x05state\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.moveit_msgs.msg.RobotState\x12P\n\x0fhighlight_links\x18\x02 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.moveit_msgs.msg.ObjectColor\x12\x0c\n\x04hide\x18\x03 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.display_robot_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DISPLAYROBOTSTATE']._serialized_start=242
  _globals['_DISPLAYROBOTSTATE']._serialized_end=428
# @@protoc_insertion_point(module_scope)
