# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/camera_image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import mounting_position_f_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_mounting__position__f__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/ibeo_msgs/msg/camera_image.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x41make87_messages_ros2/rolling/ibeo_msgs/msg/ibeo_data_header.proto\x1a\x44make87_messages_ros2/rolling/ibeo_msgs/msg/mounting_position_f.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xa9\x04\n\x0b\x43\x61meraImage\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12O\n\x0bibeo_header\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.ibeo_msgs.msg.IbeoDataHeader\x12\x14\n\x0cimage_format\x18\x03 \x01(\r\x12\x19\n\x11us_since_power_on\x18\x04 \x01(\r\x12L\n\ttimestamp\x18\x05 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x11\n\tdevice_id\x18\x06 \x01(\r\x12X\n\x11mounting_position\x18\x07 \x01(\x0b\x32=.make87_messages_ros2.rolling.ibeo_msgs.msg.MountingPositionF\x12 \n\x18horizontal_opening_angle\x18\x08 \x01(\x01\x12\x1e\n\x16vertical_opening_angle\x18\t \x01(\x01\x12\x13\n\x0bimage_width\x18\n \x01(\r\x12\x14\n\x0cimage_height\x18\x0b \x01(\r\x12\x17\n\x0f\x63ompressed_size\x18\x0c \x01(\r\x12\x14\n\x0cimage_buffer\x18\r \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.camera_image_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CAMERAIMAGE']._serialized_start=367
  _globals['_CAMERAIMAGE']._serialized_end=920
# @@protoc_insertion_point(module_scope)
