# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/srv/file_remove.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/mavros_msgs/srv/file_remove.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.srv\"&\n\x11\x46ileRemoveRequest\x12\x11\n\tfile_path\x18\x01 \x01(\t\"6\n\x12\x46ileRemoveResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07r_errno\x18\x02 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.srv.file_remove_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FILEREMOVEREQUEST']._serialized_start=108
  _globals['_FILEREMOVEREQUEST']._serialized_end=146
  _globals['_FILEREMOVERESPONSE']._serialized_start=148
  _globals['_FILEREMOVERESPONSE']._serialized_end=202
# @@protoc_insertion_point(module_scope)
