# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/type_description_interfaces/msg/type_description.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.type_description_interfaces.msg import individual_type_description_pb2 as make87__messages__ros2_dot_rolling_dot_type__description__interfaces_dot_msg_dot_individual__type__description__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/rolling/type_description_interfaces/msg/type_description.proto\x12<make87_messages_ros2.rolling.type_description_interfaces.msg\x1a^make87_messages_ros2/rolling/type_description_interfaces/msg/individual_type_description.proto\"\x83\x02\n\x0fTypeDescription\x12q\n\x10type_description\x18\x01 \x01(\x0b\x32W.make87_messages_ros2.rolling.type_description_interfaces.msg.IndividualTypeDescription\x12}\n\x1creferenced_type_descriptions\x18\x02 \x03(\x0b\x32W.make87_messages_ros2.rolling.type_description_interfaces.msg.IndividualTypeDescriptionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.type_description_interfaces.msg.type_description_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TYPEDESCRIPTION']._serialized_start=246
  _globals['_TYPEDESCRIPTION']._serialized_end=505
# @@protoc_insertion_point(module_scope)
