# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/wiimote_msgs/msg/state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.humble.wiimote_msgs.msg import ir_source_info_pb2 as make87__messages__ros2_dot_humble_dot_wiimote__msgs_dot_msg_dot_ir__source__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/humble/wiimote_msgs/msg/state.proto\x12,make87_messages_ros2.humble.wiimote_msgs.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/builtin_interfaces/msg/time.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/vector3.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\x1a\x41make87_messages_ros2/humble/wiimote_msgs/msg/ir_source_info.proto\"\xca\x08\n\x05State\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12W\n\x17\x61ngular_velocity_zeroed\x18\x03 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12T\n\x14\x61ngular_velocity_raw\x18\x04 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12#\n\x1b\x61ngular_velocity_covariance\x18\x05 \x03(\x01\x12Z\n\x1alinear_acceleration_zeroed\x18\x06 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12W\n\x17linear_acceleration_raw\x18\x07 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12&\n\x1elinear_acceleration_covariance\x18\x08 \x03(\x01\x12[\n\x1bnunchuk_acceleration_zeroed\x18\t \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12X\n\x18nunchuk_acceleration_raw\x18\n \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12\x1f\n\x17nunchuk_joystick_zeroed\x18\x0b \x03(\x02\x12\x1c\n\x14nunchuk_joystick_raw\x18\x0c \x03(\x02\x12\x0f\n\x07\x62uttons\x18\r \x03(\x08\x12\x17\n\x0fnunchuk_buttons\x18\x0e \x03(\x08\x12\x0c\n\x04leds\x18\x0f \x03(\x08\x12\x0e\n\x06rumble\x18\x10 \x01(\x08\x12O\n\x0bir_tracking\x18\x11 \x03(\x0b\x32:.make87_messages_ros2.humble.wiimote_msgs.msg.IrSourceInfo\x12\x13\n\x0braw_battery\x18\x12 \x01(\x02\x12\x17\n\x0fpercent_battery\x18\x13 \x01(\x02\x12N\n\x0czeroing_time\x18\x14 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12\x0e\n\x06\x65rrors\x18\x15 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.wiimote_msgs.msg.state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STATE']._serialized_start=388
  _globals['_STATE']._serialized_end=1486
# @@protoc_insertion_point(module_scope)
