# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/visualization_msgs/msg/image_marker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_color__rgba__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/visualization_msgs/msg/image_marker.proto\x12\x31make87_messages_ros2.jazzy.visualization_msgs.msg\x1a@make87_messages_ros2/jazzy/builtin_interfaces/msg/duration.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a\x38make87_messages_ros2/jazzy/std_msgs/msg/color_rgba.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xdd\x04\n\x0bImageMarker\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\n\n\x02ns\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x05\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\x05\x12\x45\n\x08position\x18\x06 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12\r\n\x05scale\x18\x07 \x01(\x02\x12I\n\routline_color\x18\x08 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBA\x12\x0e\n\x06\x66illed\x18\t \x01(\r\x12\x46\n\nfill_color\x18\n \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBA\x12M\n\x08lifetime\x18\x0b \x01(\x0b\x32;.make87_messages_ros2.jazzy.builtin_interfaces.msg.Duration\x12\x43\n\x06points\x18\x0c \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12J\n\x0eoutline_colors\x18\r \x03(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBAb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.visualization_msgs.msg.image_marker_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_IMAGEMARKER']._serialized_start=360
  _globals['_IMAGEMARKER']._serialized_end=965
# @@protoc_insertion_point(module_scope)
