# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/vision.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import ball_pb2 as make87__messages__ros2_dot_jazzy_dot_rcss3d__agent__msgs_dot_msg_dot_ball__pb2
from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import field_line_pb2 as make87__messages__ros2_dot_jazzy_dot_rcss3d__agent__msgs_dot_msg_dot_field__line__pb2
from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import flag_pb2 as make87__messages__ros2_dot_jazzy_dot_rcss3d__agent__msgs_dot_msg_dot_flag__pb2
from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import goalpost_pb2 as make87__messages__ros2_dot_jazzy_dot_rcss3d__agent__msgs_dot_msg_dot_goalpost__pb2
from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import player_pb2 as make87__messages__ros2_dot_jazzy_dot_rcss3d__agent__msgs_dot_msg_dot_player__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/vision.proto\x12\x30make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg\x1a;make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/ball.proto\x1a\x41make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/field_line.proto\x1a;make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/flag.proto\x1a?make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/goalpost.proto\x1a=make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/player.proto\"\x81\x03\n\x06Vision\x12\x44\n\x04\x62\x61ll\x18\x01 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.Ball\x12P\n\x0b\x66ield_lines\x18\x02 \x03(\x0b\x32;.make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.FieldLine\x12\x45\n\x05\x66lags\x18\x03 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.Flag\x12M\n\tgoalposts\x18\x04 \x03(\x0b\x32:.make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.Goalpost\x12I\n\x07players\x18\x05 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.Playerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.vision_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_VISION']._serialized_start=433
  _globals['_VISION']._serialized_end=818
# @@protoc_insertion_point(module_scope)
