# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/mavros_msgs/msg/sys_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/humble/mavros_msgs/msg/sys_status.proto\x12+make87_messages_ros2.humble.mavros_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xae\x03\n\tSysStatus\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x17\n\x0fsensors_present\x18\x03 \x01(\r\x12\x17\n\x0fsensors_enabled\x18\x04 \x01(\r\x12\x16\n\x0esensors_health\x18\x05 \x01(\r\x12\x0c\n\x04load\x18\x06 \x01(\r\x12\x17\n\x0fvoltage_battery\x18\x07 \x01(\r\x12\x17\n\x0f\x63urrent_battery\x18\x08 \x01(\x05\x12\x19\n\x11\x62\x61ttery_remaining\x18\t \x01(\x05\x12\x16\n\x0e\x64rop_rate_comm\x18\n \x01(\r\x12\x13\n\x0b\x65rrors_comm\x18\x0b \x01(\r\x12\x15\n\rerrors_count1\x18\x0c \x01(\r\x12\x15\n\rerrors_count2\x18\r \x01(\r\x12\x15\n\rerrors_count3\x18\x0e \x01(\r\x12\x15\n\rerrors_count4\x18\x0f \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.mavros_msgs.msg.sys_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SYSSTATUS']._serialized_start=200
  _globals['_SYSSTATUS']._serialized_end=630
# @@protoc_insertion_point(module_scope)
