# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/geographic_msgs/msg/geographic_map_changes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geographic_msgs.msg import geographic_map_pb2 as make87__messages__ros2_dot_jazzy_dot_geographic__msgs_dot_msg_dot_geographic__map__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_jazzy_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/jazzy/geographic_msgs/msg/geographic_map_changes.proto\x12.make87_messages_ros2.jazzy.geographic_msgs.msg\x1a\x43make87_messages_ros2/jazzy/geographic_msgs/msg/geographic_map.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a@make87_messages_ros2/jazzy/unique_identifier_msgs/msg/uuid.proto\"\xf3\x01\n\x14GeographicMapChanges\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12L\n\x05\x64iffs\x18\x02 \x01(\x0b\x32=.make87_messages_ros2.jazzy.geographic_msgs.msg.GeographicMap\x12L\n\x07\x64\x65letes\x18\x03 \x03(\x0b\x32;.make87_messages_ros2.jazzy.unique_identifier_msgs.msg.UUIDb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.geographic_msgs.msg.geographic_map_changes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GEOGRAPHICMAPCHANGES']._serialized_start=317
  _globals['_GEOGRAPHICMAPCHANGES']._serialized_end=560
# @@protoc_insertion_point(module_scope)
