# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_reservation_msgs/msg/claim_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_reservation_msgs.msg import ticket_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__reservation__msgs_dot_msg_dot_ticket__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/rmf_reservation_msgs/msg/claim_request.proto\x12\x35make87_messages_ros2.rolling.rmf_reservation_msgs.msg\x1a\x42make87_messages_ros2/rolling/rmf_reservation_msgs/msg/ticket.proto\"r\n\x0c\x43laimRequest\x12M\n\x06ticket\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.rolling.rmf_reservation_msgs.msg.Ticket\x12\x13\n\x0bwait_points\x18\x02 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_reservation_msgs.msg.claim_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLAIMREQUEST']._serialized_start=200
  _globals['_CLAIMREQUEST']._serialized_end=314
# @@protoc_insertion_point(module_scope)
