# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/space.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose2_d_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose2__d__pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import shape_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_shape__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/rmf_traffic_msgs/msg/space.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1a<make87_messages_ros2/rolling/geometry_msgs/msg/pose2_d.proto\x1a=make87_messages_ros2/rolling/rmf_traffic_msgs/msg/shape.proto\"\x96\x01\n\x05Space\x12G\n\x05shape\x18\x01 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.Shape\x12\x44\n\x04pose\x18\x02 \x01(\x0b\x32\x36.make87_messages_ros2.rolling.geometry_msgs.msg.Pose2Db\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.space_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SPACE']._serialized_start=242
  _globals['_SPACE']._serialized_end=392
# @@protoc_insertion_point(module_scope)
