# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_participant_patch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_change_add_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_schedule__change__add__pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_change_delay_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_schedule__change__delay__pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_change_progress_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_schedule__change__progress__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_participant_patch.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1aKmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_change_add.proto\x1aMmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_change_delay.proto\x1aPmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_change_progress.proto\"\xed\x02\n\x18ScheduleParticipantPatch\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\x04\x12\x19\n\x11itinerary_version\x18\x02 \x01(\x04\x12\x10\n\x08\x65rasures\x18\x03 \x03(\x04\x12V\n\x06\x64\x65lays\x18\x04 \x03(\x0b\x32\x46.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.ScheduleChangeDelay\x12W\n\tadditions\x18\x05 \x01(\x0b\x32\x44.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.ScheduleChangeAdd\x12[\n\x08progress\x18\x06 \x01(\x0b\x32I.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.ScheduleChangeProgressb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.schedule_participant_patch_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCHEDULEPARTICIPANTPATCH']._serialized_start=376
  _globals['_SCHEDULEPARTICIPANTPATCH']._serialized_end=741
# @@protoc_insertion_point(module_scope)
