# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mobileye_560_660_msgs/msg/obstacle_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/mobileye_560_660_msgs/msg/obstacle_data.proto\x12\x36make87_messages_ros2.rolling.mobileye_560_660_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xa3\x05\n\x0cObstacleData\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x13\n\x0bobstacle_id\x18\x02 \x01(\r\x12\x16\n\x0eobstacle_pos_x\x18\x03 \x01(\x01\x12\x16\n\x0eobstacle_pos_y\x18\x04 \x01(\x01\x12\x14\n\x0c\x62linker_info\x18\x05 \x01(\r\x12\x16\n\x0e\x63ut_in_and_out\x18\x06 \x01(\r\x12\x1a\n\x12obstacle_rel_vel_x\x18\x07 \x01(\x01\x12\x15\n\robstacle_type\x18\x08 \x01(\r\x12\x17\n\x0fobstacle_status\x18\t \x01(\r\x12\x1d\n\x15obstacle_brake_lights\x18\n \x01(\x08\x12\x16\n\x0eobstacle_valid\x18\x0b \x01(\r\x12\x17\n\x0fobstacle_length\x18\x0c \x01(\x02\x12\x16\n\x0eobstacle_width\x18\r \x01(\x02\x12\x14\n\x0cobstacle_age\x18\x0e \x01(\r\x12\x15\n\robstacle_lane\x18\x0f \x01(\r\x12\x11\n\tcipv_flag\x18\x10 \x01(\x08\x12\x13\n\x0bradar_pos_x\x18\x11 \x01(\x02\x12\x13\n\x0bradar_vel_x\x18\x12 \x01(\x02\x12\x1e\n\x16radar_match_confidence\x18\x13 \x01(\r\x12\x18\n\x10matched_radar_id\x18\x14 \x01(\r\x12\x1b\n\x13obstacle_angle_rate\x18\x15 \x01(\x02\x12\x1d\n\x15obstacle_scale_change\x18\x16 \x01(\x01\x12\x16\n\x0eobject_accel_x\x18\x17 \x01(\x02\x12\x19\n\x11obstacle_replaced\x18\x18 \x01(\x08\x12\x16\n\x0eobstacle_angle\x18\x19 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mobileye_560_660_msgs.msg.obstacle_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBSTACLEDATA']._serialized_start=191
  _globals['_OBSTACLEDATA']._serialized_end=866
# @@protoc_insertion_point(module_scope)
