# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/trajectory_msgs/msg/multi_dof_joint_trajectory_point.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_transform__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import twist_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_twist__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUmake87_messages_ros2/jazzy/trajectory_msgs/msg/multi_dof_joint_trajectory_point.proto\x12.make87_messages_ros2.jazzy.trajectory_msgs.msg\x1a@make87_messages_ros2/jazzy/builtin_interfaces/msg/duration.proto\x1a<make87_messages_ros2/jazzy/geometry_msgs/msg/transform.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/twist.proto\"\xd6\x02\n\x1cMultiDOFJointTrajectoryPoint\x12K\n\ntransforms\x18\x01 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.geometry_msgs.msg.Transform\x12G\n\nvelocities\x18\x02 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Twist\x12J\n\raccelerations\x18\x03 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Twist\x12T\n\x0ftime_from_start\x18\x04 \x01(\x0b\x32;.make87_messages_ros2.jazzy.builtin_interfaces.msg.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.trajectory_msgs.msg.multi_dof_joint_trajectory_point_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MULTIDOFJOINTTRAJECTORYPOINT']._serialized_start=324
  _globals['_MULTIDOFJOINTTRAJECTORYPOINT']._serialized_end=666
# @@protoc_insertion_point(module_scope)
