# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/scan_data2202.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import scan_point2202_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_scan__point2202__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/ibeo_msgs/msg/scan_data2202.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x41make87_messages_ros2/rolling/ibeo_msgs/msg/ibeo_data_header.proto\x1a?make87_messages_ros2/rolling/ibeo_msgs/msg/scan_point2202.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xee\x06\n\x0cScanData2202\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12O\n\x0bibeo_header\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.ibeo_msgs.msg.IbeoDataHeader\x12\x13\n\x0bscan_number\x18\x03 \x01(\r\x12\x16\n\x0escanner_status\x18\x04 \x01(\r\x12\x19\n\x11sync_phase_offset\x18\x05 \x01(\r\x12R\n\x0fscan_start_time\x18\x06 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12P\n\rscan_end_time\x18\x07 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12 \n\x18\x61ngle_ticks_per_rotation\x18\x08 \x01(\r\x12\x19\n\x11start_angle_ticks\x18\t \x01(\x05\x12\x17\n\x0f\x65nd_angle_ticks\x18\n \x01(\x05\x12\x19\n\x11scan_points_count\x18\x0b \x01(\r\x12 \n\x18mounting_yaw_angle_ticks\x18\x0c \x01(\x05\x12\"\n\x1amounting_pitch_angle_ticks\x18\r \x01(\x05\x12!\n\x19mounting_roll_angle_ticks\x18\x0e \x01(\x05\x12\x1b\n\x13mounting_position_x\x18\x0f \x01(\x05\x12\x1b\n\x13mounting_position_y\x18\x10 \x01(\x05\x12\x1b\n\x13mounting_position_z\x18\x11 \x01(\x05\x12\x16\n\x0eground_labeled\x18\x12 \x01(\x08\x12\x14\n\x0c\x64irt_labeled\x18\x13 \x01(\x08\x12\x14\n\x0crain_labeled\x18\x14 \x01(\x08\x12\x13\n\x0bmirror_side\x18\x15 \x01(\r\x12R\n\x0fscan_point_list\x18\x16 \x03(\x0b\x32\x39.make87_messages_ros2.rolling.ibeo_msgs.msg.ScanPoint2202b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.scan_data2202_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCANDATA2202']._serialized_start=363
  _globals['_SCANDATA2202']._serialized_end=1241
# @@protoc_insertion_point(module_scope)
