# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/sick_safetyscanners2_interfaces/msg/scan_point.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/sick_safetyscanners2_interfaces/msg/scan_point.proto\x12?make87_messages_ros2.humble.sick_safetyscanners2_interfaces.msg\x1a!make87_messages/core/header.proto\"\xe9\x01\n\tScanPoint\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05\x61ngle\x18\x02 \x01(\x02\x12\x10\n\x08\x64istance\x18\x03 \x01(\r\x12\x14\n\x0creflectivity\x18\x04 \x01(\r\x12\r\n\x05valid\x18\x05 \x01(\x08\x12\x10\n\x08infinite\x18\x06 \x01(\x08\x12\r\n\x05glare\x18\x07 \x01(\x08\x12\x11\n\treflector\x18\x08 \x01(\x08\x12\x15\n\rcontamination\x18\t \x01(\x08\x12\x1d\n\x15\x63ontamination_warning\x18\n \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.sick_safetyscanners2_interfaces.msg.scan_point_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCANPOINT']._serialized_start=185
  _globals['_SCANPOINT']._serialized_end=418
# @@protoc_insertion_point(module_scope)
