# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/py_trees_ros_interfaces/srv/introspect_publishers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.py_trees_ros_interfaces.msg import publisher_details_pb2 as make87__messages__ros2_dot_humble_dot_py__trees__ros__interfaces_dot_msg_dot_publisher__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/humble/py_trees_ros_interfaces/srv/introspect_publishers.proto\x12\x37make87_messages_ros2.humble.py_trees_ros_interfaces.srv\x1a!make87_messages/core/header.proto\x1aOmake87_messages_ros2/humble/py_trees_ros_interfaces/msg/publisher_details.proto\"K\n\x1bIntrospectPublishersRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\"\xb2\x01\n\x1cIntrospectPublishersResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x64\n\x11publisher_details\x18\x02 \x03(\x0b\x32I.make87_messages_ros2.humble.py_trees_ros_interfaces.msg.PublisherDetailsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.py_trees_ros_interfaces.srv.introspect_publishers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INTROSPECTPUBLISHERSREQUEST']._serialized_start=260
  _globals['_INTROSPECTPUBLISHERSREQUEST']._serialized_end=335
  _globals['_INTROSPECTPUBLISHERSRESPONSE']._serialized_start=338
  _globals['_INTROSPECTPUBLISHERSRESPONSE']._serialized_end=516
# @@protoc_insertion_point(module_scope)
