# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/plansys2_msgs/srv/add_problem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/plansys2_msgs/srv/add_problem.proto\x12,make87_messages_ros2.jazzy.plansys2_msgs.srv\"$\n\x11\x41\x64\x64ProblemRequest\x12\x0f\n\x07problem\x18\x01 \x01(\t\"9\n\x12\x41\x64\x64ProblemResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nerror_info\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.plansys2_msgs.srv.add_problem_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ADDPROBLEMREQUEST']._serialized_start=112
  _globals['_ADDPROBLEMREQUEST']._serialized_end=148
  _globals['_ADDPROBLEMRESPONSE']._serialized_start=150
  _globals['_ADDPROBLEMRESPONSE']._serialized_end=207
# @@protoc_insertion_point(module_scope)
