# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/bosch_locator_bridge/srv/client_expand_map_enable.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/humble/bosch_locator_bridge/srv/client_expand_map_enable.proto\x12\x34make87_messages_ros2.humble.bosch_locator_bridge.srv\x1a!make87_messages/core/header.proto\"d\n\x1c\x43lientExpandMapEnableRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x16\n\x0eprior_map_name\x18\x02 \x01(\t\"M\n\x1d\x43lientExpandMapEnableResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Headerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.bosch_locator_bridge.srv.client_expand_map_enable_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLIENTEXPANDMAPENABLEREQUEST']._serialized_start=176
  _globals['_CLIENTEXPANDMAPENABLEREQUEST']._serialized_end=276
  _globals['_CLIENTEXPANDMAPENABLERESPONSE']._serialized_start=278
  _globals['_CLIENTEXPANDMAPENABLERESPONSE']._serialized_end=355
# @@protoc_insertion_point(module_scope)
