# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ouster_msgs/msg/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/humble/ouster_msgs/msg/metadata.proto\x12+make87_messages_ros2.humble.ouster_msgs.msg\x1a!make87_messages/core/header.proto\"\xc4\x02\n\x08Metadata\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x12\n\nlidar_mode\x18\x03 \x01(\t\x12\x16\n\x0etimestamp_mode\x18\x04 \x01(\t\x12\x1b\n\x13\x62\x65\x61m_azimuth_angles\x18\x05 \x03(\x01\x12\x1c\n\x14\x62\x65\x61m_altitude_angles\x18\x06 \x03(\x01\x12\x1f\n\x17imu_to_sensor_transform\x18\x07 \x03(\x01\x12!\n\x19lidar_to_sensor_transform\x18\x08 \x03(\x01\x12\x11\n\tserial_no\x18\t \x01(\t\x12\x14\n\x0c\x66irmware_rev\x18\n \x01(\t\x12\x10\n\x08imu_port\x18\x0b \x01(\x05\x12\x12\n\nlidar_port\x18\x0c \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ouster_msgs.msg.metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_METADATA']._serialized_start=143
  _globals['_METADATA']._serialized_end=467
# @@protoc_insertion_point(module_scope)
