# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/place_location.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import gripper_translation_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_gripper__translation__pb2
from make87_messages_ros2.jazzy.trajectory_msgs.msg import joint_trajectory_pb2 as make87__messages__ros2_dot_jazzy_dot_trajectory__msgs_dot_msg_dot_joint__trajectory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/moveit_msgs/msg/place_location.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a?make87_messages_ros2/jazzy/geometry_msgs/msg/pose_stamped.proto\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/gripper_translation.proto\x1a\x45make87_messages_ros2/jazzy/trajectory_msgs/msg/joint_trajectory.proto\"\xaf\x03\n\rPlaceLocation\x12\n\n\x02id\x18\x01 \x01(\t\x12[\n\x12post_place_posture\x18\x02 \x01(\x0b\x32?.make87_messages_ros2.jazzy.trajectory_msgs.msg.JointTrajectory\x12M\n\nplace_pose\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.geometry_msgs.msg.PoseStamped\x12\x0f\n\x07quality\x18\x04 \x01(\x01\x12Z\n\x12pre_place_approach\x18\x05 \x01(\x0b\x32>.make87_messages_ros2.jazzy.moveit_msgs.msg.GripperTranslation\x12Z\n\x12post_place_retreat\x18\x06 \x01(\x0b\x32>.make87_messages_ros2.jazzy.moveit_msgs.msg.GripperTranslation\x12\x1d\n\x15\x61llowed_touch_objects\x18\x07 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.place_location_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLACELOCATION']._serialized_start=318
  _globals['_PLACELOCATION']._serialized_end=749
# @@protoc_insertion_point(module_scope)
