# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/septentrio_gnss_driver/msg/rf_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.septentrio_gnss_driver.msg import block_header_pb2 as make87__messages__ros2_dot_rolling_dot_septentrio__gnss__driver_dot_msg_dot_block__header__pb2
from make87_messages_ros2.rolling.septentrio_gnss_driver.msg import rf_band_pb2 as make87__messages__ros2_dot_rolling_dot_septentrio__gnss__driver_dot_msg_dot_rf__band__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/septentrio_gnss_driver/msg/rf_status.proto\x12\x37make87_messages_ros2.rolling.septentrio_gnss_driver.msg\x1aJmake87_messages_ros2/rolling/septentrio_gnss_driver/msg/block_header.proto\x1a\x45make87_messages_ros2/rolling/septentrio_gnss_driver/msg/rf_band.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xa7\x02\n\x08RFStatus\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12Z\n\x0c\x62lock_header\x18\x02 \x01(\x0b\x32\x44.make87_messages_ros2.rolling.septentrio_gnss_driver.msg.BlockHeader\x12\t\n\x01n\x18\x03 \x01(\r\x12\x11\n\tsb_length\x18\x04 \x01(\r\x12\r\n\x05\x66lags\x18\x05 \x01(\r\x12O\n\x06rfband\x18\x06 \x03(\x0b\x32?.make87_messages_ros2.rolling.septentrio_gnss_driver.msg.RFBandb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.septentrio_gnss_driver.msg.rf_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RFSTATUS']._serialized_start=336
  _globals['_RFSTATUS']._serialized_end=631
# @@protoc_insertion_point(module_scope)
