# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_task_msgs/msg/tow.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6make87_messages_ros2/jazzy/rmf_task_msgs/msg/tow.proto\x12,make87_messages_ros2.jazzy.rmf_task_msgs.msg\"\xb1\x01\n\x03Tow\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x13\n\x0bobject_type\x18\x02 \x01(\t\x12\x1a\n\x12is_object_id_known\x18\x03 \x01(\x08\x12\x11\n\tobject_id\x18\x04 \x01(\t\x12\x19\n\x11pickup_place_name\x18\x05 \x01(\t\x12\x1e\n\x16is_dropoff_place_known\x18\x06 \x01(\x08\x12\x1a\n\x12\x64ropoff_place_name\x18\x07 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_task_msgs.msg.tow_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TOW']._serialized_start=105
  _globals['_TOW']._serialized_end=282
# @@protoc_insertion_point(module_scope)
