# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_fleet_msgs/msg/closed_lanes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/rmf_fleet_msgs/msg/closed_lanes.proto\x12-make87_messages_ros2.jazzy.rmf_fleet_msgs.msg\"7\n\x0b\x43losedLanes\x12\x12\n\nfleet_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63losed_lanes\x18\x02 \x03(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.closed_lanes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLOSEDLANES']._serialized_start=115
  _globals['_CLOSEDLANES']._serialized_end=170
# @@protoc_insertion_point(module_scope)
