# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/geographic_msgs/srv/get_geographic_map.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geographic_msgs.msg import bounding_box_pb2 as make87__messages__ros2_dot_rolling_dot_geographic__msgs_dot_msg_dot_bounding__box__pb2
from make87_messages_ros2.rolling.geographic_msgs.msg import geographic_map_pb2 as make87__messages__ros2_dot_rolling_dot_geographic__msgs_dot_msg_dot_geographic__map__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/geographic_msgs/srv/get_geographic_map.proto\x12\x30make87_messages_ros2.rolling.geographic_msgs.srv\x1a\x43make87_messages_ros2/rolling/geographic_msgs/msg/bounding_box.proto\x1a\x45make87_messages_ros2/rolling/geographic_msgs/msg/geographic_map.proto\"u\n\x17GetGeographicMapRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12M\n\x06\x62ounds\x18\x02 \x01(\x0b\x32=.make87_messages_ros2.rolling.geographic_msgs.msg.BoundingBox\"\x89\x01\n\x18GetGeographicMapResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\t\x12L\n\x03map\x18\x03 \x01(\x0b\x32?.make87_messages_ros2.rolling.geographic_msgs.msg.GeographicMapb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.geographic_msgs.srv.get_geographic_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETGEOGRAPHICMAPREQUEST']._serialized_start=267
  _globals['_GETGEOGRAPHICMAPREQUEST']._serialized_end=384
  _globals['_GETGEOGRAPHICMAPRESPONSE']._serialized_start=387
  _globals['_GETGEOGRAPHICMAPRESPONSE']._serialized_end=524
# @@protoc_insertion_point(module_scope)
