# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nav2_msgs/srv/get_costmap.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.nav2_msgs.msg import costmap_pb2 as make87__messages__ros2_dot_jazzy_dot_nav2__msgs_dot_msg_dot_costmap__pb2
from make87_messages_ros2.jazzy.nav2_msgs.msg import costmap_meta_data_pb2 as make87__messages__ros2_dot_jazzy_dot_nav2__msgs_dot_msg_dot_costmap__meta__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/nav2_msgs/srv/get_costmap.proto\x12(make87_messages_ros2.jazzy.nav2_msgs.srv\x1a\x36make87_messages_ros2/jazzy/nav2_msgs/msg/costmap.proto\x1a@make87_messages_ros2/jazzy/nav2_msgs/msg/costmap_meta_data.proto\"]\n\x11GetCostmapRequest\x12H\n\x05specs\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.nav2_msgs.msg.CostmapMetaData\"T\n\x12GetCostmapResponse\x12>\n\x03map\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.jazzy.nav2_msgs.msg.Costmapb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nav2_msgs.srv.get_costmap_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETCOSTMAPREQUEST']._serialized_start=226
  _globals['_GETCOSTMAPREQUEST']._serialized_end=319
  _globals['_GETCOSTMAPRESPONSE']._serialized_start=321
  _globals['_GETCOSTMAPRESPONSE']._serialized_end=405
# @@protoc_insertion_point(module_scope)
