# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_reservation_msgs/msg/flexible_time_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_reservation_msgs.msg import flexible_time_reservation_alt_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__reservation__msgs_dot_msg_dot_flexible__time__reservation__alt__pb2
from make87_messages_ros2.rolling.rmf_reservation_msgs.msg import request_header_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__reservation__msgs_dot_msg_dot_request__header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/rolling/rmf_reservation_msgs/msg/flexible_time_request.proto\x12\x35make87_messages_ros2.rolling.rmf_reservation_msgs.msg\x1aYmake87_messages_ros2/rolling/rmf_reservation_msgs/msg/flexible_time_reservation_alt.proto\x1aJmake87_messages_ros2/rolling/rmf_reservation_msgs/msg/request_header.proto\"\xd4\x01\n\x13\x46lexibleTimeRequest\x12T\n\x06header\x18\x01 \x01(\x0b\x32\x44.make87_messages_ros2.rolling.rmf_reservation_msgs.msg.RequestHeader\x12g\n\x0c\x61lternatives\x18\x02 \x03(\x0b\x32Q.make87_messages_ros2.rolling.rmf_reservation_msgs.msg.FlexibleTimeReservationAltb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_reservation_msgs.msg.flexible_time_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FLEXIBLETIMEREQUEST']._serialized_start=308
  _globals['_FLEXIBLETIMEREQUEST']._serialized_end=520
# @@protoc_insertion_point(module_scope)
