# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_plan.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import path_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_path__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_plan.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.srv\x1a?make87_messages_ros2/jazzy/geometry_msgs/msg/pose_stamped.proto\x1a\x36make87_messages_ros2/jazzy/rtabmap_msgs/msg/path.proto\"\x7f\n\x0eGetPlanRequest\x12\x11\n\tgoal_node\x18\x01 \x01(\x05\x12G\n\x04goal\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.geometry_msgs.msg.PoseStamped\x12\x11\n\ttolerance\x18\x03 \x01(\x02\"R\n\x0fGetPlanResponse\x12?\n\x04plan\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.jazzy.rtabmap_msgs.msg.Pathb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.srv.get_plan_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETPLANREQUEST']._serialized_start=228
  _globals['_GETPLANREQUEST']._serialized_end=355
  _globals['_GETPLANRESPONSE']._serialized_start=357
  _globals['_GETPLANRESPONSE']._serialized_end=439
# @@protoc_insertion_point(module_scope)
