# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/point_cloud_interfaces/msg/compressed_point_cloud2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sensor_msgs.msg import point_field_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_point__field__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/jazzy/point_cloud_interfaces/msg/compressed_point_cloud2.proto\x12\x35make87_messages_ros2.jazzy.point_cloud_interfaces.msg\x1a<make87_messages_ros2/jazzy/sensor_msgs/msg/point_field.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xb6\x02\n\x15\x43ompressedPointCloud2\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0e\n\x06height\x18\x02 \x01(\r\x12\r\n\x05width\x18\x03 \x01(\r\x12\x46\n\x06\x66ields\x18\x04 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.sensor_msgs.msg.PointField\x12\x14\n\x0cis_bigendian\x18\x05 \x01(\x08\x12\x12\n\npoint_step\x18\x06 \x01(\r\x12\x10\n\x08row_step\x18\x07 \x01(\r\x12\x17\n\x0f\x63ompressed_data\x18\x08 \x03(\r\x12\x10\n\x08is_dense\x18\t \x01(\x08\x12\x0e\n\x06\x66ormat\x18\n \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.point_cloud_interfaces.msg.compressed_point_cloud2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMPRESSEDPOINTCLOUD2']._serialized_start=259
  _globals['_COMPRESSEDPOINTCLOUD2']._serialized_end=569
# @@protoc_insertion_point(module_scope)
