# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/lgsvl_msgs/msg/detection3_d.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import twist_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_twist__pb2
from make87_messages_ros2.rolling.lgsvl_msgs.msg import bounding_box3_d_pb2 as make87__messages__ros2_dot_rolling_dot_lgsvl__msgs_dot_msg_dot_bounding__box3__d__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/lgsvl_msgs/msg/detection3_d.proto\x12+make87_messages_ros2.rolling.lgsvl_msgs.msg\x1a:make87_messages_ros2/rolling/geometry_msgs/msg/twist.proto\x1a\x41make87_messages_ros2/rolling/lgsvl_msgs/msg/bounding_box3_d.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\x8d\x02\n\x0b\x44\x65tection3D\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\n\n\x02id\x18\x02 \x01(\r\x12\r\n\x05label\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x02\x12H\n\x04\x62\x62ox\x18\x05 \x01(\x0b\x32:.make87_messages_ros2.rolling.lgsvl_msgs.msg.BoundingBox3D\x12G\n\x08velocity\x18\x06 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Twistb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.lgsvl_msgs.msg.detection3_d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DETECTION3D']._serialized_start=295
  _globals['_DETECTION3D']._serialized_end=564
# @@protoc_insertion_point(module_scope)
