# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/srv/command_ack.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/mavros_msgs/srv/command_ack.proto\x12,make87_messages_ros2.rolling.mavros_msgs.srv\"]\n\x11\x43ommandAckRequest\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\r\x12\x0e\n\x06result\x18\x02 \x01(\r\x12\x10\n\x08progress\x18\x03 \x01(\r\x12\x15\n\rresult_param2\x18\x04 \x01(\r\"5\n\x12\x43ommandAckResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06result\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.srv.command_ack_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMMANDACKREQUEST']._serialized_start=112
  _globals['_COMMANDACKREQUEST']._serialized_end=205
  _globals['_COMMANDACKRESPONSE']._serialized_start=207
  _globals['_COMMANDACKRESPONSE']._serialized_end=260
# @@protoc_insertion_point(module_scope)
