# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/action_msgs/msg/goal_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_jazzy_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/action_msgs/msg/goal_info.proto\x12*make87_messages_ros2.jazzy.action_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a@make87_messages_ros2/jazzy/unique_identifier_msgs/msg/uuid.proto\"\xa0\x01\n\x08GoalInfo\x12L\n\x07goal_id\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.jazzy.unique_identifier_msgs.msg.UUID\x12\x46\n\x05stamp\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Timeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.action_msgs.msg.goal_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GOALINFO']._serialized_start=235
  _globals['_GOALINFO']._serialized_end=395
# @@protoc_insertion_point(module_scope)
