# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ds_dbw_msgs/msg/monitor_report.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/ds_dbw_msgs/msg/monitor_report.proto\x12+make87_messages_ros2.humble.ds_dbw_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xf3\x0c\n\rMonitorReport\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\r\n\x05\x66\x61ult\x18\x03 \x01(\x08\x12\x0f\n\x07shutoff\x18\x04 \x01(\x08\x12\x19\n\x11shutoff_on_motion\x18\x05 \x01(\x08\x12\x12\n\nstationary\x18\x06 \x01(\x08\x12\x12\n\nfault_test\x18\x07 \x01(\r\x12\x14\n\x0c\x66\x61ult_system\x18\x08 \x01(\r\x12\x13\n\x0b\x66\x61ult_steer\x18\t \x01(\r\x12\x13\n\x0b\x66\x61ult_brake\x18\n \x01(\r\x12\x13\n\x0b\x66\x61ult_thrtl\x18\x0b \x01(\r\x12\x12\n\nfault_gear\x18\x0c \x01(\r\x12\x11\n\tfault_ulc\x18\r \x01(\r\x12\x1e\n\x16\x66\x61ult_vehicle_velocity\x18\x0e \x01(\r\x12\x1c\n\x14\x66\x61ult_steer_feedback\x18\x0f \x01(\r\x12\x19\n\x11\x66\x61ult_steer_input\x18\x10 \x01(\r\x12\x19\n\x11\x66\x61ult_steer_param\x18\x11 \x01(\r\x12\x19\n\x11\x66\x61ult_steer_limit\x18\x12 \x01(\r\x12\x1c\n\x14\x66\x61ult_steer_override\x18\x13 \x01(\r\x12\x17\n\x0f\x66\x61ult_steer_cmd\x18\x14 \x01(\r\x12\x1c\n\x14\x66\x61ult_steer_cmd_rate\x18\x15 \x01(\r\x12\x1a\n\x12\x66\x61ult_steer_cmd_en\x18\x16 \x01(\r\x12\x1b\n\x13\x66\x61ult_steer_cmd_sys\x18\x17 \x01(\r\x12\x1b\n\x13\x66\x61ult_steer_cmd_ovr\x18\x18 \x01(\r\x12\x1c\n\x14\x66\x61ult_brake_feedback\x18\x19 \x01(\r\x12\x19\n\x11\x66\x61ult_brake_input\x18\x1a \x01(\r\x12\x19\n\x11\x66\x61ult_brake_param\x18\x1b \x01(\r\x12\x19\n\x11\x66\x61ult_brake_limit\x18\x1c \x01(\r\x12\x1c\n\x14\x66\x61ult_brake_override\x18\x1d \x01(\r\x12\x17\n\x0f\x66\x61ult_brake_cmd\x18\x1e \x01(\r\x12\x1b\n\x13\x66\x61ult_brake_cmd_ulc\x18\x1f \x01(\r\x12\x1a\n\x12\x66\x61ult_brake_cmd_en\x18  \x01(\r\x12\x1b\n\x13\x66\x61ult_brake_cmd_sys\x18! \x01(\r\x12\x1b\n\x13\x66\x61ult_brake_cmd_ovr\x18\" \x01(\r\x12\x1c\n\x14\x66\x61ult_thrtl_feedback\x18# \x01(\r\x12\x19\n\x11\x66\x61ult_thrtl_input\x18$ \x01(\r\x12\x19\n\x11\x66\x61ult_thrtl_param\x18% \x01(\r\x12\x19\n\x11\x66\x61ult_thrtl_limit\x18& \x01(\r\x12\x1c\n\x14\x66\x61ult_thrtl_override\x18\' \x01(\r\x12\x17\n\x0f\x66\x61ult_thrtl_cmd\x18( \x01(\r\x12\x1b\n\x13\x66\x61ult_thrtl_cmd_ulc\x18) \x01(\r\x12\x1a\n\x12\x66\x61ult_thrtl_cmd_en\x18* \x01(\r\x12\x1b\n\x13\x66\x61ult_thrtl_cmd_sys\x18+ \x01(\r\x12\x1b\n\x13\x66\x61ult_thrtl_cmd_ovr\x18, \x01(\r\x12\x1b\n\x13\x66\x61ult_gear_feedback\x18- \x01(\r\x12\x18\n\x10\x66\x61ult_gear_input\x18. \x01(\r\x12\x18\n\x10\x66\x61ult_gear_param\x18/ \x01(\r\x12\x1b\n\x13\x66\x61ult_gear_override\x18\x30 \x01(\r\x12\x16\n\x0e\x66\x61ult_gear_cmd\x18\x31 \x01(\r\x12\x1a\n\x12\x66\x61ult_gear_cmd_ulc\x18\x32 \x01(\r\x12\x1a\n\x12\x66\x61ult_system_param\x18\x33 \x01(\r\x12\x1b\n\x13steer_cmd_match_oem\x18\x34 \x01(\x08\x12\x1b\n\x13steer_cmd_match_dbw\x18\x35 \x01(\x08\x12\x1b\n\x13\x62rake_cmd_match_oem\x18\x36 \x01(\x08\x12\x1b\n\x13\x62rake_cmd_match_dbw\x18\x37 \x01(\x08\x12\x1b\n\x13thrtl_cmd_match_oem\x18\x38 \x01(\x08\x12\x1b\n\x13thrtl_cmd_match_dbw\x18\x39 \x01(\x08\x12\x1a\n\x12gear_cmd_match_oem\x18: \x01(\x08\x12\x1a\n\x12gear_cmd_match_dbw\x18; \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ds_dbw_msgs.msg.monitor_report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MONITORREPORT']._serialized_start=204
  _globals['_MONITORREPORT']._serialized_end=1855
# @@protoc_insertion_point(module_scope)
