# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/neobotix_usboard_msgs/msg/command.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/neobotix_usboard_msgs/msg/command.proto\x12\x34make87_messages_ros2.jazzy.neobotix_usboard_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xbf\x02\n\x07\x43ommand\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\r\x12\x14\n\x0c\x63ommand_data\x18\x03 \x01(\x04\x12\x0f\n\x07set_num\x18\x04 \x01(\r\x12\x15\n\rparaset_byte6\x18\x05 \x01(\r\x12\x15\n\rparaset_byte5\x18\x06 \x01(\r\x12\x15\n\rparaset_byte4\x18\x07 \x01(\r\x12\x15\n\rparaset_byte3\x18\x08 \x01(\r\x12\x15\n\rparaset_byte2\x18\t \x01(\r\x12\x15\n\rparaset_byte1\x18\n \x01(\r\x12\x18\n\x10set_active_9to16\x18\x0b \x01(\r\x12\x17\n\x0fset_active_1to8\x18\x0c \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.neobotix_usboard_msgs.msg.command_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMMAND']._serialized_start=179
  _globals['_COMMAND']._serialized_end=498
# @@protoc_insertion_point(module_scope)
