# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/msg/sensor_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_transform__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import env_sensor_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_env__sensor__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import global_descriptor_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_global__descriptor__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import gps_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_gps__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import key_point_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_key__point__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import landmark_detection_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_landmark__detection__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import point3f_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_point3f__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import camera_info_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_camera__info__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import image_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_image__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import imu_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_imu__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/rtabmap_msgs/msg/sensor_data.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.msg\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x1a<make87_messages_ros2/jazzy/geometry_msgs/msg/transform.proto\x1a<make87_messages_ros2/jazzy/rtabmap_msgs/msg/env_sensor.proto\x1a\x43make87_messages_ros2/jazzy/rtabmap_msgs/msg/global_descriptor.proto\x1a\x35make87_messages_ros2/jazzy/rtabmap_msgs/msg/gps.proto\x1a;make87_messages_ros2/jazzy/rtabmap_msgs/msg/key_point.proto\x1a\x44make87_messages_ros2/jazzy/rtabmap_msgs/msg/landmark_detection.proto\x1a\x39make87_messages_ros2/jazzy/rtabmap_msgs/msg/point3f.proto\x1a<make87_messages_ros2/jazzy/sensor_msgs/msg/camera_info.proto\x1a\x36make87_messages_ros2/jazzy/sensor_msgs/msg/image.proto\x1a\x34make87_messages_ros2/jazzy/sensor_msgs/msg/imu.proto\x1a=make87_messages_ros2/jazzy/sensor_msgs/msg/point_cloud2.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x9c\r\n\nSensorData\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12?\n\x04left\x18\x02 \x01(\x0b\x32\x31.make87_messages_ros2.jazzy.sensor_msgs.msg.Image\x12@\n\x05right\x18\x03 \x01(\x0b\x32\x31.make87_messages_ros2.jazzy.sensor_msgs.msg.Image\x12\x17\n\x0fleft_compressed\x18\x04 \x03(\r\x12\x18\n\x10right_compressed\x18\x05 \x03(\r\x12P\n\x10left_camera_info\x18\x06 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.sensor_msgs.msg.CameraInfo\x12Q\n\x11right_camera_info\x18\x07 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.sensor_msgs.msg.CameraInfo\x12P\n\x0flocal_transform\x18\x08 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.geometry_msgs.msg.Transform\x12K\n\nlaser_scan\x18\t \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.sensor_msgs.msg.PointCloud2\x12\x1d\n\x15laser_scan_compressed\x18\n \x03(\r\x12\x1a\n\x12laser_scan_max_pts\x18\x0b \x01(\x05\x12\x1c\n\x14laser_scan_max_range\x18\x0c \x01(\x02\x12\x19\n\x11laser_scan_format\x18\r \x01(\x05\x12[\n\x1alaser_scan_local_transform\x18\x0e \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.geometry_msgs.msg.Transform\x12\x11\n\tuser_data\x18\x0f \x03(\r\x12\x13\n\x0bgrid_ground\x18\x10 \x03(\r\x12\x16\n\x0egrid_obstacles\x18\x11 \x03(\r\x12\x18\n\x10grid_empty_cells\x18\x12 \x03(\r\x12\x16\n\x0egrid_cell_size\x18\x13 \x01(\x02\x12M\n\x0fgrid_view_point\x18\x14 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.rtabmap_msgs.msg.Point3f\x12I\n\nkey_points\x18\x15 \x03(\x0b\x32\x35.make87_messages_ros2.jazzy.rtabmap_msgs.msg.KeyPoint\x12\x44\n\x06points\x18\x16 \x03(\x0b\x32\x34.make87_messages_ros2.jazzy.rtabmap_msgs.msg.Point3f\x12\x13\n\x0b\x64\x65scriptors\x18\x17 \x03(\r\x12Y\n\x12global_descriptors\x18\x18 \x03(\x0b\x32=.make87_messages_ros2.jazzy.rtabmap_msgs.msg.GlobalDescriptor\x12K\n\x0b\x65nv_sensors\x18\x19 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.rtabmap_msgs.msg.EnvSensor\x12<\n\x03imu\x18\x1a \x01(\x0b\x32/.make87_messages_ros2.jazzy.sensor_msgs.msg.Imu\x12T\n\x13imu_local_transform\x18\x1b \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.geometry_msgs.msg.Transform\x12Q\n\tlandmarks\x18\x1c \x03(\x0b\x32>.make87_messages_ros2.jazzy.rtabmap_msgs.msg.LandmarkDetection\x12M\n\x11ground_truth_pose\x18\x1d \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12=\n\x03gps\x18\x1e \x01(\x0b\x32\x30.make87_messages_ros2.jazzy.rtabmap_msgs.msg.GPSb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.msg.sensor_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SENSORDATA']._serialized_start=895
  _globals['_SENSORDATA']._serialized_end=2587
# @@protoc_insertion_point(module_scope)
