# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ibeo_msgs/msg/scanner_info2205.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import mounting_position_f_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_mounting__position__f__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import resolution_info_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_resolution__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/ibeo_msgs/msg/scanner_info2205.proto\x12)make87_messages_ros2.humble.ibeo_msgs.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/builtin_interfaces/msg/time.proto\x1a\x43make87_messages_ros2/humble/ibeo_msgs/msg/mounting_position_f.proto\x1a?make87_messages_ros2/humble/ibeo_msgs/msg/resolution_info.proto\"\xed\x05\n\x0fScannerInfo2205\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x14\n\x0cscanner_type\x18\x03 \x01(\r\x12\x13\n\x0bscan_number\x18\x04 \x01(\r\x12\x13\n\x0bstart_angle\x18\x05 \x01(\x02\x12\x11\n\tend_angle\x18\x06 \x01(\x02\x12Q\n\x0fscan_start_time\x18\x07 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12O\n\rscan_end_time\x18\x08 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12]\n\x1bscan_start_time_from_device\x18\t \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12[\n\x19scan_end_time_from_device\x18\n \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12\x16\n\x0escan_frequency\x18\x0b \x01(\x02\x12\x11\n\tbeam_tilt\x18\x0c \x01(\x02\x12\x12\n\nscan_flags\x18\r \x01(\r\x12W\n\x11mounting_position\x18\x0e \x01(\x0b\x32<.make87_messages_ros2.humble.ibeo_msgs.msg.MountingPositionF\x12N\n\x0bresolutions\x18\x0f \x03(\x0b\x32\x39.make87_messages_ros2.humble.ibeo_msgs.msg.ResolutionInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ibeo_msgs.msg.scanner_info2205_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCANNERINFO2205']._serialized_start=344
  _globals['_SCANNERINFO2205']._serialized_end=1093
# @@protoc_insertion_point(module_scope)
