# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/map_msgs/srv/get_map_roi.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.nav_msgs.msg import occupancy_grid_pb2 as make87__messages__ros2_dot_humble_dot_nav__msgs_dot_msg_dot_occupancy__grid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/humble/map_msgs/srv/get_map_roi.proto\x12(make87_messages_ros2.humble.map_msgs.srv\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/nav_msgs/msg/occupancy_grid.proto\"p\n\x10GetMapROIRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\x0b\n\x03l_x\x18\x04 \x01(\x01\x12\x0b\n\x03l_y\x18\x05 \x01(\x01\"\x8b\x01\n\x11GetMapROIResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12H\n\x07sub_map\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.humble.nav_msgs.msg.OccupancyGridb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.map_msgs.srv.get_map_roi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETMAPROIREQUEST']._serialized_start=202
  _globals['_GETMAPROIREQUEST']._serialized_end=314
  _globals['_GETMAPROIRESPONSE']._serialized_start=317
  _globals['_GETMAPROIRESPONSE']._serialized_end=456
# @@protoc_insertion_point(module_scope)
