# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marine_acoustic_msgs/msg/raw_sonar_image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.marine_acoustic_msgs.msg import ping_info_pb2 as make87__messages__ros2_dot_rolling_dot_marine__acoustic__msgs_dot_msg_dot_ping__info__pb2
from make87_messages_ros2.rolling.marine_acoustic_msgs.msg import sonar_image_data_pb2 as make87__messages__ros2_dot_rolling_dot_marine__acoustic__msgs_dot_msg_dot_sonar__image__data__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/rolling/marine_acoustic_msgs/msg/raw_sonar_image.proto\x12\x35make87_messages_ros2.rolling.marine_acoustic_msgs.msg\x1a\x45make87_messages_ros2/rolling/marine_acoustic_msgs/msg/ping_info.proto\x1aLmake87_messages_ros2/rolling/marine_acoustic_msgs/msg/sonar_image_data.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xf5\x02\n\rRawSonarImage\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12R\n\tping_info\x18\x02 \x01(\x0b\x32?.make87_messages_ros2.rolling.marine_acoustic_msgs.msg.PingInfo\x12\x13\n\x0bsample_rate\x18\x03 \x01(\x02\x12\x18\n\x10samples_per_beam\x18\x04 \x01(\r\x12\x0f\n\x07sample0\x18\x05 \x01(\r\x12\x11\n\ttx_delays\x18\x06 \x03(\x02\x12\x11\n\ttx_angles\x18\x07 \x03(\x02\x12\x11\n\trx_angles\x18\x08 \x03(\x02\x12T\n\x05image\x18\t \x01(\x0b\x32\x45.make87_messages_ros2.rolling.marine_acoustic_msgs.msg.SonarImageDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marine_acoustic_msgs.msg.raw_sonar_image_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RAWSONARIMAGE']._serialized_start=340
  _globals['_RAWSONARIMAGE']._serialized_end=713
# @@protoc_insertion_point(module_scope)
