# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/goalpost.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import spherical_pb2 as make87__messages__ros2_dot_jazzy_dot_rcss3d__agent__msgs_dot_msg_dot_spherical__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/goalpost.proto\x12\x30make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg\x1a@make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/spherical.proto\"b\n\x08Goalpost\x12\x0c\n\x04name\x18\x01 \x01(\t\x12H\n\x03top\x18\x02 \x01(\x0b\x32;.make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.Sphericalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.goalpost_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GOALPOST']._serialized_start=183
  _globals['_GOALPOST']._serialized_end=281
# @@protoc_insertion_point(module_scope)
