# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/py_trees_ros_interfaces/srv/get_blackboard_variables.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWmake87_messages_ros2/rolling/py_trees_ros_interfaces/srv/get_blackboard_variables.proto\x12\x38make87_messages_ros2.rolling.py_trees_ros_interfaces.srv\"\x1f\n\x1dGetBlackboardVariablesRequest\"3\n\x1eGetBlackboardVariablesResponse\x12\x11\n\tvariables\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.py_trees_ros_interfaces.srv.get_blackboard_variables_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETBLACKBOARDVARIABLESREQUEST']._serialized_start=149
  _globals['_GETBLACKBOARDVARIABLESREQUEST']._serialized_end=180
  _globals['_GETBLACKBOARDVARIABLESRESPONSE']._serialized_start=182
  _globals['_GETBLACKBOARDVARIABLESRESPONSE']._serialized_end=233
# @@protoc_insertion_point(module_scope)
