# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/py_trees_ros_interfaces/msg/behaviour.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.py_trees_ros_interfaces.msg import key_value_pb2 as make87__messages__ros2_dot_rolling_dot_py__trees__ros__interfaces_dot_msg_dot_key__value__pb2
from make87_messages_ros2.rolling.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_rolling_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/py_trees_ros_interfaces/msg/behaviour.proto\x12\x38make87_messages_ros2.rolling.py_trees_ros_interfaces.msg\x1aHmake87_messages_ros2/rolling/py_trees_ros_interfaces/msg/key_value.proto\x1a\x42make87_messages_ros2/rolling/unique_identifier_msgs/msg/uuid.proto\"\x9c\x05\n\tBehaviour\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nclass_name\x18\x02 \x01(\t\x12M\n\x06own_id\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12P\n\tparent_id\x18\x04 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12M\n\x06tip_id\x18\x05 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12P\n\tchild_ids\x18\x06 \x03(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12W\n\x10\x63urrent_child_id\x18\x07 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12\x0c\n\x04type\x18\x08 \x01(\r\x12\x19\n\x11\x61\x64\x64itional_detail\x18\t \x01(\t\x12\x16\n\x0e\x62lackbox_level\x18\n \x01(\r\x12\x0e\n\x06status\x18\x0b \x01(\r\x12\x0f\n\x07message\x18\x0c \x01(\t\x12\x11\n\tis_active\x18\r \x01(\x08\x12]\n\x11\x62lackboard_access\x18\x0e \x03(\x0b\x32\x42.make87_messages_ros2.rolling.py_trees_ros_interfaces.msg.KeyValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.py_trees_ros_interfaces.msg.behaviour_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BEHAVIOUR']._serialized_start=277
  _globals['_BEHAVIOUR']._serialized_end=945
# @@protoc_insertion_point(module_scope)
