# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rcss3d_agent_msgs/msg/universal_joint_vel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/rolling/rcss3d_agent_msgs/msg/universal_joint_vel.proto\x12\x32make87_messages_ros2.rolling.rcss3d_agent_msgs.msg\";\n\x11UniversalJointVel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03\x61x1\x18\x02 \x01(\x02\x12\x0b\n\x03\x61x2\x18\x03 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rcss3d_agent_msgs.msg.universal_joint_vel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UNIVERSALJOINTVEL']._serialized_start=132
  _globals['_UNIVERSALJOINTVEL']._serialized_end=191
# @@protoc_insertion_point(module_scope)
