# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_nav_msgs/srv/get_route_list.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.marti_nav_msgs.msg import route_pb2 as make87__messages__ros2_dot_rolling_dot_marti__nav__msgs_dot_msg_dot_route__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/rolling/marti_nav_msgs/srv/get_route_list.proto\x12/make87_messages_ros2.rolling.marti_nav_msgs.srv\x1a;make87_messages_ros2/rolling/marti_nav_msgs/msg/route.proto\"\x15\n\x13GetRouteListRequest\"\x80\x01\n\x14GetRouteListResponse\x12\x46\n\x06routes\x18\x01 \x03(\x0b\x32\x36.make87_messages_ros2.rolling.marti_nav_msgs.msg.Route\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0f\n\x07message\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_nav_msgs.srv.get_route_list_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETROUTELISTREQUEST']._serialized_start=182
  _globals['_GETROUTELISTREQUEST']._serialized_end=203
  _globals['_GETROUTELISTRESPONSE']._serialized_start=206
  _globals['_GETROUTELISTRESPONSE']._serialized_end=334
# @@protoc_insertion_point(module_scope)
