# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/canopen_interfaces/srv/co_target_double.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/canopen_interfaces/srv/co_target_double.proto\x12\x33make87_messages_ros2.rolling.canopen_interfaces.srv\"\'\n\x15\x43OTargetDoubleRequest\x12\x0e\n\x06target\x18\x01 \x01(\x01\")\n\x16\x43OTargetDoubleResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.canopen_interfaces.srv.co_target_double_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COTARGETDOUBLEREQUEST']._serialized_start=131
  _globals['_COTARGETDOUBLEREQUEST']._serialized_end=170
  _globals['_COTARGETDOUBLERESPONSE']._serialized_start=172
  _globals['_COTARGETDOUBLERESPONSE']._serialized_end=213
# @@protoc_insertion_point(module_scope)
