# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/get_planner_params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import planner_params_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_planner__params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/moveit_msgs/srv/get_planner_params.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\x1a?make87_messages_ros2/jazzy/moveit_msgs/msg/planner_params.proto\"U\n\x17GetPlannerParamsRequest\x12\x13\n\x0bpipeline_id\x18\x01 \x01(\t\x12\x16\n\x0eplanner_config\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\"e\n\x18GetPlannerParamsResponse\x12I\n\x06params\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.moveit_msgs.msg.PlannerParamsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.get_planner_params_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETPLANNERPARAMSREQUEST']._serialized_start=180
  _globals['_GETPLANNERPARAMSREQUEST']._serialized_end=265
  _globals['_GETPLANNERPARAMSRESPONSE']._serialized_start=267
  _globals['_GETPLANNERPARAMSRESPONSE']._serialized_end=368
# @@protoc_insertion_point(module_scope)
