# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rcl_interfaces/srv/get_logger_levels.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rcl_interfaces.msg import logger_level_pb2 as make87__messages__ros2_dot_jazzy_dot_rcl__interfaces_dot_msg_dot_logger__level__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/rcl_interfaces/srv/get_logger_levels.proto\x12-make87_messages_ros2.jazzy.rcl_interfaces.srv\x1a@make87_messages_ros2/jazzy/rcl_interfaces/msg/logger_level.proto\"\'\n\x16GetLoggerLevelsRequest\x12\r\n\x05names\x18\x01 \x03(\t\"e\n\x17GetLoggerLevelsResponse\x12J\n\x06levels\x18\x01 \x03(\x0b\x32:.make87_messages_ros2.jazzy.rcl_interfaces.msg.LoggerLevelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rcl_interfaces.srv.get_logger_levels_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETLOGGERLEVELSREQUEST']._serialized_start=186
  _globals['_GETLOGGERLEVELSREQUEST']._serialized_end=225
  _globals['_GETLOGGERLEVELSRESPONSE']._serialized_start=227
  _globals['_GETLOGGERLEVELSRESPONSE']._serialized_end=328
# @@protoc_insertion_point(module_scope)
