# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/msg/load_carrier_with_filling_level.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import box_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_box__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import cell_filling_level_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_cell__filling__level__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import grid_size_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_grid__size__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import rectangle_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_rectangle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUmake87_messages_ros2/rolling/rc_reason_msgs/msg/load_carrier_with_filling_level.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.msg\x1a\x41make87_messages_ros2/rolling/geometry_msgs/msg/pose_stamped.proto\x1a\x39make87_messages_ros2/rolling/rc_reason_msgs/msg/box.proto\x1aHmake87_messages_ros2/rolling/rc_reason_msgs/msg/cell_filling_level.proto\x1a?make87_messages_ros2/rolling/rc_reason_msgs/msg/grid_size.proto\x1a?make87_messages_ros2/rolling/rc_reason_msgs/msg/rectangle.proto\"\xab\x06\n\x1bLoadCarrierWithFillingLevel\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12N\n\x10outer_dimensions\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.rc_reason_msgs.msg.Box\x12N\n\x10inner_dimensions\x18\x04 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.rc_reason_msgs.msg.Box\x12Q\n\rrim_thickness\x18\x05 \x01(\x0b\x32:.make87_messages_ros2.rolling.rc_reason_msgs.msg.Rectangle\x12\x17\n\x0frim_step_height\x18\x06 \x01(\x01\x12M\n\trim_ledge\x18\x07 \x01(\x0b\x32:.make87_messages_ros2.rolling.rc_reason_msgs.msg.Rectangle\x12\x18\n\x10height_open_side\x18\x08 \x01(\x01\x12I\n\x04pose\x18\t \x01(\x0b\x32;.make87_messages_ros2.rolling.geometry_msgs.msg.PoseStamped\x12\x12\n\noverfilled\x18\n \x01(\x08\x12`\n\x15overall_filling_level\x18\x0b \x01(\x0b\x32\x41.make87_messages_ros2.rolling.rc_reason_msgs.msg.CellFillingLevel\x12_\n\x14\x63\x65lls_filling_levels\x18\x0c \x03(\x0b\x32\x41.make87_messages_ros2.rolling.rc_reason_msgs.msg.CellFillingLevel\x12[\n\x18\x66illing_level_cell_count\x18\r \x01(\x0b\x32\x39.make87_messages_ros2.rolling.rc_reason_msgs.msg.GridSizeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.msg.load_carrier_with_filling_level_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LOADCARRIERWITHFILLINGLEVEL']._serialized_start=469
  _globals['_LOADCARRIERWITHFILLINGLEVEL']._serialized_end=1280
# @@protoc_insertion_point(module_scope)
