# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/nav2_msgs/srv/is_path_valid.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.nav_msgs.msg import path_pb2 as make87__messages__ros2_dot_humble_dot_nav__msgs_dot_msg_dot_path__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/humble/nav2_msgs/srv/is_path_valid.proto\x12)make87_messages_ros2.humble.nav2_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x33make87_messages_ros2/humble/nav_msgs/msg/path.proto\"\x80\x01\n\x12IsPathValidRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12<\n\x04path\x18\x02 \x01(\x0b\x32..make87_messages_ros2.humble.nav_msgs.msg.Path\"s\n\x13IsPathValidResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08is_valid\x18\x02 \x01(\x08\x12\x1c\n\x14invalid_pose_indices\x18\x03 \x03(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.nav2_msgs.srv.is_path_valid_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ISPATHVALIDREQUEST']._serialized_start=197
  _globals['_ISPATHVALIDREQUEST']._serialized_end=325
  _globals['_ISPATHVALIDRESPONSE']._serialized_start=327
  _globals['_ISPATHVALIDRESPONSE']._serialized_end=442
# @@protoc_insertion_point(module_scope)
