# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/get_group_urdf.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/moveit_msgs/srv/get_group_urdf.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/move_it_error_codes.proto\")\n\x13GetGroupUrdfRequest\x12\x12\n\ngroup_name\x18\x01 \x01(\t\"}\n\x14GetGroupUrdfResponse\x12P\n\nerror_code\x18\x01 \x01(\x0b\x32<.make87_messages_ros2.jazzy.moveit_msgs.msg.MoveItErrorCodes\x12\x13\n\x0burdf_string\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.get_group_urdf_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETGROUPURDFREQUEST']._serialized_start=181
  _globals['_GETGROUPURDFREQUEST']._serialized_end=222
  _globals['_GETGROUPURDFRESPONSE']._serialized_start=224
  _globals['_GETGROUPURDFRESPONSE']._serialized_end=349
# @@protoc_insertion_point(module_scope)
