# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_nav_msgs/msg/route.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.marti_common_msgs.msg import key_value_pb2 as make87__messages__ros2_dot_rolling_dot_marti__common__msgs_dot_msg_dot_key__value__pb2
from make87_messages_ros2.rolling.marti_nav_msgs.msg import route_point_pb2 as make87__messages__ros2_dot_rolling_dot_marti__nav__msgs_dot_msg_dot_route__point__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/rolling/marti_nav_msgs/msg/route.proto\x12/make87_messages_ros2.rolling.marti_nav_msgs.msg\x1a\x42make87_messages_ros2/rolling/marti_common_msgs/msg/key_value.proto\x1a\x41make87_messages_ros2/rolling/marti_nav_msgs/msg/route_point.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xef\x01\n\x05Route\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12Q\n\x0croute_points\x18\x02 \x03(\x0b\x32;.make87_messages_ros2.rolling.marti_nav_msgs.msg.RoutePoint\x12P\n\nproperties\x18\x03 \x03(\x0b\x32<.make87_messages_ros2.rolling.marti_common_msgs.msg.KeyValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_nav_msgs.msg.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROUTE']._serialized_start=304
  _globals['_ROUTE']._serialized_end=543
# @@protoc_insertion_point(module_scope)
