# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ros_gz_interfaces/srv/delete_entity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ros_gz_interfaces.msg import entity_pb2 as make87__messages__ros2_dot_rolling_dot_ros__gz__interfaces_dot_msg_dot_entity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/ros_gz_interfaces/srv/delete_entity.proto\x12\x32make87_messages_ros2.rolling.ros_gz_interfaces.srv\x1a?make87_messages_ros2/rolling/ros_gz_interfaces/msg/entity.proto\"a\n\x13\x44\x65leteEntityRequest\x12J\n\x06\x65ntity\x18\x01 \x01(\x0b\x32:.make87_messages_ros2.rolling.ros_gz_interfaces.msg.Entity\"\'\n\x14\x44\x65leteEntityResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ros_gz_interfaces.srv.delete_entity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DELETEENTITYREQUEST']._serialized_start=191
  _globals['_DELETEENTITYREQUEST']._serialized_end=288
  _globals['_DELETEENTITYRESPONSE']._serialized_start=290
  _globals['_DELETEENTITYRESPONSE']._serialized_end=329
# @@protoc_insertion_point(module_scope)
