# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ros_gz_interfaces/msg/entity_wrench.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import wrench_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_wrench__pb2
from make87_messages_ros2.jazzy.ros_gz_interfaces.msg import entity_pb2 as make87__messages__ros2_dot_jazzy_dot_ros__gz__interfaces_dot_msg_dot_entity__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/ros_gz_interfaces/msg/entity_wrench.proto\x12\x30make87_messages_ros2.jazzy.ros_gz_interfaces.msg\x1a\x39make87_messages_ros2/jazzy/geometry_msgs/msg/wrench.proto\x1a=make87_messages_ros2/jazzy/ros_gz_interfaces/msg/entity.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xdf\x01\n\x0c\x45ntityWrench\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12H\n\x06\x65ntity\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.ros_gz_interfaces.msg.Entity\x12\x44\n\x06wrench\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.geometry_msgs.msg.Wrenchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ros_gz_interfaces.msg.entity_wrench_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ENTITYWRENCH']._serialized_start=299
  _globals['_ENTITYWRENCH']._serialized_end=522
# @@protoc_insertion_point(module_scope)
