# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_nav_pvt.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import carr_soln_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_carr__soln__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import gps_fix_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_gps__fix__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import psmpvt_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_psmpvt__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_nav_pvt.proto\x12-make87_messages_ros2.jazzy.ublox_ubx_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a=make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/carr_soln.proto\x1a;make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/gps_fix.proto\x1a:make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/psmpvt.proto\"\xac\x07\n\tUBXNavPVT\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0c\n\x04itow\x18\x02 \x01(\r\x12\x0c\n\x04year\x18\x03 \x01(\r\x12\r\n\x05month\x18\x04 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x05 \x01(\r\x12\x0c\n\x04hour\x18\x06 \x01(\r\x12\x0b\n\x03min\x18\x07 \x01(\r\x12\x0b\n\x03sec\x18\x08 \x01(\r\x12\x12\n\nvalid_date\x18\t \x01(\x08\x12\x12\n\nvalid_time\x18\n \x01(\x08\x12\x16\n\x0e\x66ully_resolved\x18\x0b \x01(\x08\x12\x11\n\tvalid_mag\x18\x0c \x01(\x08\x12\r\n\x05t_acc\x18\r \x01(\r\x12\x0c\n\x04nano\x18\x0e \x01(\x05\x12\x46\n\x07gps_fix\x18\x0f \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.GpsFix\x12\x13\n\x0bgnss_fix_ok\x18\x10 \x01(\x08\x12\x11\n\tdiff_soln\x18\x11 \x01(\x08\x12\x42\n\x03psm\x18\x12 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.PSMPVT\x12\x16\n\x0ehead_veh_valid\x18\x13 \x01(\x08\x12J\n\tcarr_soln\x18\x14 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.CarrSoln\x12\x17\n\x0f\x63onfirmed_avail\x18\x15 \x01(\x08\x12\x16\n\x0e\x63onfirmed_date\x18\x16 \x01(\x08\x12\x16\n\x0e\x63onfirmed_time\x18\x17 \x01(\x08\x12\x0e\n\x06num_sv\x18\x18 \x01(\r\x12\x0b\n\x03lon\x18\x19 \x01(\x05\x12\x0b\n\x03lat\x18\x1a \x01(\x05\x12\x0e\n\x06height\x18\x1b \x01(\x05\x12\x0c\n\x04hmsl\x18\x1c \x01(\x05\x12\r\n\x05h_acc\x18\x1d \x01(\r\x12\r\n\x05v_acc\x18\x1e \x01(\r\x12\r\n\x05vel_n\x18\x1f \x01(\x05\x12\r\n\x05vel_e\x18  \x01(\x05\x12\r\n\x05vel_d\x18! \x01(\x05\x12\x0f\n\x07g_speed\x18\" \x01(\x05\x12\x10\n\x08head_mot\x18# \x01(\x05\x12\r\n\x05s_acc\x18$ \x01(\r\x12\x10\n\x08head_acc\x18% \x01(\r\x12\r\n\x05p_dop\x18& \x01(\r\x12\x13\n\x0binvalid_llh\x18\' \x01(\x08\x12\x10\n\x08head_veh\x18( \x01(\x05\x12\x0f\n\x07mag_dec\x18) \x01(\x05\x12\x0f\n\x07mag_acc\x18* \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.ubx_nav_pvt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UBXNAVPVT']._serialized_start=353
  _globals['_UBXNAVPVT']._serialized_end=1293
# @@protoc_insertion_point(module_scope)
