# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/nao_lola_command_msgs/msg/head_leds.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/nao_lola_command_msgs/msg/head_leds.proto\x12\x36make87_messages_ros2.rolling.nao_lola_command_msgs.msg\"\x1f\n\x08HeadLeds\x12\x13\n\x0bintensities\x18\x01 \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.nao_lola_command_msgs.msg.head_leds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_HEADLEDS']._serialized_start=130
  _globals['_HEADLEDS']._serialized_end=161
# @@protoc_insertion_point(module_scope)
