# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_safevisionary_interfaces/msg/field_information.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/jazzy/sick_safevisionary_interfaces/msg/field_information.proto\x12<make87_messages_ros2.jazzy.sick_safevisionary_interfaces.msg\"{\n\x10\x46ieldInformation\x12\x10\n\x08\x66ield_id\x18\x01 \x01(\r\x12\x14\n\x0c\x66ield_set_id\x18\x02 \x01(\r\x12\x14\n\x0c\x66ield_result\x18\x03 \x01(\r\x12\x13\n\x0b\x65val_method\x18\x04 \x01(\r\x12\x14\n\x0c\x66ield_active\x18\x05 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_safevisionary_interfaces.msg.field_information_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FIELDINFORMATION']._serialized_start=150
  _globals['_FIELDINFORMATION']._serialized_end=273
# @@protoc_insertion_point(module_scope)
