# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/plansys2_msgs/srv/affect_param.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.plansys2_msgs.msg import param_pb2 as make87__messages__ros2_dot_humble_dot_plansys2__msgs_dot_msg_dot_param__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/plansys2_msgs/srv/affect_param.proto\x12-make87_messages_ros2.humble.plansys2_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/plansys2_msgs/msg/param.proto\"\x87\x01\n\x12\x41\x66\x66\x65\x63tParamRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x43\n\x05param\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.humble.plansys2_msgs.msg.Param\"h\n\x13\x41\x66\x66\x65\x63tParamResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x12\n\nerror_info\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.plansys2_msgs.srv.affect_param_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AFFECTPARAMREQUEST']._serialized_start=210
  _globals['_AFFECTPARAMREQUEST']._serialized_end=345
  _globals['_AFFECTPARAMRESPONSE']._serialized_start=347
  _globals['_AFFECTPARAMRESPONSE']._serialized_end=451
# @@protoc_insertion_point(module_scope)
