# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/srv/get_state_validity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import constraint_eval_result_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_constraint__eval__result__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import constraints_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_constraints__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import contact_information_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_contact__information__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import cost_source_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_cost__source__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/moveit_msgs/srv/get_state_validity.proto\x12+make87_messages_ros2.humble.moveit_msgs.srv\x1a!make87_messages/core/header.proto\x1aHmake87_messages_ros2/humble/moveit_msgs/msg/constraint_eval_result.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/constraints.proto\x1a\x45make87_messages_ros2/humble/moveit_msgs/msg/contact_information.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/cost_source.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/robot_state.proto\"\xf8\x01\n\x17GetStateValidityRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12L\n\x0brobot_state\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.RobotState\x12\x12\n\ngroup_name\x18\x03 \x01(\t\x12M\n\x0b\x63onstraints\x18\x04 \x01(\x0b\x32\x38.make87_messages_ros2.humble.moveit_msgs.msg.Constraints\"\xd7\x02\n\x18GetStateValidityResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05valid\x18\x02 \x01(\x08\x12Q\n\x08\x63ontacts\x18\x03 \x03(\x0b\x32?.make87_messages_ros2.humble.moveit_msgs.msg.ContactInformation\x12M\n\x0c\x63ost_sources\x18\x04 \x03(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.CostSource\x12\\\n\x11\x63onstraint_result\x18\x05 \x03(\x0b\x32\x41.make87_messages_ros2.humble.moveit_msgs.msg.ConstraintEvalResultb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.srv.get_state_validity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETSTATEVALIDITYREQUEST']._serialized_start=487
  _globals['_GETSTATEVALIDITYREQUEST']._serialized_end=735
  _globals['_GETSTATEVALIDITYRESPONSE']._serialized_start=738
  _globals['_GETSTATEVALIDITYRESPONSE']._serialized_end=1081
# @@protoc_insertion_point(module_scope)
