# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_queries.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import schedule_identity_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_schedule__identity__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import schedule_query_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_schedule__query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_queries.proto\x12\x30make87_messages_ros2.humble.rmf_traffic_msgs.msg\x1a!make87_messages/core/header.proto\x1aHmake87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_identity.proto\x1a\x45make87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_query.proto\"\xf9\x01\n\x0fScheduleQueries\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12S\n\x07node_id\x18\x02 \x01(\x0b\x32\x42.make87_messages_ros2.humble.rmf_traffic_msgs.msg.ScheduleIdentity\x12P\n\x07queries\x18\x03 \x03(\x0b\x32?.make87_messages_ros2.humble.rmf_traffic_msgs.msg.ScheduleQuery\x12\x11\n\tquery_ids\x18\x04 \x03(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rmf_traffic_msgs.msg.schedule_queries_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCHEDULEQUERIES']._serialized_start=306
  _globals['_SCHEDULEQUERIES']._serialized_end=555
# @@protoc_insertion_point(module_scope)
