# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/visualization_msgs/msg/interactive_marker_control.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import quaternion_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_quaternion__pb2
from make87_messages_ros2.humble.visualization_msgs.msg import marker_pb2 as make87__messages__ros2_dot_humble_dot_visualization__msgs_dot_msg_dot_marker__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/humble/visualization_msgs/msg/interactive_marker_control.proto\x12\x32make87_messages_ros2.humble.visualization_msgs.msg\x1a!make87_messages/core/header.proto\x1a>make87_messages_ros2/humble/geometry_msgs/msg/quaternion.proto\x1a?make87_messages_ros2/humble/visualization_msgs/msg/marker.proto\"\xfc\x02\n\x18InteractiveMarkerControl\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\x12N\n\x0borientation\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.humble.geometry_msgs.msg.Quaternion\x12\x18\n\x10orientation_mode\x18\x04 \x01(\r\x12\x18\n\x10interaction_mode\x18\x05 \x01(\r\x12\x16\n\x0e\x61lways_visible\x18\x06 \x01(\x08\x12K\n\x07markers\x18\x07 \x03(\x0b\x32:.make87_messages_ros2.humble.visualization_msgs.msg.Marker\x12&\n\x1eindependent_marker_orientation\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.visualization_msgs.msg.interactive_marker_control_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INTERACTIVEMARKERCONTROL']._serialized_start=304
  _globals['_INTERACTIVEMARKERCONTROL']._serialized_end=684
# @@protoc_insertion_point(module_scope)
