# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/std_msgs/msg/u_int16_multi_array.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import multi_array_layout_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_multi__array__layout__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/std_msgs/msg/u_int16_multi_array.proto\x12\'make87_messages_ros2.jazzy.std_msgs.msg\x1a@make87_messages_ros2/jazzy/std_msgs/msg/multi_array_layout.proto\"k\n\x10UInt16MultiArray\x12I\n\x06layout\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.std_msgs.msg.MultiArrayLayout\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.std_msgs.msg.u_int16_multi_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UINT16MULTIARRAY']._serialized_start=176
  _globals['_UINT16MULTIARRAY']._serialized_end=283
# @@protoc_insertion_point(module_scope)
