# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/tuw_object_map_msgs/msg/object.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.rolling.tuw_object_map_msgs.msg import geo_point_pb2 as make87__messages__ros2_dot_rolling_dot_tuw__object__map__msgs_dot_msg_dot_geo__point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/tuw_object_map_msgs/msg/object.proto\x12\x34make87_messages_ros2.rolling.tuw_object_map_msgs.msg\x1a:make87_messages_ros2/rolling/geometry_msgs/msg/point.proto\x1a\x44make87_messages_ros2/rolling/tuw_object_map_msgs/msg/geo_point.proto\"\xf3\x01\n\x06Object\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\r\x12R\n\ngeo_points\x18\x03 \x03(\x0b\x32>.make87_messages_ros2.rolling.tuw_object_map_msgs.msg.GeoPoint\x12I\n\nmap_points\x18\x04 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Point\x12\x18\n\x10\x65nflation_radius\x18\x05 \x03(\x01\x12\x16\n\x0e\x62ondary_radius\x18\x06 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.tuw_object_map_msgs.msg.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECT']._serialized_start=254
  _globals['_OBJECT']._serialized_end=497
# @@protoc_insertion_point(module_scope)
