# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/canopen_interfaces/srv/co_nmt_id.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/humble/canopen_interfaces/srv/co_nmt_id.proto\x12\x32make87_messages_ros2.humble.canopen_interfaces.srv\x1a!make87_messages/core/header.proto\"b\n\x0e\x43ONmtIDRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x12\n\nnmtcommand\x18\x02 \x01(\r\x12\x0e\n\x06nodeid\x18\x03 \x01(\r\"P\n\x0f\x43ONmtIDResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.canopen_interfaces.srv.co_nmt_id_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONMTIDREQUEST']._serialized_start=157
  _globals['_CONMTIDREQUEST']._serialized_end=255
  _globals['_CONMTIDRESPONSE']._serialized_start=257
  _globals['_CONMTIDRESPONSE']._serialized_end=337
# @@protoc_insertion_point(module_scope)
