# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sbg_driver/msg/sbg_gps_hdt.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/jazzy/sbg_driver/msg/sbg_gps_hdt.proto\x12)make87_messages_ros2.jazzy.sbg_driver.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x8e\x02\n\tSbgGpsHdt\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x12\n\ntime_stamp\x18\x02 \x01(\r\x12\x0e\n\x06status\x18\x03 \x01(\r\x12\x0b\n\x03tow\x18\x04 \x01(\r\x12\x14\n\x0ctrue_heading\x18\x05 \x01(\x02\x12\x18\n\x10true_heading_acc\x18\x06 \x01(\x02\x12\r\n\x05pitch\x18\x07 \x01(\x02\x12\x11\n\tpitch_acc\x18\x08 \x01(\x02\x12\x10\n\x08\x62\x61seline\x18\t \x01(\x02\x12\x16\n\x0enum_sv_tracked\x18\n \x01(\r\x12\x13\n\x0bnum_sv_used\x18\x0b \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sbg_driver.msg.sbg_gps_hdt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SBGGPSHDT']._serialized_start=161
  _globals['_SBGGPSHDT']._serialized_end=431
# @@protoc_insertion_point(module_scope)
