# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/septentrio_gnss_driver/msg/ins_nav_cart.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.septentrio_gnss_driver.msg import block_header_pb2 as make87__messages__ros2_dot_humble_dot_septentrio__gnss__driver_dot_msg_dot_block__header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/humble/septentrio_gnss_driver/msg/ins_nav_cart.proto\x12\x36make87_messages_ros2.humble.septentrio_gnss_driver.msg\x1a!make87_messages/core/header.proto\x1aImake87_messages_ros2/humble/septentrio_gnss_driver/msg/block_header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xc5\x06\n\nINSNavCart\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12Y\n\x0c\x62lock_header\x18\x03 \x01(\x0b\x32\x43.make87_messages_ros2.humble.septentrio_gnss_driver.msg.BlockHeader\x12\x11\n\tgnss_mode\x18\x04 \x01(\r\x12\r\n\x05\x65rror\x18\x05 \x01(\r\x12\x0c\n\x04info\x18\x06 \x01(\r\x12\x10\n\x08gnss_age\x18\x07 \x01(\r\x12\t\n\x01x\x18\x08 \x01(\x01\x12\t\n\x01y\x18\t \x01(\x01\x12\t\n\x01z\x18\n \x01(\x01\x12\x10\n\x08\x61\x63\x63uracy\x18\x0b \x01(\r\x12\x0f\n\x07latency\x18\x0c \x01(\r\x12\r\n\x05\x64\x61tum\x18\r \x01(\r\x12\x0f\n\x07sb_list\x18\x0e \x01(\r\x12\x11\n\tx_std_dev\x18\x0f \x01(\x02\x12\x11\n\ty_std_dev\x18\x10 \x01(\x02\x12\x11\n\tz_std_dev\x18\x11 \x01(\x02\x12\x0e\n\x06xy_cov\x18\x12 \x01(\x02\x12\x0e\n\x06xz_cov\x18\x13 \x01(\x02\x12\x0e\n\x06yz_cov\x18\x14 \x01(\x02\x12\x0f\n\x07heading\x18\x15 \x01(\x02\x12\r\n\x05pitch\x18\x16 \x01(\x02\x12\x0c\n\x04roll\x18\x17 \x01(\x02\x12\x17\n\x0fheading_std_dev\x18\x18 \x01(\x02\x12\x15\n\rpitch_std_dev\x18\x19 \x01(\x02\x12\x14\n\x0croll_std_dev\x18\x1a \x01(\x02\x12\x19\n\x11heading_pitch_cov\x18\x1b \x01(\x02\x12\x18\n\x10heading_roll_cov\x18\x1c \x01(\x02\x12\x16\n\x0epitch_roll_cov\x18\x1d \x01(\x02\x12\n\n\x02vx\x18\x1e \x01(\x02\x12\n\n\x02vy\x18\x1f \x01(\x02\x12\n\n\x02vz\x18  \x01(\x02\x12\x12\n\nvx_std_dev\x18! \x01(\x02\x12\x12\n\nvy_std_dev\x18\" \x01(\x02\x12\x12\n\nvz_std_dev\x18# \x01(\x02\x12\x11\n\tvx_vy_cov\x18$ \x01(\x02\x12\x11\n\tvx_vz_cov\x18% \x01(\x02\x12\x11\n\tvy_vz_cov\x18& \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.septentrio_gnss_driver.msg.ins_nav_cart_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INSNAVCART']._serialized_start=299
  _globals['_INSNAVCART']._serialized_end=1136
# @@protoc_insertion_point(module_scope)
