# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mola_msgs/srv/map_load.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/jazzy/mola_msgs/srv/map_load.proto\x12(make87_messages_ros2.jazzy.mola_msgs.srv\"\"\n\x0eMapLoadRequest\x12\x10\n\x08map_path\x18\x01 \x01(\t\"9\n\x0fMapLoadResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mola_msgs.srv.map_load_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MAPLOADREQUEST']._serialized_start=101
  _globals['_MAPLOADREQUEST']._serialized_end=135
  _globals['_MAPLOADRESPONSE']._serialized_start=137
  _globals['_MAPLOADRESPONSE']._serialized_end=194
# @@protoc_insertion_point(module_scope)
