# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/robot_controllers_msgs/msg/diff_drive_limiter_params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nVmake87_messages_ros2/humble/robot_controllers_msgs/msg/diff_drive_limiter_params.proto\x12\x36make87_messages_ros2.humble.robot_controllers_msgs.msg\x1a!make87_messages/core/header.proto\"\xce\x02\n\x16\x44iffDriveLimiterParams\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x1b\n\x13max_linear_velocity\x18\x02 \x01(\x01\x12\x1f\n\x17max_linear_acceleration\x18\x03 \x01(\x01\x12\x1c\n\x14max_angular_velocity\x18\x04 \x01(\x01\x12 \n\x18max_angular_acceleration\x18\x05 \x01(\x01\x12\x1a\n\x12max_wheel_velocity\x18\x06 \x01(\x01\x12\x13\n\x0btrack_width\x18\x07 \x01(\x01\x12/\n\'angular_velocity_limits_linear_velocity\x18\x08 \x01(\x08\x12&\n\x1escale_to_wheel_velocity_limits\x18\t \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.robot_controllers_msgs.msg.diff_drive_limiter_params_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DIFFDRIVELIMITERPARAMS']._serialized_start=182
  _globals['_DIFFDRIVELIMITERPARAMS']._serialized_end=516
# @@protoc_insertion_point(module_scope)
