# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/flexbe_msgs/msg/container_structure.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.flexbe_msgs.msg import container_pb2 as make87__messages__ros2_dot_rolling_dot_flexbe__msgs_dot_msg_dot_container__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/flexbe_msgs/msg/container_structure.proto\x12,make87_messages_ros2.rolling.flexbe_msgs.msg\x1a<make87_messages_ros2/rolling/flexbe_msgs/msg/container.proto\"v\n\x12\x43ontainerStructure\x12\x13\n\x0b\x62\x65havior_id\x18\x01 \x01(\x05\x12K\n\ncontainers\x18\x02 \x03(\x0b\x32\x37.make87_messages_ros2.rolling.flexbe_msgs.msg.Containerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.flexbe_msgs.msg.container_structure_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONTAINERSTRUCTURE']._serialized_start=182
  _globals['_CONTAINERSTRUCTURE']._serialized_end=300
# @@protoc_insertion_point(module_scope)
