# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/robot_calibration_msgs/msg/calibration_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.robot_calibration_msgs.msg import observation_pb2 as make87__messages__ros2_dot_jazzy_dot_robot__calibration__msgs_dot_msg_dot_observation__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import joint_state_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_joint__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/jazzy/robot_calibration_msgs/msg/calibration_data.proto\x12\x35make87_messages_ros2.jazzy.robot_calibration_msgs.msg\x1aGmake87_messages_ros2/jazzy/robot_calibration_msgs/msg/observation.proto\x1a<make87_messages_ros2/jazzy/sensor_msgs/msg/joint_state.proto\"\xb9\x01\n\x0f\x43\x61librationData\x12L\n\x0cjoint_states\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.sensor_msgs.msg.JointState\x12X\n\x0cobservations\x18\x02 \x03(\x0b\x32\x42.make87_messages_ros2.jazzy.robot_calibration_msgs.msg.Observationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.robot_calibration_msgs.msg.calibration_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CALIBRATIONDATA']._serialized_start=271
  _globals['_CALIBRATIONDATA']._serialized_end=456
# @@protoc_insertion_point(module_scope)
