# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/msg/planning_scene_world.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import collision_object_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_collision__object__pb2
from make87_messages_ros2.humble.octomap_msgs.msg import octomap_with_pose_pb2 as make87__messages__ros2_dot_humble_dot_octomap__msgs_dot_msg_dot_octomap__with__pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/humble/moveit_msgs/msg/planning_scene_world.proto\x12+make87_messages_ros2.humble.moveit_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x42make87_messages_ros2/humble/moveit_msgs/msg/collision_object.proto\x1a\x44make87_messages_ros2/humble/octomap_msgs/msg/octomap_with_pose.proto\"\xeb\x01\n\x12PlanningSceneWorld\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12W\n\x11\x63ollision_objects\x18\x02 \x03(\x0b\x32<.make87_messages_ros2.humble.moveit_msgs.msg.CollisionObject\x12N\n\x07octomap\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.humble.octomap_msgs.msg.OctomapWithPoseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.msg.planning_scene_world_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLANNINGSCENEWORLD']._serialized_start=293
  _globals['_PLANNINGSCENEWORLD']._serialized_end=528
# @@protoc_insertion_point(module_scope)
