# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_change_progress.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_change_progress.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\"T\n\x16ScheduleChangeProgress\x12\x14\n\x0chas_progress\x18\x01 \x01(\x08\x12\x0f\n\x07version\x18\x02 \x01(\x04\x12\x13\n\x0b\x63heckpoints\x18\x03 \x03(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.schedule_change_progress_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCHEDULECHANGEPROGRESS']._serialized_start=135
  _globals['_SCHEDULECHANGEPROGRESS']._serialized_end=219
# @@protoc_insertion_point(module_scope)
