# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mola_msgs/srv/relocalize_from_gnss.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/mola_msgs/srv/relocalize_from_gnss.proto\x12(make87_messages_ros2.jazzy.mola_msgs.srv\"\x1b\n\x19RelocalizeFromGNSSRequest\".\n\x1aRelocalizeFromGNSSResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mola_msgs.srv.relocalize_from_gnss_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RELOCALIZEFROMGNSSREQUEST']._serialized_start=113
  _globals['_RELOCALIZEFROMGNSSREQUEST']._serialized_end=140
  _globals['_RELOCALIZEFROMGNSSRESPONSE']._serialized_start=142
  _globals['_RELOCALIZEFROMGNSSRESPONSE']._serialized_end=188
# @@protoc_insertion_point(module_scope)
