# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ds_dbw_msgs/msg/brake_diagnostics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/ds_dbw_msgs/msg/brake_diagnostics.proto\x12*make87_messages_ros2.jazzy.ds_dbw_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xf8\x0c\n\x10\x42rakeDiagnostics\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x10\n\x08\x64\x65graded\x18\x02 \x01(\x08\x12\x19\n\x11\x64\x65graded_cmd_type\x18\x03 \x01(\x08\x12\x16\n\x0e\x64\x65graded_comms\x18\x04 \x01(\x08\x12\x1a\n\x12\x64\x65graded_comms_dbw\x18\x05 \x01(\x08\x12\"\n\x1a\x64\x65graded_comms_dbw_gateway\x18\x06 \x01(\x08\x12 \n\x18\x64\x65graded_comms_dbw_steer\x18\x07 \x01(\x08\x12 \n\x18\x64\x65graded_comms_dbw_thrtl\x18\x08 \x01(\x08\x12\x1f\n\x17\x64\x65graded_comms_dbw_gear\x18\t \x01(\x08\x12\x1e\n\x16\x64\x65graded_comms_vehicle\x18\n \x01(\x08\x12\x1f\n\x17\x64\x65graded_comms_actuator\x18\x0b \x01(\x08\x12!\n\x19\x64\x65graded_comms_actuator_1\x18\x0c \x01(\x08\x12!\n\x19\x64\x65graded_comms_actuator_2\x18\r \x01(\x08\x12\x19\n\x11\x64\x65graded_internal\x18\x0e \x01(\x08\x12$\n\x1c\x64\x65graded_control_performance\x18\x0f \x01(\x08\x12\x1f\n\x17\x64\x65graded_param_mismatch\x18\x10 \x01(\x08\x12\x1f\n\x17\x64\x65graded_btsi_stuck_low\x18\x11 \x01(\x08\x12 \n\x18\x64\x65graded_btsi_stuck_high\x18\x12 \x01(\x08\x12\x18\n\x10\x64\x65graded_vehicle\x18\x13 \x01(\x08\x12\x1e\n\x16\x64\x65graded_vehicle_speed\x18\x14 \x01(\x08\x12\x1e\n\x16\x64\x65graded_bped_feedback\x18\x15 \x01(\x08\x12\x19\n\x11\x64\x65graded_actuator\x18\x16 \x01(\x08\x12\x1b\n\x13\x64\x65graded_actuator_1\x18\x17 \x01(\x08\x12\x1b\n\x13\x64\x65graded_actuator_2\x18\x18 \x01(\x08\x12\"\n\x1a\x64\x65graded_actuator_aeb_deny\x18\x19 \x01(\x08\x12\x1e\n\x16\x64\x65graded_actuator_warm\x18\x1a \x01(\x08\x12\x1c\n\x14\x64\x65graded_calibration\x18\x1b \x01(\x08\x12\r\n\x05\x66\x61ult\x18\x1c \x01(\x08\x12\x13\n\x0b\x66\x61ult_power\x18\x1d \x01(\x08\x12\x13\n\x0b\x66\x61ult_comms\x18\x1e \x01(\x08\x12\x16\n\x0e\x66\x61ult_internal\x18\x1f \x01(\x08\x12\x15\n\rfault_vehicle\x18  \x01(\x08\x12\x16\n\x0e\x66\x61ult_actuator\x18! \x01(\x08\x12\x17\n\x0f\x66\x61ult_comms_dbw\x18\" \x01(\x08\x12\x1f\n\x17\x66\x61ult_comms_dbw_gateway\x18# \x01(\x08\x12\x1d\n\x15\x66\x61ult_comms_dbw_steer\x18$ \x01(\x08\x12\x1d\n\x15\x66\x61ult_comms_dbw_thrtl\x18% \x01(\x08\x12\x1c\n\x14\x66\x61ult_comms_dbw_gear\x18& \x01(\x08\x12\x1b\n\x13\x66\x61ult_comms_vehicle\x18\' \x01(\x08\x12\x1c\n\x14\x66\x61ult_comms_actuator\x18( \x01(\x08\x12\x1e\n\x16\x66\x61ult_comms_actuator_1\x18) \x01(\x08\x12\x1e\n\x16\x66\x61ult_comms_actuator_2\x18* \x01(\x08\x12\x1b\n\x13\x66\x61ult_vehicle_speed\x18+ \x01(\x08\x12\x1f\n\x17\x66\x61ult_actuator_acc_deny\x18, \x01(\x08\x12#\n\x1b\x66\x61ult_actuator_pedal_sensor\x18- \x01(\x08\x12\x1b\n\x13\x66\x61ult_bped_sensor_1\x18. \x01(\x08\x12\x1b\n\x13\x66\x61ult_bped_sensor_2\x18/ \x01(\x08\x12\"\n\x1a\x66\x61ult_bped_sensor_mismatch\x18\x30 \x01(\x08\x12\x18\n\x10\x66\x61ult_actuator_1\x18\x31 \x01(\x08\x12\x18\n\x10\x66\x61ult_actuator_2\x18\x32 \x01(\x08\x12!\n\x19\x66\x61ult_control_performance\x18\x33 \x01(\x08\x12\x1c\n\x14\x66\x61ult_param_mismatch\x18\x34 \x01(\x08\x12\x1a\n\x12\x66\x61ult_param_limits\x18\x35 \x01(\x08\x12\x19\n\x11\x66\x61ult_calibration\x18\x36 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ds_dbw_msgs.msg.brake_diagnostics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BRAKEDIAGNOSTICS']._serialized_start=169
  _globals['_BRAKEDIAGNOSTICS']._serialized_end=1825
# @@protoc_insertion_point(module_scope)
