# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/yasmin_msgs/msg/state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.yasmin_msgs.msg import transition_pb2 as make87__messages__ros2_dot_rolling_dot_yasmin__msgs_dot_msg_dot_transition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/rolling/yasmin_msgs/msg/state.proto\x12,make87_messages_ros2.rolling.yasmin_msgs.msg\x1a=make87_messages_ros2/rolling/yasmin_msgs/msg/transition.proto\"\xb9\x01\n\x05State\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0e\n\x06parent\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12M\n\x0btransitions\x18\x04 \x03(\x0b\x32\x38.make87_messages_ros2.rolling.yasmin_msgs.msg.Transition\x12\x10\n\x08outcomes\x18\x05 \x03(\t\x12\x0e\n\x06is_fsm\x18\x06 \x01(\x08\x12\x15\n\rcurrent_state\x18\x07 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.yasmin_msgs.msg.state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STATE']._serialized_start=170
  _globals['_STATE']._serialized_end=355
# @@protoc_insertion_point(module_scope)
