# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/controller_manager_msgs/srv/set_hardware_component_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.lifecycle_msgs.msg import state_pb2 as make87__messages__ros2_dot_jazzy_dot_lifecycle__msgs_dot_msg_dot_state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYmake87_messages_ros2/jazzy/controller_manager_msgs/srv/set_hardware_component_state.proto\x12\x36make87_messages_ros2.jazzy.controller_manager_msgs.srv\x1a\x39make87_messages_ros2/jazzy/lifecycle_msgs/msg/state.proto\"|\n SetHardwareComponentStateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12J\n\x0ctarget_state\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.lifecycle_msgs.msg.State\"t\n!SetHardwareComponentStateResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x43\n\x05state\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.lifecycle_msgs.msg.Stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.controller_manager_msgs.srv.set_hardware_component_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETHARDWARECOMPONENTSTATEREQUEST']._serialized_start=208
  _globals['_SETHARDWARECOMPONENTSTATEREQUEST']._serialized_end=332
  _globals['_SETHARDWARECOMPONENTSTATERESPONSE']._serialized_start=334
  _globals['_SETHARDWARECOMPONENTSTATERESPONSE']._serialized_end=450
# @@protoc_insertion_point(module_scope)
