# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/nav_velned.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/ublox_msgs/msg/nav_velned.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\"\x96\x01\n\tNavVELNED\x12\r\n\x05i_tow\x18\x01 \x01(\r\x12\r\n\x05vel_n\x18\x02 \x01(\x05\x12\r\n\x05vel_e\x18\x03 \x01(\x05\x12\r\n\x05vel_d\x18\x04 \x01(\x05\x12\r\n\x05speed\x18\x05 \x01(\r\x12\x0f\n\x07g_speed\x18\x06 \x01(\r\x12\x0f\n\x07heading\x18\x07 \x01(\x05\x12\r\n\x05s_acc\x18\x08 \x01(\r\x12\r\n\x05\x63_acc\x18\t \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.nav_velned_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NAVVELNED']._serialized_start=106
  _globals['_NAVVELNED']._serialized_end=256
# @@protoc_insertion_point(module_scope)
