# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/test_interface_files/msg/strings.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/test_interface_files/msg/strings.proto\x12\x33make87_messages_ros2.jazzy.test_interface_files.msg\"\x9b\x03\n\x07Strings\x12\x14\n\x0cstring_value\x18\x01 \x01(\t\x12\x1d\n\x15string_value_default1\x18\x02 \x01(\t\x12\x1d\n\x15string_value_default2\x18\x03 \x01(\t\x12\x1d\n\x15string_value_default3\x18\x04 \x01(\t\x12\x1d\n\x15string_value_default4\x18\x05 \x01(\t\x12\x1d\n\x15string_value_default5\x18\x06 \x01(\t\x12\x1c\n\x14\x62ounded_string_value\x18\x07 \x01(\t\x12%\n\x1d\x62ounded_string_value_default1\x18\x08 \x01(\t\x12%\n\x1d\x62ounded_string_value_default2\x18\t \x01(\t\x12%\n\x1d\x62ounded_string_value_default3\x18\n \x01(\t\x12%\n\x1d\x62ounded_string_value_default4\x18\x0b \x01(\t\x12%\n\x1d\x62ounded_string_value_default5\x18\x0c \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.test_interface_files.msg.strings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STRINGS']._serialized_start=123
  _globals['_STRINGS']._serialized_end=534
# @@protoc_insertion_point(module_scope)
