# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rosbag2_interfaces/srv/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/rosbag2_interfaces/srv/snapshot.proto\x12\x31make87_messages_ros2.jazzy.rosbag2_interfaces.srv\"\x11\n\x0fSnapshotRequest\"#\n\x10SnapshotResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rosbag2_interfaces.srv.snapshot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SNAPSHOTREQUEST']._serialized_start=119
  _globals['_SNAPSHOTREQUEST']._serialized_end=136
  _globals['_SNAPSHOTRESPONSE']._serialized_start=138
  _globals['_SNAPSHOTRESPONSE']._serialized_end=173
# @@protoc_insertion_point(module_scope)
