# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_fleet_msgs/msg/delivery_alert.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import delivery_alert_action_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__fleet__msgs_dot_msg_dot_delivery__alert__action__pb2
from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import delivery_alert_category_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__fleet__msgs_dot_msg_dot_delivery__alert__category__pb2
from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import delivery_alert_tier_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__fleet__msgs_dot_msg_dot_delivery__alert__tier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/rmf_fleet_msgs/msg/delivery_alert.proto\x12-make87_messages_ros2.jazzy.rmf_fleet_msgs.msg\x1aImake87_messages_ros2/jazzy/rmf_fleet_msgs/msg/delivery_alert_action.proto\x1aKmake87_messages_ros2/jazzy/rmf_fleet_msgs/msg/delivery_alert_category.proto\x1aGmake87_messages_ros2/jazzy/rmf_fleet_msgs/msg/delivery_alert_tier.proto\"\xb9\x02\n\rDeliveryAlert\x12\n\n\x02id\x18\x01 \x01(\t\x12V\n\x08\x63\x61tegory\x18\x02 \x01(\x0b\x32\x44.make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.DeliveryAlertCategory\x12N\n\x04tier\x18\x03 \x01(\x0b\x32@.make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.DeliveryAlertTier\x12\x0f\n\x07task_id\x18\x04 \x01(\t\x12R\n\x06\x61\x63tion\x18\x05 \x01(\x0b\x32\x42.make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.DeliveryAlertAction\x12\x0f\n\x07message\x18\x06 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.delivery_alert_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DELIVERYALERT']._serialized_start=343
  _globals['_DELIVERYALERT']._serialized_end=656
# @@protoc_insertion_point(module_scope)
