# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/fuse_msgs/srv/set_graph.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.fuse_msgs.msg import serialized_graph_pb2 as make87__messages__ros2_dot_jazzy_dot_fuse__msgs_dot_msg_dot_serialized__graph__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/fuse_msgs/srv/set_graph.proto\x12(make87_messages_ros2.jazzy.fuse_msgs.srv\x1a?make87_messages_ros2/jazzy/fuse_msgs/msg/serialized_graph.proto\"[\n\x0fSetGraphRequest\x12H\n\x05graph\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.fuse_msgs.msg.SerializedGraph\"4\n\x10SetGraphResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.fuse_msgs.srv.set_graph_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETGRAPHREQUEST']._serialized_start=167
  _globals['_SETGRAPHREQUEST']._serialized_end=258
  _globals['_SETGRAPHRESPONSE']._serialized_start=260
  _globals['_SETGRAPHRESPONSE']._serialized_end=312
# @@protoc_insertion_point(module_scope)
