# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/visualization_msgs/msg/interactive_marker_control.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import quaternion_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_quaternion__pb2
from make87_messages_ros2.rolling.visualization_msgs.msg import marker_pb2 as make87__messages__ros2_dot_rolling_dot_visualization__msgs_dot_msg_dot_marker__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/rolling/visualization_msgs/msg/interactive_marker_control.proto\x12\x33make87_messages_ros2.rolling.visualization_msgs.msg\x1a?make87_messages_ros2/rolling/geometry_msgs/msg/quaternion.proto\x1a@make87_messages_ros2/rolling/visualization_msgs/msg/marker.proto\"\xd0\x02\n\x18InteractiveMarkerControl\x12\x0c\n\x04name\x18\x01 \x01(\t\x12O\n\x0borientation\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.geometry_msgs.msg.Quaternion\x12\x18\n\x10orientation_mode\x18\x03 \x01(\r\x12\x18\n\x10interaction_mode\x18\x04 \x01(\r\x12\x16\n\x0e\x61lways_visible\x18\x05 \x01(\x08\x12L\n\x07markers\x18\x06 \x03(\x0b\x32;.make87_messages_ros2.rolling.visualization_msgs.msg.Marker\x12&\n\x1eindependent_marker_orientation\x18\x07 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.visualization_msgs.msg.interactive_marker_control_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INTERACTIVEMARKERCONTROL']._serialized_start=273
  _globals['_INTERACTIVEMARKERCONTROL']._serialized_end=609
# @@protoc_insertion_point(module_scope)
