# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ibeo_msgs/msg/object2270.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ibeo_msgs.msg import point2_di_pb2 as make87__messages__ros2_dot_jazzy_dot_ibeo__msgs_dot_msg_dot_point2__di__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/ibeo_msgs/msg/object2270.proto\x12(make87_messages_ros2.jazzy.ibeo_msgs.msg\x1a\x38make87_messages_ros2/jazzy/ibeo_msgs/msg/point2_di.proto\"\xf5\x07\n\nObject2270\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0b\n\x03\x61ge\x18\x02 \x01(\r\x12\x16\n\x0eprediction_age\x18\x03 \x01(\r\x12&\n\x1erelative_moment_of_measurement\x18\x04 \x01(\r\x12 \n\x18reference_point_location\x18\x05 \x01(\r\x12\"\n\x1areference_point_position_x\x18\x06 \x01(\x05\x12\"\n\x1areference_point_position_y\x18\x07 \x01(\x05\x12(\n reference_point_position_sigma_x\x18\x08 \x01(\r\x12(\n reference_point_position_sigma_y\x18\t \x01(\r\x12\x1c\n\x14\x63ontour_points_cog_x\x18\n \x01(\x05\x12\x1c\n\x14\x63ontour_points_cog_y\x18\x0b \x01(\x05\x12\x19\n\x11object_box_length\x18\x0c \x01(\r\x12\x18\n\x10object_box_width\x18\r \x01(\r\x12$\n\x1cobject_box_orientation_angle\x18\x0e \x01(\x05\x12*\n\"object_box_orientation_angle_sigma\x18\x0f \x01(\x05\x12\x1b\n\x13\x61\x62solute_velocity_x\x18\x10 \x01(\x05\x12\x1b\n\x13\x61\x62solute_velocity_y\x18\x11 \x01(\x05\x12!\n\x19\x61\x62solute_velocity_sigma_x\x18\x12 \x01(\r\x12!\n\x19\x61\x62solute_velocity_sigma_y\x18\x13 \x01(\r\x12\x1b\n\x13relative_velocity_x\x18\x14 \x01(\x05\x12\x1b\n\x13relative_velocity_y\x18\x15 \x01(\x05\x12!\n\x19relative_velocity_sigma_x\x18\x16 \x01(\r\x12!\n\x19relative_velocity_sigma_y\x18\x17 \x01(\r\x12\x16\n\x0e\x63lassification\x18\x18 \x01(\r\x12\x16\n\x0etracking_model\x18\x19 \x01(\r\x12\x17\n\x0fmobile_detected\x18\x1a \x01(\x08\x12\x13\n\x0btrack_valid\x18\x1b \x01(\x08\x12\x1a\n\x12\x63lassification_age\x18\x1c \x01(\r\x12!\n\x19\x63lassification_confidence\x18\x1d \x01(\r\x12 \n\x18number_of_contour_points\x18\x1e \x01(\r\x12N\n\x12\x63ontour_point_list\x18\x1f \x03(\x0b\x32\x32.make87_messages_ros2.jazzy.ibeo_msgs.msg.Point2Dib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ibeo_msgs.msg.object2270_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECT2270']._serialized_start=162
  _globals['_OBJECT2270']._serialized_end=1175
# @@protoc_insertion_point(module_scope)
