# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/delphi_srr_msgs/msg/srr_status5.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/delphi_srr_msgs/msg/srr_status5.proto\x12/make87_messages_ros2.humble.delphi_srr_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xfc\x07\n\nSrrStatus5\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x1a\n\x12\x64isable_auto_align\x18\x03 \x01(\x08\x12\x1e\n\x16\x63\x61n_tx_yaw_rate_ref_qf\x18\x04 \x01(\r\x12\x1e\n\x16\x63\x61n_tx_yaw_rate_raw_qf\x18\x05 \x01(\r\x12!\n\x19\x63\x61n_tx_yaw_rate_reference\x18\x06 \x01(\x02\x12\x1b\n\x13\x63\x61n_tx_yaw_rate_raw\x18\x07 \x01(\x02\x12\x1c\n\x14\x63\x61n_tx_system_status\x18\x08 \x01(\r\x12\"\n\x1a\x63\x61n_tx_outside_temperature\x18\t \x01(\x05\x12 \n\x18\x63\x61n_blockage_mnr_blocked\x18\n \x01(\x08\x12\x1f\n\x17\x63\x61n_blockage_bb_blocked\x18\x0b \x01(\x08\x12\"\n\x1a\x63\x61n_blockage_radar_blocked\x18\x0c \x01(\x08\x12\x16\n\x0e\x63\x61n_td_blocked\x18\r \x01(\x08\x12\x1c\n\x14radar_tx_power_error\x18\x0e \x01(\x08\x12\x1c\n\x14radar_lo_power_error\x18\x0f \x01(\x08\x12\x1d\n\x15radar_data_sync_error\x18\x10 \x01(\x08\x12%\n\x1dlinearizer_spi_transfer_error\x18\x11 \x01(\x08\x12#\n\x1bsaturated_tuning_freq_error\x18\x12 \x01(\x08\x12\x1e\n\x16rtn_spi_transfer_error\x18\x13 \x01(\x08\x12\x1e\n\x16rrn_spi_transfer_error\x18\x14 \x01(\x08\x12 \n\x18video_port_capture_error\x18\x15 \x01(\x08\x12#\n\x1bvertical_misalignment_error\x18\x16 \x01(\x08\x12\x1c\n\x14tx_temperature_fault\x18\x17 \x01(\x08\x12\x1c\n\x14transmitter_id_error\x18\x18 \x01(\x08\x12#\n\x1b\x64sp_unit_cal_checksum_error\x18\x19 \x01(\x08\x12\'\n\x1f\x64sp_unit_cal_block_chcksm_error\x18\x1a \x01(\x08\x12$\n\x1c\x64sp_tuning_sensitivity_error\x18\x1b \x01(\x08\x12\x1e\n\x16\x64sp_loop_overrun_error\x18\x1c \x01(\x08\x12\x1e\n\x16\x61\x64\x63_spi_transfer_error\x18\x1d \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.delphi_srr_msgs.msg.srr_status5_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SRRSTATUS5']._serialized_start=209
  _globals['_SRRSTATUS5']._serialized_end=1229
# @@protoc_insertion_point(module_scope)
