from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WeightedPoseWithCovariance(_message.Message):
    __slots__ = ["pose", "covariance", "weight"]
    POSE_FIELD_NUMBER: _ClassVar[int]
    COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    pose: _pose_pb2.Pose
    covariance: _containers.RepeatedScalarFieldContainer[float]
    weight: float
    def __init__(self, pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., covariance: _Optional[_Iterable[float]] = ..., weight: _Optional[float] = ...) -> None: ...
