# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/cartographer_ros_msgs/msg/bagfile_progress.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/rolling/cartographer_ros_msgs/msg/bagfile_progress.proto\x12\x36make87_messages_ros2.rolling.cartographer_ros_msgs.msg\"\xc9\x01\n\x0f\x42\x61gfileProgress\x12\x1c\n\x14\x63urrent_bagfile_name\x18\x01 \x01(\t\x12\x1a\n\x12\x63urrent_bagfile_id\x18\x02 \x01(\r\x12\x16\n\x0etotal_bagfiles\x18\x03 \x01(\r\x12\x16\n\x0etotal_messages\x18\x04 \x01(\r\x12\x1a\n\x12processed_messages\x18\x05 \x01(\r\x12\x15\n\rtotal_seconds\x18\x06 \x01(\x02\x12\x19\n\x11processed_seconds\x18\x07 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.cartographer_ros_msgs.msg.bagfile_progress_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BAGFILEPROGRESS']._serialized_start=138
  _globals['_BAGFILEPROGRESS']._serialized_end=339
# @@protoc_insertion_point(module_scope)
