# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/qb_device_msgs/msg/state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.qb_device_msgs.msg import resource_data_pb2 as make87__messages__ros2_dot_humble_dot_qb__device__msgs_dot_msg_dot_resource__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/humble/qb_device_msgs/msg/state.proto\x12.make87_messages_ros2.humble.qb_device_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x42make87_messages_ros2/humble/qb_device_msgs/msg/resource_data.proto\"\x87\x02\n\x05State\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12O\n\tactuators\x18\x02 \x03(\x0b\x32<.make87_messages_ros2.humble.qb_device_msgs.msg.ResourceData\x12L\n\x06joints\x18\x03 \x03(\x0b\x32<.make87_messages_ros2.humble.qb_device_msgs.msg.ResourceData\x12\x13\n\x0bis_reliable\x18\x04 \x01(\x08\x12\x1c\n\x14\x63onsecutive_failures\x18\x05 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.qb_device_msgs.msg.state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STATE']._serialized_start=214
  _globals['_STATE']._serialized_end=477
# @@protoc_insertion_point(module_scope)
