# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/aid_hui.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/jazzy/ublox_msgs/msg/aid_hui.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\"\xc6\x02\n\x06\x41idHUI\x12\x0e\n\x06health\x18\x01 \x01(\r\x12\x0e\n\x06utc_a0\x18\x02 \x01(\x01\x12\x0e\n\x06utc_a1\x18\x03 \x01(\x01\x12\x0f\n\x07utc_tow\x18\x04 \x01(\x05\x12\x0f\n\x07utc_wnt\x18\x05 \x01(\x05\x12\x0e\n\x06utc_ls\x18\x06 \x01(\x05\x12\x0f\n\x07utc_wnf\x18\x07 \x01(\x05\x12\x0e\n\x06utc_dn\x18\x08 \x01(\x05\x12\x0f\n\x07utc_lsf\x18\t \x01(\x05\x12\x11\n\tutc_spare\x18\n \x01(\x05\x12\x0f\n\x07klob_a0\x18\x0b \x01(\x02\x12\x0f\n\x07klob_a1\x18\x0c \x01(\x02\x12\x0f\n\x07klob_a2\x18\r \x01(\x02\x12\x0f\n\x07klob_a3\x18\x0e \x01(\x02\x12\x0f\n\x07klob_b0\x18\x0f \x01(\x02\x12\x0f\n\x07klob_b1\x18\x10 \x01(\x02\x12\x0f\n\x07klob_b2\x18\x11 \x01(\x02\x12\x0f\n\x07klob_b3\x18\x12 \x01(\x02\x12\r\n\x05\x66lags\x18\x13 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.aid_hui_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AIDHUI']._serialized_start=103
  _globals['_AIDHUI']._serialized_end=429
# @@protoc_insertion_point(module_scope)
