# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/polygon_msgs/msg/complex_polygon2_d_collection.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.polygon_msgs.msg import complex_polygon2_d_pb2 as make87__messages__ros2_dot_humble_dot_polygon__msgs_dot_msg_dot_complex__polygon2__d__pb2
from make87_messages_ros2.humble.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_color__rgba__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/polygon_msgs/msg/complex_polygon2_d_collection.proto\x12,make87_messages_ros2.humble.polygon_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x45make87_messages_ros2/humble/polygon_msgs/msg/complex_polygon2_d.proto\x1a\x39make87_messages_ros2/humble/std_msgs/msg/color_rgba.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xa8\x02\n\x1a\x43omplexPolygon2DCollection\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12P\n\x08polygons\x18\x03 \x03(\x0b\x32>.make87_messages_ros2.humble.polygon_msgs.msg.ComplexPolygon2D\x12\x43\n\x06\x63olors\x18\x04 \x03(\x0b\x32\x33.make87_messages_ros2.humble.std_msgs.msg.ColorRGBAb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.polygon_msgs.msg.complex_polygon2_d_collection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMPLEXPOLYGON2DCOLLECTION']._serialized_start=351
  _globals['_COMPLEXPOLYGON2DCOLLECTION']._serialized_end=647
# @@protoc_insertion_point(module_scope)
