# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/srv/publish_map.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/rtabmap_msgs/srv/publish_map.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.srv\"N\n\x11PublishMapRequest\x12\x12\n\nglobal_map\x18\x01 \x01(\x08\x12\x11\n\toptimized\x18\x02 \x01(\x08\x12\x12\n\ngraph_only\x18\x03 \x01(\x08\"\x14\n\x12PublishMapResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.srv.publish_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PUBLISHMAPREQUEST']._serialized_start=110
  _globals['_PUBLISHMAPREQUEST']._serialized_end=188
  _globals['_PUBLISHMAPRESPONSE']._serialized_start=190
  _globals['_PUBLISHMAPRESPONSE']._serialized_end=210
# @@protoc_insertion_point(module_scope)
