# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/pendulum_msgs/msg/rttest_results.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.pendulum_msgs.msg import joint_command_pb2 as make87__messages__ros2_dot_jazzy_dot_pendulum__msgs_dot_msg_dot_joint__command__pb2
from make87_messages_ros2.jazzy.pendulum_msgs.msg import joint_state_pb2 as make87__messages__ros2_dot_jazzy_dot_pendulum__msgs_dot_msg_dot_joint__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/pendulum_msgs/msg/rttest_results.proto\x12,make87_messages_ros2.jazzy.pendulum_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a@make87_messages_ros2/jazzy/pendulum_msgs/msg/joint_command.proto\x1a>make87_messages_ros2/jazzy/pendulum_msgs/msg/joint_state.proto\"\xf6\x02\n\rRttestResults\x12\x46\n\x05stamp\x18\x01 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12K\n\x07\x63ommand\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.jazzy.pendulum_msgs.msg.JointCommand\x12G\n\x05state\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.pendulum_msgs.msg.JointState\x12\x13\n\x0b\x63ur_latency\x18\x04 \x01(\x04\x12\x14\n\x0cmean_latency\x18\x05 \x01(\x01\x12\x13\n\x0bmin_latency\x18\x06 \x01(\x04\x12\x13\n\x0bmax_latency\x18\x07 \x01(\x04\x12\x18\n\x10minor_pagefaults\x18\x08 \x01(\x04\x12\x18\n\x10major_pagefaults\x18\t \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.pendulum_msgs.msg.rttest_results_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RTTESTRESULTS']._serialized_start=308
  _globals['_RTTESTRESULTS']._serialized_end=682
# @@protoc_insertion_point(module_scope)
