# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sbg_driver/msg/sbg_ship_motion_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/sbg_driver/msg/sbg_ship_motion_status.proto\x12)make87_messages_ros2.jazzy.sbg_driver.msg\"\xa4\x01\n\x13SbgShipMotionStatus\x12\x13\n\x0bheave_valid\x18\x01 \x01(\x08\x12\x17\n\x0fheave_vel_aided\x18\x02 \x01(\x08\x12\x1b\n\x13surge_sway_included\x18\x03 \x01(\x08\x12\x18\n\x10period_available\x18\x04 \x01(\x08\x12\x14\n\x0cperiod_valid\x18\x05 \x01(\x08\x12\x12\n\nswell_mode\x18\x06 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sbg_driver.msg.sbg_ship_motion_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SBGSHIPMOTIONSTATUS']._serialized_start=118
  _globals['_SBGSHIPMOTIONSTATUS']._serialized_end=282
# @@protoc_insertion_point(module_scope)
