# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_dispenser_msgs/msg/dispenser_request_item.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/rolling/rmf_dispenser_msgs/msg/dispenser_request_item.proto\x12\x33make87_messages_ros2.rolling.rmf_dispenser_msgs.msg\"U\n\x14\x44ispenserRequestItem\x12\x11\n\ttype_guid\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\x05\x12\x18\n\x10\x63ompartment_name\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_dispenser_msgs.msg.dispenser_request_item_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DISPENSERREQUESTITEM']._serialized_start=137
  _globals['_DISPENSERREQUESTITEM']._serialized_end=222
# @@protoc_insertion_point(module_scope)
