# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/hil_gps.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geographic_msgs.msg import geo_point_pb2 as make87__messages__ros2_dot_jazzy_dot_geographic__msgs_dot_msg_dot_geo__point__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/mavros_msgs/msg/hil_gps.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\x1a>make87_messages_ros2/jazzy/geographic_msgs/msg/geo_point.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x96\x02\n\x06HilGPS\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x10\n\x08\x66ix_type\x18\x02 \x01(\r\x12\x45\n\x03geo\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.geographic_msgs.msg.GeoPoint\x12\x0b\n\x03\x65ph\x18\x04 \x01(\r\x12\x0b\n\x03\x65pv\x18\x05 \x01(\r\x12\x0b\n\x03vel\x18\x06 \x01(\r\x12\n\n\x02vn\x18\x07 \x01(\x05\x12\n\n\x02ve\x18\x08 \x01(\x05\x12\n\n\x02vd\x18\t \x01(\x05\x12\x0b\n\x03\x63og\x18\n \x01(\r\x12\x1a\n\x12satellites_visible\x18\x0b \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.hil_gps_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_HILGPS']._serialized_start=223
  _globals['_HILGPS']._serialized_end=501
# @@protoc_insertion_point(module_scope)
