# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/delphi_mrr_msgs/msg/mrr_control_msg_nr.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/delphi_mrr_msgs/msg/mrr_control_msg_nr.proto\x12.make87_messages_ros2.jazzy.delphi_mrr_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xb0\x02\n\x0fMrrControlMsgNR\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x1f\n\x17\x63\x61n_stop_frequency_nrml\x18\x02 \x01(\r\x12\x1b\n\x13\x63\x61n_prp_factor_nrml\x18\x03 \x01(\r\x12!\n\x19\x63\x61n_desired_sweep_bw_nrml\x18\x04 \x01(\r\x12\x1a\n\x12\x63\x61n_radiation_ctrl\x18\x05 \x01(\x08\x12\x1f\n\x17\x63\x61n_stop_frequency_nrll\x18\x06 \x01(\r\x12\x1b\n\x13\x63\x61n_prp_factor_nrll\x18\x07 \x01(\r\x12!\n\x19\x63\x61n_desired_sweep_bw_nrll\x18\x08 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.delphi_mrr_msgs.msg.mrr_control_msg_nr_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MRRCONTROLMSGNR']._serialized_start=178
  _globals['_MRRCONTROLMSGNR']._serialized_end=482
# @@protoc_insertion_point(module_scope)
