# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rmf_scheduler_msgs/msg/schedule.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rmf_scheduler_msgs.msg import payload_pb2 as make87__messages__ros2_dot_humble_dot_rmf__scheduler__msgs_dot_msg_dot_payload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/rmf_scheduler_msgs/msg/schedule.proto\x12\x32make87_messages_ros2.humble.rmf_scheduler_msgs.msg\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/rmf_scheduler_msgs/msg/payload.proto\"\xee\x01\n\x08Schedule\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\x12\x10\n\x08schedule\x18\x04 \x01(\t\x12\x10\n\x08start_at\x18\x05 \x01(\x03\x12\x11\n\tfinish_at\x18\x06 \x01(\x03\x12\r\n\x05group\x18\x07 \x01(\t\x12L\n\x07payload\x18\x08 \x01(\x0b\x32;.make87_messages_ros2.humble.rmf_scheduler_msgs.msg.Payloadb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rmf_scheduler_msgs.msg.schedule_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCHEDULE']._serialized_start=223
  _globals['_SCHEDULE']._serialized_end=461
# @@protoc_insertion_point(module_scope)
