# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/object_recognition_msgs/msg/object_information.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.humble.shape_msgs.msg import mesh_pb2 as make87__messages__ros2_dot_humble_dot_shape__msgs_dot_msg_dot_mesh__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/object_recognition_msgs/msg/object_information.proto\x12\x37make87_messages_ros2.humble.object_recognition_msgs.msg\x1a!make87_messages/core/header.proto\x1a>make87_messages_ros2/humble/sensor_msgs/msg/point_cloud2.proto\x1a\x35make87_messages_ros2/humble/shape_msgs/msg/mesh.proto\"\xf8\x01\n\x11ObjectInformation\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\x12K\n\x11ground_truth_mesh\x18\x03 \x01(\x0b\x32\x30.make87_messages_ros2.humble.shape_msgs.msg.Mesh\x12Z\n\x18ground_truth_point_cloud\x18\x04 \x01(\x0b\x32\x38.make87_messages_ros2.humble.sensor_msgs.msg.PointCloud2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.object_recognition_msgs.msg.object_information_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECTINFORMATION']._serialized_start=296
  _globals['_OBJECTINFORMATION']._serialized_end=544
# @@protoc_insertion_point(module_scope)
