# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/novatel_gps_msgs/msg/range_information.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/novatel_gps_msgs/msg/range_information.proto\x12/make87_messages_ros2.jazzy.novatel_gps_msgs.msg\"\xc9\x01\n\x10RangeInformation\x12\x12\n\nprn_number\x18\x01 \x01(\r\x12\x0f\n\x07glofreq\x18\x02 \x01(\r\x12\x0b\n\x03psr\x18\x03 \x01(\x01\x12\x0f\n\x07psr_std\x18\x04 \x01(\x02\x12\x0b\n\x03\x61\x64r\x18\x05 \x01(\x01\x12\x0f\n\x07\x61\x64r_std\x18\x06 \x01(\x02\x12\x0c\n\x04\x64opp\x18\x07 \x01(\x02\x12\x1b\n\x13noise_density_ratio\x18\x08 \x01(\x02\x12\x10\n\x08locktime\x18\t \x01(\x02\x12\x17\n\x0ftracking_status\x18\n \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.novatel_gps_msgs.msg.range_information_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RANGEINFORMATION']._serialized_start=125
  _globals['_RANGEINFORMATION']._serialized_end=326
# @@protoc_insertion_point(module_scope)
