# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mrpt_nav_interfaces/srv/get_layers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/mrpt_nav_interfaces/srv/get_layers.proto\x12\x32make87_messages_ros2.jazzy.mrpt_nav_interfaces.srv\"\x12\n\x10GetLayersRequest\"#\n\x11GetLayersResponse\x12\x0e\n\x06layers\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mrpt_nav_interfaces.srv.get_layers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETLAYERSREQUEST']._serialized_start=123
  _globals['_GETLAYERSREQUEST']._serialized_end=141
  _globals['_GETLAYERSRESPONSE']._serialized_start=143
  _globals['_GETLAYERSRESPONSE']._serialized_end=178
# @@protoc_insertion_point(module_scope)
