# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_traffic_msgs/srv/register_participant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import participant_description_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__traffic__msgs_dot_msg_dot_participant__description__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/rmf_traffic_msgs/srv/register_participant.proto\x12/make87_messages_ros2.jazzy.rmf_traffic_msgs.srv\x1aMmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/participant_description.proto\"z\n\x1aRegisterParticipantRequest\x12\\\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32G.make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.ParticipantDescription\"\x95\x01\n\x1bRegisterParticipantResponse\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\x04\x12\x1e\n\x16last_itinerary_version\x18\x02 \x01(\x04\x12\x14\n\x0clast_plan_id\x18\x03 \x01(\x04\x12\x19\n\x11next_storage_base\x18\x04 \x01(\x04\x12\r\n\x05\x65rror\x18\x05 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_traffic_msgs.srv.register_participant_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_REGISTERPARTICIPANTREQUEST']._serialized_start=206
  _globals['_REGISTERPARTICIPANTREQUEST']._serialized_end=328
  _globals['_REGISTERPARTICIPANTRESPONSE']._serialized_start=331
  _globals['_REGISTERPARTICIPANTRESPONSE']._serialized_end=480
# @@protoc_insertion_point(module_scope)
