# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/marti_nav_msgs/msg/tracked_object.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_twist__with__covariance__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/humble/marti_nav_msgs/msg/tracked_object.proto\x12.make87_messages_ros2.humble.marti_nav_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x41make87_messages_ros2/humble/builtin_interfaces/msg/duration.proto\x1a\x39make87_messages_ros2/humble/geometry_msgs/msg/point.proto\x1aHmake87_messages_ros2/humble/geometry_msgs/msg/pose_with_covariance.proto\x1aImake87_messages_ros2/humble/geometry_msgs/msg/twist_with_covariance.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/vector3.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xdf\x06\n\rTrackedObject\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\n\n\x02id\x18\x03 \x01(\r\x12O\n\x04pose\x18\x04 \x01(\x0b\x32\x41.make87_messages_ros2.humble.geometry_msgs.msg.PoseWithCovariance\x12T\n\x08velocity\x18\x05 \x01(\x0b\x32\x42.make87_messages_ros2.humble.geometry_msgs.msg.TwistWithCovariance\x12S\n\x13linear_acceleration\x18\x06 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12&\n\x1elinear_acceleration_covariance\x18\x07 \x03(\x01\x12\x45\n\x07polygon\x18\x08 \x03(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Point\x12\x0e\n\x06length\x18\t \x01(\x02\x12\x16\n\x0elength_quality\x18\n \x01(\x02\x12\r\n\x05width\x18\x0b \x01(\x02\x12\x15\n\rwidth_quality\x18\x0c \x01(\x02\x12\x16\n\x0e\x63lassification\x18\r \x01(\r\x12\x1e\n\x16\x63lassification_quality\x18\x0e \x01(\x02\x12\x1d\n\x15\x65xistence_probability\x18\x0f \x01(\x02\x12R\n\x0c\x61ge_duration\x18\x10 \x01(\x0b\x32<.make87_messages_ros2.humble.builtin_interfaces.msg.Duration\x12Y\n\x13prediction_duration\x18\x11 \x01(\x0b\x32<.make87_messages_ros2.humble.builtin_interfaces.msg.Duration\x12\x0e\n\x06\x61\x63tive\x18\x12 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.marti_nav_msgs.msg.tracked_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TRACKEDOBJECT']._serialized_start=546
  _globals['_TRACKEDOBJECT']._serialized_end=1409
# @@protoc_insertion_point(module_scope)
