# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/object_recognition_msgs/msg/recognized_object.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_with_covariance_stamped_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__stamped__pb2
from make87_messages_ros2.jazzy.object_recognition_msgs.msg import object_type_pb2 as make87__messages__ros2_dot_jazzy_dot_object__recognition__msgs_dot_msg_dot_object__type__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.jazzy.shape_msgs.msg import mesh_pb2 as make87__messages__ros2_dot_jazzy_dot_shape__msgs_dot_msg_dot_mesh__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/jazzy/object_recognition_msgs/msg/recognized_object.proto\x12\x36make87_messages_ros2.jazzy.object_recognition_msgs.msg\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1aOmake87_messages_ros2/jazzy/geometry_msgs/msg/pose_with_covariance_stamped.proto\x1aHmake87_messages_ros2/jazzy/object_recognition_msgs/msg/object_type.proto\x1a=make87_messages_ros2/jazzy/sensor_msgs/msg/point_cloud2.proto\x1a\x34make87_messages_ros2/jazzy/shape_msgs/msg/mesh.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xf7\x03\n\x10RecognizedObject\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12P\n\x04type\x18\x02 \x01(\x0b\x32\x42.make87_messages_ros2.jazzy.object_recognition_msgs.msg.ObjectType\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12M\n\x0cpoint_clouds\x18\x04 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.sensor_msgs.msg.PointCloud2\x12\x46\n\rbounding_mesh\x18\x05 \x01(\x0b\x32/.make87_messages_ros2.jazzy.shape_msgs.msg.Mesh\x12N\n\x11\x62ounding_contours\x18\x06 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12U\n\x04pose\x18\x07 \x01(\x0b\x32G.make87_messages_ros2.jazzy.geometry_msgs.msg.PoseWithCovarianceStampedb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.object_recognition_msgs.msg.recognized_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RECOGNIZEDOBJECT']._serialized_start=523
  _globals['_RECOGNIZEDOBJECT']._serialized_end=1026
# @@protoc_insertion_point(module_scope)
