# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_node_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rtabmap_msgs.msg import node_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_node__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_node_data.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.srv\x1a\x36make87_messages_ros2/jazzy/rtabmap_msgs/msg/node.proto\"`\n\x12GetNodeDataRequest\x12\x0b\n\x03ids\x18\x01 \x03(\x05\x12\x0e\n\x06images\x18\x02 \x01(\x08\x12\x0c\n\x04scan\x18\x03 \x01(\x08\x12\x0c\n\x04grid\x18\x04 \x01(\x08\x12\x11\n\tuser_data\x18\x05 \x01(\x08\"V\n\x13GetNodeDataResponse\x12?\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x31.make87_messages_ros2.jazzy.rtabmap_msgs.msg.Nodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.srv.get_node_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETNODEDATAREQUEST']._serialized_start=168
  _globals['_GETNODEDATAREQUEST']._serialized_end=264
  _globals['_GETNODEDATARESPONSE']._serialized_start=266
  _globals['_GETNODEDATARESPONSE']._serialized_end=352
# @@protoc_insertion_point(module_scope)
