# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosapi_msgs/srv/topics_and_raw_types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/rosapi_msgs/srv/topics_and_raw_types.proto\x12,make87_messages_ros2.rolling.rosapi_msgs.srv\"\x1a\n\x18TopicsAndRawTypesRequest\"V\n\x19TopicsAndRawTypesResponse\x12\x0e\n\x06topics\x18\x01 \x03(\t\x12\r\n\x05types\x18\x02 \x03(\t\x12\x1a\n\x12typedefs_full_text\x18\x03 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosapi_msgs.srv.topics_and_raw_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TOPICSANDRAWTYPESREQUEST']._serialized_start=121
  _globals['_TOPICSANDRAWTYPESREQUEST']._serialized_end=147
  _globals['_TOPICSANDRAWTYPESRESPONSE']._serialized_start=149
  _globals['_TOPICSANDRAWTYPESRESPONSE']._serialized_end=235
# @@protoc_insertion_point(module_scope)
