# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/smacc2_msgs/srv/smacc_get_transition_history.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.smacc2_msgs.msg import smacc_transition_log_entry_pb2 as make87__messages__ros2_dot_jazzy_dot_smacc2__msgs_dot_msg_dot_smacc__transition__log__entry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/jazzy/smacc2_msgs/srv/smacc_get_transition_history.proto\x12*make87_messages_ros2.jazzy.smacc2_msgs.srv\x1aKmake87_messages_ros2/jazzy/smacc2_msgs/msg/smacc_transition_log_entry.proto\"\"\n SmaccGetTransitionHistoryRequest\"y\n!SmaccGetTransitionHistoryResponse\x12T\n\x07history\x18\x01 \x03(\x0b\x32\x43.make87_messages_ros2.jazzy.smacc2_msgs.msg.SmaccTransitionLogEntryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.smacc2_msgs.srv.smacc_get_transition_history_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SMACCGETTRANSITIONHISTORYREQUEST']._serialized_start=202
  _globals['_SMACCGETTRANSITIONHISTORYREQUEST']._serialized_end=236
  _globals['_SMACCGETTRANSITIONHISTORYRESPONSE']._serialized_start=238
  _globals['_SMACCGETTRANSITIONHISTORYRESPONSE']._serialized_end=359
# @@protoc_insertion_point(module_scope)
