# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ublox_ubx_msgs/msg/esf_sensor_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/humble/ublox_ubx_msgs/msg/esf_sensor_status.proto\x12.make87_messages_ros2.humble.ublox_ubx_msgs.msg\x1a!make87_messages/core/header.proto\"\x95\x02\n\x0f\x45SFSensorStatus\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x18\n\x10sensor_data_type\x18\x02 \x01(\r\x12\x0c\n\x04used\x18\x03 \x01(\x08\x12\r\n\x05ready\x18\x04 \x01(\x08\x12\x14\n\x0c\x63\x61lib_status\x18\x05 \x01(\r\x12\x13\n\x0btime_status\x18\x06 \x01(\r\x12\x0c\n\x04\x66req\x18\x07 \x01(\r\x12\x16\n\x0e\x66\x61ult_bad_meas\x18\x08 \x01(\x08\x12\x16\n\x0e\x66\x61ult_bad_ttag\x18\t \x01(\x08\x12\x1a\n\x12\x66\x61ult_missing_meas\x18\n \x01(\x08\x12\x18\n\x10\x66\x61ult_noisy_meas\x18\x0b \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ublox_ubx_msgs.msg.esf_sensor_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ESFSENSORSTATUS']._serialized_start=158
  _globals['_ESFSENSORSTATUS']._serialized_end=435
# @@protoc_insertion_point(module_scope)
