# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/test_interface_files/srv/basic_types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/test_interface_files/srv/basic_types.proto\x12\x35make87_messages_ros2.rolling.test_interface_files.srv\"\xbd\x02\n\x11\x42\x61sicTypesRequest\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x12\x12\n\nbyte_value\x18\x02 \x01(\r\x12\x12\n\nchar_value\x18\x03 \x01(\x05\x12\x15\n\rfloat32_value\x18\x04 \x01(\x02\x12\x15\n\rfloat64_value\x18\x05 \x01(\x01\x12\x12\n\nint8_value\x18\x06 \x01(\x05\x12\x13\n\x0buint8_value\x18\x07 \x01(\r\x12\x13\n\x0bint16_value\x18\x08 \x01(\x05\x12\x14\n\x0cuint16_value\x18\t \x01(\r\x12\x13\n\x0bint32_value\x18\n \x01(\x05\x12\x14\n\x0cuint32_value\x18\x0b \x01(\r\x12\x13\n\x0bint64_value\x18\x0c \x01(\x03\x12\x14\n\x0cuint64_value\x18\r \x01(\x04\x12\x14\n\x0cstring_value\x18\x0e \x01(\t\"\xbe\x02\n\x12\x42\x61sicTypesResponse\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x12\x12\n\nbyte_value\x18\x02 \x01(\r\x12\x12\n\nchar_value\x18\x03 \x01(\x05\x12\x15\n\rfloat32_value\x18\x04 \x01(\x02\x12\x15\n\rfloat64_value\x18\x05 \x01(\x01\x12\x12\n\nint8_value\x18\x06 \x01(\x05\x12\x13\n\x0buint8_value\x18\x07 \x01(\r\x12\x13\n\x0bint16_value\x18\x08 \x01(\x05\x12\x14\n\x0cuint16_value\x18\t \x01(\r\x12\x13\n\x0bint32_value\x18\n \x01(\x05\x12\x14\n\x0cuint32_value\x18\x0b \x01(\r\x12\x13\n\x0bint64_value\x18\x0c \x01(\x03\x12\x14\n\x0cuint64_value\x18\r \x01(\x04\x12\x14\n\x0cstring_value\x18\x0e \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.test_interface_files.srv.basic_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BASICTYPESREQUEST']._serialized_start=131
  _globals['_BASICTYPESREQUEST']._serialized_end=448
  _globals['_BASICTYPESRESPONSE']._serialized_start=451
  _globals['_BASICTYPESRESPONSE']._serialized_end=769
# @@protoc_insertion_point(module_scope)
