from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Speed(_message.Message):
    __slots__ = ["header", "module_name", "speed", "acceleration_limit", "deceleration_limit"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MODULE_NAME_FIELD_NUMBER: _ClassVar[int]
    SPEED_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_LIMIT_FIELD_NUMBER: _ClassVar[int]
    DECELERATION_LIMIT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    module_name: str
    speed: float
    acceleration_limit: float
    deceleration_limit: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., module_name: _Optional[str] = ..., speed: _Optional[float] = ..., acceleration_limit: _Optional[float] = ..., deceleration_limit: _Optional[float] = ...) -> None: ...
