# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mobileye_560_660_msgs/msg/lka_lane.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/mobileye_560_660_msgs/msg/lka_lane.proto\x12\x36make87_messages_ros2.rolling.mobileye_560_660_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xe0\x02\n\x07LkaLane\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x11\n\tlane_type\x18\x02 \x01(\r\x12\x0f\n\x07quality\x18\x03 \x01(\r\x12\x14\n\x0cmodel_degree\x18\x04 \x01(\r\x12\x1d\n\x15position_parameter_c0\x18\x05 \x01(\x01\x12\x1e\n\x16\x63urvature_parameter_c2\x18\x06 \x01(\x01\x12)\n!curvature_derivative_parameter_c3\x18\x07 \x01(\x01\x12\x15\n\rmarking_width\x18\x08 \x01(\x02\x12\"\n\x1aheading_angle_parameter_c1\x18\t \x01(\x01\x12\x12\n\nview_range\x18\n \x01(\x02\x12\x1f\n\x17view_range_availability\x18\x0b \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mobileye_560_660_msgs.msg.lka_lane_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LKALANE']._serialized_start=186
  _globals['_LKALANE']._serialized_end=538
# @@protoc_insertion_point(module_scope)
