# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/delphi_srr_msgs/msg/srr_debug3.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/delphi_srr_msgs/msg/srr_debug3.proto\x12/make87_messages_ros2.humble.delphi_srr_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xfa\n\n\tSrrDebug3\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x1a\n\x12timer_create_error\x18\x03 \x01(\x08\x12\x1b\n\x13thread_create_error\x18\x04 \x01(\x08\x12\x1d\n\x15\x61rm_calibration_error\x18\x05 \x01(\x08\x12\x15\n\rspi_fee_error\x18\x06 \x01(\x08\x12\x16\n\x0espi_comm_error\x18\x07 \x01(\x08\x12\x1a\n\x12socket_write_error\x18\x08 \x01(\x08\x12!\n\x19\x64sp_cal_obsolete_62_error\x18\t \x01(\x08\x12\x19\n\x11socket_read_error\x18\n \x01(\x08\x12\x19\n\x11socket_init_error\x18\x0b \x01(\x08\x12\x19\n\x11signal_wait_error\x18\x0c \x01(\x08\x12\x19\n\x11signal_send_error\x18\r \x01(\x08\x12\x1b\n\x13signal_create_error\x18\x0e \x01(\x08\x12\x1e\n\x16shared_mem_write_error\x18\x0f \x01(\x08\x12\x1d\n\x15shared_mem_read_error\x18\x10 \x01(\x08\x12\x1f\n\x17shared_mem_config_error\x18\x11 \x01(\x08\x12\x1c\n\x14share_mem_init_error\x18\x12 \x01(\x08\x12\x16\n\x0eram_test_error\x18\x13 \x01(\x08\x12\x12\n\nnum_errors\x18\x14 \x01(\x08\x12\x19\n\x11mmap_memory_error\x18\x15 \x01(\x08\x12\x18\n\x10isr_attach_error\x18\x16 \x01(\x08\x12\x1b\n\x13ipc_drv_write_error\x18\x17 \x01(\x08\x12\x1d\n\x15ipc_drv_trigger_error\x18\x18 \x01(\x08\x12\x1a\n\x12ipc_drv_sync_error\x18\x19 \x01(\x08\x12\x1a\n\x12ipc_drv_read_error\x18\x1a \x01(\x08\x12\x1a\n\x12ipc_drv_init_error\x18\x1b \x01(\x08\x12\x1e\n\x16interrupt_enable_error\x18\x1c \x01(\x08\x12\x18\n\x10hil_format_error\x18\x1d \x01(\x08\x12\x1e\n\x16\x66lash_filesystem_error\x18\x1e \x01(\x08\x12\x12\n\nerror_none\x18\x1f \x01(\x08\x12\x1b\n\x13\x64sp_load_read_error\x18  \x01(\x08\x12\x1b\n\x13\x64sp_load_open_error\x18! \x01(\x08\x12\x1e\n\x16\x64sp_load_address_error\x18\" \x01(\x08\x12\x1b\n\x13\x64sp_isp_write_error\x18# \x01(\x08\x12\x1a\n\x12\x64sp_ipc_read_error\x18$ \x01(\x08\x12\x14\n\x0c\x64sp_ipc_init\x18% \x01(\x08\x12\x16\n\x0e\x64sp_init_error\x18& \x01(\x08\x12\x1b\n\x13\x64sp_drv_start_error\x18\' \x01(\x08\x12\x1a\n\x12\x64sp_drv_load_error\x18( \x01(\x08\x12\x1a\n\x12\x64sp_drv_init_error\x18) \x01(\x08\x12\x1b\n\x13\x64sp_drv_init2_error\x18* \x01(\x08\x12\x1b\n\x13\x64sp_drv_init1_error\x18+ \x01(\x08\x12\x1d\n\x15\x64sp_calibration_error\x18, \x01(\x08\x12\x15\n\rcan_xmt_error\x18- \x01(\x08\x12\x15\n\rcan_rcv_error\x18. \x01(\x08\x12\x1a\n\x12\x63\x61n_hardware_error\x18/ \x01(\x08\x12\x13\n\x0b\x61lways_true\x18\x30 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.delphi_srr_msgs.msg.srr_debug3_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SRRDEBUG3']._serialized_start=208
  _globals['_SRRDEBUG3']._serialized_end=1610
# @@protoc_insertion_point(module_scope)
