# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/vision_msgs/msg/bounding_box2_d.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.vision_msgs.msg import pose2_d_pb2 as make87__messages__ros2_dot_jazzy_dot_vision__msgs_dot_msg_dot_pose2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/vision_msgs/msg/bounding_box2_d.proto\x12*make87_messages_ros2.jazzy.vision_msgs.msg\x1a\x38make87_messages_ros2/jazzy/vision_msgs/msg/pose2_d.proto\"s\n\rBoundingBox2D\x12\x42\n\x06\x63\x65nter\x18\x01 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.vision_msgs.msg.Pose2D\x12\x0e\n\x06size_x\x18\x02 \x01(\x01\x12\x0e\n\x06size_y\x18\x03 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.vision_msgs.msg.bounding_box2_d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BOUNDINGBOX2D']._serialized_start=170
  _globals['_BOUNDINGBOX2D']._serialized_end=285
# @@protoc_insertion_point(module_scope)
