# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/test_interface_files/msg/w_strings.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/test_interface_files/msg/w_strings.proto\x12\x35make87_messages_ros2.rolling.test_interface_files.msg\"\xea\x01\n\x08WStrings\x12\x15\n\rwstring_value\x18\x01 \x01(\t\x12\x1e\n\x16wstring_value_default1\x18\x02 \x01(\t\x12\x1e\n\x16wstring_value_default2\x18\x03 \x01(\t\x12\x1e\n\x16wstring_value_default3\x18\x04 \x01(\t\x12\x19\n\x11\x61rray_of_wstrings\x18\x05 \x03(\t\x12$\n\x1c\x62ounded_sequence_of_wstrings\x18\x06 \x03(\t\x12&\n\x1eunbounded_sequence_of_wstrings\x18\x07 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.test_interface_files.msg.w_strings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_WSTRINGS']._serialized_start=129
  _globals['_WSTRINGS']._serialized_end=363
# @@protoc_insertion_point(module_scope)
