# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/vision_msgs/msg/object_hypothesis_with_pose.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.rolling.vision_msgs.msg import object_hypothesis_pb2 as make87__messages__ros2_dot_rolling_dot_vision__msgs_dot_msg_dot_object__hypothesis__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/vision_msgs/msg/object_hypothesis_with_pose.proto\x12,make87_messages_ros2.rolling.vision_msgs.msg\x1aImake87_messages_ros2/rolling/geometry_msgs/msg/pose_with_covariance.proto\x1a\x44make87_messages_ros2/rolling/vision_msgs/msg/object_hypothesis.proto\"\xc0\x01\n\x18ObjectHypothesisWithPose\x12R\n\nhypothesis\x18\x01 \x01(\x0b\x32>.make87_messages_ros2.rolling.vision_msgs.msg.ObjectHypothesis\x12P\n\x04pose\x18\x02 \x01(\x0b\x32\x42.make87_messages_ros2.rolling.geometry_msgs.msg.PoseWithCovarianceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.vision_msgs.msg.object_hypothesis_with_pose_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECTHYPOTHESISWITHPOSE']._serialized_start=274
  _globals['_OBJECTHYPOTHESISWITHPOSE']._serialized_end=466
# @@protoc_insertion_point(module_scope)
