# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ibeo_msgs/msg/ibeo_data_header.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/ibeo_msgs/msg/ibeo_data_header.proto\x12(make87_messages_ros2.jazzy.ibeo_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\"\xb6\x01\n\x0eIbeoDataHeader\x12\x1d\n\x15previous_message_size\x18\x01 \x01(\r\x12\x14\n\x0cmessage_size\x18\x02 \x01(\r\x12\x11\n\tdevice_id\x18\x03 \x01(\r\x12\x14\n\x0c\x64\x61ta_type_id\x18\x04 \x01(\r\x12\x46\n\x05stamp\x18\x05 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Timeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ibeo_msgs.msg.ibeo_data_header_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_IBEODATAHEADER']._serialized_start=172
  _globals['_IBEODATAHEADER']._serialized_end=354
# @@protoc_insertion_point(module_scope)
